@REM BEGIN COPYRIGHT
@REM *************************************************************************
@REM
@REM  Licensed Materials - Property of IBM
@REM  5725-C94, 5725-C95, 5725-C96
@REM  (C) Copyright IBM Corporation 2010, 2016. All Rights Reserved.
@REM  US Government Users Restricted Rights- Use, duplication or disclosure
@REM  restricted by GSA ADP Schedule Contract with IBM Corp.
@REM
@REM *************************************************************************
@REM END COPYRIGHT
@echo off
REM
REM ----------------------------------------------------------------------------------------------------------------
REM
REM
REM
REM Description:   Configure DB2 database environment during Migration
REM                This file is for use on Windows systems
REM                This batch file updates databases
REM                Run the script where it is located rather than running it from a different folder
REM Usage:
REM                dropSchema.bat <dbUserId> <dbPassword>
REM Example:1
REM                dropSchema.bat dbUserId dbPassword
REM ----------------------------------------------------------------------------------------------------------------
setlocal

SET CUR_DIR=%cd%

%~d0
cd %~p0


if  "%1" == "-h"  	goto PRINT_USAGE
if  "%1" == "-help"  	goto PRINT_USAGE

FOR /F "tokens=3" %%i IN ('REG QUERY "HKCU\Control Panel\International" /v iDate') DO SET dateFormat=%%i
FOR /F "tokens=3" %%s IN ('REG QUERY "HKCU\Control Panel\International" /v sDate') DO SET dateSeperator=%%s
FOR /F "tokens=3" %%s IN ('REG QUERY "HKCU\Control Panel\International" /v sTime') DO SET timeSeperator=%%s
FOR /F "tokens=1-3 delims=%dateSeperator%" %%A IN ("%date%") DO (
    IF "%dateFormat%"=="0" SET DAY=%%B&SET MONTH=%%A&SET YEAR=%%C
    IF "%dateFormat%"=="1" SET DAY=%%A&SET MONTH=%%B&SET YEAR=%%C
    IF "%dateFormat%"=="2" SET DAY=%%C&SET MONTH=%%B&SET YEAR=%%A
)
FOR /F "tokens=1-3 delims=%timeSeperator%" %%A IN ("%time%") DO SET HOUR=%%A&SET MINUTE=%%B&SET SECOND=%%C
if not "%YEAR%"=="%YEAR: =%" (
    FOR /F "tokens=1-2 delims= " %%A IN ("%YEAR%") DO SET YEAR=%%B
)
if not "%MONTH%"=="%MONTH: =%" (
    FOR /F "tokens=1-2 delims= " %%A IN ("%MONTH%") DO SET MONTH=%%B
)
if not "%DAY%"=="%DAY: =%" (
    FOR /F "tokens=1-2 delims= " %%A IN ("%DAY%") DO SET DAY=%%B
)
SET HOUR=%HOUR: =%
SET MINUTE=%MINUTE: =%
SET SECOND=%SECOND: =%
SET SECOND=%SECOND:.=%
SET SECOND=%SECOND:,=%
SET SECOND=%SECOND:'=%
SET PRE_LOG_FILE_NAME="result_%YEAR%%MONTH%%DAY%%HOUR%%MINUTE%%SECOND%.log"
SET LOG_FILE_NAME=result.log
if exist %LOG_FILE_NAME% ren %LOG_FILE_NAME% %PRE_LOG_FILE_NAME%


set DB_USER=%1
set DB_PASSWORD=%2
set DB_NAME=@DB_NAME@

if not "%1" == ""  (
	if not "%2" == ""  (
	 	goto INVOKE_SCRIPT
	) else (
  		goto INPUT_PASSWORD
  	)
  ) else (
	goto INPUT_USERNAME
)


:INPUT_USERNAME
if "%DB_USER%"==""  (
  set /p DB_USER="Enter DB2 user[dbUserId]:":
  goto INPUT_USERNAME
)

:INPUT_PASSWORD
if "%DB_PASSWORD%"==""  (
  set /p DB_PASSWORD="Enter DB2 password[dbPassword]:":
  goto INPUT_PASSWORD
)

:INVOKE_SCRIPT
db2cmd /w /c /i .\dropSchemaTables.bat %DB_NAME% %DB_USER% %DB_PASSWORD%

if not %ERRORLEVEL%==0 (
    goto PRINT_USAGE
) else (
    goto END
)


:PRINT_USAGE

REM Print usage messages

echo.
echo ===================================================================================================
echo "Usage: dropSchema.bat  <dbUserName> <dbPassword> "
echo
echo "Parameters:"
echo "dbUserName        -  User who can execute SQL scripts, for example, db2admin"
echo "dbPassword        -  Password for user who can execute SQL scripts, for example, db2admin. If the password"
echo "                     contains special characters, enclose the password in quotation marks."
echo
echo "Examples:"
echo "     1.dropSchema.bat -help "
echo "     2.dropSchema.bat [interactive mode] "
echo "     3.dropSchema.bat  db2admin db2admin "
echo
echo ===================================================================================================

goto END

:END
cd /d "%CUR_DIR%"
endlocal
