@REM BEGIN COPYRIGHT
@REM *************************************************************************
@REM
@REM  Licensed Materials - Property of IBM
@REM  5725-C94, 5725-C95, 5725-C96
@REM  (C) Copyright IBM Corporation 2010, 2016. All Rights Reserved.
@REM  US Government Users Restricted Rights- Use, duplication or disclosure
@REM  restricted by GSA ADP Schedule Contract with IBM Corp.
@REM
@REM *************************************************************************
@REM END COPYRIGHT

@echo off
REM
REM ----------------------------------------------------------------------------------------------------------------
REM
REM
REM The SQL Server JDBC driver only supports mixed authentication mode. Therefore,
REM when the SQL Server instance is created, the authentication must be set to
REM "SQL Server and Windows"
REM Make sure OSQL command can be invoked from command line
REM
REM Description:   Configure SQL Server Database environment during Migration
REM                This file is for use on Windows systems
REM                This batch file updates databases
REM                Run the script where it is located rather than running it from a different folder
REM Usage:
REM                upgradeSchema.bat <dbUserId> <dbPassword> <dbHostName>
REM Example:1
REM                upgradeSchema.bat dbUserId dbPassword localhost
REM ----------------------------------------------------------------------------------------------------------------
setlocal enabledelayedexpansion

SET CUR_DIR=%cd%

%~d0
cd %~p0


if  "%1" == "-h"        goto PRINT_USAGE
if  "%1" == "-help"     goto PRINT_USAGE

FOR /F "tokens=3" %%i IN ('REG QUERY "HKCU\Control Panel\International" /v iDate') DO SET dateFormat=%%i
FOR /F "tokens=3" %%s IN ('REG QUERY "HKCU\Control Panel\International" /v sDate') DO SET dateSeperator=%%s
FOR /F "tokens=3" %%s IN ('REG QUERY "HKCU\Control Panel\International" /v sTime') DO SET timeSeperator=%%s
FOR /F "tokens=1-3 delims=%dateSeperator%" %%A IN ("%date%") DO (
    IF "%dateFormat%"=="0" SET DAY=%%B&SET MONTH=%%A&SET YEAR=%%C
    IF "%dateFormat%"=="1" SET DAY=%%A&SET MONTH=%%B&SET YEAR=%%C
    IF "%dateFormat%"=="2" SET DAY=%%C&SET MONTH=%%B&SET YEAR=%%A
)
FOR /F "tokens=1-3 delims=%timeSeperator%" %%A IN ("%time%") DO SET HOUR=%%A&SET MINUTE=%%B&SET SECOND=%%C
if not "%YEAR%"=="%YEAR: =%" (
    FOR /F "tokens=1-2 delims= " %%A IN ("%YEAR%") DO SET YEAR=%%B
)
if not "%MONTH%"=="%MONTH: =%" (
    FOR /F "tokens=1-2 delims= " %%A IN ("%MONTH%") DO SET MONTH=%%B
)
if not "%DAY%"=="%DAY: =%" (
    FOR /F "tokens=1-2 delims= " %%A IN ("%DAY%") DO SET DAY=%%B
)
SET HOUR=%HOUR: =%
SET MINUTE=%MINUTE: =%
SET SECOND=%SECOND: =%
SET SECOND=%SECOND:.=%
SET SECOND=%SECOND:,=%
SET SECOND=%SECOND:'=%
SET PRE_LOG_FILE_NAME="result_%YEAR%%MONTH%%DAY%%HOUR%%MINUTE%%SECOND%.log"
SET LOG_FILE_NAME=result.log
if exist %LOG_FILE_NAME% ren %LOG_FILE_NAME% %PRE_LOG_FILE_NAME%

set DB_USER=%1
set DB_PASSWORD=%2
set DB_HOST=%3

if not "%1" == ""  (
        if not "%2" == ""  (
                if not "%3" == ""  (
                        goto INVOKE_SCRIPT
                ) else (
                        goto INPUT_HOSTNAME
                )
        ) else (
                goto INPUT_PASSWORD
        )
  ) else (
        goto INPUT_USERNAME
)


:INPUT_USERNAME
if "%DB_USER%"==""  (
  set /p DB_USER="Enter SQL Server user[dbUserId]:":
  goto INPUT_USERNAME
)

:INPUT_PASSWORD
if "%DB_PASSWORD%"==""  (
  set /p DB_PASSWORD="Enter SQL Server password[dbPassword]:":
  goto INPUT_PASSWORD
)

:INPUT_HOSTNAME
if "%DB_HOST%"==""  (
  set /p DB_HOST="Enter SQL Server host[dbHostName]:":
  goto INPUT_HOSTNAME
)

:INVOKE_SCRIPT

REM :SERVER
set SERVER_PARAM=-S %DB_HOST%
if "%SERVER%"=="" set SERVER_PARAM=

set CONNECTION_ID=-U %DB_USER% -P %DB_PASSWORD%

REM --  CONNECT TO THE EXISTING DATABSE FOR COMMONDB UPDATES

osql -e -b -d @DB_NAME@ %SERVER_PARAM% %CONNECTION_ID% -iupgradeSchema_SchemaStatus.sql -o result.log
if not %ERRORLEVEL%==0 (
    echo The upgradeSchema script has failed. Please check the log for more information.
    goto END
)


ren upgradeSchema_SchemaStatus.sql upgradeSchema_SchemaStatus.done

if exist BPM_855.log (
   del BPM_855.log
)

dir /B | findstr "upgradeSchema*.*sql" > BPM_855.log


for /F "tokens=1* delims=" %%v in ( BPM_855.log ) do (
    osql -e -b -d @DB_NAME@ %SERVER_PARAM% %CONNECTION_ID% -i%%v -o result.log
    if not !ERRORLEVEL!==0 (
        echo The upgradeSchema script has failed. Please check the log for more information.
        goto END
    )
)

ren upgradeSchema_SchemaStatus.done upgradeSchema_SchemaStatus.sql

echo The upgradeSchema script completed successfully.
goto END

:PRINT_USAGE

REM Print usage messages
echo.
echo ======================================================================
echo Usage: upgradeSchema.bat ^<dbUserId^> ^<dbPassword^> ^<dbHostName^>
echo.
echo Parameters:
echo dbUsername        -  User who can execute common scripts using dbName
echo dbPassword        -  Password for dbuser
echo dbHostName        -  Sql server HostName
echo.
echo Examples:
echo         1. upgradeSchema.bat -help
echo         2. upgradeSchema.bat [interactive mode]
echo         3. upgradeSchema.bat dbUserId dbPassword localhost
echo.
echo ===========================================================================

goto END

:END

if exist BPM_855.log (
   del BPM_855.log
)
cd /d "%CUR_DIR%"
endlocal
