<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />
	<xsl:output method="html" encoding="utf-8"
	doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />
	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>
	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Business Space Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="outerScript" />
			<xsl:call-template name="innerScript" />
		</xsl:element>
	</xsl:template>
	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="outerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="src">
				<xsl:text>../js/colorfulTable.js</xsl:text>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>
	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
				<xsl:text>text/javascript</xsl:text>
			</xsl:attribute>
			<xsl:text disable-output-escaping="yes">function showDetailInfo(id, status) {
				var displayTr = document.getElementById(id);
				var twistie = document.getElementById(id + "_link");
				if (status != "Started") {
				if (displayTr.style.display == "none") {
				displayTr.style.display = "table-row";
				twistie.src = "../css/images/section_collapse.gif";
				} else {
				displayTr.style.display = "none";
				twistie.src = "../css/images/section_expand.gif";
				}
				}
				}</xsl:text>
		</xsl:element>
	</xsl:template>
	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:BusinessSpacePreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:BusinessSpacePreValidation/ns:description" />
			</div>
			<xsl:variable name="title" select="ns:BusinessSpacePreValidation/ns:title" />
			<xsl:variable name="description" select="ns:BusinessSpacePreValidation/ns:description" />
			<table class="reportTable" summary="{$description}" id="grid1"
			role="grid" aria-label="{$title}">
				<thead>
					<tr role="row">
						<xsl:for-each select="ns:BusinessSpacePreValidation/ns:columnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" id="{$headerName}" scope="col"
							tabindex="-1" role="gridcell">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="header1"
					select="ns:BusinessSpacePreValidation/ns:columnHeader[1]/ns:headerName" />
					<xsl:variable name="header2"
					select="ns:BusinessSpacePreValidation/ns:columnHeader[2]/ns:headerName" />
					<xsl:variable name="header3"
					select="ns:BusinessSpacePreValidation/ns:columnHeader[3]/ns:headerName" />
					<xsl:for-each select="ns:BusinessSpacePreValidation/ns:resultList">
						<xsl:variable name="status" select="ns:status" />
						<tr class="colorfulTr" role="row">
							<td headers="{$header1}" tabindex="-1" role="gridcell" align="center">
								<xsl:choose>
									<xsl:when test="ns:status = 'Info'">
										<img src="../css/images/success.gif" alt="Normal" title="Normal"></img>
									</xsl:when>
									<xsl:otherwise>
										<img src="../css/images/error.gif" alt="Error" title="Error"></img>
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td headers="{$header2}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:tableName" />
								</span>
							</td>
							<td headers="{$header3}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:description" />
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:BusinessSpacePreValidation/ns:oobLoadedStatusCheck/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<img alt="Info" align="top" height="16" width="16"
				src="../css/images/warning.gif" title="Info"></img>
				<xsl:value-of select="ns:BusinessSpacePreValidation/ns:oobLoadedStatusCheck/ns:description" />
			</div>
			<table role="grid" summary="Check oobLoadedStatus.properties file" aria-label="Check oobLoadedStatus.properties file">
				<tbody>
					<tr role="row">
						<td colspan="5" tabindex="-1" role="gridcell" headers="title">
							<div>
								<div style="padding-left:3px;padding-bottom:5px;">
									<span>
										<xsl:value-of select="ns:BusinessSpacePreValidation/ns:oobLoadedStatusCheck/ns:detail1" />
									</span>
								</div>
								<div style="padding-left:3px;font-weight:bolder;color:#996600;">
									<span>importTemplates.txt=false</span>
								</div>
								<div style="padding-left:3px;font-weight:bolder;color:#996600;">
									<span>importSpaces.txt=false</span>
								</div>
								<div style="padding-left:3px;font-weight:bolder;color:#996600;">
									<span>importThemes.txt=false</span>
								</div>
								<br/>
								<div style="padding-left:3px;">
									<span>
										<xsl:value-of select="ns:BusinessSpacePreValidation/ns:oobLoadedStatusCheck/ns:detail2" />
									</span>
								</div>
							</div>
						</td>
					</tr>
				</tbody>
			</table>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>