<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Data Volume Analysis Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="innerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			function showDetailInfo(appName) {
				var displayTr = document.getElementById(appName);
				if (displayTr.style.display == "none") {
					displayTr.style.display = "table-row";
				} else {
					displayTr.style.display = "none";
				}
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:dataVolumePreValidation/ns:title" />
			</div>
			<xsl:variable name="title" select="ns:dataVolumePreValidation/ns:title" />
			<xsl:for-each select="ns:dataVolumePreValidation/ns:databaseAnalysisList">							
				<div class="description-bread-crumb">
					<xsl:value-of select="ns:description"/>
				</div>
				<xsl:variable name="description" select="ns:description" />
				<xsl:variable name="header1"
							select="ns:columnHeader[1]/ns:headerName" />
				<xsl:variable name="header2"
							select="ns:columnHeader[2]/ns:headerName" />
				<xsl:variable name="headerlength" select="count(nodes/node)"/>
				<xsl:variable name="header3"
							select="ns:columnHeader[count(ns:columnHeader)]/ns:headerName" />
					<xsl:variable name="headerList"
							select="ns:columnHeader" />
				<table class="reportTable" role="grid" summary="{$description}"
					aria-label="{$title}">
					<thead>
						<tr role="row">
							<xsl:for-each select="ns:columnHeader">
								<xsl:variable name="headerName" select="ns:headerName" />
								<th class="column-head-name" id="{$headerName}" scope="col"
									tabindex="-1" role="gridcell">
									<xsl:value-of select="ns:headerName" />
								</th>
							</xsl:for-each>
						</tr>
					</thead>
					<tbody>
						<xsl:for-each select="ns:resultList">
							<xsl:sort select="ns:tableName" />
							<tr role="row">
								<td headers="{$header1}" tabindex="-1" role="gridcell" align="center">
									<xsl:choose>
										<xsl:when test="ns:markFlag = '2'">
											<img src="../css/images/warning.gif" title="warning" alt="warning" />
										</xsl:when>
										<xsl:otherwise>
											<img src="../css/images/success.gif" title="success" alt="success" />
										</xsl:otherwise>
									</xsl:choose>
								</td>
								<td headers="{$header2}" tabindex="-1" role="gridcell">
									<span>
										<xsl:value-of select="ns:tableName" />
									</span>
								</td>
								<xsl:for-each select="ns:columnValue">
									<xsl:variable name="headern"
										select="$headerList[position()+2]/ns:headerName" />	
									<td headers="{headern}" tabindex="-1" role="gridcell">
										<span>
											<xsl:value-of select="ns:colValue" />
										</span>
									</td>
								</xsl:for-each>
								<td headers="{$header3}" tabindex="-1" role="gridcell">
									<span>
										<xsl:value-of select="ns:description" />
									</span>
								</td>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
			</xsl:for-each>
			<div class="validation-error">
				<span>
					<xsl:value-of select="ns:dataVolumePreValidation/ns:validationResult/@summary"/>
				</span>
			</div>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>