<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>DB2 Configuration Analysis Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="innerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			function showDetailInfo(appName) {
				var displayTr = document.getElementById(appName);
				if (displayTr.style.display == "none") {
					displayTr.style.display = "table-row";
				} else {
					displayTr.style.display = "none";
				}
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:db2ConfigPreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:db2ConfigPreValidation/ns:description" />
			</div>
			<xsl:variable name="title" select="ns:db2ConfigPreValidation/ns:title" />
			<xsl:variable name="description"
				select="ns:db2ConfigPreValidation/ns:description" />
			<table class="reportTable" role="grid" summary="{$description}"
				aria-label="{$title}">
				<thead>
					<tr role="row">
						<xsl:for-each select="ns:db2ConfigPreValidation/ns:columnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" id="{$headerName}" scope="col"
								tabindex="-1" role="gridcell">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="header1"
						select="ns:db2ConfigPreValidation/ns:columnHeader[1]/ns:headerName" />
					<xsl:variable name="header2"
						select="ns:db2ConfigPreValidation/ns:columnHeader[2]/ns:headerName" />
					<xsl:variable name="header3"
						select="ns:db2ConfigPreValidation/ns:columnHeader[3]/ns:headerName" />
					<xsl:for-each select="ns:db2ConfigPreValidation/ns:resultList">
						<xsl:sort select="ns:tableName" />
						<tr role="row">
							<td headers="{$header1}" tabindex="-1" role="gridcell" rowspan="3" align="center">
								<xsl:choose>
									<xsl:when test="ns:status = '2'">
										<img src="../css/images/warning.gif" title="warning" alt="warning" />
									</xsl:when>
									<xsl:otherwise>
										<img src="../css/images/success.gif" title="success" alt="success" />
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td headers="{$header2}" tabindex="-1" role="gridcell" rowspan="3">
								<span>
									<xsl:value-of select="ns:category" />
								</span>
							</td>
						</tr>
						<xsl:for-each select="ns:recordDetails">
						<tr>
							<td tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:databaseName" />
								</span>
							</td>
							<td tabindex="-1" role="gridcell">
								<span>
									<xsl:copy-of select="ns:details" disable-output-escaping="yes" />
								</span>
							</td>
						</tr>
						</xsl:for-each>
					</xsl:for-each>
				</tbody>
			</table>
			<xsl:value-of select="ns:db2ConfigPreValidation/ns:validationResult/@summary" />
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>