<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>SIBus destination Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="innerScript" />
			<xsl:call-template name="outerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="outerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="src">
				<xsl:text>../js/colorfulTable.js</xsl:text>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>
	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			function showDetailInfo(id) {
				var displayTr = document.getElementById(id);
				var twistie = document.getElementById(id + "_link");
				
				if (displayTr.style.display == "none") {
					displayTr.style.display = "table-row";
					twistie.src = "../css/images/section_collapse.gif";
				} else {
					displayTr.style.display = "none";
					twistie.src = "../css/images/section_expand.gif";
				}
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:SIBDestinationPreValition/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:SIBDestinationPreValition/ns:description" />
			</div>
			<xsl:variable name="title"
				select="ns:SIBDestinationPreValition/ns:title" />
			<xsl:variable name="description"
				select="ns:SIBDestinationPreValition/ns:description" />
			<xsl:if test="ns:SIBDestinationPreValition/ns:exist = 'false'">
				<table role="grid" summary="{$description}" aria-label="{$title}">
					<thead style="display:none;">
						<tr role="row">
							<th tabindex="-1" role="gridcell" id="title" scope="col">title</th>
						</tr>
					</thead>
					<tbody>
						<tr role="row">
							<td colspan="2" tabindex="-1" role="gridcell" headers="title">
								<div>
									<img alt="Info" align="top" height="16" width="16"
										src="../css/images/information.gif" title="Info"></img>
									<span style="padding-left:3px;">
										<xsl:value-of select="ns:SIBDestinationPreValition/ns:result" />
									</span>
								</div>
							</td>
						</tr>
					</tbody>
				</table>
			</xsl:if>
			<xsl:if test="ns:SIBDestinationPreValition/ns:exist = 'true'">
				<table class="reportTable" role="grid" summary="{$description}"
					aria-label="{$title}">
					<thead>
						<tr role="row">
							<xsl:for-each select="ns:SIBDestinationPreValition/ns:columnHeader">
								<xsl:variable name="headerName" select="ns:headerName" />
								<th class="column-head-name" tabindex="-1" scope="col" role="gridcell"
									id="{$headerName}">
									<xsl:value-of select="ns:headerName" />
								</th>
							</xsl:for-each>
						</tr>
					</thead>
					<tbody>
						<xsl:variable name="header1"
							select="ns:SIBDestinationPreValition/ns:columnHeader[1]/ns:headerName" />
						<xsl:variable name="header2"
							select="ns:SIBDestinationPreValition/ns:columnHeader[2]/ns:headerName" />
						<xsl:variable name="header3"
							select="ns:SIBDestinationPreValition/ns:columnHeader[3]/ns:headerName" />
						<xsl:variable name="header4"
							select="ns:SIBDestinationPreValition/ns:columnHeader[4]/ns:headerName" />
						<xsl:for-each select="ns:SIBDestinationPreValition/ns:SIBDestination">
							<xsl:variable name="className" select="ns:name" />
							<xsl:variable name="status" select="ns:status" />
							<tr class="colorfulTr" role="row">
								<td headers="{$header1}" tabindex="-1" role="gridcell" align="center">
									<img src="../css/images/warning.gif" alt="Stopped" title="Stopped" />
								</td>
								<td headers="{$header2}" tabindex="-1" role="gridcell">
									<img src="../css/images/section_expand.gif" id="{$className}_link"
										height="10" width="10" onclick="showDetailInfo('{$className}')"
										style="padding-right:2px" />
									<a href="#" onclick="showDetailInfo('{$className}')">
										<span>
											<xsl:value-of select="ns:name" />
										</span>
									</a>
								</td>
								<td headers="{$header3}" tabindex="-1" role="gridcell">
									<span>
										<xsl:value-of select="ns:busName" />
									</span>
								</td>
								<td headers="{$header4}" tabindex="-1" role="gridcell">
									<span>
										<xsl:value-of select="ns:messageEngineName" />
									</span>
								</td>
							</tr>
							<tr style="display:none" id="{$className}" class="explanationTr">
								<td colspan="3">
									<div class="explanationDiv">
										<span class="validation-warning">
											<xsl:value-of select="ns:problem/ns:explanation" />
										</span>
									</div>
									<div class="userActionDiv">
										<span class="validation-warning">
											<xsl:value-of select="ns:problem/ns:userAction" />
										</span>
									</div>
								</td>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
			</xsl:if>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>