<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Failed Events Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:FailedEventPreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:FailedEventPreValidation/ns:description" />
			</div>
			<xsl:variable name="title"
				select="ns:FailedEventPreValidation/ns:title"></xsl:variable>
			<xsl:variable name="description"
				select="ns:FailedEventPreValidation/ns:description"></xsl:variable>
			
			<xsl:if test="ns:FailedEventPreValidation/ns:validationResult/@type = 'Error'">
				<table class="reportTable" summary="{$description}" id="grid1" role="grid" aria-label="{$title}">
					<thead style="display:none;">
						<tr role="row">
							<th id="tablehead1" scope="col" tabindex="-1" role="gridcell"
							aria-label="arialabel"></th>
						</tr>
					</thead>
					<tbody>
						<tr class="explanationTr" role="row">
							<td colspan="6" headers="tablehead1" tabindex="-1" role="gridcell" align="left">
								<div class="explanationDiv">
									<img alt="Error" align="top" height="16" width="16"
										src="../css/images/error.gif" title="Error"></img>
									<span class="validation-error">
										<xsl:value-of
											select="ns:FailedEventPreValidation/ns:validationResult/@summary" />
									</span>
								</div>
							</td>
						</tr>
					</tbody>
				</table>
			</xsl:if>
			<xsl:if test="ns:FailedEventPreValidation/ns:validationResult/@type != 'Error'">
				<table class="reportTable" summary="{$description}" id="grid1"
					role="grid" aria-label="{$title}">
					<thead style="display:none;">
						<tr role="row">
							<th id="tablehead1" scope="col" tabindex="-1" role="gridcell"
								aria-label="arialabel"></th>
						</tr>
					</thead>
					<tbody>
						<xsl:if
							test="ns:FailedEventPreValidation/ns:EventClean/ns:eventIsClean = 'false'">
							<tr class="explanationTr" role="row">
								<td colspan="2" headers="tablehead1" tabindex="-1" role="gridcell" align="center">
									<div class="explanationDiv">
										<img alt="Error" align="top" height="16" width="16"
											src="../css/images/warning.gif" title="Warning"></img>
										<span class="validation-warning">
											<xsl:value-of
												select="ns:FailedEventPreValidation/ns:EventClean/ns:problem/ns:explanation" />
										</span>
									</div>
									<div class="userActionDiv">
										<span class="validation-warning">
											<xsl:value-of
												select="ns:FailedEventPreValidation/ns:EventClean/ns:problem/ns:userAction" />
										</span>
									</div>
								</td>
							</tr>
						</xsl:if>
						<xsl:if
							test="ns:FailedEventPreValidation/ns:EventClean/ns:eventIsClean = 'true'">
							<tr role="row">
								<td colspan="2" headers="tablehead1" tabindex="-1" role="gridcell">
									<div>
										<img alt="Info" align="top" height="16" width="16"
											src="../css/images/information.gif" title="Info"></img>
										<span style="padding-left:3px;">
											<xsl:value-of select="ns:FailedEventPreValidation/ns:EventClean/ns:result" />
										</span>
									</div>
								</td>
							</tr>
						</xsl:if>
					</tbody>
				</table>
			</xsl:if>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>