<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Index Customization Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="innerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			function showDetailInfo(appName) {
				var displayTr = document.getElementById(appName);
				if (displayTr.style.display == "none") {
					displayTr.style.display = "table-row";
				} else {
					displayTr.style.display = "none";
				}
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:indexPreValidation/ns:title" />
			</div>
			<xsl:variable name="title" select="ns:indexPreValidation/ns:title" />
			<xsl:variable name="description"
				select="ns:indexPreValidation/ns:description" />
			<xsl:choose>
				<xsl:when test="ns:indexPreValidation/ns:faultMessage != ''">
					<table role="grid" summary="{$description}" aria-label="{$title}">
						<thead style="display:none;">
							<tr role="row">
								<th tabindex="-1" role="gridcell" id="title" scope="col">title</th>
							</tr>
						</thead>
						<tbody>
							<tr role="row">
								<td colspan="2" tabindex="-1" role="gridcell" headers="title" align="center">
									<div class="validation-error">
										<img alt="Info" align="baseline" height="16" width="16"
											src="../css/images/error.gif" title="Error"></img>
										<span>
											<xsl:value-of select="ns:indexPreValidation/ns:faultMessage" />
										</span>
									</div>
								</td>
							</tr>
						</tbody>
					</table>
				</xsl:when>
				<xsl:otherwise>

					<!--if the conflict list is empty part-->
					<xsl:if test="ns:indexPreValidation/ns:confilctExist = 'false'">
						<table role="grid" summary="{$description}" aria-label="{$title}">
							<thead style="display:none;">
							<tr role="row">
								<th tabindex="-1" role="gridcell" id="title" scope="col">title</th>
							</tr>
							</thead>
							<tbody>
								<tr role="row">
									<td colspan="2" tabindex="-1" role="gridcell" headers="title">
										<div>
										<img alt="Info" align="top" height="16" width="16"
										src="../css/images/information.gif" title="Info"></img>
										<span style="padding-left:3px;">
										<xsl:value-of select="ns:indexPreValidation/ns:result" />
										</span>
										</div>
									</td>
								</tr>
							</tbody>
						</table>
					</xsl:if>
					
					<!--if the conflict list is NOT empty part-->
					<xsl:if test="ns:indexPreValidation/ns:confilctExist = 'true'">
					<div class="description-bread-crumb">
						<xsl:value-of select="ns:indexPreValidation/ns:description" />
					</div>
					<table class="reportTable" role="grid" summary="{$description}"
						aria-label="{$title}">
						<thead>
							<tr role="row">
								<xsl:for-each select="ns:indexPreValidation/ns:columnHeader">
									<xsl:variable name="headerName" select="ns:headerName" />
									<th class="column-head-name" width="25%" scope="col"
										tabindex="-1" role="gridcell" id="{$headerName}">
										<xsl:value-of select="ns:headerName" />
									</th>
								</xsl:for-each>
							</tr>
						</thead>
						<tbody>
							<xsl:variable name="header1"
								select="ns:indexPreValidation/ns:columnHeader[1]/ns:headerName" />
							<xsl:variable name="header2"
								select="ns:indexPreValidation/ns:columnHeader[2]/ns:headerName" />
							<xsl:variable name="header3"
								select="ns:indexPreValidation/ns:columnHeader[3]/ns:headerName" />
							<xsl:for-each select="ns:indexPreValidation/ns:indexValidationList">
								<xsl:sort select="ns:indexName" />
								<tr class="colorfulTr" role="row">
									<td headers="{$header1}" tabindex="-1" role="gridcell">
										<span>
											<xsl:value-of select="ns:indexName" />
										</span>
									</td>
									<td headers="{$header2}" tabindex="-1" role="gridcell">
										<xsl:if test="ns:tableName = '' ">
											<span>-</span>
										</xsl:if>
										<xsl:if test="ns:tableName != '' ">
											<span>
												<xsl:value-of select="ns:tableName" />
											</span>
										</xsl:if>
									</td>
									<td headers="{$header3}" tabindex="-1" role="gridcell">
										<span>
											<xsl:value-of select="ns:description" />
										</span>
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>