<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Limitation Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="outerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="outerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="src">
				<xsl:text>../js/colorfulTable.js</xsl:text>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:LimitationPreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:LimitationPreValidation/ns:description" />
			</div>
			<div class="sub-title-bread-crumb">
				<xsl:value-of
					select="ns:LimitationPreValidation/ns:AuthAliasLimitationListDesc" />
			</div>
			<xsl:variable name="title"
				select="ns:LimitationPreValidation/ns:title" />
			<xsl:variable name="authAliasLimitationListDesc"
				select="ns:LimitationPreValidation/ns:AuthAliasLimitationListDesc"></xsl:variable>
			<!--authentication alias part-->
			<xsl:if test="ns:LimitationPreValidation/ns:AuthAliasLimitationListExist = 'false'">
					<table role="grid" summary="{$authAliasLimitationListDesc}" aria-label="{$title}">
					<thead style="display:none;">
						<tr role="row">
							<th tabindex="-1" role="gridcell" id="title" scope="col">title</th>
						</tr>
					</thead>
					<tbody>
						<tr role="row">
							<td colspan="2" tabindex="-1" role="gridcell" headers="title">
								<div>
									<img alt="Info" align="top" height="16" width="16"
										src="../css/images/information.gif" title="Info"></img>
									<span style="padding-left:3px;">
										<xsl:value-of select="ns:LimitationPreValidation/ns:AuthAliasLimitationValidationResult" />
									</span>
								</div>
							</td>
						</tr>
					</tbody>
				</table>
			</xsl:if>
			<xsl:if test="ns:LimitationPreValidation/ns:AuthAliasLimitationListExist = 'true'">
				<table class="reportTable" summary="{$authAliasLimitationListDesc}"
				id="grid1" role="grid" aria-label="grid1_label">
				<thead>
					<tr role="row">
						<xsl:for-each select="ns:LimitationPreValidation/ns:aliasColumnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" id="Alias{$headerName}" scope="col"
								tabindex="-1" role="gridcell">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="header1"
						select="ns:LimitationPreValidation/ns:aliasColumnHeader[1]/ns:headerName" />
					<xsl:for-each
						select="ns:LimitationPreValidation/ns:AuthAliasLimitationList">
						<xsl:sort select="ns:name" />
						<tr class="colorfulTr" role="row">
							<td tabindex="-1" role="gridcell" headers="Alias{$header1}">
								<span>
									<xsl:value-of select="ns:name" />
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			</xsl:if>
			
			<!--datasource part-->
			<div class="sub-title-bread-crumb">
				<xsl:value-of
					select="ns:LimitationPreValidation/ns:DataSourceLimitationListDesc" />
			</div>
			<xsl:variable name="dataSourceLimitationListDesc"
				select="ns:LimitationPreValidation/ns:DataSourceLimitationListDesc"></xsl:variable>
			<xsl:if test="ns:LimitationPreValidation/ns:DataSourceLimitationListExist = 'false'">
					<table role="grid" summary="{$dataSourceLimitationListDesc}" aria-label="{$title}">
					<thead style="display:none;">
						<tr role="row">
							<th tabindex="-1" role="gridcell" id="title" scope="col">title</th>
						</tr>
					</thead>
					<tbody>
						<tr role="row">
							<td colspan="2" tabindex="-1" role="gridcell" headers="title">
								<div>
									<img alt="Info" align="top" height="16" width="16"
										src="../css/images/information.gif" title="Info"></img>
									<span style="padding-left:3px;">
										<xsl:value-of select="ns:LimitationPreValidation/ns:DataSourceLimitationValidationResult" />
									</span>
								</div>
							</td>
						</tr>
					</tbody>
				</table>
			</xsl:if>
			<xsl:if test="ns:LimitationPreValidation/ns:DataSourceLimitationListExist = 'true'">
				<table class="reportTable" summary="{$dataSourceLimitationListDesc}"
				id="grid2" role="grid" aria-label="grid2_label">
				<thead>
					<tr role="row">
						<xsl:for-each select="ns:LimitationPreValidation/ns:dsColumnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" id="{$headerName}" scope="col"
								tabindex="-1" role="gridcell">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="dsheader1"
						select="ns:LimitationPreValidation/ns:dsColumnHeader[1]/ns:headerName" />
					<xsl:variable name="dsheader2"
						select="ns:LimitationPreValidation/ns:dsColumnHeader[2]/ns:headerName" />
					<xsl:variable name="dsheader3"
						select="ns:LimitationPreValidation/ns:dsColumnHeader[3]/ns:headerName" />
					<xsl:variable name="dsheader4"
						select="ns:LimitationPreValidation/ns:dsColumnHeader[4]/ns:headerName" />
					<xsl:variable name="dsheader5"
						select="ns:LimitationPreValidation/ns:dsColumnHeader[5]/ns:headerName" />
					<xsl:for-each
						select="ns:LimitationPreValidation/ns:DataSourceLimitationList">
						<xsl:sort select="ns:name" />
						<tr class="colorfulTr" role="row">
							<td headers="{$dsheader1}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:name" />
								</span>
							</td>
							<td headers="{$dsheader2}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:jndiName" />
								</span>
							</td>
							<td headers="{$dsheader3}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:scope" />
								</span>
							</td>
							<td headers="{$dsheader4}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:provider" />
								</span>
							</td>
							<td headers="{$dsheader5}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:description" />
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			</xsl:if>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>