<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Lombardi Customization XML File Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="innerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:text disable-output-escaping="yes">
		<![CDATA[<style type="text/css">
			td,th {
				word-break : break-all;
		</style>]]>
		</xsl:text>
	</xsl:template>

	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			function showDetailInfo(appName) {
				var displayTr = document.getElementById(appName);
				if (displayTr.style.display == "none") {
					displayTr.style.display = "table-row";
				} else {
					displayTr.style.display = "none";
				}
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:LombardiXMLPreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:copy-of select="ns:LombardiXMLPreValidation/ns:description" disable-output-escaping="yes" /><xsl:text> </xsl:text><xsl:value-of select="ns:LombardiXMLPreValidation/ns:moreInfo" />, see the "Security configuration properties" topic in the documentation.
			</div>
			<xsl:variable name="title"
				select="ns:LombardiXMLPreValidation/ns:title" />
			<xsl:variable name="description"
				select="ns:LombardiXMLPreValidation/ns:description" />
			<table class="reportTable" role="grid" summary="{$description}"
				aria-label="{$title}">
				<thead>
					<tr role="row">
						<xsl:for-each select="ns:LombardiXMLPreValidation/ns:columnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" width="25%" scope="col" tabindex="-1"
								role="gridcell" id="{$headerName}">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="header1"
						select="ns:LombardiXMLPreValidation/ns:columnHeader[1]/ns:headerName" />
					<xsl:variable name="header2"
						select="ns:LombardiXMLPreValidation/ns:columnHeader[2]/ns:headerName" />
					<xsl:variable name="header3"
						select="ns:LombardiXMLPreValidation/ns:columnHeader[3]/ns:headerName" />
					<xsl:variable name="header4"
						select="ns:LombardiXMLPreValidation/ns:columnHeader[4]/ns:headerName" />
					<xsl:for-each select="ns:LombardiXMLPreValidation/ns:LombardiXML">
						<tr role="row">
							<td headers="{$header1}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:lombardiPropertyName" />
								</span>
							</td>
							<td headers="{$header2}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:lombardiPropertyValue" />
								</span>
							</td>
							<td headers="{$header3}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:wccmScope" />
								</span>
							</td>
							<td headers="{$header4}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:description" />
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
