<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>LTPA Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="innerScript" />
			<xsl:call-template name="outerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="outerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="src">
				<xsl:text>../js/colorfulTable.js</xsl:text>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			function showDetailInfo(appName) {
				var displayTr = document.getElementById(appName);
				if (displayTr.style.display == "none") {
					displayTr.style.display = "table-row";
				} else {
					displayTr.style.display = "none";
				}
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:LTPAPreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:LTPAPreValidation/ns:description" />
			</div>
			<xsl:variable name="description" select="ns:LTPAPreValidation/ns:description"></xsl:variable>
			<table class="reportTable" summary="{$description}" id="grid1"
				role="grid" aria-label="grid1_label">
				<thead>
					<tr role="row">
						<xsl:for-each
							select="ns:LTPAPreValidation/ns:ltpaKeySetGroupColumnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" id="{$headerName}1" scope="col"
								tabindex="-1" role="gridcell">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="gheader1"
						select="ns:LTPAPreValidation/ns:ltpaKeySetGroupColumnHeader[1]/ns:headerName" />
					<xsl:variable name="gheader2"
						select="ns:LTPAPreValidation/ns:ltpaKeySetGroupColumnHeader[2]/ns:headerName" />
					<xsl:for-each select="ns:LTPAPreValidation/ns:LTPAKeySetGroup">
						<tr class="colorfulTr" role="row">
							<td headers="{$gheader1}1" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:ltpaKeySetGroupName" />
								</span>
							</td>
							<td headers="{$gheader2}1" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:description" />
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
			<table class="reportTable" summary="{$description}" id="grid2"
				role="grid" aria-label="grid2_label">
				<thead>
					<tr role="row">
						<xsl:for-each select="ns:LTPAPreValidation/ns:ltpaKeySetColumnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" id="{$headerName}2" scope="col"
								tabindex="-1" role="gridcell">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="sheader1"
						select="ns:LTPAPreValidation/ns:ltpaKeySetColumnHeader[1]/ns:headerName" />
					<xsl:variable name="sheader2"
						select="ns:LTPAPreValidation/ns:ltpaKeySetColumnHeader[2]/ns:headerName" />
					<xsl:for-each select="ns:LTPAPreValidation/ns:LTPAKeySet">
						<tr class="colorfulTr" role="row">
							<td headers="{$sheader1}2" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:ltpaKeySetName" />
								</span>
							</td>
							<td headers="{$sheader2}2" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:description" />
								</span>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>