<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Messaging Engine Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="outerScript" />
			<xsl:call-template name="innerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="outerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="src">
				<xsl:text>../js/colorfulTable.js</xsl:text>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>

	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			function showDetailInfo(id, status) {
				var displayTr = document.getElementById(id);
				var twistie = document.getElementById(id + "_link");
				
				if (status != "Started") {
					if (displayTr.style.display == "none") {
						displayTr.style.display = "table-row";
						twistie.src = "../css/images/section_collapse.gif";
					} else {
						displayTr.style.display = "none";
						twistie.src = "../css/images/section_expand.gif";
					}
				}
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:MessagingEnginePreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:MessagingEnginePreValidation/ns:description" />
			</div>
			<xsl:variable name="title"
				select="ns:MessagingEnginePreValidation/ns:title"></xsl:variable>
			<xsl:variable name="description"
				select="ns:MessagingEnginePreValidation/ns:description"></xsl:variable>
			<table class="reportTable" summary="{$description}" id="grid1"
				role="grid" aria-label="{$title}">
				<thead>
					<tr role="row">
						<xsl:for-each select="ns:MessagingEnginePreValidation/ns:columnHeader">
							<xsl:variable name="headerName" select="ns:headerName" />
							<th class="column-head-name" id="{$headerName}" scope="col"
								tabindex="-1" role="gridcell">
								<xsl:value-of select="ns:headerName" />
							</th>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:variable name="header1"
						select="ns:MessagingEnginePreValidation/ns:columnHeader[1]/ns:headerName" />
					<xsl:variable name="header2"
						select="ns:MessagingEnginePreValidation/ns:columnHeader[2]/ns:headerName" />
					<xsl:variable name="header3"
						select="ns:MessagingEnginePreValidation/ns:columnHeader[3]/ns:headerName" />
					<xsl:for-each
						select="ns:MessagingEnginePreValidation/ns:SIBMessagingEngine">
						<xsl:sort select="ns:name" />
						<xsl:variable name="className" select="ns:name" />
						<xsl:variable name="status" select="ns:status" />
						<tr class="colorfulTr" role="row">
							<td headers="{$header1}" tabindex="-1" role="gridcell" align="center">
								<xsl:choose>
									<xsl:when test="ns:status = 'Started'">
										<img src="../css/images/success.gif" alt="Started" title="Started"></img>
									</xsl:when>
									<xsl:otherwise>
										<img src="../css/images/error.gif" alt="Stopped" title="Stopped"></img>
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td headers="{$header2}" tabindex="-1" role="gridcell">
								<xsl:choose>
									<xsl:when test="ns:status != 'Started'">
										<img src="../css/images/section_expand.gif" id="{$className}_link"
											height="10" width="10"
											onclick="showDetailInfo('{$className}', '{$status}')" style="padding-right:2px" />
										<a href="javascript:void(0)" onclick="showDetailInfo('{$className}', '{$status}')"
											role="navigation" aria-label="{$className}" tabindex="1">
											<span>
												<xsl:value-of select="ns:name" />
											</span>
										</a>
									</xsl:when>
									<xsl:otherwise>
										<span>
											<xsl:value-of select="ns:name" />
										</span>
									</xsl:otherwise>
								</xsl:choose>
							</td>
							<td headers="{$header3}" tabindex="-1" role="gridcell">
								<span>
									<xsl:value-of select="ns:busName" />
								</span>
							</td>
						</tr>
						<xsl:choose>
							<xsl:when test="ns:status != 'Started'">
								<tr style="display:none" id="{$className}" class="explanationTr">
									<td colspan="3">
										<div class="explanationDiv">
											<span class="validation-error">
												<xsl:value-of select="ns:problem/ns:explanation" />
											</span>
										</div>
										<div class="userActionDiv">
											<span class="validation-error">
												<xsl:value-of select="ns:problem/ns:userAction" />
											</span>
										</div>
									</td>
								</tr>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>