<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Product Prevalidation Report</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/style.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>../css/table.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="role">
				<xsl:text>main</xsl:text>
			</xsl:attribute>
			<div class="title-bread-crumb">
				<xsl:value-of select="ns:ProductPreValidation/ns:title" />
			</div>
			<div class="description-bread-crumb">
				<xsl:value-of select="ns:ProductPreValidation/ns:description" />
			</div>
			<table class="reportTable">
				<tr>
					<th class="td-head-name" scope="row" id="version">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[1]/ns:headerName" />
					</th>
					<td headers="version">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:version" />
						</span>
					</td>
				</tr>
				<tr>
					<th class="td-head-name" scope="row" id="productType">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[2]/ns:headerName" />
					</th>
					<td headers="productType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:productType" />
						</span>
					</td>
				</tr>
				<tr>
					<th class="td-head-name" scope="row" id="environmentType">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[3]/ns:headerName" />
					</th>
					<td headers="environmentType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:environmentType" />
						</span>
					</td>
				</tr>
				<tr>
					<th class="td-head-name" scope="row" id="profilePath">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[4]/ns:headerName"/>
					</th>
					<td headers="environmentType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:profilePath" />
						</span>
					</td>
				</tr>
				<tr>
					<th class="td-head-name" scope="row" id="topology">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[5]/ns:headerName" />
					</th>
					<td headers="environmentType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:topology" />
						</span>
					</td>
				</tr>
				<xsl:if test="ns:ProductPreValidation/ns:environmentInformation/ns:deName != ''">
				<tr>
					<th class="td-head-name" scope="row" id="deName">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[6]/ns:headerName" />
					</th>
					<td headers="environmentType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:deName" />
						</span>
					</td>
				</tr>
				</xsl:if>
				<xsl:if test="ns:ProductPreValidation/ns:environmentInformation/ns:clusterNumber != ''">
				<tr>
					<th class="td-head-name" scope="row" id="clusterNumber">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[7]/ns:headerName" />
					</th>
					<td headers="environmentType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:clusterNumber" />
						</span>
					</td>
				</tr>
				</xsl:if>
				<xsl:if test="ns:ProductPreValidation/ns:environmentInformation/ns:nodeNumber != ''">
				<tr>
					<th class="td-head-name" scope="row" id="nodeNumber">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[8]/ns:headerName" />
					</th>
					<td headers="environmentType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:nodeNumber" />
						</span>
					</td>
				</tr>
				</xsl:if>
				<tr>
					<th class="td-head-name" scope="row" id="dbType">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[9]/ns:headerName" />
					</th>
					<td headers="environmentType">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:environmentInformation/ns:dbType" />
						</span>
					</td>
				</tr>
				<tr>
					<th class="td-head-name" scope="row" id="isSupportMigration">
						<xsl:value-of
							select="ns:ProductPreValidation/ns:columnHeader[10]/ns:headerName" />
					</th>
					<td headers="isSupportMigration">
						<span>
							<xsl:value-of
								select="ns:ProductPreValidation/ns:SupportMigration/ns:isSupportMigration" />
						</span>
					</td>
				</tr>
				<xsl:if
					test="ns:ProductPreValidation/ns:SupportMigration/ns:isSupportMigration = 'No'">
					<tr class="explanationTr">
						<td colspan="2">
							<div class="explanationDiv">
								<img alt="Error" align="baseline" height="16" width="16"
									src="../css/images/error.gif" title="Error"></img>
								<span class="boldText">Explanation: </span>
								<span class="validation-error">
									<xsl:value-of
										select="ns:ProductPreValidation/ns:SupportMigration/ns:problem/ns:explanation" />
								</span>
							</div>
							<div class="userActionDiv" style="margin-left: 32px;">
								<span class="boldText">User Action: </span>
								<span class="validation-error">
									<xsl:value-of
										select="ns:ProductPreValidation/ns:SupportMigration/ns:problem/ns:userAction" />
								</span>
							</div>
						</td>
					</tr>
				</xsl:if>
			</table>
			<xsl:if test="ns:ProductPreValidation/ns:validationResult/@type = 'Error'">
				<div style="margin-left: 32px;">
					<img alt="Error" align="top" height="16" width="16" src="../css/images/error.gif" title="Error" />
					<span class="validation-error" style="padding-left:3px;"><xsl:value-of select="ns:ProductPreValidation/ns:validationResult/@summary" /></span>
				</div>
			</xsl:if>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>