<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ns="http://ibm.com/bpm/migration/schema">
	<xsl:import href="common.xsl" />

	<xsl:output method="html" encoding="utf-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" />

	<xsl:template match="/">
		<xsl:element name="HTML">
			<xsl:attribute name="lang">
				<xsl:text>en</xsl:text>
			</xsl:attribute>
			<xsl:call-template name="head" />
			<xsl:call-template name="body" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="head">
		<xsl:element name="HEAD">
			<xsl:call-template name="formTitle">
				<xsl:with-param name="titleText">
					<xsl:text>Menu</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="styleSheet" />
			<xsl:call-template name="innerScript" />
		</xsl:element>
	</xsl:template>

	<xsl:template name="styleSheet">
		<xsl:call-template name="includeStyleSheet">
			<xsl:with-param name="styleSheet">
				<xsl:text>css/nav.css</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="innerScript">
		<xsl:element name="SCRIPT">
			<xsl:attribute name="type">
          <xsl:text>text/javascript</xsl:text>
        </xsl:attribute>
			<xsl:text disable-output-escaping="yes">
			var dgeid = document.getElementById;

			function expandCollapse(n) {
				N = new String("N");
				I = new String("I");
				a = N.concat(n);
				g = I.concat(n);
		
				if (!dgeid)
					return;
				if (document.getElementById(a).style.display == 'none') {
					document.getElementById(a).style.display = 'block';
					document.getElementById(g).src = 'css/images/arrow_expanded.gif';
					document.getElementById(g).title = 'Collapse';
					document.getElementById(g).alt = 'Collapse';
				} else {
					document.getElementById(a).style.display = 'none';
					document.getElementById(g).src = 'css/images/arrow_collapsed.gif';
					document.getElementById(g).title = 'Expand';
					document.getElementById(g).alt = 'Expand';
				}
			}
			function navKey() {
				
			}
          </xsl:text>
		</xsl:element>
	</xsl:template>

	<xsl:template name="body">
		<xsl:element name="BODY">
			<xsl:attribute name="class">
              <xsl:text>menu_body</xsl:text>
          </xsl:attribute>
			<div class="navBody" role="main">
				<table height="26" id="navTable" title="Navigation frame"
					summary="Navigation Table" width="100%" cellspacing="0"
					cellpadding="0" role="grid">
					<thead display="none">
						<tr role="row" onkeydown="navKey()">
							<th id="d01" role="gridcell" scope="col" aria-label="Navigation"></th>
						</tr>
					</thead>
					<tbody>
						<tr role="row" aria-selected="false" onkeydown="navKey()">
							<td align="left" colspan="2" class="navtree" headers="d01"
								role="gridcell" aria-label="Navigation Tree">
								<div style="margin-top:5px;">
									<ul class="nav-child" dir="ltr">
										<li class="navigation-bullet">
											<a href="welcome.html" target="infoFrame" style="text-decoration: none">
												<xsl:value-of select="ns:NavMenu/ns:Home" />
											</a>
										</li>
									</ul>
								</div>
								<xsl:for-each select="ns:NavMenu/ns:Menu[@level='1']">
									<xsl:variable name="mainTitle" select="ns:MenuTitle" />
									<div class="main-task" style="margin-left: 0.3em;">
										<a class="level1Link" href="javascript:expandCollapse('{$mainTitle}');"
											title="{$mainTitle}">
											<img src="css/images/arrow_expanded.gif" title="Expand"
												alt="Expand" id="I{$mainTitle}" border="0" align="absmiddle" />
											<span dir="ltr">
												<xsl:value-of select="ns:MenuTitle" />
											</span>
										</a>
									</div>
									<div class="nav-child-container" style="margin-left: 0.3em; display: block;"
										id="N{$mainTitle}">
										<xsl:for-each select="ns:Categorys/ns:Menu[@level='2']">
											<xsl:variable name="menuName" select="ns:LinkFileName" />
											<xsl:variable name="title" select="ns:MenuTitle" />
											<xsl:variable name="status" select="ns:MenuStatus" />
											<ul class="nav-child" dir="ltr" role="navigation"
												aria-label="Navigation {$title}">
												<li class="navigation-bullet">
													<a style="text-decoration: none" dir="ltr" href="html/{$menuName}"
														target="infoFrame" title="{$title}" role="link">
														<xsl:if test="ns:MenuStatus= 'Info'">
															<img src="css/images/success.gif" title="Success"
																height="13" width="13" alt="Success" border="0"
																class="menuHintIcon" align="top"/>
														</xsl:if>
														<xsl:if test="ns:MenuStatus = 'Warning'">
															<img src="css/images/warning.gif" title="Warning"
																height="13" width="13" alt="Warning" border="0"
																class="menuHintIcon" align="top"/>
															<span style="padding-left:3px;">(</span>
															<span>
																<xsl:value-of select="ns:ResultNumber" />
															</span>
															<span>)</span>
														</xsl:if>
														<xsl:if test="ns:MenuStatus = 'Error'">
															<img src="css/images/error.gif" title="Error" height="13"
																width="13" alt="Error" border="0" class="menuHintIcon" align="top"/>
															<span style="padding-left:3px;">(</span>
															<span>
																<xsl:value-of select="ns:ResultNumber" />
															</span>
															<span>)</span>
														</xsl:if>
														<span style="padding-left:3px;">
															<xsl:value-of select="ns:MenuTitle" />
														</span>
													</a>
												</li>
											</ul>
										</xsl:for-each>
									</div>
								</xsl:for-each>
							</td>
						</tr>
					</tbody>
				</table>
			</div>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>