#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2014, 2016. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
import os,sys,re,shutil
from com.ibm.ISecurityUtilityImpl import PasswordUtil
from com.ibm.websphere.management.configservice import ConfigServiceFactory
from com.ibm.websphere.management.configservice import ConfigServiceHelper
from com.ibm.websphere.management import Session
from java.util.logging import Logger
from java.util.logging import FileHandler
from java.util.logging import ConsoleHandler
from java.util.logging import Level
from java.text import SimpleDateFormat
from java.util.logging import LogRecord
from java.lang import Boolean
from java.util.logging import Formatter
from java.util import Date
from java.io import File
from java.util import Properties
from java.io import FileInputStream
from java.lang import System

loglevel=Level.INFO
actions = ["-listDataSources",\
            "-exportDataSource",\
            "-exportAllDataSources",\
            "-listJDBCProviders",\
            "-exportAllJDBCProviders",\
            "-listJMSProviders",\
            "-exportAllJMSProviders",\
            "-listConnectionFactories",\
            "-exportAllConnectionFactories",\
            "-exportConnectionFactory",\
            "-listActivationSpecs",\
            "-exportAllActivationSpecs",\
            "-exportActivationSpec",\
            "-listQueuesAndTopics",\
            "-exportAllQueuesAndTopics",\
            "-exportQueueOrTopic",\
            "-listNameSpaceBindings",\
            "-exportAllNameSpaceBindings",\
            "-exportNameSpaceBinding",\
            "-listAuthAliases",\
            "-exportAuthAlias",\
            "-exportAllAuthAliases",\
            "-exportSSLSettings",\
            "-exportJavaSecurityFile",\
            "-exportSIBusConfig"]
#------------------------------------------------------------------------------
# Print exporting action usage
#------------------------------------------------------------------------------
def usage():
    tips=["List all data sources",\
            "Export data source by JNDI name in scope",\
            "Export all data sources by scope",\
            "List all JDBC providers",\
            "Export all JDBC providers by scope",\
            "List all JMS providers",\
            "Export all JMS providers by scope",\
            "List all connection factories",\
            "Export all connection factories by scope",\
            "Export connection factory by JNDI name in scope",\
            "List all activation specifications",\
            "Export all activation specifications by scope",\
            "Export activation specification by JNDI name in scope",\
            "List all queues and topics",\
            "Export all queues and topics by scope",\
            "Export queue or topic by JDNI name in scope",\
            "List all namespace bindings",\
            "Export all namespace bindings by scope",\
            "Export namespace bindings by namespace binding identifier in scope",\
            "List all authentication aliases",\
            "Export authentication alias by name",\
            "Export all authentication aliases",\
            "Export all SSL settings",\
            "Export Java security file java.security",\
            "Export bus configuration by name"]
    
    print "WebSphere Application Server configuration export usage:"
    print "For each detailed action usage, use '<Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py <action name> -exportHelp':"
    print "For example: '<Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportDataSource -exportHelp' will list export datasource usage."
    for action, tip in zip(actions,tips):
        if(len(action) >= 24):
            print action +"\t\t"+tip
        else:
            print action +"\t\t\t"+tip
    sys.exit()
    
#------------------------------------------------------------------------------
# Print datasource export/list usage
#------------------------------------------------------------------------------
def dsUsage():
    print "Datasource related usage:\n"
    print "List all data sources:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listDataSources\n"
    
    print "Export data source by JNDI name in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportDataSource <Datasource_JNDI> <output_dir>\n"
    print "Export data source by JNDI name in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportDataSource <Datasource_JNDI> <output_dir> -cell <cell_name>\n"
    print "Export data source by JNDI name in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportDataSource <Datasource_JNDI> <output_dir> -node <node_name>\n"
    print "Export data source by JNDI name in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportDataSource <Datasource_JNDI> <output_dir> -node <node_name> -server <server_name>\n"
    print "Export data source by JNDI name in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportDataSource <Datasource_JNDI> <output_dir> -cluster <clusterName>\n"

    print "Export all data sources in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllDataSources <output_dir>\n"
    print "Export all data sources in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllDataSources <output_dir> -cell <cell_name>\n"
    print "Export all data sources in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllDataSources <output_dir> -node <node_name>\n"
    print "Export all data sources in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllDataSources <output_dir> -node <node_name> -server <server_name>\n"
    print "Export all data sources in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllDataSources <output_dir> -cluster <clusterName>\n"
    sys.exit()

#------------------------------------------------------------------------------
# Print jdbc provider export usage
#------------------------------------------------------------------------------
def jdbcProviderUsage():
    print "JDBC provider related usage:\n"
    print "List all JDBC providers:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listJDBCProviders\n"
    
    print "Export all JDBC providers in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJDBCProviders <output_dir>\n"
    print "Export all JDBC providers in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJDBCProviders <output_dir> -cell <cell_name>\n"
    print "Export all JDBC providers in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJDBCProviders <output_dir> -node <node_name>\n"
    print "Export all JDBC providers in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJDBCProviders <output_dir> -node <node_name> -server <server_name>\n"
    print "Export all JDBC providers in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJDBCProviders <output_dir> -cluster <clusterName>\n"
    sys.exit()

#------------------------------------------------------------------------------
# Print jms provider export usage
#------------------------------------------------------------------------------
def jmsProviderUsage():
    print "JMS provider related usage:\n"
    print "List all JMS providers:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listJMSProviders\n"
    
    print "Export all JMS providers in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJMSProviders <output_dir>\n"
    print "Export all JMS providers in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJMSProviders <output_dir> -cell <cell_name>\n"
    print "Export all JMS providers in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJMSProviders <output_dir> -node <node_name>\n"
    print "Export all JMS providers in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJMSProviders <output_dir> -node <node_name> -server <server_name>\n"
    print "Export all JMS providers in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllJMSProviders <output_dir> -cluster <clusterName>\n"
    sys.exit()
    
#------------------------------------------------------------------------------
# Print connection factory exporting usage
#------------------------------------------------------------------------------
def cfUsage():
    print "Connection factory related usage:\n"
    print "List all connection factories:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listConnectionFactories\n"
    
    print "Export all connection factories in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllConnectionFactories <output_dir>\n"
    print "Export all connection factories in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllConnectionFactories <output_dir> -cell <cell_name>\n"
    print "Export all connection factories in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllConnectionFactories <output_dir> -node <node_name>\n"
    print "Export all connection factories in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllConnectionFactories <output_dir> -node <node_name> -server <server_name>\n"
    print "Export all connection factories in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllConnectionFactories <output_dir> -cluster <clusterName>\n"
    
    print "Export connection factory by JNDI name in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportConnectionFactory <connection_factory_JNDI> <output_dir>\n"
    print "Export connection factory by JNDI name in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportConnectionFactory <connection_factory_JNDI> <output_dir> -cell <cell_name>\n"
    print "Export connection factory by JNDI name in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportConnectionFactory <connection_factory_JNDI> <output_dir> -node <node_name>\n"
    print "Export connection factory by JNDI name in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportConnectionFactory <connection_factory_JNDI> <output_dir> -node <node_name> -server <server_name>\n"
    print "Export connection factory by JNDI name in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportConnectionFactory <connection_factory_JNDI> <output_dir> -cluster <clusterName>\n"
    sys.exit()

#------------------------------------------------------------------------------
# Print activation specification exporting usage
#------------------------------------------------------------------------------
def asUsage():
    print "Activation specifications related usage:\n"
    print "List all activation specifications:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listActivationSpecs\n"
    
    print "Export all activation specifications in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllActivationSpecs <output_dir>\n"
    print "Export all activation specifications in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllActivationSpecs <output_dir> -cell <cell_name>\n"
    print "Export all activation specifications in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllActivationSpecs <output_dir> -node <node_name>\n"
    print "Export all activation specifications in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllActivationSpecs <output_dir> -node <node_name> -server <server_name>\n"
    print "Export all activation specifications in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllActivationSpecs <output_dir> -cluster <clusterName>\n"
    
    print "Export activation specification by JNDI name in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportActivationSpec <activation_specification_JNDI> <output_dir>\n"
    print "Export activation specification by JNDI name in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportActivationSpec <activation_specification_JNDI> <output_dir> -cell <cell_name>\n"
    print "Export activation specification by JNDI name in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportActivationSpec <activation_specification_JNDI> <output_dir> -node <node_name>\n"
    print "Export activation specification by JNDI name in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportActivationSpec <activation_specification_JNDI> <output_dir> -node <node_name> -server <server_name>\n"
    print "Export activation specification by JNDI name in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportActivationSpec <activation_specification_JNDI> <output_dir> -cluster <clusterName>\n"
    sys.exit()
 
#------------------------------------------------------------------------------
# Print admin object exporting usage
#------------------------------------------------------------------------------
def aoUsage():
    print "Queue and topic specifications related usage:\n"
    print "List all queues and topics:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listQueuesAndTopics\n"
    
    print "Export all queues and topics in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllQueuesAndTopics <output_dir>\n"
    print "Export all queues and topics in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllQueuesAndTopics <output_dir> -cell <cell_name>\n"
    print "Export all queues and topics in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllQueuesAndTopics <output_dir> -node <node_name>\n"
    print "Export all queues and topics in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllQueuesAndTopics <output_dir> -node <node_name> -server <server_name>\n"
    print "Export all queues and topics in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllQueuesAndTopics <output_dir> -cluster <clusterName>\n"
    
    print "Export queue or topic by JNDI name in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportQueueOrTopic <queue_or_topic_JNDI> <output_dir>\n"
    print "Export queue or topic by JNDI name in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportQueueOrTopic <queue_or_topic_JNDI> <output_dir> -cell <cell_name>\n"
    print "Export queue or topic by JNDI name in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportQueueOrTopic <queue_or_topic_JNDI> <output_dir> -node <node_name>\n"
    print "Export queue or topic by JNDI name in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportQueueOrTopic <queue_or_topic_JNDI> <output_dir> -node <node_name> -server <server_name>\n"
    print "Export queue or topic by JNDI name in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportQueueOrTopic <queue_or_topic_JNDI> <output_dir> -cluster <clusterName>\n"
    sys.exit()
    
def nsUsage():
    print "Namingspace bindings related usage:\n"
    print "List all namespace bindings:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listNameSpaceBindings\n"
    
    print "Export all namespace bindings in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllNameSpaceBindings <output_dir>\n"
    print "Export all namespace bindings in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllNameSpaceBindings <output_dir> -cell <cell_name>\n"
    print "Export all namespace bindings in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllNameSpaceBindings <output_dir> -node <node_name>\n"
    print "Export all namespace bindings in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllNameSpaceBindings <output_dir> -node <node_name> -server <server_name>\n"
    print "Export all namespace bindings in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllNameSpaceBindings <output_dir> -cluster <clusterName>\n"
    
    print "Export namespace bindings by namespace identifier in all scopes:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportNameSpaceBinding <namespace_identifier> <output_dir>\n"
    print "Export namespace binding by namespace identifier in cell scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportNameSpaceBinding <namespace_identifier> <output_dir> -cell <cell_name>\n"
    print "Export namespace binding by namespace identifier in node scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportNameSpaceBinding <namespace_identifier> <output_dir> -node <node_name>\n"
    print "Export namespace binding by namespace identifier in server scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportNameSpaceBinding <namespace_identifier> <output_dir> -node <node_name> -server <server_name>\n"
    print "Export namespace binding by namespace identifier in cluster scope:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportNameSpaceBinding <namespace_identifier> <output_dir> -cluster <clusterName>\n"
    
    sys.exit()
    
def aaUsage():
    print "Authentication aliases related usage:\n"
    print "List all authentication aliases:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -listAuthAliases\n"    
    
    print "Export authentication alias by name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAuthAlias <Auth_Alias_Name> <output_dir>\n"
    
    print "Export all authentication aliases:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportAllAuthAliases <output_dir>\n"
    sys.exit()

def busUsage():
    print "SI bus related usage:\n"
    print "Export bus configuration by name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportSIBusConfig <Bus_Name> <output_dir>\n"
    sys.exit()
    
def sslUsage():
    print "SSL related usage:\n"
    print "Export all SSL settings:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportSSLSettings <output_dir>\n"
    sys.exit()
    
def javaUsage():
    print "Java security related usage:\n"
    print "Export Java security file java.security:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f exportWASConfig.py -exportJavaSecurityFile <output_dir>\n"
    sys.exit()

class exportLogFormatter(Formatter):
    def format(self,LogRecord):
        logMsg = ""
        if LogRecord.getSourceClassName():
            logMsg=logMsg+"["+str(LogRecord.getLoggerName())+"/"+str(LogRecord.getLevel())+"]: "
            if LogRecord.getSourceMethodName():
                logMsg=logMsg+""+str(LogRecord.getSourceMethodName())+"()"
            logMsg=logMsg+": "
            if LogRecord.getMessage():
                logMsg=logMsg+str(LogRecord.getMessage())
        logMsg=logMsg+ System.getProperty("line.separator", "\r\n")
        return logMsg
    
def initlog():
    # define log file name
    pyFileName=_pyFileName[0:-3]
    datFormat=str(SimpleDateFormat("yyyyMMdd_HHmmss").format(Date()))
    _pyLogFileName=pyFileName+"_"+datFormat+".log"
    _pyLogFilePathName=os.path.join(sys.path[0], _pyLogFileName)
    print "INFO: the log file is in current directory and the name is: "+str(_pyLogFilePathName)
    # get the log object
    logger = Logger.getLogger("")
    # remove all handlers
    for handler  in logger.getHandlers():
        logger.removeHandler(handler)
    logger = Logger.getLogger(_pyFileName)
    logger.setLevel(Level.ALL)
    # define file handler
    filehandler = FileHandler(_pyLogFilePathName,Boolean.TRUE)
    filehandler.setLevel(loglevel)
    logger.addHandler(filehandler)
    formatter = exportLogFormatter()
    filehandler.setFormatter(formatter)
    # define console handler
    consoleHandler = ConsoleHandler()
    consoleHandler.setLevel(Level.OFF)
    logger.addHandler(consoleHandler)
    return logger

_pyFileName="exportWASConfig.py"
logger=initlog()
DS_PROPERTY_FILE_NAME="exportDS.properties"
CF_PROPERTY_FILE_NAME="exportCF.properties"
AS_PROPERTY_FILE_NAME="exportAS.properties"
JDBCPROVIDER_PROPERTY_FILE_NAME="exportJDBCProvider.properties"
JMSPROVIDER_PROPERTY_FILE_NAME="exportJMSProvider.properties"
AO_PROPERTY_FILE_NAME="exportAO.properties"
AA_PROPERTY_FILE_NAME="exportAlias.properties"
NS_PROPERTY_FILE_NAME="exportNameSpaceBinding.properties"
SSL_PROPERTY_FILE_NAME="exportSSL.properties"
#--------------------------------------------------------------
# Helper Class to convert string to list
#--------------------------------------------------------------
def wsadminToList(inlist):
    method="wsadminToList"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input string="+str(inlist))
    outList=[]
    if (len(inlist) > 0):
        if (inlist[0] == '[' and inlist[len(inlist) - 1] == ']'):
            # Special checking when the config name contain space 
            if (inlist[1] == "\"" and inlist[len(inlist)-2] == "\""):
                clist = inlist[1:len(inlist) -1].split(")\" ")
            else:
                clist = inlist[1:len(inlist) - 1].split(" ")
        else:
            clist = inlist.split(System.getProperty("line.separator"))

        for elem in clist:
            elem = elem.rstrip();   #removes any Windows "\r"
            if (len(elem) > 0):
                if (elem[0] == "\"" and elem[len(elem) -1] != "\""):
                    elem = elem+")\""
                outList.append(elem)
    logger.logp(Level.INFO, _pyFileName, method, "after convert="+str(outList))
    logger.exiting(_pyFileName, method)
    return outList
#endDef

#--------------------------------------------------------------
# Helper to fetch object ID from object string
#--------------------------------------------------------------
def extractFileName(objectID):
    method="extractFileName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "obj id="+str(objectID))
    fileName = None
    regexp = re.compile('.*xml#(.*_[0-9]+).*')
    match = re.match(regexp,objectID)
    if(match != None):
        fileName = str(match.group(1))
    else:
        logger.logp(Level.WARNING, _pyFileName, method, "File name not found in " + str(objectID))
        print "WARNING: File name not found in " + str(objectID)
    logger.logp(Level.INFO, _pyFileName, method, "file name="+str(fileName))
    logger.exiting(_pyFileName, method)
    return str(fileName) 

#--------------------------------------------------------------
# Append to target list
#--------------------------------------------------------------
def wsadminAppendList(inList, inStr):
    method="wsadminAppendList"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "list="+str(inList) + ", candidate="+str(inStr))
    if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
        tmpList = inStr[1:-1].split() #splits space-separated lists,
    else:
        tmpList = inStr.split("\n")   #splits for Windows or Linux
    for item in tmpList:
        item = item.rstrip()         #removes any Windows "\r"
        if (len(item)>0):
            inList.append(item)
    logger.logp(Level.INFO, _pyFileName, method, "after append to list="+str(inList))
    logger.exiting(_pyFileName, method)
    return inList
#endDef

#------------------------------------------------------------------------------
# get the scope ID according to cellname, nodename, servername, clustername
#------------------------------------------------------------------------------
def getScopeId(cellName,nodeName,serverName,clusterName):
    method="getScopeId"
    logger.entering(_pyFileName, method)  
    logger.logp(Level.INFO, _pyFileName, method, "cellName="+str(cellName) + ", nodeName="+str(nodeName)+ ", serverName="+str(serverName)+ ", clusterName="+str(clusterName))
    scopeId=None
    if (cellName == None):
        logger.logp(Level.FINER, _pyFileName, method, "cell name is None.")
        scopeId=None
    elif (nodeName ==None):
        if(clusterName == None):
            logger.logp(Level.FINER, _pyFileName, method, "both node name and cluster name are None.")
            scopeId=AdminConfig.getid('/Cell:' + cellName)
        else:
            scopeId=AdminConfig.getid('/Cell:' + cellName + '/ServerCluster:' + clusterName)
    elif (serverName == None and clusterName == None):
        scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' + nodeName)
    elif (serverName == None):
        scopeId=AdminConfig.getid('/Cell:' + cellName + '/ServerCluster:' + clusterName)
    else:
        scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' +nodeName + '/Server:' + serverName)   
    logger.logp(Level.INFO, _pyFileName, method, "scope id="+str(scopeId))
    logger.exiting(_pyFileName, method)
    return scopeId
#endDef

#------------------------------------------------------------------------------
# get the scopes according to scopeId
#------------------------------------------------------------------------------
def deScopeId(scopeId,cellOnly):
    method="deScopeId"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "scope id="+str(scopeId))
    scopeString = ""
    if(scopeId):
        subScopeId = scopeId[scopeId.find("(")+1:scopeId.find("|")]
        scopes=subScopeId.split("/")
        scopeString =""
        index=0
        while(index < len(scopes)):
            if not scopeString:
                scopeString = scopes[index]+":"+scopes[index+1]
            else:
                scopeString= scopeString +","+ scopes[index]+":"+scopes[index+1]
            index=index+2 
        if scopeString and len(scopeString.split(",")) == 1 and cellOnly=="false":
            scopeString = "All scope"
    logger.logp(Level.INFO, _pyFileName, method, "after de-scoping id="+str(scopeString))
    logger.exiting(_pyFileName, method)
    return scopeString
#endDef

#------------------------------------------------------------------------------
# clean up object ID list to make sure only cell scope objects will be kept
#------------------------------------------------------------------------------
def eliminateNoneCellScopeObject(objectIdList):
    method="eliminateNoneCellScopeObject"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "original list ="+str(objectIdList))
    freshObjectList=[]
    if(objectIdList):
        logger.logp(Level.FINE, _pyFileName, method, "looping object list")
        for objectId in objectIdList:
            subScopeId = objectId[objectId.find("(")+1:objectId.find("|")]
            scopes=subScopeId.split("/")
            if(len(scopes) == 2):
                logger.logp(Level.INFO, _pyFileName, method, "appending to list:"+str(objectId))
                freshObjectList.append(objectId)
    logger.logp(Level.INFO, _pyFileName, method, "after removing non cell scope objects:"+str(freshObjectList))
    logger.exiting(_pyFileName, method)
    return freshObjectList

#------------------------------------------------------------------------------
# clean up object ID list to make sure only node scope objects will be kept 
# when scope was set to node scope
#------------------------------------------------------------------------------
def eliminateServerScopeObject(objectIdList):
    method="eliminateServerScopeObject"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "original list ="+str(objectIdList))
    freshObjectList=[]
    if(objectIdList):
        logger.logp(Level.FINE, _pyFileName, method, "looping object list")
        for objectId in objectIdList:
            subScopeId = objectId[objectId.find("(")+1:objectId.find("|")]
            scopes=subScopeId.split("/")
            if(len(scopes) == 4 and len(scopes) != 6 and scopes[2]=="nodes"):
                logger.logp(Level.INFO, _pyFileName, method, "appending to list:"+str(objectId))
                freshObjectList.append(objectId)
    logger.logp(Level.INFO, _pyFileName, method, "after removing non cell scope objects:"+str(freshObjectList))
    logger.exiting(_pyFileName, method)
    return freshObjectList

#------------------------------------------------------------------------------
# Handle parsed parameter for specifying scope
#------------------------------------------------------------------------------
def pasrseParam(params):
    method="pasrseParam"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "parameters list ="+str(params))
    result = {}
    index = 0
    while(index < len(params)):
        result[params[index]] = params[index+1]
        index = index + 2
    logger.logp(Level.INFO, _pyFileName, method, "after parsing:"+str(result))
    logger.exiting(_pyFileName, method)
    return result

#-----------------------------------------------------------------------------
# get the cell name
#-----------------------------------------------------------------------------
def getCellName():
    method="getCellName"
    logger.entering(_pyFileName, method)
    cellList = wsadminToList(AdminConfig.list('Cell'))
    cellName = AdminConfig.showAttribute(cellList[0],'name')
    logger.logp(Level.INFO, _pyFileName, method, "cellName: "+str(cellName))
    logger.exiting(_pyFileName, method)
    return cellName 

#------------------------------------------------------------------------------
# Exclude data source
#------------------------------------------------------------------------------
def excludeDSByJndi(jndiName):
    method="excludeDSByJndi"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input jndi: "+str(jndiName))
    dsJndiArray=["jdbc/DefaultEJBTimerDataSource","OTiSDataSource"]
    excluded="false"
    if(jndiName==None or jndiName ==""):
        excluded="true"
    else:
        for jndi in dsJndiArray:
            if(jndi == jndiName):
                excluded="true"
    logger.logp(Level.INFO, _pyFileName, method, "excluded? "+str(excluded))
    logger.exiting(_pyFileName, method)
    return excluded

#------------------------------------------------------------------------------
# Exclude JDBC provider 
#------------------------------------------------------------------------------
def excludeJDBCProviderByImplClassName(implClassName):
    method="excludeJDBCProviderByImplClassName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input class name: "+str(implClassName))
    # Only provider implementation class name in this array should be exported
    implClassNameArray=["com.microsoft.sqlserver.jdbc.SQLServerXADataSource","com.microsoft.sqlserver.jdbc.SQLServerConnectionPoolDataSource","oracle.jdbc.xa.client.OracleXADataSource","com.ibm.db2.jcc.DB2XADataSource","com.ibm.db2.jcc.DB2ConnectionPoolDataSource","oracle.jdbc.pool.OracleConnectionPoolDataSource"]
    excluded="true"
    if(implClassName==None or implClassName ==""):
        excluded="true"
    else:
        for _implClassName in implClassNameArray:
            if(implClassName == _implClassName):
                excluded="false"
                break
    logger.logp(Level.INFO, _pyFileName, method, "excluded? "+str(excluded))
    logger.exiting(_pyFileName, method)
    return excluded

#------------------------------------------------------------------------------
# Exclude JMS provider 
#------------------------------------------------------------------------------
def excludeJMSProvider(jmsProviderId):
    method="excludeJMSProvider"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input provider id: "+str(jmsProviderId))
    excludeRegx='(.xml#builtin)'    
    excluded="false"
    if(jmsProviderId==None or jmsProviderId ==""):
        excluded="true"
    else:
        result=re.compile(excludeRegx).search(jmsProviderId)
        if(result!=None):
            excluded="true"
    logger.logp(Level.INFO, _pyFileName, method, "excluded? "+str(excluded))
    logger.exiting(_pyFileName, method)
    return excluded

#----------------------------------------------------------------------------
# Get certain attribute names from given object
#-----------------------------------------------------------------------------
def getAttributeFromObj(objType, attrName):
    method="getAttributeFromObj"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input obj type"+str(objType)+", and attr name: "+str(attrName))
    attrList=AdminConfig.attributes(objType)
    attr=None
    for _attr in wsadminToList(attrList):
        offsetOfFirstSpace = _attr.find(" ")
        attributeName = _attr[0:offsetOfFirstSpace]
        if(attributeName==attrName):
            attr=attributeName
            break
    logger.logp(Level.INFO, _pyFileName, method, "attribute names= "+str(attr))
    logger.exiting(_pyFileName, method)
    return attr

#------------------------------------------------------------------------------
# Check the output dir whether its exists or the certain property file
# already exists. for export all action, if this directory already contains the
# same WAS object property file, the action should be ended.
#------------------------------------------------------------------------------
def exportPrecheck(outputDir, propertyFileName):
    method="exportPrecheck"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(outputDir) +", " + str(propertyFileName))
    existed="false"
    # if the output directory does not exist, create it
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    # if the output directory already exist, check the property file exists or not
    else:
        if os.path.isdir(outputDir):
            for fileName in os.listdir(outputDir):
                if fileName == propertyFileName:
                    existed="true"
                    break
        else:
            print "ERROR: Input output directory "+str(outputDir) +" is a file, choose a correct one."
            print "**************************************" 
            logger.logp(Level.SEVERE, _pyFileName, method, "Input output directory "+str(outputDir) +" is a file, choose a correct one.")
            sys.exit()
    logger.logp(Level.INFO, _pyFileName, method, "Export precheck returns " + str(existed)) 
    logger.exiting(_pyFileName, method)
    return existed

#------------------------------------------------------------------------------
# Check whether the object already been exported using keyValue1, keyValue2
# normally, the keyvalue1 is 'name' or 'jndiName'
#           the keyValue2 is 'scopeId'
# 'true' means already been exported
# 'false' means NOT been exported
#------------------------------------------------------------------------------
def checkObjectExported(sumPropertyFile, keyValue1, keyValue2):
    method="checkObjectExported"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(sumPropertyFile) +", " + str(keyValue1)+", " +str(keyValue2))
    exported="false"
    if sumPropertyFile and os.path.exists(sumPropertyFile) and sumPropertyFile.endswith(".properties") and keyValue1:
        propsFile = Properties()
        inputSream = FileInputStream(sumPropertyFile)
        propsFile.load(inputSream)
        logger.logp(Level.FINER, _pyFileName, method, "existed property iterm number is:"+str(propsFile.keySet().size()))
        for propertyName in propsFile.keySet():
            propertyValue=str(propsFile.getProperty(propertyName, "none")).strip()
            # firstly, we need to find out the target property name, maybe more than one
            if propertyValue == keyValue1:
                # if keyValue2 is not set value, only checking keyValue1 is okay
                if not keyValue2:
                    exported = "true"
                    logger.logp(Level.FINER, _pyFileName, method, "the target WebSphere Application Server object has been exported.")
                    break
                # get the property name prefix
                propertyNamePrefix=propertyName[0: propertyName.rfind(".")+1]
                subSumProperties = getSubSumProperties(propsFile, propertyNamePrefix)
                subSumPropertyValues=subSumProperties.values()
                if subSumPropertyValues.contains(keyValue1) and subSumPropertyValues.contains(keyValue2):
                    exported = "true"
                    logger.logp(Level.FINER, _pyFileName, method, "the target WebSphere Application Server object has been exported.")
                    break
        inputSream.close()
    logger.logp(Level.INFO, _pyFileName, method, "Export checking returns " + str(exported)) 
    logger.exiting(_pyFileName, method)
    return exported

def getSubSumProperties(propsFile, propertyNamePrefix):
    method="getSubSumProperties"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(propertyNamePrefix))
    subProps = Properties()
    if propertyNamePrefix and propsFile and propsFile.keySet().size() > 0:
        for key  in propsFile.keySet():
            if key.startswith(propertyNamePrefix):
                subProps.setProperty(key, propsFile.getProperty(key))
    logger.logp(Level.INFO, _pyFileName, method, "get sub-properties returns " + str(subProps)) 
    logger.exiting(_pyFileName, method)
    return subProps

#------------------------------------------------------------------------------
# Export all databases under specified scope
#------------------------------------------------------------------------------
def exportAllDataSources(outputFilePath,scopeId, cellOnly,nodeOnly):
    method="exportAllDataSources"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputFilePath, DS_PROPERTY_FILE_NAME)
    dataSourceList=AdminConfig.list("DataSource",scopeId)
    dataSources = wsadminToList(dataSourceList)
    # for cell-only scope, we need to remove other scopes, since if the cell scope is specified, the data sources in all scopes will be exported
    if(cellOnly == "true"):
        dataSources=eliminateNoneCellScopeObject(dataSources)
    if(nodeOnly == "true"):
        dataSources=eliminateServerScopeObject(dataSources)
    logger.logp(Level.FINE, _pyFileName, method, "data source list: "+str(nodeOnly))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath,DS_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    hasValidDs = "false" 
    print "**************************************"
    if(len(dataSources) > 0):
        for ds in dataSources:
            logger.logp(Level.INFO, _pyFileName, method, "looping data sources.")
            fileName = extractFileName(ds)      
            logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
            jndiName=AdminConfig.showAttribute(ds,"jndiName")
            if(excludeDSByJndi(jndiName)=="true"):
                logger.logp(Level.FINE, _pyFileName, method, "excluded jndi="+str(jndiName))
                continue
            if(jndiName):
                hasValidDs="true"
                findex = ds.rfind("(")
                lindex = ds.find("resources.xml#")
                scopeIdInSrc = ds[findex+1:lindex-1]
                if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                    logger.logp(Level.INFO, _pyFileName, method, "Skip to export data source "  + str(jndiName) + " since it was already exported.")
                    print "INFO:Skip to export data source "  + str(jndiName) + " since it was already exported."
                    print
                    continue
                outputObjFileName = os.path.join(outputFilePath,fileName + ".obj")
                logger.logp(Level.INFO, _pyFileName, method, "About to export properties of data source with JNDI " + str(jndiName))
#               exportDataSource(ds,outputPropFileName)
                exportObj(ds,outputObjFileName)
                sumPropertyFile.write("#Exported Data Source Object with JNDI name -- " + str(jndiName) + "\n")
                sumPropertyFile.write(jndiName +"."+str(index)+ ".ObjectFileName=" + str(fileName)+".obj\n")
                sumPropertyFile.write(jndiName +"."+str(index)+ ".ObjectType=DataSource\n")
                sumPropertyFile.write(jndiName +"."+str(index)+ ".ScopeId="+str(scopeIdInSrc)+"\n")
                sumPropertyFile.write(jndiName +"."+str(index)+ ".JNDIName="+str(jndiName)+"\n")
                jdbcProvider = AdminConfig.showAttribute(ds,"provider")
                logger.logp(Level.FINE, _pyFileName, method, "jdbc provider="+str(jdbcProvider))
                if(jdbcProvider != None):
                    sumPropertyFile.write(jndiName +"."+str(index)+ ".Provider=" + str(AdminConfig.showAttribute(jdbcProvider,"name")) + "\n")   
                    sumPropertyFile.write(jndiName +"."+str(index)+ ".ProviderType=" + str(AdminConfig.showAttribute(jdbcProvider,"providerType")) + "\n")
                resourceAdapter = AdminConfig.showAttribute(ds,"relationalResourceAdapter")
                logger.logp(Level.FINE, _pyFileName, method, "resourceAdapter="+str(resourceAdapter))
                if(resourceAdapter != None):
                    sumPropertyFile.write(jndiName  +"."+str(index)+ ".ResourceAdapter=" + str(AdminConfig.showAttribute(resourceAdapter,"name")) + "\n\n")
                index=index+1           
                logger.logp(Level.INFO, _pyFileName, method, "Data source with JNDI name "  + str(jndiName) + " was exported to file " + DS_PROPERTY_FILE_NAME + " and " + fileName + ".obj under " + outputFilePath)
                print "INFO:Data source with JNDI name "  + str(jndiName) + " was exported to file " + DS_PROPERTY_FILE_NAME + " and " + fileName + ".obj under " + outputFilePath
                print
        if(hasValidDs == "true"):
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + outputPropFile + " for the export summary.")
            print "INFO:Check file " + outputPropFile + " for the export summary."
    if(hasValidDs == "false"):
        print "INFO:No datas ource was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No data source was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Get bus name from Obj
#------------------------------------------------------------------------------
def getBusNameFromJ2EEPropertySet(obj, objType):
    method="getBusNameFromJ2EEPropertySet"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " +str(obj)+", "+str(objType))
    j2EEObjTypeList=["J2CConnectionFactory", "J2CActivationSpec","J2CAdminObject"]
    resourcePropertyType="J2EEResourceProperty"
    busNameValue=""
    isValidJ2EEType="false"
    for j2EEObjType in j2EEObjTypeList:
        if(j2EEObjType == objType):
            isValidJ2EEType="true"
            break
    logger.logp(Level.INFO, _pyFileName, method, "is valid JEE object type? " +str(isValidJ2EEType))
    if(isValidJ2EEType=="true"):
        resourcePropertyList=AdminConfig.list(resourcePropertyType,obj)
        logger.logp(Level.FINE, _pyFileName, method, "resourcePropertyList: " +str(resourcePropertyList))
        if(len(resourcePropertyList)>0):
            for resourceProperty in wsadminToList(resourcePropertyList):
                propertyName= AdminConfig.showAttribute(resourceProperty, "name")
                if(propertyName=="BusName" or propertyName=="busName"):
                    busNameValue=AdminConfig.showAttribute(resourceProperty, "value")
                    break
    logger.logp(Level.INFO, _pyFileName, method, "bus name: " +str(busNameValue))
    logger.exiting(_pyFileName, method)
    return busNameValue

def isJmsConnectionFactory(cfImplCls):
    method="isJmsConnectionFactory"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameter: " +str(cfImplCls))
    jmsConnectoryFactoryClsList = ['com.ibm.ws.sib.api.jms.impl.JmsTopicConnFactoryImpl',\
                            'com.ibm.ws.sib.api.jms.impl.JmsConnFactoryImpl',\
                            'com.ibm.ws.sib.api.jms.impl.JmsQueueConnFactoryImpl'
                            ]
    isCorrect="false"
    if cfImplCls:
        for cls in jmsConnectoryFactoryClsList:
            if cls == cfImplCls:
                isCorrect="true"
                break
    logger.logp(Level.INFO, _pyFileName, method, "is jms connection factory? " +str(isCorrect))
    logger.exiting(_pyFileName, method)
    return isCorrect

def isJmsActivationSpec(asCls):
    method="isJmsActivationSpec"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameter: " +str(asCls))
    jmsActivationSpecClsList = ['com.ibm.ws.sib.api.jmsra.impl.JmsJcaActivationSpecImpl',\
                            'com.ibm.mq.connector.inbound.ActivationSpecImpl'
                            ]
    isCorrect="false"
    if asCls:
        for cls in jmsActivationSpecClsList:
            if cls == asCls:
                isCorrect="true"
                break
    logger.logp(Level.INFO, _pyFileName, method, "is jms activation specification? " +str(isCorrect))
    logger.exiting(_pyFileName, method)
    return isCorrect

def isJmsAo(aoCls):
    method="isJmsAo"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameter: " +str(aoCls))
    jmsAdminObjectClsList = ['com.ibm.ws.sib.api.jms.impl.JmsTopicImpl',\
                            'com.ibm.ws.sib.api.jms.impl.JmsQueueImpl'
                            ]
    isCorrect="false"
    if aoCls:
        for cls in jmsAdminObjectClsList:
            if cls == aoCls:
                isCorrect="true"
                break
    logger.logp(Level.INFO, _pyFileName, method, "is JMS queue or topic? " +str(isCorrect))
    logger.exiting(_pyFileName, method)
    return isCorrect

def listConnectionFactories():
    method="listConnectionFactories"
    logger.entering(_pyFileName, method)
    cfType= "J2CConnectionFactory"
    cfList=AdminConfig.list(cfType)
    cfs = wsadminToList(cfList)
    index = 1
    print "**************************************"
    print "Connection factory configuration list:"
    if(len(cfs) > 0):
        index=1
        logger.logp(Level.INFO, _pyFileName, method, "looping connection factory list.")
        for cf in cfs:   
            jndiName=AdminConfig.showAttribute(cf,"jndiName")
            logger.logp(Level.FINE, _pyFileName, method, "jndiName="+str(jndiName))      
            if(jndiName):
                #fetch ConnectionDefinition connectionFactoryImplClass attr
                connFactoryDef=AdminConfig.showAttribute(cf,"connectionDefinition")
                #some built-in connection factories have no connection definitions, so do not export these connection factories 
                if(connFactoryDef is None):
                    logger.logp(Level.FINE, _pyFileName, method, "connFactory definition="+str(connFactoryDef))      
                    continue
                connFactoryInterCls=AdminConfig.showAttribute("ConnectionDefinition"+connFactoryDef, "connectionFactoryImplClass")
                if isJmsConnectionFactory(connFactoryInterCls) == "false":
                    logger.logp(Level.FINE, _pyFileName, method, "connFactory interface class="+str(connFactoryInterCls))   
                    continue
                findex = cf.rfind("(")
                lindex = cf.find("resources.xml#")
                scopeId = cf[findex+1:lindex-1]
                cfName=AdminConfig.showAttribute(cf,"name")
                jndiName=AdminConfig.showAttribute(cf,"jndiName")
                logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+str(cfName)+ " Scope:"+str(scopeId)+"\nJNDI:"+str(jndiName))
                print index,"\nName:",cfName,"\nScope:",scopeId,"\nJNDI:",jndiName
                index = index + 1
    else:
        print "INFO: No connection factory configuration was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export all connection factories under specified scope
#------------------------------------------------------------------------------
def exportAllCFs(outputFilePath,scopeId, cellOnly,nodeOnly):
    method="exportAllCFs"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(outputFilePath) + ", "+str(scopeId)+ ", "+str(cellOnly)+ ", "+str(nodeOnly))      
    propertyFileExists=exportPrecheck(outputFilePath, CF_PROPERTY_FILE_NAME)
    cfType= "J2CConnectionFactory"
    cfList=AdminConfig.list(cfType,scopeId)
    cfs = wsadminToList(cfList)
    if(cellOnly == "true"):
        cfs=eliminateNoneCellScopeObject(cfs)
    if(nodeOnly == "true"):
        cfs=eliminateServerScopeObject(cfs)
    # determin how to export WAS object to file system, create a new property file or append to an existed property file    
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath,CF_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    hasValidCF = "false"  
    print "**************************************"
    if(len(cfs) > 0):
        logger.logp(Level.INFO, _pyFileName, method, "looping connection factory list.")
        for cf in cfs:       
            fileName = extractFileName(cf) 
            logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
            jndiName=AdminConfig.showAttribute(cf,"jndiName")      
            if(jndiName):
                #fetch ConnectionDefinition connectionFactoryImplClass attr
                connFactoryDef=AdminConfig.showAttribute(cf,"connectionDefinition")
                #some built-in connection factories have no connection definitions, so do not export these connection factories 
                logger.logp(Level.FINE, _pyFileName, method, "connFactory definition="+str(connFactoryDef))
                if(connFactoryDef is None):
                    continue
                connFactoryInterCls=AdminConfig.showAttribute("ConnectionDefinition"+connFactoryDef, "connectionFactoryImplClass")
                logger.logp(Level.FINE, _pyFileName, method, "connFactory interface class="+str(connFactoryInterCls))   
                if isJmsConnectionFactory(connFactoryInterCls) == "false":
                    continue
                hasValidCF="true"
                findex = cf.rfind("(")
                lindex = cf.find("resources.xml#")
                scopeIdInSrc = cf[findex+1:lindex-1]
                # check whether this connection factory object has already been exported
                if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                    logger.logp(Level.INFO, _pyFileName, method, "Skip to export JMS connection factory "  + str(jndiName) + " since it was already exported.")
                    print "INFO:Skip to export JMS connection factory "  + str(jndiName) + " since it was already exported."
                    print
                    continue
                #fetch bus name
                busName=getBusNameFromJ2EEPropertySet(cf,cfType)
                outputObjFile = os.path.join(outputFilePath,fileName + ".obj")
                logger.logp(Level.INFO, _pyFileName, method, "About to export properties of connection factory with JNDI name " + str(jndiName))
                exportObj(cf,outputObjFile)
                sumPropertyFile.write("#Exported "+cfType+" with JNDI name -- " + jndiName + "\n")
                sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
                sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectType="+cfType+"\n")
                sumPropertyFile.write(jndiName +"."+ str(index) +".Provider=" + str(AdminConfig.showAttribute(cf,"provider")) + "\n")
                sumPropertyFile.write(jndiName +"."+ str(index) +".BusName=" + busName + "\n")
                sumPropertyFile.write(jndiName +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n")
                sumPropertyFile.write(jndiName +"."+str(index)+ ".JNDIName="+jndiName+"\n")
                sumPropertyFile.write(jndiName +"."+ str(index) +".ConnectionFactoryImplClass=" + connFactoryInterCls + "\n\n")
                print "INFO: JMS connection factory with JNDI name "  + jndiName + " was exported to file " + outputObjFile + "."
                print
                index=index+1
    if(hasValidCF == "true"):
        print "INFO:Check file " + outputPropFile + " for the export summary."
    else:
        print "INFO:No JMS connection factory was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No JMS connection factory was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

def listActivationSpecs():
    method="listActivationSpecs"
    logger.entering(_pyFileName, method)
    asType="J2CActivationSpec"
    raType="J2CResourceAdapter"   
    raList=AdminConfig.list(raType)
    raes = wsadminToList(raList)
    print "**************************************"
    print "Activation specification list:"
    if(len(raes) > 0):
        index=1
        logger.logp(Level.INFO, _pyFileName, method, "looping activation specifications")   
        for ra in raes:
            asList=AdminConfig.list(asType,ra)
            ases = wsadminToList(asList)
            if(len(ases) > 0):       
                for _as in ases:
                    fileName = extractFileName(_as) 
                    logger.logp(Level.INFO, _pyFileName, method, "Output file name:" + str(fileName))
                    jndiName=AdminConfig.showAttribute(_as,"jndiName")
                    logger.logp(Level.INFO, _pyFileName, method, "JNDI name="+str(jndiName))   
                    if not jndiName:
                        continue
                    #fetch ConnectionDefinition connectionFactoryImplClass attr
                    asDef=AdminConfig.showAttribute(_as,"activationSpec")
                    asInterCls=AdminConfig.showAttribute("ActivationSpec"+asDef, "activationSpecClass")
                    logger.logp(Level.INFO, _pyFileName, method, "activationSpec activationSpecClass="+str(asInterCls))   
                    if isJmsActivationSpec(asInterCls) == "false":
                        continue
                    findex = _as.rfind("(")
                    lindex = _as.find("resources.xml#")
                    scopeId = _as[findex+1:lindex-1]
                    asName=AdminConfig.showAttribute(_as,"name")
                    jndiName=AdminConfig.showAttribute(_as,"jndiName")
                    logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+str(asName)+" Scope:"+str(scopeId)+"JNDI:"+str(jndiName)) 
                    print index,"\nName:",asName,"\nScope:",scopeId,"\nJNDI:",jndiName
                    index = index + 1
    else:
        print "INFO: No activation specification was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export all activation specifications under specified scope
#------------------------------------------------------------------------------
def exportAllASes(outputFilePath,scopeId,cellOnly,nodeOnly):
    method="exportAllASes"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(outputFilePath) + ", "+str(scopeId)+ ", "+str(cellOnly)+ ", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputFilePath, AS_PROPERTY_FILE_NAME)
    asType="J2CActivationSpec"
    raType="J2CResourceAdapter"   
    raList=AdminConfig.list(raType,scopeId)
    raes = wsadminToList(raList)
    if(cellOnly == "true"):
        raes=eliminateNoneCellScopeObject(raes)
    if(nodeOnly == "true"):
        raes=eliminateServerScopeObject(raes)
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath,AS_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    hasValidAS="false"
    print "**************************************"
    if(len(raes) > 0):
        logger.logp(Level.INFO, _pyFileName, method, "looping resource adapter") 
        for ra in raes:
            asList=AdminConfig.list(asType,ra)
            ases = wsadminToList(asList)
            raName=str(AdminConfig.showAttribute(ra,"name"))
            if(len(ases) > 0):
                logger.logp(Level.INFO, _pyFileName, method, "looping activation spec") 
                for _as in ases:
                    fileName = extractFileName(_as)
                    logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))   
                    jndiName=AdminConfig.showAttribute(_as,"jndiName")
                    logger.logp(Level.INFO, _pyFileName, method, "JNDI name="+str(jndiName))    
                    if(jndiName):
                        findex = _as.rfind("(")
                        lindex = _as.find("resources.xml#")
                        scopeIdInSrc = _as[findex+1:lindex-1]
                        outputObjFile = os.path.join(outputFilePath,fileName + ".obj")
                        #fetch ConnectionDefinition connectionFactoryImplClass attr
                        asDef=AdminConfig.showAttribute(_as,"activationSpec")
                        asInterCls=AdminConfig.showAttribute("ActivationSpec"+asDef, "activationSpecClass")
                        logger.logp(Level.INFO, _pyFileName, method, "activation specification interface class="+str(asInterCls))
                        if isJmsActivationSpec(asInterCls) == "false":
                            continue
                        hasValidAS="true"
                        # check whether this activation specification object has already been exported
                        if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                            logger.logp(Level.INFO, _pyFileName, method, "Skip to export JMS activation specification "  + str(jndiName) + " since it was already exported.")
                            print "INFO:Skip to export JMS activation specification "  + str(jndiName) + " since it was already exported."
                            print
                            continue
                        #fetch bus name
                        busName=getBusNameFromJ2EEPropertySet(_as,asType)
                        logger.logp(Level.FINE, _pyFileName, method, "About to export properties of activiation specification with JNDI name " + str(jndiName)) 
                        exportObj(_as,outputObjFile)
                        sumPropertyFile.write("#Exported "+asType+" Object with JNDI name -- " + jndiName + "\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".AdapterName="+raName+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ActivationSpec="+asInterCls+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".BusName=" + busName + "\n")
                        sumPropertyFile.write(jndiName +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n")
                        sumPropertyFile.write(jndiName +"."+str(index)+ ".JNDIName="+jndiName+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectType="+asType+"\n\n")
                        logger.logp(Level.INFO, _pyFileName, method, "JMS activation specification  with JNDI name " + str(jndiName) + " was exported to file " + str(outputObjFile) + ".")
                        print "INFO: JMS activation specification  with JNDI name " + str(jndiName) + " was exported to file " + str(outputObjFile) + "."
                        print
                        index=index+1
    if(hasValidAS == "true"):
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + outputPropFile + " for the export summary.")
        print "INFO:Check file " + outputPropFile + " for the export summary."  
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No JMS activation specification was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
        print "INFO: No JMS activation specification was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."   
        sumPropertyFile.write("#No JMS activation specification was found in scope:"+str(deScopeId(scopeId,cellOnly))+".") 
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

def listJDBCProviders():
    method="listJDBCProviders"
    logger.entering(_pyFileName, method)
    jdbcProviderType="JDBCProvider"
    providerList=AdminConfig.list(jdbcProviderType)
    providers = wsadminToList(providerList)
    logger.logp(Level.FINE, _pyFileName, method, "JDBC provider list:"+str(providers))
    index = 1
    print "**************************************"
    print "JDBC Provider list:"
    if len(providers) > 0:
        logger.logp(Level.INFO, _pyFileName, method, "looping data source list.")
        for provider in providers:
            providerImplClassName=AdminConfig.showAttribute(provider, "implementationClassName")
            providerName=AdminConfig.showAttribute(provider, "name")
            logger.logp(Level.INFO, _pyFileName, method, "JDBC provider name:"+str(providerName))
            if(excludeJDBCProviderByImplClassName(providerImplClassName)=="true"):
                #print "This JDBC provider["+providerName+"] is not supported for export."
                continue
            findex = provider.rfind("(")
            lindex = provider.find("resources.xml#")
            scopeId = provider[findex+1:lindex-1]
            logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+str(providerName)+" Scope:"+str(scopeId))
            print index,"\nName:",providerName,"\nScope:",scopeId
            index = index + 1
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No JDBC Provider was found.")
        print "INFO: No JDBC Provider was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)
    
#------------------------------------------------------------------------------
# Export all JDBC providers under the specified scope for certain provider types; 
# refer to method "excludeJDBCProviderByImplClassName"
#------------------------------------------------------------------------------
def exportAllJDBCProviders(outputFilePath,scopeId,cellOnly,nodeOnly):
    method="exportAllJDBCProviders"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    jdbcProviderType="JDBCProvider"
    propertyFileExists=exportPrecheck(outputFilePath, JDBCPROVIDER_PROPERTY_FILE_NAME)
    providerList=AdminConfig.list(jdbcProviderType,scopeId)
    providers = wsadminToList(providerList)
    if(cellOnly == "true"):
        providers=eliminateNoneCellScopeObject(providers)
    if(nodeOnly == "true"):
        providers=eliminateServerScopeObject(providers)
    logger.logp(Level.FINE, _pyFileName, method, "JDBC provider list:"+str(providers))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath,JDBCPROVIDER_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    hasValidProvider="false"
    print "**************************************"     
    if(len(providers) > 0):
        for provider in providers:
            providerImplClassName=AdminConfig.showAttribute(provider, "implementationClassName")
            providerName=AdminConfig.showAttribute(provider, "name")
            logger.logp(Level.INFO, _pyFileName, method, "JDBC provider name:"+str(providerName))
            if(excludeJDBCProviderByImplClassName(providerImplClassName)=="true"):
                #print "This JDBC provider["+providerName+"] is not supported for export."
                continue
            hasValidProvider="true"
            findex = provider.rfind("(")
            lindex = provider.find("resources.xml#")
            scopeIdInSrc = provider[findex+1:lindex-1]
            # check whether this JDBC provider object has already been exported
            if checkObjectExported(outputPropFile, providerName, scopeIdInSrc) == "true":
                logger.logp(Level.INFO, _pyFileName, method, "Skip to export JDBC provider "  + str(providerName) + " since it was already exported.")
                print "INFO:Skip to export JDBC provider "  + str(providerName) + " since it was already exported."
                print
                continue
            providerType=AdminConfig.showAttribute(provider, "providerType")
            fileName = extractFileName(provider) 
            logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
            outputObjFile = os.path.join(outputFilePath,fileName + ".obj")          
            exportObj(provider,outputObjFile)
            sumPropertyFile.write("#Exported "+jdbcProviderType+" Object\n")
            sumPropertyFile.write(jdbcProviderType +"."+str(index)+ ".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(jdbcProviderType +"."+str(index)+ ".ProviderType=" + providerType+"\n")
            sumPropertyFile.write(jdbcProviderType +"."+str(index)+ ".JDBCProviderName=" + providerName+"\n")
            sumPropertyFile.write(jdbcProviderType +"."+str(index)+ ".ObjectType="+jdbcProviderType+"\n")
            sumPropertyFile.write(jdbcProviderType +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n")
            index=index+1
            logger.logp(Level.INFO, _pyFileName, method, str(jdbcProviderType)+" with provider name " + str(providerName) + " was exported to file " + str(outputObjFile) + ".")
            print "INFO: "+str(jdbcProviderType)+" with provider name " + str(providerName) + " was exported to file " + str(outputObjFile) + "."
            print
    if(hasValidProvider == "true"):
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
        print "INFO: Check file " + outputPropFile + " for the export summary."
    else:
        logger.logp(Level.INFO, _pyFileName, method, str(jdbcProviderType)+" was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
        print "INFO:No "+jdbcProviderType+" was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."    
        sumPropertyFile.write("#No "+jdbcProviderType+" was found in scope:"+str(deScopeId(scopeId,cellOnly))+".") 
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

def listJMSProviders():
    method="listJMSProviders"
    logger.entering(_pyFileName, method)
    jmsProviderType="JMSProvider"
    providerList=AdminConfig.list(jmsProviderType)
    providers = wsadminToList(providerList)
    logger.logp(Level.FINE, _pyFileName, method, "JMS provider list:"+str(providers))
    index = 1
    print "**************************************"
    print "JMS Provider list:"
    if len(providers) > 0:
        for provider in providers:
            providerName=AdminConfig.showAttribute(provider, "name")
            if(excludeJMSProvider(provider)=="true"):
                #print "This JMS provider["+providerName+"] is a built-in provider and is not supported for export."
                continue
            findex = provider.rfind("(")
            lindex = provider.find("resources.xml#")
            scopeId = provider[findex+1:lindex-1]
            logger.logp(Level.INFO, _pyFileName, method, str(index)+"\nName:"+providerName+"\nScope:"+scopeId)
            print index,"\nName:",providerName,"\nScope:",scopeId
            index = index + 1
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No JMS Provider was found.")
        print "INFO: No JMS Provider was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)
    
#------------------------------------------------------------------------------
# Export all JMS providers under the specified scope for certain provider types; refer to method "excludeJMSProvider"
#------------------------------------------------------------------------------
def exportAllJMSProviders(outputFilePath,scopeId,cellOnly,nodeOnly):
    method="exportAllJMSProviders"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    jmsProviderType="JMSProvider"
    propertyFileExists=exportPrecheck(outputFilePath, JMSPROVIDER_PROPERTY_FILE_NAME)
    providerList=AdminConfig.list(jmsProviderType,scopeId)
    providers = wsadminToList(providerList)
    if cellOnly == "true":
        providers=eliminateNoneCellScopeObject(providers)
    if nodeOnly == "true":
        providers=eliminateServerScopeObject(providers)
    logger.logp(Level.FINE, _pyFileName, method, "JMS provider list:"+str(providers))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath, JMSPROVIDER_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    hasValidProvider="false"
    print "**************************************"
    if(len(providers) > 0):
        logger.logp(Level.INFO, _pyFileName, method, "looping JMS provider list.")
        for provider in providers:
            providerName=AdminConfig.showAttribute(provider, "name")
            logger.logp(Level.INFO, _pyFileName, method, "JMS provider name:"+str(providerName))
            if(excludeJMSProvider(provider)=="true"):
                #print "This JMS provider["+providerName+"] is a built-in provider and is not supported for export."
                continue
            hasValidProvider="true"
            findex = provider.rfind("(")
            lindex = provider.find("resources.xml#")
            scopeIdInSrc = provider[findex+1:lindex-1]
            # check whether this JMS provider object has already been exported
            if checkObjectExported(outputPropFile, providerName, scopeIdInSrc) == "true":
                logger.logp(Level.INFO, _pyFileName, method, "Skip to export JMS provider "  + str(providerName) + " since it was already exported.")
                print "INFO:Skip to export JMS provider "  + str(providerName) + " since it was already exported."
                print
                continue
            fileName = extractFileName(provider) 
            logger.logp(Level.FINE, _pyFileName, method,"Output file name:" + str(fileName))                  
            outputObjFile = os.path.join(outputFilePath,fileName + ".obj")          
            exportObj(provider,outputObjFile)
            sumPropertyFile.write("#Exported "+jmsProviderType+" Object\n")
            sumPropertyFile.write(jmsProviderType +"."+str(index)+ ".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(jmsProviderType +"."+str(index)+ ".JMSProviderName=" + providerName+"\n")
            sumPropertyFile.write(jmsProviderType +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n")
            sumPropertyFile.write(jmsProviderType +"."+str(index)+ ".ObjectType="+jmsProviderType+"\n\n")  
            index=index +1
            logger.logp(Level.INFO, _pyFileName, method,jmsProviderType+" with provider name " + str(providerName) + " was exported to file " + str(outputObjFile) + ".")
            print "INFO: "+jmsProviderType+" with provider name " + str(providerName) + " was exported to file " + str(outputObjFile) + "."
            print
    if(hasValidProvider == "true"):
        logger.logp(Level.INFO, _pyFileName, method,"Check file " + str(outputPropFile) + " for the export summary.")      
        print "INFO: Check file " + str(outputPropFile) + " for the export summary."
    else:
        logger.logp(Level.INFO, _pyFileName, method,"No "+str(jmsProviderType)+" was found in scope:"+str(deScopeId(scopeId,cellOnly))+"." ) 
        print "INFO:No "+str(jmsProviderType)+" was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."                   
        sumPropertyFile.write("#No "+str(jmsProviderType)+" was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)
    
#------------------------------------------------------------------------------
# List all data source names/JNDI names in all scope
#------------------------------------------------------------------------------
def listDataSources():
    method="listDataSources"
    logger.entering(_pyFileName, method)
    dataSourceList=AdminConfig.list("DataSource")
    dataSources = wsadminToList(dataSourceList)
    logger.logp(Level.FINE, _pyFileName, method, "data sources="+str(dataSources))
    index = 1
    print "**************************************"
    print "Data source list:"
    if len(dataSources) > 0:
        logger.logp(Level.INFO, _pyFileName, method,"looping data source list.") 
        for ds in dataSources:
            findex = ds.rfind("(")
            lindex = ds.find("resources.xml#")
            scopeId = ds[findex+1:lindex-1]
            dsName=AdminConfig.showAttribute(ds,"name")
            jndiName=AdminConfig.showAttribute(ds,"jndiName")
            if(excludeDSByJndi(jndiName)=="true"):
                logger.logp(Level.FINE, _pyFileName, method, "execluded data source jndi ="+str(jndiName))
                continue
            providerType=AdminConfig.showAttribute(ds,"providerType")
            logger.logp(Level.INFO, _pyFileName, method,str(index)+" Name:"+str(dsName)+" Scope:"+str(scopeId)+" JNDI:"+str(jndiName)+" ProviderType:"+str(providerType)) 
            print index,"\nName:",dsName,"\nScope:",scopeId,"\nJNDI:",jndiName,"\nProviderType:",providerType
            index = index + 1
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No data source was found.")
        print "INFO: No data source was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)
        
#------------------------------------------------------------------------------
# List all authentication aliases
#------------------------------------------------------------------------------
def listAuthAliases():
    method="listAuthAliases"
    logger.entering(_pyFileName, method)
    globalSecurity = AdminConfig.list("Security" )
    authAliases = AdminConfig.list("JAASAuthData",globalSecurity)   
    logger.logp(Level.FINE, _pyFileName, method, "auth aliases list="+str(authAliases))
    print "**************************************"
    print "Authentication alias list:"
    if len(authAliases) > 0 :
        index=1
        logger.logp(Level.FINE, _pyFileName, method, "looping auth alias list.")
        for authAlias in wsadminToList(authAliases):
            authAliasName = AdminConfig.showAttribute(authAlias,"alias")
            logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+ str(authAliasName))
            print index, "\nName:",authAliasName
            index=index+1
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No authentication alias was found.")
        print "INFO: No authentication alias was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export data source by JNDI name in specified scope
#------------------------------------------------------------------------------            
def exportDataSourceByJNDI(dsJNDI,outputFilePath,scopeId,cellOnly,nodeOnly):    
    method="exportDataSourceByJNDI"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(dsJNDI) +", "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+","+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputFilePath, DS_PROPERTY_FILE_NAME)
    dataSourceList=AdminConfig.list("DataSource",scopeId)
    dataSources = wsadminToList(dataSourceList)
    if cellOnly == "true":
        dataSources=eliminateNoneCellScopeObject(dataSources)
    if nodeOnly == "true":
        dataSources=eliminateServerScopeObject(dataSources)
    logger.logp(Level.FINE, _pyFileName, method, "datasource list:"+str(dataSources))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath, DS_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    found = "false" 
    print "**************************************"
    logger.logp(Level.INFO, _pyFileName, method, "looping datasource.")
    for datasource in dataSources:        
        fileName = extractFileName(datasource) 
        jndiName=AdminConfig.showAttribute(datasource,"jndiName")
        logger.logp(Level.INFO, _pyFileName, method, "jndi name="+str(jndiName))
        if(excludeDSByJndi(jndiName)=="true"):
            continue
        if (jndiName != None and jndiName == dsJNDI):
            found = "true"     
            findex = datasource.rfind("(")
            lindex = datasource.find("resources.xml#")
            scopeIdInSrc = datasource[findex+1:lindex-1]
            if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                logger.logp(Level.INFO, _pyFileName, method, "Skip to export data source "  + str(jndiName) + " since it was already exported.")
                print "INFO:Skip to export data source "  + str(jndiName) + " since it was already exported."
                print
                continue
            outputObjFileName = os.path.join(outputFilePath,fileName + ".obj")           
            exportObj(datasource,outputObjFileName)
            sumPropertyFile.write("#Exported Data Source Object with JNDI name -- " + jndiName + "\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectType=DataSource\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".ScopeId="+scopeIdInSrc+"\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".JNDIName="+jndiName+"\n")
            jdbcProvider = AdminConfig.showAttribute(datasource,"provider")
            logger.logp(Level.INFO, _pyFileName, method, "JDBC provider="+str(jdbcProvider))
            if(jdbcProvider != None):
                sumPropertyFile.write(jndiName +"."+ str(index) +".Provider=" + str(AdminConfig.showAttribute(jdbcProvider,"name")) + "\n")   
                sumPropertyFile.write(jndiName +"."+ str(index) +".ProviderType=" + str(AdminConfig.showAttribute(jdbcProvider,"providerType")) + "\n")
            resourceAdapter = AdminConfig.showAttribute(datasource,"relationalResourceAdapter")
            logger.logp(Level.INFO, _pyFileName, method, "resource adapter="+str(resourceAdapter))
            if(resourceAdapter != None):
                sumPropertyFile.write(jndiName +"."+ str(index) +".ResourceAdapter=" + str(AdminConfig.showAttribute(resourceAdapter,"name")) + "\n\n")
            logger.logp(Level.INFO, _pyFileName, method, "Data source with JNDI name "  + str(jndiName) + " was exported to file " + fileName + ".obj under " + outputFilePath)
            print "INFO:Data source with JNDI name "  + str(jndiName) + " was exported to file " + fileName + ".obj under " + outputFilePath
            print
            index=index+1
    if (found == "true"):
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + outputPropFile + " for the export summary.")
        print "INFO:Check file " + outputPropFile + " for the export summary."
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No data source with JNDI name " + str(dsJNDI) + " found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
        print "INFO:No data source with JNDI name " + str(dsJNDI) + " found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No data source with JNDI name " + str(dsJNDI) + " found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

#----------------------------------------------------------------------------
# Find out the property index
#------------------------------------------------------------------------------
def calculatePropertyIndex(sumPropertyFile):
    method="calculatePropertyIndex"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(sumPropertyFile))
    index=1
    internalIndex=1
    if sumPropertyFile and os.path.exists(sumPropertyFile) and sumPropertyFile.endswith(".properties"):
        propsFile = Properties()
        inputSream = FileInputStream(sumPropertyFile)
        propsFile.load(inputSream)
        logger.logp(Level.INFO, _pyFileName, method, "existed property iterm number is:"+str(propsFile.keySet().size()))
        for propertyName in propsFile.keySet():
            logger.logp(Level.FINE, _pyFileName, method, "property name is:"+str(propertyName))
            if str(propertyName).find(".ObjectFileName") >0:
                logger.logp(Level.FINE, _pyFileName, method, "found target property name is:"+str(propertyName))
                subPropertyName=propertyName[0:propertyName.rfind(".")]
                tempInternalIndex=int(subPropertyName[subPropertyName.rfind(".")+1: len(subPropertyName)])
                logger.logp(Level.FINE, _pyFileName, method, "found target property temp internal index is:"+str(tempInternalIndex))
                if internalIndex < tempInternalIndex:
                    internalIndex = tempInternalIndex
                index=index+1
        inputSream.close()
        logger.logp(Level.FINE, _pyFileName, method, "found target property internal index is:"+str(internalIndex))
        if index <= internalIndex:
            index = internalIndex
            index=index+1
    logger.logp(Level.INFO, _pyFileName, method, "calculated index is:"+str(index))
    logger.exiting(_pyFileName, method)
    return index
    
#----------------------------------------------------------------------------
# Export connection factory by JNDI name in specified scope
#------------------------------------------------------------------------------            
def exportCFByJNDI(cfJNDI,outputFilePath,scopeId,cellOnly,nodeOnly):
    method="exportCFByJNDI"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(cfJNDI)+", "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputFilePath, CF_PROPERTY_FILE_NAME)
    cfType="J2CConnectionFactory"
    cfList=AdminConfig.list(cfType,scopeId)
    cfs = wsadminToList(cfList)
    if(cellOnly == "true"):
        cfs=eliminateNoneCellScopeObject(cfs)
    if(nodeOnly == "true"):
        cfs=eliminateServerScopeObject(cfs)
    logger.logp(Level.FINE, _pyFileName, method, "connection factory list:"+str(cfs))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath,CF_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    found = "false" 
    print "**************************************"
    logger.logp(Level.FINE, _pyFileName, method, "looping connection factory list")
    for cf in cfs:        
        fileName = extractFileName(cf) 
        jndiName=AdminConfig.showAttribute(cf,"jndiName")
        logger.logp(Level.FINE, _pyFileName, method, "jndi name is:"+str(jndiName))
        if (jndiName != None and jndiName == cfJNDI):     
            outputObjFile = os.path.join(outputFilePath,fileName + ".obj")           
            connFactoryDef=AdminConfig.showAttribute(cf,"connectionDefinition")
            #some built-in connection factories have no connection definitions, so do not export these connection factories 
            logger.logp(Level.FINE, _pyFileName, method, "connection factory defination: "+str(connFactoryDef))
            if(connFactoryDef is None):
                continue
            connFactoryInterCls=AdminConfig.showAttribute("ConnectionDefinition"+connFactoryDef, "connectionFactoryImplClass")
            logger.logp(Level.FINE, _pyFileName, method, "connection factory interface class: "+str(connFactoryInterCls))
            if isJmsConnectionFactory(connFactoryInterCls) == "false":
                continue
            found = "true"
            # fetch scope id
            findex = cf.rfind("(")
            lindex = cf.find("resources.xml#")
            scopeIdInSrc = cf[findex+1:lindex-1]
            # check whether this connection factory object has already been exported
            if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                logger.logp(Level.INFO, _pyFileName, method, "Skip to export JMS connection factory "  + str(jndiName) + " since it was already exported.")
                print "INFO:Skip to export JMS connection factory "  + str(jndiName) + " since it was already exported."
                print
                continue
            # fetch bus name
            busName=getBusNameFromJ2EEPropertySet(cf,cfType)
            exportObj(cf,outputObjFile)
            sumPropertyFile.write("#Exported "+cfType+" Object with JNDI name -- " + jndiName + "\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectType="+cfType+"\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".Provider=" + str(AdminConfig.showAttribute(cf,"provider")) + "\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".BusName="+busName+ "\n")
            sumPropertyFile.write(jndiName +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n")
            sumPropertyFile.write(jndiName +"."+str(index)+ ".JNDIName="+jndiName+"\n")
            sumPropertyFile.write(jndiName +"."+ str(index) +".ConnectionFactoryImplClass=" + connFactoryInterCls + "\n\n")   
            logger.logp(Level.FINE, _pyFileName, method, "JMS connection factory with JNDI name "  + str(jndiName) + " was exported to file " + str(outputObjFile) + ".")
            print "INFO: JMS connection factory with JNDI name "  + str(jndiName) + " was exported to file " + str(outputObjFile) + "."
            print
            index=index+1
    if (found == "true"):
        logger.logp(Level.FINE, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
        print "INFO: Check file " + str(outputPropFile) + " for the export summary."
    else:
        logger.logp(Level.FINE, _pyFileName, method, "JMS connection factory with JNDI name " + str(cfJNDI) + " was not found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
        print "INFO: JMS connection factory with JNDI name " + str(cfJNDI) + " was not found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No JMS connection factory with JNDI name " + str(cfJNDI) + " found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export activation specification by JNDI name in specified scope
#------------------------------------------------------------------------------            
def exportASByJNDI(asJNDI,outputFilePath,scopeId,cellOnly,nodeOnly):
    method="exportASByJNDI"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(asJNDI)+", "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputFilePath, AS_PROPERTY_FILE_NAME)
    asType="J2CActivationSpec"   
    raType="J2CResourceAdapter" 
    raList=AdminConfig.list(raType,scopeId)
    raes = wsadminToList(raList)
    if(cellOnly == "true"):
        raes=eliminateNoneCellScopeObject(raes)
    if(nodeOnly == "true"):
        raes=eliminateServerScopeObject(raes)
    logger.logp(Level.FINE, _pyFileName, method, "resource adapter list:"+str(raes))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath, AS_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    found = "false"   
    print "**************************************"
    if(len(raes) > 0):
        logger.logp(Level.INFO, _pyFileName, method, "looping resource adapters.")
        for ra in raes:
            asList=AdminConfig.list(asType,ra)
            ases = wsadminToList(asList)
            logger.logp(Level.FINE, _pyFileName, method, "activation specification list:"+str(ases))
            raName=str(AdminConfig.showAttribute(ra,"name"))
            if(len(ases) > 0):
                logger.logp(Level.INFO, _pyFileName, method, "looping activation specification list.")     
                for _as in ases:
                    jndiName=AdminConfig.showAttribute(_as,"jndiName") 
                    logger.logp(Level.INFO, _pyFileName, method, "jndi name="+str(jndiName))        
                    if (jndiName != None and jndiName == asJNDI):         
                        fileName = extractFileName(_as) 
                        logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))                     
                        outputObjFile = os.path.join(outputFilePath,fileName + ".obj")
                        #fetch ConnectionDefinition connectionFactoryImplClass attr
                        asDef=AdminConfig.showAttribute(_as,"activationSpec")
                        asInterCls=AdminConfig.showAttribute("ActivationSpec"+asDef, "activationSpecClass")
                        logger.logp(Level.INFO, _pyFileName, method, "ActivationSpec activationSpecClass="+str(asInterCls)) 
                        if isJmsActivationSpec(asInterCls) == "false":
                            continue
                        found = "true"
                        findex = _as.rfind("(")
                        lindex = _as.find("resources.xml#")
                        scopeIdInSrc = _as[findex+1:lindex-1]
                        # check whether this activiation specification object has already been exported
                        if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                            logger.logp(Level.INFO, _pyFileName, method, "Skip to export JMS activation specification "  + str(jndiName) + " since it was already exported.")
                            print "INFO:Skip to export JMS activation specification "  + str(jndiName) + " since it was already exported."
                            print
                            continue
                        #fetch bus name
                        busName=getBusNameFromJ2EEPropertySet(_as,asType)       
                        exportObj(_as,outputObjFile)
                        sumPropertyFile.write("#Exported "+asType+" Object with JNDI name -- " + jndiName + "\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".AdapterName="+raName+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ActivationSpec="+asInterCls+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".BusName=" + busName + "\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectType="+asType+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".JNDIName="+jndiName+"\n")
                        sumPropertyFile.write(jndiName +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n\n")
                        logger.logp(Level.INFO, _pyFileName, method, "JMS activation specification with JNDI name "  + str(jndiName) + " was exported to file " + str(outputObjFile) + ".") 
                        print "INFO: JMS activation specification with JNDI name "  + str(jndiName) + " was exported to file " + str(outputObjFile) + "."
                        print
                        index=index+1
    if (found == "true"):
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.") 
        print "INFO:Check file " + str(outputPropFile) + " for the export summary."
    else:
        logger.logp(Level.INFO, _pyFileName, method, "JMS activation specification with JNDI name " + str(asJNDI) + " was not found in scope:"+str(deScopeId(scopeId,cellOnly))+".") 
        print "INFO: JMS activation specification with JNDI name " + str(asJNDI) + " was not found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No JMS activation specification with JNDI name " + str(asJNDI) + " found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

def listQueuesAndTopics():
    method="listQueuesAndTopics"
    logger.entering(_pyFileName, method)
    aoType="J2CAdminObject"
    raType="J2CResourceAdapter" 
    raList=AdminConfig.list(raType)
    raes = wsadminToList(raList)
    logger.logp(Level.FINE, _pyFileName, method, "resource adapter list:"+str(raes))
    print "**************************************"
    print "Queue and topic list:"
    if(len(raes) > 0):
        index=1
        for ra in raes:
            aoList=AdminConfig.list(aoType,ra)
            aos = wsadminToList(aoList)
            logger.logp(Level.FINE, _pyFileName, method, "queue or topic list:"+str(aos))
            if(len(aos) > 0):        
                for ao in aos:       
                    fileName  = extractFileName(ao) 
                    logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
                    jndiName=AdminConfig.showAttribute(ao,"jndiName")  
                    logger.logp(Level.INFO, _pyFileName, method, "jndi namet:"+str(jndiName))    
                    if not jndiName:
                        continue
                    aoObj=AdminConfig.showAttribute(ao, "adminObject")
                    aoObjClass=AdminConfig.showAttribute("AdminObject"+aoObj,"adminObjectClass")
                    logger.logp(Level.INFO, _pyFileName, method, "queue or topic class:"+str(aoObjClass))
                    if isJmsAo(aoObjClass) == "false":
                        continue
                    findex = ao.rfind("(")
                    lindex = ao.find("resources.xml#")
                    scopeId = ao[findex+1:lindex-1]
                    aoName=AdminConfig.showAttribute(ao,"name")
                    jndiName=AdminConfig.showAttribute(ao,"jndiName")
                    logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+str(aoName)+" Scope:"+str(scopeId)+"JNDI:"+str(jndiName))
                    print index,"\nName:",aoName,"\nScope:",scopeId,"\nJNDI:",jndiName
                    index = index + 1
    else:
        logger.logp(Level.INFO, _pyFileName, method,  "No queue or topic was found.")
        print "INFO: No queue or topic was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)
    
#------------------------------------------------------------------------------
# Export all queues or topics under specified scope
#------------------------------------------------------------------------------
def exportAllAOs(outputFilePath,scopeId,cellOnly,nodeOnly):
    method="exportAllAOs"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputFilePath, AO_PROPERTY_FILE_NAME)
    aoType="J2CAdminObject"
    raType="J2CResourceAdapter" 
    raList=AdminConfig.list(raType,scopeId)
    raes = wsadminToList(raList)
    if cellOnly=="true":
        raes=eliminateNoneCellScopeObject(raes)
    if nodeOnly=="true":
        raes=eliminateServerScopeObject(raes)
    logger.logp(Level.FINE, _pyFileName, method, "resource adapter list:"+str(raes))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath, AO_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    hasValidAO="false"
    print "**************************************"
    if(len(raes) > 0):
        logger.logp(Level.INFO, _pyFileName, method, "looping resource adapter")
        for ra in raes:
            aoList=AdminConfig.list(aoType,ra)
            aos = wsadminToList(aoList)
            logger.logp(Level.FINE, _pyFileName, method, "queues or topics list:"+str(aos))
            logger.logp(Level.INFO, _pyFileName, method, "looping queues or topics")
            raName=str(AdminConfig.showAttribute(ra,"name"))        
            if(len(aos) > 0):        
                for ao in aos:       
                    fileName  = extractFileName(ao) 
                    logger.logp(Level.FINE, _pyFileName, method, "looping queues or topic")
                    jndiName=AdminConfig.showAttribute(ao,"jndiName")
                    logger.logp(Level.INFO, _pyFileName, method, "jndi name="+str(jndiName))   
                    if(jndiName):
                        outputObjFile = os.path.join(outputFilePath,fileName + ".obj")
                        #fetch adminObjectClass value
                        aoObj=AdminConfig.showAttribute(ao, "adminObject")
                        aoObjClass=AdminConfig.showAttribute("AdminObject"+aoObj,"adminObjectClass")
                        if isJmsAo(aoObjClass) == "false":
                            continue
                        hasValidAO="true"
                        findex = ao.rfind("(")
                        lindex = ao.find("resources.xml#")
                        scopeIdInSrc = ao[findex+1:lindex-1]
                        # check whether this admin object has already been exported
                        if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                            logger.logp(Level.INFO, _pyFileName, method, "Skip to export JMS queue or topic "  + str(jndiName) + " since it was already exported.")
                            print "INFO:Skip to export JMS queue or topic "  + str(jndiName) + " since it was already exported."
                            print
                            continue
                        #fetch bus name
                        busName=getBusNameFromJ2EEPropertySet(ao,aoType)
                        logger.logp(Level.INFO, _pyFileName, method, "About to export properties of qeue or topic with JNDI name " + str(jndiName))   
                        exportObj(ao,outputObjFile)
                        sumPropertyFile.write("#Exported "+aoType+" with JNDI name -- " + jndiName + "\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".AdapterName="+raName+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".AdminObjectClass="+aoObjClass+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".BusName=" + busName + "\n")
                        sumPropertyFile.write(jndiName +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n")
                        sumPropertyFile.write(jndiName +"."+str(index)+ ".JNDIName="+jndiName+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectType="+aoType+"\n\n")  
                        logger.logp(Level.INFO, _pyFileName, method, "JMS queue or topic with JNDI name " + str(jndiName) + " was exported to file " + str(outputObjFile) + ".")       
                        print "INFO: JMS queue or topic with JNDI name " + str(jndiName) + " was exported to file " + str(outputObjFile) + "."
                        print
                        index=index+1
    if(hasValidAO == "true"):
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for export all summary.") 
        print "INFO:Check file " + str(outputPropFile) + " for export all summary."
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No JMS queue or topic was found in scope:"+str(deScopeId(scopeId,cellOnly))+".") 
        print "INFO:No JMS queue or topic was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No JMS queue or topic was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export admin object by JNDI name in specified scope
#------------------------------------------------------------------------------            
def exportAOByJNDI(aoJNDI,outputFilePath,scopeId,cellOnly,nodeOnly):  
    method="exportAOByJNDI"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(aoJNDI)+", "+str(outputFilePath)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputFilePath, AO_PROPERTY_FILE_NAME)
    aoType="J2CAdminObject"
    raType="J2CResourceAdapter"
    raes = wsadminToList(AdminConfig.list(raType,scopeId))
    if cellOnly=="true":
        raes=eliminateNoneCellScopeObject(raes)
    if nodeOnly=="true":
        raes=eliminateServerScopeObject(raes)
    logger.logp(Level.FINE, _pyFileName, method, "resource adapter list:"+str(raes)+".")
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputFilePath,AO_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    found = "false"
    print "**************************************"
    if(len(raes) > 0):
        logger.logp(Level.INFO, _pyFileName, method, "looping resource adapters.")
        for ra in raes:
            aos = wsadminToList(AdminConfig.list(aoType,ra))
            logger.logp(Level.FINE, _pyFileName, method, "queue or topics list:"+str(aos)+".")
            raName=AdminConfig.showAttribute(ra,"name")        
            if(len(aos) > 0):        
                logger.logp(Level.INFO, _pyFileName, method, "looping queue or topic.")
                for ao in aos:       
                    fileName  = extractFileName(ao) 
                    logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))     
                    jndiName=AdminConfig.showAttribute(ao,"jndiName") 
                    logger.logp(Level.INFO, _pyFileName, method, "JNDI name="+str(jndiName))     
                    if (jndiName != None and jndiName == aoJNDI):
                        #fetch adminObjectClass value
                        aoObj=AdminConfig.showAttribute(ao, "adminObject")
                        aoObjClass=AdminConfig.showAttribute("AdminObject"+aoObj,"adminObjectClass")
                        logger.logp(Level.INFO, _pyFileName, method, "queue or topic class:" + str(aoObjClass)) 
                        if isJmsAo(aoObjClass) == "false":
                            continue
                        found = "true"
                        findex = ao.rfind("(")
                        lindex = ao.find("resources.xml#")
                        scopeIdInSrc = ao[findex+1:lindex-1]
                        # check whether this admin object has already been exported
                        if checkObjectExported(outputPropFile, jndiName, scopeIdInSrc) == "true":
                            logger.logp(Level.INFO, _pyFileName, method, "Skip to export JMS queue or topic "  + str(jndiName) + " since it was already exported.")
                            print "INFO:Skip to export JMS queue or topic "  + str(jndiName) + " since it was already exported."
                            print
                            continue
                        outputObjFile = os.path.join(outputFilePath,fileName + ".obj")           
                        exportObj(ao,outputObjFile)
                        #fetch bus name
                        busName=getBusNameFromJ2EEPropertySet(ao,aoType)
                        sumPropertyFile.write("#Exported "+aoType+" with JNDI name -- " + jndiName + "\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".AdapterName="+raName+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".AdminObjectClass="+aoObjClass+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".BusName=" + busName + "\n")
                        sumPropertyFile.write(jndiName +"."+str(index)+ ".ScopeId="+scopeIdInSrc+"\n")
                        sumPropertyFile.write(jndiName +"."+str(index)+ ".JNDIName="+jndiName+"\n")
                        sumPropertyFile.write(jndiName +"."+ str(index) +".ObjectType="+aoType+"\n\n")
                        logger.logp(Level.INFO, _pyFileName, method, "JMS queue or topic with JNDI name "  + str(jndiName) + " was exported to file " + str(outputObjFile) + ".")
                        print "INFO: JMS queue or topic with JNDI name "  + str(jndiName) + " was exported to file " + str(outputObjFile) + "."
                        print
                        index=index+1
    if (found == "true"):
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
        print "INFO:Check file " + outputPropFile + " for the export summary."
    else:
        logger.logp(Level.INFO, _pyFileName, method, "JMS queue or topic with JNDI name " + str(aoJNDI) + " was not found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
        print "INFO: JMS queue or topic with JNDI name " + str(aoJNDI) + " was not found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No JMS queue or topic with JNDI name " + str(aoJNDI) + " found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export data source by show all
#------------------------------------------------------------------------------            
def exportObj(obj,outputObjFileName):
    method="exportObj"
    logger.entering(_pyFileName, method)
    logger.logp(Level.FINE, _pyFileName, method, "input parameters: "+str(obj)+", "+str(outputObjFileName))
    outputObjFile = open(outputObjFileName,"w")
    commonObjStr = str(AdminConfig.showall(obj))
    if commonObjStr.find("\"[") >0:
        commonObjStr = commonObjStr.replace("\"[", "[")
        commonObjStr = commonObjStr.replace("]\"", "]")
        logger.logp(Level.INFO, _pyFileName, method, "found the characters that AdminConfig command cannot handle.")
        logger.logp(Level.FINE, _pyFileName, method, "after repace: "+str(commonObjStr))
    outputObjFile.write(commonObjStr)
    if(outputObjFile):
        outputObjFile.flush()
        outputObjFile.close()
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export data source by show
#------------------------------------------------------------------------------            
def exportObjByShow(obj,outputObjFileName):
    method="exportObjByShow"
    logger.entering(_pyFileName, method)
    logger.logp(Level.FINE, _pyFileName, method, "input parameters: "+str(obj)+", "+str(outputObjFileName))
    outputObjFile = open(outputObjFileName,"w")
    commonObj = AdminConfig.show(obj)
    logger.logp(Level.FINER, _pyFileName, method, "object after show: "+str(commonObj))
    outputObjFile.write(str(commonObj))
    if(outputObjFile):
        outputObjFile.flush()
        outputObjFile.close()
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export data source
#------------------------------------------------------------------------------        
def exportDataSource(datasource,outputFilePath):
    method="exportDataSource"
    logger.entering(_pyFileName, method)
    simpleAttrTypes = ["long","int","String","boolean"]
    outputFile = open(outputFilePath,"w")
    outputFile.write("#Exported properties of data source with JNDI name - "+str(AdminConfig.showAttribute(datasource,"jndiName"))+"\n")    
    outputFile.write("\n")
    outputFile.write("#General properties\n")
    dsAttributes = wsadminToList(AdminConfig.attributes("DataSource"))
    logger.logp(Level.FINE, _pyFileName, method, "datasource list: " + str(dsAttributes))
    for dsAttr in dsAttributes:
        logger.logp(Level.FINE, _pyFileName, method, "Data source general property --" + str(dsAttr))
        if(dsAttr):
            offsetOfFirstSpace = dsAttr.find(" ")
            attributeName = dsAttr[0:offsetOfFirstSpace]
            attributeType = dsAttr[offsetOfFirstSpace+1:]
            logger.logp(Level.FINE, _pyFileName, method, "Name:" + str(attributeName) + "  Type:" + str(attributeType))
            if(attributeType in simpleAttrTypes) or attributeType.startswith("ENUM"):
                attributeValue=AdminConfig.showAttribute(datasource,attributeName)   
                logger.logp(Level.FINE, _pyFileName, method, "Value:"+str(attributeValue))                         
                outputFile.write(str(attributeName)+ "=" + str(attributeValue)+"\n")
    outputFile.write("\n")
    outputFile.write("#Custom properties\n")
    propSet = AdminConfig.showAttribute(datasource,"propertySet")
    resoucepropertiesList = wsadminToList(AdminConfig.list("J2EEResourceProperty", propSet))
    for propid in resoucepropertiesList:
        curPropName=AdminConfig.showAttribute(propid,"name")
        curPropValue=AdminConfig.showAttribute(propid,"value")
        curPropType=AdminConfig.showAttribute(propid,"type")
        curPropRequired=AdminConfig.showAttribute(propid,"required")
        curPropIgnore=AdminConfig.showAttribute(propid,"ignore")
        curPropConfidential=AdminConfig.showAttribute(propid,"confidential")
        curPropSupportDynamic=AdminConfig.showAttribute(propid,"supportsDynamicUpdates")
        outputFile.write(str(curPropName) + "=" + str(curPropValue))
        outputFile.write("  #(type="+str(curPropType)+",required="+str(curPropRequired)+",ignore="+str(curPropIgnore) +",confidential=" + str(curPropConfidential)+",supportsDynamicUpdates=" + str(curPropSupportDynamic)+")\n")
    outputFile.write("\n")
    outputFile.write("#Connection pool properties\n")
    connectionPool = AdminConfig.showAttribute(datasource,"connectionPool")
    connectionPoolAttributes = wsadminToList(AdminConfig.attributes("ConnectionPool"))
    for connectionPoolAttribute in connectionPoolAttributes:
        if(connectionPoolAttribute):
            offsetOfFirstSpace = connectionPoolAttribute.find(" ")
            cpAttributeName = connectionPoolAttribute[0:offsetOfFirstSpace]
            cpAttributeType = connectionPoolAttribute[offsetOfFirstSpace+1:]
            logger.logp(Level.FINE, _pyFileName, method, "Name:" + str(cpAttributeName) + "  Type:" + str(cpAttributeType))         
            if(cpAttributeType in simpleAttrTypes) or cpAttributeType.startswith("ENUM"):
                cpAttributeValue=AdminConfig.showAttribute(connectionPool,cpAttributeName)   
                logger.logp(Level.FINE, _pyFileName, method, "Value:"+str(cpAttributeValue))                          
                outputFile.write(str(cpAttributeName)+ "=" + str(cpAttributeValue)+"\n")
    outputFile.write("\n")
    if(outputFile):
        outputFile.flush()
        outputFile.close()
    logger.exiting(_pyFileName, method)

def exportAuthAliasObj(authAlias,outputObjFileName,namePasswordMap):
    method="exportAuthAliasObj"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(authAlias)+", "+str(outputObjFileName)+", "+str(namePasswordMap))    
    encodedPassword = None
    outputObjFile = open(outputObjFileName,"w")
    authAliasObj = AdminConfig.showall(authAlias)
    if(namePasswordMap.has_key(str(AdminConfig.showAttribute(authAlias,"alias")))):
        password = namePasswordMap[str(AdminConfig.showAttribute(authAlias,"alias"))]
        encodedPassword = PasswordUtil.passwordEncode(password)
    if(authAliasObj.rfind("*****") > 0 and encodedPassword != None):
        authAliasObj = authAliasObj.replace("*****",encodedPassword)       
    outputObjFile.write(str(authAliasObj))
    if(outputObjFile):
        outputObjFile.flush()
        outputObjFile.close()      
    logger.exiting(_pyFileName, method)       

#------------------------------------------------------------------------------
# Export authentication alias 
#------------------------------------------------------------------------------
def exportAuthAlias(authAlias,outputPropFile):   
    method="exportAuthAlias"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(authAlias)+", "+str(outputPropFile))  
    outputFile = open(outputPropFile,"w")
    outputFile.write("#Exported properties of auth alias - "+str(AdminConfig.showAttribute(authAlias,"alias"))+"\n")       
    outputFile.write("alias=" + str(AdminConfig.showAttribute(authAlias,"alias")) + "\n")
    outputFile.write("userId=" + str(AdminConfig.showAttribute(authAlias,"userId")) + "\n")
    outputFile.write("password=" + str(AdminConfig.showAttribute(authAlias,"password")) + "\n")
    outputFile.write("description=" + str(AdminConfig.showAttribute(authAlias,"description")) + "\n")          
    if(outputFile):
        outputFile.flush()
        outputFile.close()
    logger.exiting(_pyFileName, method)

def getAuthAliasNamePasswordMapping():
    method="getAuthAliasNamePasswordMapping"
    logger.entering(_pyFileName, method)
    namePwMap = {}
    session=Session()
    configService=ConfigServiceFactory.getConfigService()
    queryObject=ConfigServiceHelper.createObjectName(None,"JAASAuthData")
    authAliases = configService.queryConfigObjects(session,None,queryObject,None)
    for authAlias in authAliases:
        name = configService.getAttribute(session,authAlias,"alias")
        password = configService.getAttribute(session,authAlias,"password")
        namePwMap[name] = password
    logger.logp(Level.INFO, _pyFileName, method, "returned auth alias map:"+str(namePwMap))
    logger.exiting(_pyFileName, method)
    return namePwMap
       
#------------------------------------------------------------------------------
# Export all authentication aliases
#------------------------------------------------------------------------------
def exportAllAuthAliases(outputDir):
    method="exportAllAuthAliases"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(outputDir))
    propertyFileExists=exportPrecheck(outputDir, AA_PROPERTY_FILE_NAME)
    namePasswordMap = getAuthAliasNamePasswordMapping()
    globalSecurity = AdminConfig.list("Security" )
    authAliases = AdminConfig.list("JAASAuthData",globalSecurity)
    logger.logp(Level.FINE, _pyFileName, method, "auth alias list:"+str(authAliases))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    sumPropertyFile=None
    outputPropFile = os.path.join(outputDir,AA_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        sumPropertyFile = open(outputPropFile,"a")
    found="false"   
    print "**************************************"
    if len(authAliases) > 0 :
        for authAlias in wsadminToList(authAliases):
            found="true"
            aliasName = str(AdminConfig.showAttribute(authAlias,"alias"))
            # check whether this authentication alias object has already been exported
            if checkObjectExported(outputPropFile, aliasName, None) == "true":
                logger.logp(Level.INFO, _pyFileName, method, "Skip to export authentication alias "  + str(aliasName) + " since it was already exported.")
                print "INFO:Skip to export authentication alias "  + str(aliasName) + " since it was already exported."
                print
                continue
            fileName = extractFileName(authAlias) 
            logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
            outputObjFileName = os.path.join(outputDir,fileName + ".obj")           
            exportAuthAliasObj(authAlias,outputObjFileName,namePasswordMap)
            logger.logp(Level.INFO, _pyFileName, method, "auth alias name:"+str(aliasName))
            if(aliasName.count(" ",0, len(aliasName)) > 0):
                aliasName= aliasName.replace(" ","\ ")
            sumPropertyFile.write("#Exported Auth Alias\n")
            sumPropertyFile.write(aliasName + ".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(aliasName + ".Name=" + aliasName+"\n")
            sumPropertyFile.write(aliasName + ".ObjectType=JAASAuthData\n\n") 
            print "INFO:Auth Alias "  + str(AdminConfig.showAttribute(authAlias,"alias")) + " was exported to file " + str(fileName) +".obj under " + str(outputDir)
            print
            logger.logp(Level.INFO, _pyFileName, method, "Auth Alias "  + str(AdminConfig.showAttribute(authAlias,"alias")) + " was exported to file " + str(fileName) +".obj under " + str(outputDir))
    if found=="true":    
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + os.path.join(outputDir,AA_PROPERTY_FILE_NAME) + " for the export summary.")
        print "INFO:Check file " + os.path.join(outputDir,AA_PROPERTY_FILE_NAME) + " for the export summary."      
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No authentication alias was found.")
        print "INFO:No authentication alias was found."
        sumPropertyFile.write("#No authentication alias was found.")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

def getAllNsBindingsByScope(scopeId,cellOnly,nodeOnly):
    method="getAllNsBindingsByScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    stringBindings = AdminConfig.list("StringNameSpaceBinding",scopeId)
    ejbBindings = AdminConfig.list("EjbNameSpaceBinding",scopeId)
    corbaBindings = AdminConfig.list("CORBAObjectNameSpaceBinding",scopeId)
    indirectLookupBindings = AdminConfig.list("IndirectLookupNameSpaceBinding",scopeId)
    bindings=wsadminToList(stringBindings)
    bindings=wsadminAppendList(bindings,ejbBindings)
    bindings=wsadminAppendList(bindings,corbaBindings)
    bindings=wsadminAppendList(bindings,indirectLookupBindings)
    if cellOnly=="true":
        bindings=eliminateNoneCellScopeObject(bindings)
    if nodeOnly=="true":
        bindings=eliminateServerScopeObject(bindings)
    logger.logp(Level.INFO, _pyFileName, method, "returned binding list:"+str(bindings))
    logger.exiting(_pyFileName, method)
    return bindings

def exportNsBindingsByIdentifier(nsIdentifier, outputDir,scopeId,cellOnly,nodeOnly):
    method="exportNsBindingsByIdentifier"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(nsIdentifier)+", "+str(outputDir)+", "+str(scopeId)+", "+str(cellOnly) +", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputDir, NS_PROPERTY_FILE_NAME)
    found="false"
    bindings = getAllNsBindingsByScope(scopeId,cellOnly,nodeOnly)
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputDir, NS_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    print "**************************************"
    if len(bindings) > 0 :
        logger.logp(Level.INFO, _pyFileName, method, "looping binding list.")
        for binding in bindings:
            identifier=str(AdminConfig.showAttribute(binding,"name"))
            logger.logp(Level.INFO, _pyFileName, method, "identifier = "+str(identifier))
            if not identifier == nsIdentifier:
                continue
            found="true"
            findex = binding.rfind("(")
            lindex = binding.find("namebindings.xml#")
            scopeIdInSrc = binding[findex+1:lindex-1]
            # check whether this namespace binding object has already been exported
            if checkObjectExported(outputPropFile, identifier, scopeIdInSrc) == "true":
                logger.logp(Level.INFO, _pyFileName, method, "Skip to export namespace binding "  + str(identifier) + " since it was already exported.")
                print "INFO:Skip to export namespace binding "  + str(identifier) + " since it was already exported."
                print
                continue
            fileName = extractFileName(binding) 
            objType = fileName[0:fileName.rfind("_")]
            logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
            outputObjFileName = os.path.join(outputDir,fileName + ".obj")
            exportObj(binding,outputObjFileName)
            identifierInFile=identifier
            if(identifierInFile.count(" ",0, len(identifierInFile)) > 0):
                identifierInFile= identifierInFile.replace(" ","\ ")
            sumPropertyFile.write("#Exported namespace bindings\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) +".ScopeId="+scopeIdInSrc+"\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) +".Identifier="+identifierInFile+"\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) + ".ObjectType="+objType+"\n\n") 
            index=index+1
            logger.logp(Level.INFO, _pyFileName, method, "Namespace binding "  + str(identifier) + " was exported to file " + str(fileName) +".obj under " + str(outputDir))
            print "INFO:Namespace binding "  + identifier + " was exported to file " + str(fileName) +".obj under " + str(outputDir)
            print
    if found=="true":
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + os.path.join(outputDir, NS_PROPERTY_FILE_NAME) + " for the export summary.")
        print "INFO:Check file " + os.path.join(outputDir, NS_PROPERTY_FILE_NAME) + " for the export summary."      
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No namespace binding was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
        print "INFO:No namespace binding was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No namespace binding was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

def listNameSpaceBindings():
    method="listNameSpaceBindings"
    logger.entering(_pyFileName, method)
    stringBindings = AdminConfig.list("StringNameSpaceBinding")
    ejbBindings = AdminConfig.list("EjbNameSpaceBinding")
    corbaBindings = AdminConfig.list("CORBAObjectNameSpaceBinding")
    indirectLookupBindings = AdminConfig.list("IndirectLookupNameSpaceBinding")
    stringBindingsList=wsadminToList(stringBindings)
    logger.logp(Level.FINE, _pyFileName, method, "stringBindingsList:"+str(stringBindingsList))
    ejbBindingsList=wsadminToList(ejbBindings)
    logger.logp(Level.FINE, _pyFileName, method, "ejbBindingsList:"+str(ejbBindingsList))
    corbaBindingsList=wsadminToList(corbaBindings)
    logger.logp(Level.FINE, _pyFileName, method, "corbaBindingsList:"+str(corbaBindingsList))
    indirectLookupBindingsList=wsadminToList(indirectLookupBindings)
    logger.logp(Level.FINE, _pyFileName, method, "indirectLookupBindingsList:"+str(indirectLookupBindingsList))
    print "**************************************"
    print "Namespace binding list:"
    index=1
    # list StringNameSpaceBinding
    if len(stringBindingsList) > 0 :
        for binding in stringBindingsList:
            identifier=str(AdminConfig.showAttribute(binding,"name"))
            findex = binding.rfind("(")
            lindex = binding.find("namebindings.xml#")
            scopeId = binding[findex+1:lindex-1]
            logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+str(identifier)+" Scope:"+str(scopeId)+" Type: StringNameSpaceBinding")
            print index,"\nName:",identifier,"\nScope:",scopeId,"\nType: StringNameSpaceBinding"
            index = index + 1
            
    # list EjbNameSpaceBinding        
    if len(ejbBindingsList) > 0 :
        for binding in ejbBindingsList:
            identifier=str(AdminConfig.showAttribute(binding,"name"))
            findex = binding.rfind("(")
            lindex = binding.find("namebindings.xml#")
            scopeId = binding[findex+1:lindex-1]
            logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+str(identifier)+" Scope:"+str(scopeId)+" Type: EjbNameSpaceBinding")
            print index,"\nName:",identifier,"\nScope:",scopeId,"\nType: EjbNameSpaceBinding"
            index = index + 1
            
    # list CORBAObjectNameSpaceBinding        
    if len(corbaBindingsList) > 0 :
        for binding in corbaBindingsList:
            identifier=str(AdminConfig.showAttribute(binding,"name"))
            findex = binding.rfind("(")
            lindex = binding.find("namebindings.xml#")
            scopeId = binding[findex+1:lindex-1]
            logger.logp(Level.INFO, _pyFileName, method, str(index)+"  Name:"+str(identifier)+" Scope:"+str(scopeId)+" Type: CORBAObjectNameSpaceBinding")
            print index,"\nName:",identifier,"\nScope:",scopeId,"\nType: CORBAObjectNameSpaceBinding"
            index = index + 1    
    
    # list IndirectLookupNameSpaceBinding        
    if len(indirectLookupBindingsList) > 0 :
        for binding in indirectLookupBindingsList:
            identifier=str(AdminConfig.showAttribute(binding,"name"))
            findex = binding.rfind("(")
            lindex = binding.find("namebindings.xml#")
            scopeId = binding[findex+1:lindex-1]
            logger.logp(Level.INFO, _pyFileName, method, str(index)+" Name:"+str(identifier)+"  Scope:"+str(scopeId)+"Type: IndirectLookupNameSpaceBinding")
            print index,"\nName:",identifier,"\nScope:",scopeId,"\nType: IndirectLookupNameSpaceBinding"
            index = index + 1    
    if index == 1:
        logger.logp(Level.INFO, _pyFileName, method, "No namespace binding was found.")
        print "INFO: No namespace binding was found."
    print "**************************************"
    logger.exiting(_pyFileName, method)
    
    
#------------------------------------------------------------------------------
# Export all namespace bindings
#------------------------------------------------------------------------------
def exportAllBindings(outputDir,scopeId,cellOnly,nodeOnly):
    method="exportAllBindings"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(outputDir)+", "+str(scopeId)+", "+str(cellOnly)+", "+str(nodeOnly))
    propertyFileExists=exportPrecheck(outputDir, NS_PROPERTY_FILE_NAME)
    bindings = getAllNsBindingsByScope(scopeId,cellOnly,nodeOnly)
    logger.logp(Level.FINE, _pyFileName, method, "all binding list:"+str(bindings))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    index=1
    sumPropertyFile=None
    outputPropFile = os.path.join(outputDir,NS_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        index=calculatePropertyIndex(outputPropFile)
        sumPropertyFile = open(outputPropFile,"a")
    found="false"
    print "**************************************"
    if len(bindings) > 0 :
        logger.logp(Level.INFO, _pyFileName, method, "looping binding list")
        for binding in bindings:
            found="true"
            findex = binding.rfind("(")
            lindex = binding.find("namebindings.xml#")
            scopeIdInSrc = binding[findex+1:lindex-1]
            identifier=str(AdminConfig.showAttribute(binding,"name"))
            # check whether this namespace binding object has already been exported
            if checkObjectExported(outputPropFile, identifier, scopeIdInSrc) == "true":
                logger.logp(Level.INFO, _pyFileName, method, "Skip to export namespace binding "  + str(identifier) + " since it was already exported.")
                print "INFO:Skip to export namespace binding "  + str(identifier) + " since it was already exported."
                print
                continue
            fileName = extractFileName(binding) 
            objType = fileName[0:fileName.rfind("_")]
            logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
            outputObjFileName = os.path.join(outputDir,fileName + ".obj")
            exportObj(binding,outputObjFileName)
            identifierInFile=identifier
            logger.logp(Level.INFO, _pyFileName, method, "identifierInFile="+str(identifierInFile))
            if(identifierInFile.count(" ",0, len(identifierInFile)) > 0):
                identifierInFile= identifierInFile.replace(" ","\ ")
                logger.logp(Level.INFO, _pyFileName, method, "identifierInFile="+str(identifierInFile))
            sumPropertyFile.write("#Exported namespace bindings\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) +".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) +".ScopeId="+scopeIdInSrc+"\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) +".Identifier="+identifierInFile+"\n")
            sumPropertyFile.write(identifierInFile +"."+ str(index) + ".ObjectType="+objType+"\n\n") 
            index=index+1
            logger.logp(Level.INFO, _pyFileName, method, "Namespace binding "  + str(identifier) + " was exported to file " + str(fileName) +".obj under " + str(outputDir))
            print "INFO:Namespace binding "  + identifier + " was exported to file " + str(fileName) +".obj under " + str(outputDir)
            print
    if found=="true": 
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(os.path.join(outputDir, NS_PROPERTY_FILE_NAME)) + " for the export summary.")
        print "INFO:Check file " + str(os.path.join(outputDir,NS_PROPERTY_FILE_NAME)) + " for the export summary."      
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No namespace binding was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
        print "INFO:No namespace binding was found in scope:"+str(deScopeId(scopeId,cellOnly))+"."
        sumPropertyFile.write("#No namespace binding was found in scope:"+str(deScopeId(scopeId,cellOnly))+".")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export authentication alias by name
#------------------------------------------------------------------------------
def exportAuthAliasByName(authAliasName,outputDir):
    method="exportAuthAliasByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(authAliasName)+", "+str(outputDir))
    propertyFileExists=exportPrecheck(outputDir, AA_PROPERTY_FILE_NAME)
    namePasswordMap = getAuthAliasNamePasswordMapping()
    globalSecurity = AdminConfig.list("Security" )
    authAliases = AdminConfig.list("JAASAuthData",globalSecurity)
    logger.logp(Level.FINE, _pyFileName, method, "auth alias list:"+str(authAliases))
    # determin how to export WAS object to file system, create a new property file or append to an existed property file
    sumPropertyFile=None
    outputPropFile = os.path.join(outputDir,AA_PROPERTY_FILE_NAME)
    if propertyFileExists == "false":
        logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
        sumPropertyFile = open(outputPropFile,"w") 
    else:
        logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
        sumPropertyFile = open(outputPropFile,"a")
    found = "false"
    print "**************************************"
    if len(authAliases) > 0 :
        logger.logp(Level.INFO, _pyFileName, method, "looping auth alias list")
        for authAlias in wsadminToList(authAliases):
            aliasName = AdminConfig.showAttribute(authAlias,"alias")
            logger.logp(Level.INFO, _pyFileName, method, "auth alias name="+str(aliasName))
            if(aliasName == authAliasName):
                found = "true"
                # check whether this authentication alias object has already been exported
                if checkObjectExported(outputPropFile, aliasName, None) == "true":
                    logger.logp(Level.INFO, _pyFileName, method, "Skip to export authentication alias "  + str(aliasName) + " since it was already exported.")
                    print "INFO:Skip to export authentication alias "  + str(aliasName) + " since it was already exported."
                    print
                    continue
                fileName = extractFileName(authAlias)
                logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
                outputObjFileName = os.path.join(outputDir,fileName + ".obj")
                exportAuthAliasObj(authAlias,outputObjFileName,namePasswordMap)
                aliasName = str(AdminConfig.showAttribute(authAlias,"alias"))
                logger.logp(Level.INFO, _pyFileName, method, "auth alias name="+str(aliasName))
                if(aliasName.count(" ",0, len(aliasName)) > 0):
                    aliasName= aliasName.replace(" ","\ ")
                    logger.logp(Level.INFO, _pyFileName, method, "after modifying auth alias name="+str(aliasName))
                sumPropertyFile.write("#Exported Auth Alias\n")
                sumPropertyFile.write(aliasName + ".ObjectFileName=" + fileName+".obj\n")
                sumPropertyFile.write(aliasName + ".Name=" + aliasName+"\n")
                sumPropertyFile.write(aliasName + ".ObjectType=JAASAuthData\n\n")    
                logger.logp(Level.INFO, _pyFileName, method, "Auth Alias "  + str(AdminConfig.showAttribute(authAlias,"alias")) + " was exported to file " + str(fileName) + ".obj under " + str(outputDir))   
                print "INFO:Auth Alias "  + str(AdminConfig.showAttribute(authAlias,"alias")) + " was exported to file " + str(fileName) + ".obj under " + str(outputDir)
                print
    if (found == "true"):
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + os.path.join(outputDir,AA_PROPERTY_FILE_NAME) + " for the export summary.")
        print "INFO:Check file " + os.path.join(outputDir,AA_PROPERTY_FILE_NAME) + " for the export summary."
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No authentication alias with name " + str(authAliasName) + " was found.")
        print "INFO:No authentication alias with name " + str(authAliasName) + " was found."
        sumPropertyFile.write("#No authentication alias with name " + str(authAliasName) + " was found.")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export bus configuration by name
#------------------------------------------------------------------------------
def exportSIBusConfigByName(busName,outputDir):
    method="exportSIBusConfigByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(busName)+", "+str(outputDir))
    outputDir=os.path.join(outputDir, busName)
    print "**************************************"
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    if len(os.listdir(outputDir)) == 0:
        busType="SIBus"
        busList = AdminConfig.list(busType) 
        found = "false"
        outputObjFile = os.path.join(outputDir,busType + ".obj")
        outputPropFile = os.path.join(outputDir,"export"+busType+".properties")
        sumPropertyFile = open(outputPropFile,"w")
        print "INFO: Export SIBus "  + str(busName) +"..."
        if len(busList) > 0 :
            for bus in wsadminToList(busList):
                _busName = AdminConfig.showAttribute(bus,"name")
                logger.logp(Level.INFO, _pyFileName, method, "bus name: " + str(_busName))
                if(busName == _busName):
                    found = "true"
                    exportObjByShow(bus,outputObjFile)
                    sumPropertyFile.write("#Exported SIBus configuration\n")
                    sumPropertyFile.write(busName + ".ObjectFileName=" + busType+".obj\n")
                    sumPropertyFile.write(busName + ".ObjectType="+busType+"\n\n")       
                    exportAllSIForeignBusByBus(bus, outputDir)
                    exportAllSIBDestinationByBusName(busName,outputDir)
                    exportAllSIBusMemberByBusName(busName,outputDir)
                    break
        if (found == "false"):
            logger.logp(Level.INFO, _pyFileName, method, "NO SIBus with name " + str(busName) + " was found.")
            print "INFO: NO SIBus with name " + str(busName) + " was found."
            sumPropertyFile.write("#NO SIBus with name " + str(busName) + " was found.")
        else:
            logger.logp(Level.INFO, _pyFileName, method, "SIBus "  + str(busName) + " was exported to file " + str(outputObjFile) + ".")
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
            print "INFO: SIBus "  + str(busName) + " was exported successfully."
        sumPropertyFile.flush()
        sumPropertyFile.close()
    else:
        logger.logp(Level.INFO, _pyFileName, method, "The output directory " + str(outputDir) + " is not empty.")
        print "INFO: Skip to export SIBus configuration, since the output directory " + str(outputDir) + " is not empty."
    print "**************************************"
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export all SIB destinations
#------------------------------------------------------------------------------
def exportAllSIBDestinationByBusName(busName, outputDir):
    method="exportAllSIBDestinationByBusName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(busName) + ", "+str(outputDir))
    destRootFolderName="Destination"
    outputDir=os.path.join(outputDir, destRootFolderName)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    exportAllSIBDestByBusName(busName, outputDir,"Queue")
    exportAllSIBDestByBusName(busName, outputDir,"TopicSpace")
    exportAllSIBDestByBusName(busName, outputDir,"Alias")
    exportAllSIBDestByBusName(busName, outputDir,"Foreign")
    logger.logp(Level.INFO, _pyFileName, method, "Completed exporting all SIBus destinations.")
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SIB destinations, such as: Queue, TopicSpace, Alias, Foreign
#------------------------------------------------------------------------------
def exportAllSIBDestByBusName(busName, outputDir, destType):
    method="exportAllSIBDestByBusName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(busName) + ", "+str(outputDir) + ", "+str(destType))
    outputDir=os.path.join(outputDir, destType)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    found="false"
    destList=AdminTask.listSIBDestinations("-bus '"+busName+"' -type "+destType)
    logger.logp(Level.INFO, _pyFileName, method, "SIB destinations list: "+str(destList))
    if len(destList) > 0 :
        logger.logp(Level.INFO, _pyFileName, method, "looping SIB destinations list")
        for dest in wsadminToList(destList) :
            found="true"
            destName=str(AdminConfig.showAttribute(dest,"identifier"))
            logger.logp(Level.INFO, _pyFileName, method, "SIB destinations name: "+str(destName))
            folderName =extractFileName(dest)  
            destOutputDir=os.path.join(outputDir, folderName)
            if(not os.path.exists(destOutputDir)):
                os.makedirs(destOutputDir) 
            outputPropFile = os.path.join(destOutputDir,"export"+destType + ".properties")
            outputObjFile = os.path.join(destOutputDir,destType + ".obj")
            exportObjByShow(dest,outputObjFile)
            exportSIBDestinationRefs(dest, destOutputDir)
            sumPropertyFile = open(outputPropFile,"w")
            sumPropertyFile.write("#Exported SIBus "+destType+" configuration\n")
            sumPropertyFile.write(destName + ".ObjectFileName=" + destType+".obj\n")
            sumPropertyFile.write(destName + ".ObjectType="+destType+"\n\n")
            logger.logp(Level.INFO, _pyFileName, method, "SIBus "  + str(destName) + " was exported to file " + str(outputObjFile) + ". ")
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")     
            sumPropertyFile.flush()
            sumPropertyFile.close()
    if found=="true":
        logger.logp(Level.INFO, _pyFileName, method, "SIBus "  + str(destType) + " was exported successfully.")
    else:
        outputPropFile = os.path.join(outputDir,"export"+str(destType) + ".properties")
        sumPropertyFile = open(outputPropFile,"w")
        sumPropertyFile.write("#No SIB SIBusDestination "+str(destType) + " found.")
        sumPropertyFile.flush()
        sumPropertyFile.close()
        logger.logp(Level.INFO, _pyFileName, method, "No SIBus Destination was found.") 
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SIB destination references
#------------------------------------------------------------------------------
def exportSIBDestinationRefs(destObj, outputDir):
    method="exportSIBDestinationRefs"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(destObj) + ", "+str(outputDir))
    refType="SIBLocalizationPointRef"
    refList=AdminConfig.list(refType, destObj)
    found="false"
    logger.logp(Level.FINE, _pyFileName, method, "SIB destination references list: "+str(refList))
    if len(refList) > 0 :
        outputPropFile = os.path.join(outputDir,"export"+refType + ".properties")
        sumPropertyFile = open(outputPropFile,"w")
        logger.logp(Level.INFO, _pyFileName, method, "looping SIB destination references")
        for ref in wsadminToList(refList) :
            found="true"
            outputObjFile = os.path.join(outputDir,refType + ".obj")
            exportObjByShow(ref,outputObjFile)
            sumPropertyFile.write("#Exported SIBLocalizationPointRef configuration\n")
            sumPropertyFile.write(refType + ".ObjectFileName=" + refType+".obj\n")
            sumPropertyFile.write(refType + ".ObjectType="+refType+"\n\n") 
            logger.logp(Level.INFO, _pyFileName, method, "SIBLocalizationPointRef was exported to file " + str(outputObjFile) + ". ")      
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")   
        if(sumPropertyFile):
            sumPropertyFile.flush()
            sumPropertyFile.close()
    if found == "true":
        logger.logp(Level.INFO, _pyFileName, method, "SIBus "  + str(refType) + " was exported successfully.")
    else:
        outputPropFile = os.path.join(outputDir,"export"+str(refType) + ".properties")
        sumPropertyFile = open(outputPropFile,"w")
        sumPropertyFile.write("#No SIB "  + str(refType) + " found.")
        sumPropertyFile.flush()
        sumPropertyFile.close()
        logger.logp(Level.INFO, _pyFileName, method, "SIBus "  + str(refType) + " was found.") 
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SIB foreign buses
#------------------------------------------------------------------------------
def exportAllSIForeignBusByBus(bus, outputDir):
    method="exportAllSIForeignBusByBus"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(bus) + ", "+str(outputDir))
    sibFBType="SIBForeignBus"
    outputDir=os.path.join(outputDir, sibFBType)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    found="false"
    sibFBList = AdminConfig.showAttribute(bus,"foreignBus")
    logger.logp(Level.FINE, _pyFileName, method, "SIB foreign bus list: " + str(sibFBList))
    if len(sibFBList) > 0 :
        logger.logp(Level.FINE, _pyFileName, method, "looping foreign bus list")
        for sibFB in wsadminToList(sibFBList) :
            found="true"
            FBName=str(AdminConfig.showAttribute(sibFB,"name"))
            folderName = extractFileName(sibFB) 
            fboutputDir=os.path.join(outputDir, folderName)
            if(not os.path.exists(fboutputDir)):
                os.makedirs(fboutputDir) 
            outputPropFile = os.path.join(fboutputDir,"export"+sibFBType + ".properties")
            outputObjFile = os.path.join(fboutputDir,sibFBType + ".obj")
            exportObjByShow(sibFB,outputObjFile)
            exportAllSIBDestinationDefaults(sibFB, fboutputDir)
            sumPropertyFile = open(outputPropFile,"w")
            sumPropertyFile.write("#Exported SIBus Foreign Bus configuration\n")
            sumPropertyFile.write(FBName + ".ObjectFileName=" + sibFBType+".obj\n")
            sumPropertyFile.write(FBName + ".ObjectType="+sibFBType+"\n\n")       
            logger.logp(Level.FINE, _pyFileName, method, "SIBForeignBus "  + str(FBName) + " was exported to file " + str(outputObjFile) + ".")
            logger.logp(Level.FINE, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
            exportAllSIBusLinkByBusName(sibFB, fboutputDir)     
            sumPropertyFile.flush()
            sumPropertyFile.close()
    if found=="true":
        logger.logp(Level.INFO, _pyFileName, method, "Completed exporting all foreign buses to "+str(outputDir)+".")
    else:
        outputPropFile = os.path.join(outputDir,"export"+sibFBType + ".properties")
        sumPropertyFile = open(outputPropFile,"w")
        sumPropertyFile.write("#No SIB Foreign Bus found.")
        sumPropertyFile.flush()
        sumPropertyFile.close()
        logger.logp(Level.INFO, _pyFileName, method, "No SIB Foreign Bus found.")
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SIB destination defaults
#------------------------------------------------------------------------------
def exportAllSIBDestinationDefaults(sibFB,outputDir):
    method="exportAllSIBDestinationDefaults"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(sibFB) + ", "+str(outputDir))
    sibDestDefaultType="SIBDestinationDefault"
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    sibDestDefaultList=AdminConfig.list(sibDestDefaultType,sibFB)
    outputPropFile = os.path.join(outputDir,"export"+sibDestDefaultType + ".properties")
    sumPropertyFile = open(outputPropFile,"w")
    if len(sibDestDefaultList) > 0 :
        for sibDestDefault in wsadminToList(sibDestDefaultList) :
            outputObjFile = os.path.join(outputDir,sibDestDefaultType + ".obj")
            exportObj(sibDestDefault,outputObjFile)
            sumPropertyFile.write("#Exported SIBus Desctination Default configuration\n")
            sumPropertyFile.write(sibDestDefaultType + ".ObjectFileName=" + sibDestDefaultType+".obj\n")
            sumPropertyFile.write(sibDestDefaultType + ".ObjectType="+sibDestDefaultType+"\n\n")
            logger.logp(Level.INFO, _pyFileName, method, "SIBDestinationDefault was exported to file " + str(outputObjFile) + ". ")  
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
    else:
        sumPropertyFile.write("#No SIBDestinationDefault was found.")
        print "No SIBDestinationDefault was found."
    sumPropertyFile.flush()
    sumPropertyFile.close()   
    logger.exiting(_pyFileName, method)
 
#------------------------------------------------------------------------------
# Export SIB foreign buses link
#------------------------------------------------------------------------------
def exportAllSIBusLinkByBusName(sibFB, outputDir):
    method="exportAllSIBusLinkByBusName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(sibFB) + ", "+str(outputDir))
    sibFBLinkType="SIBVirtualGatewayLink"
    outputDir=os.path.join(outputDir, sibFBLinkType)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    sibFBLinkList = AdminConfig.list(sibFBLinkType,sibFB)
    logger.logp(Level.FINE, _pyFileName, method, "SIB foreign link list: " + str(sibFBLinkList))
    outputPropFile = os.path.join(outputDir,"export"+sibFBLinkType + ".properties")
    sumPropertyFile = open(outputPropFile,"w")
    if len(sibFBLinkList) > 0 :
        for sibFBLink in wsadminToList(sibFBLinkList):
            FBLinkName=str(AdminConfig.showAttribute(sibFBLink,"name"))
            outputObjFile = os.path.join(outputDir,sibFBLinkType + ".obj")
            exportObjByShow(sibFBLink,outputObjFile)
            exportAllSIBLinkRefs(sibFBLink, outputDir)
            sumPropertyFile.write("#Exported SIBus Link configuration\n")
            sumPropertyFile.write(FBLinkName + ".ObjectFileName=" + sibFBLinkType+".obj\n")
            sumPropertyFile.write(FBLinkName + ".ObjectType="+sibFBLinkType+"\n\n")   
            logger.logp(Level.INFO, _pyFileName, method, "SIBus Link "  + str(FBLinkName) + " was exported to file " + str(outputObjFile) + ".")    
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")    
    else:
        sumPropertyFile.write("#No SIBus Link was found")
        logger.logp(Level.INFO, _pyFileName, method, "No SIBus Link was found.")    
    sumPropertyFile.flush()
    sumPropertyFile.close()
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SIB link reference
#------------------------------------------------------------------------------
def exportAllSIBLinkRefs(sibFBLink, outputDir):
    method="exportAllSIBLinkRefs"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(sibFBLink) + ", "+str(outputDir))
    sibLinkRefType="SIBLinkRef"
    outputDir=os.path.join(outputDir, sibLinkRefType)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    sibLinkRefList=AdminConfig.list(sibLinkRefType,sibFBLink)
    logger.logp(Level.FINE, _pyFileName, method, "SIBus link reference list: " + str(sibLinkRefList))
    if len(sibLinkRefList) > 0 :
        logger.logp(Level.INFO, _pyFileName, method, "looping SIBus link reference.")
        for sibLinkRef in wsadminToList(sibLinkRefList) :
            folderName =extractFileName(sibLinkRef)  
            sibLinkRefOutputDir=os.path.join(outputDir, folderName)
            if(not os.path.exists(sibLinkRefOutputDir)):
                os.makedirs(sibLinkRefOutputDir)
            outputPropFile = os.path.join(sibLinkRefOutputDir,"export"+sibLinkRefType + ".properties")
            outputObjFile = os.path.join(sibLinkRefOutputDir,sibLinkRefType + ".obj")
            exportObjByShow(sibLinkRef,outputObjFile)
            exportAllSIBMT(sibLinkRef, sibLinkRefOutputDir, sibLinkRefType)
            sumPropertyFile = open(outputPropFile,"w")
            sumPropertyFile.write("#Exported "+sibLinkRefType+" configuration\n")
            sumPropertyFile.write(sibLinkRefType + ".ObjectFileName=" + sibLinkRefType+".obj\n")
            sumPropertyFile.write(sibLinkRefType + ".ObjectType="+sibLinkRefType+"\n\n")
            logger.logp(Level.INFO, _pyFileName, method, str(sibLinkRefType)+" was exported to file " + str(outputObjFile) + ". ")  
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.") 
        if(sumPropertyFile):
            sumPropertyFile.flush()
            sumPropertyFile.close()   
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SI bus member target
#------------------------------------------------------------------------------
def exportAllSIBMT(sibMTParentObj, outputDir, parentObjType):
    method="exportAllSIBMT"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(sibMTParentObj) + ", "+str(outputDir) + ", "+str(parentObjType))
    sibMTType="SIBusMemberTarget"
    outputDir=os.path.join(outputDir, sibMTType)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    sibMTList = None
    if(parentObjType == "SIBLinkRef"):
        sibMTList = AdminConfig.showAttribute(sibMTParentObj,"engine")
    if(parentObjType == "SIBusMember"):
        sibMTList = AdminConfig.list(sibMTType, sibMTParentObj)
    logger.logp(Level.FINE, _pyFileName, method, "SIBus member target list: "+str(sibMTList))
    outputPropFile = os.path.join(outputDir,"export"+sibMTType + ".properties")
    sumPropertyFile = open(outputPropFile,"w")
    found ="false"
    if len(sibMTList) > 0 :
        for sibMT in wsadminToList(sibMTList) :
            found ="true"
            outputObjFile = os.path.join(outputDir,sibMTType + ".obj")
            exportObjByShow(sibMT,outputObjFile)
            sumPropertyFile.write("#Exported "+sibMTType+" configuration\n")
            sumPropertyFile.write(sibMTType + ".ObjectFileName=" + sibMTType+".obj\n")
            sumPropertyFile.write(sibMTType + ".ObjectType="+sibMTType+"\n\n")
            logger.logp(Level.FINE, _pyFileName, method, str(sibMTType) + " was exported to file " + str(outputObjFile) + ". ")
    if(found=="true"):   
        logger.logp(Level.FINE, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")     
    else:
        logger.logp(Level.FINE, _pyFileName, method, "No "+str(sibMTType)+" found.")    
        sumPropertyFile.write("#No "+sibMTType+" found.")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    logger.exiting(_pyFileName, method)


#------------------------------------------------------------------------------
# Export SIB bus members
#------------------------------------------------------------------------------
def exportAllSIBusMemberByBusName(busName,outputDir):
    method="exportAllSIBusMemberByBusName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(busName) + ", "+str(outputDir))
    sibBMType="SIBusMember"
    outputDir=os.path.join(outputDir, sibBMType)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    found ="false"
    sibBMList = AdminTask.listSIBusMembers("-bus '"+busName+"'")
    logger.logp(Level.FINE, _pyFileName, method, "SIBus member list:"+str(sibBMList))
    if len(sibBMList) > 0 :
        logger.logp(Level.INFO, _pyFileName, method, "looping SIBus member list")
        for sibBM in wsadminToList(sibBMList) :
            found="true"
            folderName = extractFileName(sibBM) 
            bmoutputDir=os.path.join(outputDir, folderName)
            if(not os.path.exists(bmoutputDir)):
                os.makedirs(bmoutputDir) 
            outputPropFile = os.path.join(bmoutputDir,"export"+sibBMType + ".properties")
            outputObjFile = os.path.join(bmoutputDir,sibBMType + ".obj")
            exportObjByShow(sibBM,outputObjFile)
            # cluster scope
            cluster=AdminConfig.showAttribute(sibBM, "cluster")
            logger.logp(Level.INFO, _pyFileName, method, "cluster name from SIBus member: "+str(cluster))
            # server scope
            node=AdminConfig.showAttribute(sibBM,"node")
            logger.logp(Level.INFO, _pyFileName, method, "node name from SIBus member: "+str(node))
            server=AdminConfig.showAttribute(sibBM, "server")
            logger.logp(Level.INFO, _pyFileName, method, "server name from SIBus member: "+str(server))
            # mq server scope
            mqServer=AdminConfig.showAttribute(sibBM, "mqServer")
            scopeId=""
            scopeMap={}
            if cluster:
                scopeMap["Cluster"] = cluster
                scopeId="Cluster:" + cluster
            elif node and server:
                scopeMap["Node"] = node
                scopeMap["Server"] = server
                scopeId = "Node:" + node + ", Server:" + server
            elif mqServer:
                scopeMap["MQServer"] = mqServer
                scopeId = "MQServer:" + mqServer
            else:
                logger.logp(Level.WARNING, _pyFileName, method, "The message engine scope is not found.")
            logger.logp(Level.INFO, _pyFileName, method, "scope parameters from SIBus member: "+str(scopeMap))
            sumPropertyFile = open(outputPropFile,"w")
            sumPropertyFile.write("#Exported "+sibBMType+" configuration\n")
            sumPropertyFile.write(sibBMType + ".ObjectFileName=" + str(sibBMType)+".obj\n")
            sumPropertyFile.write(sibBMType + ".ScopeId=" + str(scopeId)+"\n")
            sumPropertyFile.write(sibBMType + ".ObjectType="+str(sibBMType)+"\n\n")
            logger.logp(Level.INFO, _pyFileName, method, str(sibBMType) + " was exported to file " + str(outputObjFile) + ". ")
            logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")      
            sumPropertyFile.flush()     
            sumPropertyFile.close()
            exportAllSIBEnginesByBusName(busName, bmoutputDir, scopeMap)
            #exportAllSIBMT(sibBM, bmoutputDir, sibBMType)
    if found =="true":
        logger.logp(Level.INFO, _pyFileName, method, "Completed exporting all SIBus memebers.")
    else:
        outputPropFile = os.path.join(outputDir,"export"+str(sibBMType) + ".properties")
        sumPropertyFile = open(outputPropFile,"w")
        sumPropertyFile.write("#No "+str(sibBMType)+" found for " + str(busName)+".")
        sumPropertyFile.flush()
        sumPropertyFile.close()
        logger.logp(Level.INFO, _pyFileName, method, "No "+str(sibBMType)+" found for " + str(busName)+".")
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SIB messaging engines
#------------------------------------------------------------------------------
def exportAllSIBEnginesByBusName(busName, outputDir, scopeMap):
    method="exportAllSIBEnginesByBusName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(busName) + ", "+str(outputDir)+", "+str(scopeMap))
    meArgs=["-bus \""+busName+"\""]
    if scopeMap.get("MQServer"):
        sibMQServerList = AdminTask.listSIBWMQServerBusMembers(meArgs)
        found = "false"
        mqServerType ="SIBMQServerBusMember"
        logger.logp(Level.FINE, _pyFileName, method, "SIB MQ server list: " + str(sibMQServerList))
        if len(sibMQServerList) > 0 :
            for sibMQServer in wsadminToList(sibMQServerList):
                found="true"
                mqServer=str(AdminConfig.showAttribute(sibMQServer,"name"))
                #objFileName = extractFileName(sibMQServer) 
                objFileName = mqServerType
                outputPropFile = os.path.join(outputDir,"export"+mqServerType + ".properties")
                outputObjFile = os.path.join(outputDir,objFileName + ".obj")
                exportObjByShow(sibMQServer,outputObjFile)
                sumPropertyFile = open(outputPropFile,"w")
                sumPropertyFile.write("#Exported SIBus Engine configuration\n")
                sumPropertyFile.write(mqServerType+ ".ObjectFileName=" + objFileName+".obj\n")
                sumPropertyFile.write(mqServerType + ".ObjectType="+mqServerType+"\n\n")   
                logger.logp(Level.INFO, _pyFileName, method, "MQ server bus member "  + str(mqServer) + " was exported to file " + str(outputObjFile) + ".")    
                logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
                sumPropertyFile.flush()
                sumPropertyFile.close()   
        if found=="true":
            logger.logp(Level.INFO, _pyFileName, method, "Completed exporting all MQServer bus member for SIBus "+str(busName)+".")
        else:
            outputPropFile = os.path.join(outputDir,"export"+mqServerType + ".properties")
            sumPropertyFile = open(outputPropFile,"w")
            sumPropertyFile.write("#No "+str(mqServerType)+" was found.")
            sumPropertyFile.flush()
            sumPropertyFile.close()
            # there's bus member, but can not find out message engine, it's not correct.
            # exit the export action
            print "ERROR: No "+str(mqServerType)+" was found."
            logger.logp(Level.SEVERE, _pyFileName, method, "No "+str(mqServerType)+" was found.")
            sys.exit()
    else:
        if scopeMap.get("Cluster"):
            meArgs.append("-cluster")
            meArgs.append(scopeMap.get("Cluster"))
        elif scopeMap.get("Server") and scopeMap.get("Node"):
            meArgs.append("-node")
            meArgs.append(scopeMap.get("Node"))
            meArgs.append("-server")
            meArgs.append(scopeMap.get("Server"))
        # can not find out a correct scope, it's not a valid scenario.
        # exit the export action
        else:
            logger.logp(Level.SEVERE, _pyFileName, method, "Can not find out correct message engine scope for SIBus "+str(busName)+".")
            sys.exit()
        found = "false"
        sibMEType="SIBMessagingEngine"
        sibMEList = AdminTask.listSIBEngines(meArgs) 
        logger.logp(Level.FINE, _pyFileName, method, "SIB message engine list: " + str(sibMEList))
        if len(sibMEList) > 0 :
            for sibME in wsadminToList(sibMEList):
                found="true"
                sibMEName=str(AdminConfig.showAttribute(sibME,"name"))
                folderName = extractFileName(sibME) 
                subMeOutputDir=os.path.join(outputDir, folderName)
                if(not os.path.exists(subMeOutputDir)):
                    os.makedirs(subMeOutputDir) 
                outputPropFile = os.path.join(subMeOutputDir,"export"+sibMEType + ".properties")
                outputObjFile = os.path.join(subMeOutputDir,sibMEType + ".obj")
                exportObjByShow(sibME,outputObjFile)
                sumPropertyFile = open(outputPropFile,"w")
                sumPropertyFile.write("#Exported SIBus Engine configuration\n")
                sumPropertyFile.write( sibMEName+ ".ObjectFileName=" + sibMEType+".obj\n")
                sumPropertyFile.write(sibMEName + ".ObjectType="+sibMEType+"\n\n")   
                logger.logp(Level.INFO, _pyFileName, method, "SIBMessageEngine"  + str(sibMEName) + " was exported to file " + str(outputObjFile) + ".")    
                logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary.")
                sumPropertyFile.flush()
                sumPropertyFile.close()   
                ##export messaging engine data store
                exportAllDataStoreForME(sibME,subMeOutputDir)
                #export messaging engine queue localization points
                exportAllSIMEChildObject(sibME, subMeOutputDir, "SIBQueueLocalizationPoint")
                ##export messaging engine queue localization points     
                exportAllSIMEChildObject(sibME, subMeOutputDir, "SIBTopicSpaceLocalizationPoint")
                ##export messaging engine gateway link
                exportAllSIMEChildObject(sibME,subMeOutputDir, "SIBGatewayLink")
        if found=="true":
            logger.logp(Level.INFO, _pyFileName, method, "Completed exporting all message engines for SIBus "+str(busName)+".")
        else:
            outputPropFile = os.path.join(outputDir,"export"+sibMEType + ".properties")
            sumPropertyFile = open(outputPropFile,"w")
            sumPropertyFile.write("#No "+str(sibMEType)+" was found.")
            sumPropertyFile.flush()
            sumPropertyFile.close()
            # there's bus member, but can not find out message engine, it's not correct.
            # exit the export action
            print "ERROR: No "+str(sibMEType)+" was found."
            logger.logp(Level.SEVERE, _pyFileName, method, "No "+str(sibMEType)+" was found.")
            sys.exit()
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export message data store
#------------------------------------------------------------------------------
def exportAllDataStoreForME(sibME,outputDir):
    method="exportAllDataStoreForME"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(sibME) + ", "+str(outputDir))
    # firstly try to export datasource
    sibMEDSType="SIBDatastore"
    sibMEDSList=AdminConfig.list(sibMEDSType,sibME)
    # secondly if not found then try to export filestore
    if not sibMEDSList or len(sibMEDSList) == 0:
        sibMEDSType="SIBFilestore"
        sibMEDSList=AdminConfig.list(sibMEDSType,sibME)
    logger.logp(Level.INFO, _pyFileName, method, "type of message store list: " + str(sibMEDSList))
    outputPropFile = os.path.join(outputDir,"export"+sibMEDSType + ".properties")
    sumPropertyFile = open(outputPropFile,"w")
    found = "false"
    if len(sibMEDSList) > 0 :
        for sibMEDS in wsadminToList(sibMEDSList) :
            found="true"
            outputObjFile = os.path.join(outputDir,sibMEDSType + ".obj")
            exportObjByShow(sibMEDS,outputObjFile)
            sumPropertyFile.write("#Exported "+str(sibMEDSType)+" configuration\n")
            sumPropertyFile.write(sibMEDSType + ".ObjectFileName=" + sibMEDSType+".obj\n")
            sumPropertyFile.write(sibMEDSType + ".ObjectType="+sibMEDSType+"\n\n")
            logger.logp(Level.INFO, _pyFileName, method, "Type of message store was exported to file " + str(outputObjFile) + ".")
    if found=="true":  
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputPropFile) + " for the export summary." )  
    else:
        logger.logp(Level.SEVERE, _pyFileName, method, "No type of message store was found for message engine["+str(sibME)+"].") 
        sumPropertyFile.write("#No type of message store was found.")
        sumPropertyFile.flush()
        sumPropertyFile.close()
        print "ERROR: No type of message store was found, check your configuration."
        sys.exit()
    sumPropertyFile.flush()
    sumPropertyFile.close()
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export message queue localization points
#------------------------------------------------------------------------------
def exportAllSIMEChildObject(sibME,outputDir,childObjType):
    method="exportAllSIMEChildObject"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(sibME) + ", "+str(outputDir)+", "+str(childObjType))
    outputDir=os.path.join(outputDir, childObjType)
    if(not os.path.exists(outputDir)):
        os.makedirs(outputDir)
    objList = AdminConfig.list(childObjType,sibME)
    logger.logp(Level.INFO, _pyFileName, method, "message queue localization points list: " + str(objList))
    outputProFile=os.path.join(outputDir,"export"+childObjType+".properties")
    sumPropertyFile = open(outputProFile,"w")
    found="false"
    if len(objList) > 0 :
        for obj in wsadminToList(objList):
            found="true"
            pointNameProperty=getAttributeFromObj(childObjType, "name")
            if(None==pointNameProperty):
                pointNameProperty=getAttributeFromObj(childObjType, "identifier")
            childObjName=AdminConfig.showAttribute(obj,pointNameProperty)
            fileName = extractFileName(obj) 
            logger.logp(Level.FINE, _pyFileName, method, "Output file name:" + str(fileName))
            outputObjFile = os.path.join(outputDir,fileName + ".obj")
            exportObjByShow(obj,outputObjFile)
            sumPropertyFile.write("#Exported "+childObjType+" configuration\n")
            sumPropertyFile.write(childObjName + ".ObjectFileName=" + fileName+".obj\n")
            sumPropertyFile.write(childObjName + ".ObjectType="+childObjType+"\n\n")    
            logger.logp(Level.INFO, _pyFileName, method, "SIBLocalizationPoint "  + str(childObjName) + " was exported to file " + str(outputObjFile) + ".")
    if found=="true":  
        logger.logp(Level.INFO, _pyFileName, method, "Check file " + str(outputProFile) + " for the export summary.")   
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No SIBLocalizationPoint was found.")
        sumPropertyFile.write("#No SIBLocalizationPoint was found.")
    sumPropertyFile.flush()
    sumPropertyFile.close()
    logger.exiting(_pyFileName, method)

#------------------------------------------------------------------------------
# Export SSL settings in the cell
#------------------------------------------------------------------------------
def exportSSLSettings(outputDir):
    method="exportSSLSettings"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(outputDir))
    sslConfigs=None
    print "**************************************"
    try:
        sslConfigs = AdminTask.listSSLConfigs('[-all true -displayObjectName true ]')
    except :
        logger.logp(Level.WARNING, _pyFileName, method, "Exporting SSL settings is not supported on this edition of WebSphere Application Server.")
        print "WARNING: Exporting SSL settings is not supported on this edition of WebSphere Application Server."
    else:
        propertyFileExists=exportPrecheck(outputDir, SSL_PROPERTY_FILE_NAME)
        # determin how to export WAS object to file system, create a new property file or append to an existed property file
        index=1
        sumPropertyFile=None
        outputPropFile = os.path.join(outputDir,SSL_PROPERTY_FILE_NAME)
        if propertyFileExists == "false":
            logger.logp(Level.INFO, _pyFileName, method, "properties file NOT found, will create new property file and write properties.")
            sumPropertyFile = open(outputPropFile,"w") 
        else:
            logger.logp(Level.INFO, _pyFileName, method, "properties file found, will append export properties to this properties file.")
            index=calculatePropertyIndex(outputPropFile)
            sumPropertyFile = open(outputPropFile,"a")
        sslConfigs = wsadminToList(sslConfigs)
        if(len(sslConfigs) > 0):
            for sslConfig in sslConfigs:
                alias = AdminConfig.showAttribute(sslConfig,"alias")        
                managementScope = AdminConfig.showAttribute(sslConfig,"managementScope")
                scopeName = AdminConfig.showAttribute(managementScope,"scopeName")
                # check whether this SSL object has already been exported
                if checkObjectExported(outputPropFile, alias, scopeName) == "true":
                    logger.logp(Level.INFO, _pyFileName, method, "Skip to export SSL settings "  + str(alias) + " since it was already exported.")
                    print "INFO:Skip to export SSL settings "  + str(alias) + " since it was already exported."
                    print
                    continue
                setting = AdminConfig.showAttribute(sslConfig,"setting")
                #        securityLevel = AdminConfig.showAttribute(setting,"securityLevel")
                #         sslCiphers = AdminTask.listSSLCiphers('[-sslConfigAliasName ' + alias + ' -scopeName ' + scopeName + ' -securityLevel ' + securityLevel + ' ]')
                #         outputPropFile = open(os.path.join(outputDir,alias + ".properties"),"w")
                #objFileName=alias+"-"+str(index)+ ".obj"
                objFileName=extractFileName(sslConfig)
                outputObjFile = open(os.path.join(outputDir, objFileName),"w")
            
    #         outputPropFile.write("securityLelve=" + securityLevel +"\n")
    #         outputPropFile.write("managementScope=" + managementScope+"\n")
    #         outputPropFile.write("scopeName=" + scopeName+"\n")
    #         outputPropFile.write("sslCiphers=" + str(wsadminToList(sslCiphers))+"\n")        
                outputObjFile.write(AdminConfig.showall(setting))        
                sumPropertyFile.write("#Exported SLL Setting\n")
                sumPropertyFile.write(alias+"."+str(index)+".ObjectFileName=" + objFileName+"\n")
                sumPropertyFile.write(alias+"."+str(index)+".Name=" + alias+"\n")
                sumPropertyFile.write(alias+"."+str(index)+".ScopeName=" + scopeName + "\n\n")
                print "INFO:SSL setting "  + alias + " was exported to file " + alias + ".obj under " + outputDir
                print
                index=index+1
                outputObjFile.close()
            logger.logp(Level.WARNING, _pyFileName, method, "Check file " + os.path.join(outputDir,SSL_PROPERTY_FILE_NAME) + " for the export summary.")
            print "INFO:Check file " + str(os.path.join(outputDir,SSL_PROPERTY_FILE_NAME)) + " for the export summary."       
        else:
            logger.logp(Level.WARNING, _pyFileName, method, "No SSL setting was found.")
            print "INFO:No SSL setting was found."
            sumPropertyFile.write("#No SSL setting was found.")
        sumPropertyFile.flush()
        sumPropertyFile.close()
        print "**************************************"
        logger.exiting(_pyFileName, method)

def exportJavaSecurityFile(outputDir):
    method="exportJavaSecurityFile"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: " + str(outputDir))
    print "**************************************"
    defaultJDKPath = getDefaultJDKPath()
    logger.logp(Level.INFO, _pyFileName, method, "defaultJDKPath: " + str(defaultJDKPath))
    if(defaultJDKPath is not None):
        propertyFileExists=exportPrecheck(outputDir, "java.security")
        if propertyFileExists == "false":
            jreSecurityFilePath = os.path.join(defaultJDKPath,'jre/lib/security/java.security')
            exportedFilePath = os.path.join(outputDir,'java.security')
            shutil.copyfile(jreSecurityFilePath, exportedFilePath)
            logger.logp(Level.INFO, _pyFileName, method, str(jreSecurityFilePath) + " was exported to " + str(exportedFilePath))
            print "INFO:" + str(jreSecurityFilePath) + " was exported to " + str(exportedFilePath)
        else:
            print "WARNING: The output directory already contains java.security file, skip to export action."
            print "         Type a different directory and re-run command."
    else:
        logger.logp(Level.WARNING, _pyFileName, method, "WARNING: Can not find default JDK path, will skip to export Java security file.")
        print "WARNING: Can not find default JDK path, will skip to export Java security file."
    print "**************************************"
    logger.exiting(_pyFileName, method)
                  
def getDefaultJDKPath():  
    method="getDefaultJDKPath"
    logger.entering(_pyFileName, method)
    defaultSDKPath=None
    try:
        wasInstallRoot = System.getProperty('was.install.root')
        cmdDefaultSDKPropertyFilePath = os.path.join(wasInstallRoot,'properties/sdk/cmdDefaultSDK.properties')
        inputFile = FileInputStream(cmdDefaultSDKPropertyFilePath)
    except IOError:
        logger.logp(Level.WARNING, _pyFileName, method, "Cannot find default SDK path.")
        print "WARNING: Cannot find default SDK path."
    else:
        cmdDefaultSDKProperty = Properties()
        cmdDefaultSDKProperty.load(inputFile)
        defaultSDKValue = cmdDefaultSDKProperty.getProperty('COMMAND_DEFAULT_SDK')
        inputFile.close()
        defaultSdkProperty = Properties()
        defaultSdkPropertyFilePath = os.path.join(wasInstallRoot,'properties/sdk/' + str(defaultSDKValue) + ".properties")
        inputFile = FileInputStream(defaultSdkPropertyFilePath)
        defaultSdkProperty.load(inputFile)
        defaultSDKPath = defaultSdkProperty.get('com.ibm.websphere.sdk.location.' + str(defaultSDKValue))
        defaultSDKPath = defaultSDKPath.replace('${WAS_INSTALL_ROOT}',wasInstallRoot)
        logger.logp(Level.WARNING, _pyFileName, method, "Default JDK path is " + str(defaultSDKPath))
        inputFile.close()
    logger.exiting(_pyFileName, method)
    return defaultSDKPath      

############################################################################
# exportDir should be a folder holding all ouputs
############################################################################
def doUT(exportDir,version_prefix):
    #test data 6203->02
    UT62CellName=getCellName()
    UT62DmgrNodeName="bxv9v444CellManager02"
    UT62DmgrServerName="dmgr"
    UT62NodeName="bxv9v444Node02"
    UT62NodeAgentServerName="nodeagent"
    UT62AppServerName="wps_3.AppTarget.bxv9v444Node02.0"
    UT62SupServerName="wps_3.Support.bxv9v444Node02.0"
    UT62MeServerName="wps_3.Messaging.bxv9v444Node02.0"
    UT62AppClusterName="wps_3.AppTarget"
    UT62SupClusterName="wps_3.Support"
    UT62MeClusterName="wps_3.Messaging"
    UT62AuthName="WPSDB_Auth_Alias"
    UT62DsJndiName="jdbc/WPSDB"
    UT62CfJndiName="sca/resource/jms/SCA.JMS/SystemBus_CF"
    UT62AsJndiName="jms/BFMJMSAS"
    UT62AoJndiName="BFMIF_wps_3.AppTarget/com/ibm/bpe/api/sca/BFMJMS_FAILEDEVENT_D"
    UT62NamespaceName="sca_BFMIF_wps_3.AppTarget_export_com_ibm_bpe_api_sca_BFMWSDL"
    UT62BusName="BPC.bxv9v444Cell02.Bus"

    #test data 7005->08
    UT70CellName=getCellName()
    UT70DmgrNodeName="bxv9v444CellManager07"
    UT70DmgrServerName="dmgr"
    UT70NodeName="bxv9v444Node07"
    UT70NodeAgentServerName="nodeagent"
    UT70AppServerName="wps_3.AppTarget.bxv9v444Node07.0"
    UT70SupServerName="wps_3.Support.bxv9v444Node07.0"
    UT70MeServerName="wps_3.Messaging.bxv9v444Node07.0"
    UT70AppClusterName="wps_3.AppTarget"
    UT70SupClusterName="wps_3.Support"
    UT70MeClusterName="wps_3.Messaging"
    UT70AuthName="WPSDB_Auth_Alias"
    UT70DsJndiName="jdbc/WPSDB"
    UT70CfJndiName="jms/BFMJMSReplyCF"
    UT70AsJndiName="jms/BFMJMSAS"
    UT70AoJndiName="jms/BFMJMSAPIQueue"
    UT70NamespaceName="sca_BFMIF_wps_3.AppTarget_export_com_ibm_bpe_api_sca_BFMWSDL"
    UT70BusName="BPC.bxv9v444Cell07.Bus"
    
    #test data 7512->11
    UT75CellName=getCellName()
    UT75DmgrNodeName="bxv9v444CellManager09"
    UT75DmgrServerName="dmgr"
    UT75NodeName="bxv9v444Node09"
    UT75NodeAgentServerName="nodeagent"
    UT75AppServerName="stdpc_3.AppTarget.bxv9v444Node09.0"
    UT75SupServerName="stdpc_3.Support.bxv9v444Node09.0"
    UT75MeServerName="stdpc_3.Messaging.bxv9v444Node09.0"
    UT75AppClusterName="stdpc_3.AppTarget"
    UT75SupClusterName="stdpc_3.Support"
    UT75MeClusterName="stdpc_3.Messaging"
    UT75AuthName="BPMAdmin_Auth_Alias"
    UT75DsJndiName="jdbc/PerformanceDB"
    UT75CfJndiName="bpm/pal/service/deployCF"
    UT75AsJndiName="eis/EventMgrControlActivationSpec"
    UT75AoJndiName="jms/EventMgrControlTopic"
    UT75NamespaceName="test string ns binding"
    UT75BusName="PERFDW.bxv9v444Cell09.Bus"
    
    #test data 8000->09
    UT80CellName=getCellName()
    UT80DmgrNodeName="bxv9v444CellManager10"
    UT80DmgrServerName="dmgr"
    UT80NodeName="bxv9v444Node10"
    UT80NodeAgentServerName="nodeagent"
    UT80AppServerName="advpc_3.AppTarget.bxv9v444Node10.0"
    UT80SupServerName="advpc_3.Support.bxv9v444Node10.0"
    UT80MeServerName="advpc_3.Messaging.bxv9v444Node10.0"
    UT80AppClusterName="advpc_3.AppTarget"
    UT80SupClusterName="advpc_3.Support"
    UT80MeClusterName="advpc_3.Messaging"
    UT80AuthName="SCASYSME00_Auth_Alias"
    UT80DsJndiName="jdbc/com.ibm.ws.sib/advpc_3.Messaging-SCA.SYSTEM.bxv9v444Cell10.Bus"
    UT80CfJndiName="jms/cei/notification/AllEventsTopicConnectionFactory"
    UT80AsJndiName="jms/BFMJMSAS"
    UT80AoJndiName="jms/BFMJMSAPIQueue"
    UT80NamespaceName="sca_BFMIF_advpc_3.AppTarget_export_com_ibm_bpe_api_sca_BFMWSDL"
    UT80BusName="BPC.bxv9v444Cell10.Bus"
    
    #test data 8501->05
    UT85CellName=getCellName()
    UT85DmgrNodeName="bxv9v444CellManager04"
    UT85DmgrServerName="dmgr"
    UT85NodeName="bxv9v444Node04"
    UT85NodeAgentServerName="nodeagent"
    UT85AppServerName="advpc_3.AppCluster.bxv9v444Node04.0"
    UT85SupServerName="advpc_3.SupCluster.bxv9v444Node04.0"
    UT85MeServerName="advpc_3.MECluster.bxv9v444Node04.0"
    UT85AppClusterName="advpc_3.AppCluster"
    UT85SupClusterName="advpc_3.SupCluster"
    UT85MeClusterName="advpc_3.MECluster"
    UT85AuthName="BPMAdminAlias_advpc_3"
    UT85DsJndiName="jdbc/BPEDB"
    UT85CfJndiName="jms/BFMJMSReplyCF"
    UT85AsJndiName="jms/BFMJMSAS"
    UT85AoJndiName="jms/BFMJMSAPIQueue"
    UT85NamespaceName="sca_BFMIF_advpc_3.AppCluster_export_com_ibm_bpe_api_sca_BFMWSDL"
    UT85BusName="BPM.advpc_3.Bus"

    #test usage messages
    #usage()
    #test list datasource
    print "### test list data sources"
    listDataSources()
    #test list authentication aliases
    print "### test list authentication aliases"
    listAuthAliases()
    #test list jdbc providers
    print "### test list jdbc providers"
    listJDBCProviders()
    #test list jms providers
    print "### test list jms providers"
    listJMSProviders()
    #test list connection factories
    print "### test list connection factories"
    listConnectionFactories()
    #test list activation specifications
    print "### test list activation specifications"
    listActivationSpecs()
    #test list queues and topics
    print "### test list queues and topics"
    listQueuesAndTopics()
    #test list namespace bindings
    print "### test list namespace bindings"
    listNameSpaceBindings()
    
    #test export SSL configuration
    print "### test export SSL settings"
    exportSSLDir = os.path.join(exportDir,'exportSSL')
    exportSSLSettings(exportSSLDir)
    
    #test export Java security
    print "### test export JDK security"
    exportJAVASecurity=os.path.join(exportDir, "exportJavaSecurity")
    exportJavaSecurityFile(exportJAVASecurity)
        
#################################################################
#  wps 62 UT
#################################################################
    if(str(version_prefix).startswith("62")):
        #test export authentication alias by alias name
        print "### test export all authentication aliases by name"
        exportAADir = os.path.join(exportDir,'exportAA/SCASMEAlias')    
        exportAuthAliasByName(UT62AuthName,exportAADir)
        
        #test export all authentication aliases
        print "### test export all authentication aliases"
        exportAADir = os.path.join(exportDir,'exportAA')
        exportAllAuthAliases(exportAADir)
    
        print "### test export all data sources"
        doAllDatasourceUT(exportDir,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export data source by JNDI name"
        doDatasourceUT(exportDir, UT62DsJndiName, UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export all connection factories"
        doAllConnFactoryUT(exportDir,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export connection factory by JNDI name"
        doConnFactoryUT(exportDir,UT62CfJndiName,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export all activation specifications"
        doAllASesUT(exportDir,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export activation specification by JNDI name"
        doASesUT(exportDir, UT62AsJndiName,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export all JDBC providers"
        doJDBCProviderUT(exportDir,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export all JMS providers"
        doJMSProviderUT(exportDir,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export all admin objects"
        doAllAOUT(exportDir,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export admin object by JNDI name"
        doAOUT(exportDir, UT62AoJndiName,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export all namespaces"
        doNamingSpaceUT(exportDir,UT62CellName, UT62DmgrNodeName,UT62DmgrServerName,UT62NodeName,UT62NodeAgentServerName,UT62AppServerName,UT62SupServerName,UT62MeServerName,UT62AppClusterName,UT62SupClusterName,UT62MeClusterName)
    
        print "### test export namespaces by identifier"
        exportNSDir = os.path.join(exportDir,'exportNSs/Specific') 
        scopeId = getScopeId(UT62CellName,UT62NodeName,UT62AppServerName,None)
        exportNsBindingsByIdentifier(UT62NamespaceName, exportNSDir,scopeId,"false", "false")
    
        print "### test export bus by name"
        #test bus configuration by bus name
        exportBusDir = os.path.join(exportDir,'exportBus') 
        exportSIBusConfigByName(UT62BusName,exportBusDir)
        
#################################################################
#  wps 70 UT
#################################################################    
    if(str(version_prefix).startswith("70")):
        #test export authentication alias by alias name
        print "### test export all authentication aliases by name"
        exportAADir = os.path.join(exportDir,'exportAA/SCASMEAlias')    
        exportAuthAliasByName(UT70AuthName,exportAADir)
        
        #test export all authentication aliases
        print "### test export all authentication aliases"
        exportAADir = os.path.join(exportDir,'exportAA')
        exportAllAuthAliases(exportAADir)
    
        print "### test export all data sources"
        doAllDatasourceUT(exportDir,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export data source by JNDI name"
        doDatasourceUT(exportDir, UT70DsJndiName, UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export all connection factories"
        doAllConnFactoryUT(exportDir,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export connection factory by JNDI name"
        doConnFactoryUT(exportDir,UT70CfJndiName,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export all activation specifications"
        doAllASesUT(exportDir,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export activation specification by JNDI name"
        doASesUT(exportDir, UT70AsJndiName,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export all JDBC providers"
        doJDBCProviderUT(exportDir,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export all JMS providers"
        doJMSProviderUT(exportDir,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export all admin objects"
        doAllAOUT(exportDir,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export admin object by JNDI name"
        doAOUT(exportDir, UT70AoJndiName,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export all namespaces"
        doNamingSpaceUT(exportDir,UT70CellName, UT70DmgrNodeName,UT70DmgrServerName,UT70NodeName,UT70NodeAgentServerName,UT70AppServerName,UT70SupServerName,UT70MeServerName,UT70AppClusterName,UT70SupClusterName,UT70MeClusterName)
    
        print "### test export namespaces by identifier"
        exportNSDir = os.path.join(exportDir,'exportNSs/Specific') 
        scopeId = getScopeId(UT70CellName,UT70NodeName,UT70AppServerName,None)
        exportNsBindingsByIdentifier(UT70NamespaceName, exportNSDir,scopeId,"false", "false")
    
        print "### test export bus by name"
        #test bus configuration by bus name
        exportBusDir = os.path.join(exportDir,'exportBus') 
        exportSIBusConfigByName(UT70BusName,exportBusDir)
        
#################################################################
#  bpm 75 UT
#################################################################    
    if(str(version_prefix).startswith("75")):
        #test export authentication alias by alias name
        print "### test export all authentication aliases by name"
        exportAADir = os.path.join(exportDir,'exportAA/SCASMEAlias')    
        exportAuthAliasByName(UT75AuthName,exportAADir)
        
        #test export all authentication aliases
        print "### test export all authentication aliases"
        exportAADir = os.path.join(exportDir,'exportAA')
        exportAllAuthAliases(exportAADir)
    
        print "### test export all data sources"
        doAllDatasourceUT(exportDir,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export data source by JNDI name"
        doDatasourceUT(exportDir, UT75DsJndiName, UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export all connection factories"
        doAllConnFactoryUT(exportDir,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export connection factory by JNDI name"
        doConnFactoryUT(exportDir,UT75CfJndiName,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export all activation specifications"
        doAllASesUT(exportDir,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export activation specification by JNDI name"
        doASesUT(exportDir, UT75AsJndiName,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export all JDBC providers"
        doJDBCProviderUT(exportDir,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export all JMS providers"
        doJMSProviderUT(exportDir,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export all admin objects"
        doAllAOUT(exportDir,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export admin object by JNDI name"
        doAOUT(exportDir, UT75AoJndiName,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export all namespaces"
        doNamingSpaceUT(exportDir,UT75CellName, UT75DmgrNodeName,UT75DmgrServerName,UT75NodeName,UT75NodeAgentServerName,UT75AppServerName,UT75SupServerName,UT75MeServerName,UT75AppClusterName,UT75SupClusterName,UT75MeClusterName)
    
        print "### test export namespaces by identifier"
        exportNSDir = os.path.join(exportDir,'exportNSs/Specific') 
        scopeId = getScopeId(UT75CellName,UT75NodeName,UT75AppServerName,None)
        exportNsBindingsByIdentifier(UT75NamespaceName, exportNSDir,scopeId,"false", "false")
    
        print "### test export bus by name"
        #test bus configuration by bus name
        exportBusDir = os.path.join(exportDir,'exportBus') 
        exportSIBusConfigByName(UT75BusName,exportBusDir)
        
#################################################################
#  bpm 80 UT
#################################################################    
    if(str(version_prefix).startswith("80")):
        #test export authentication alias by alias name
        print "### test export all authentication aliases by name"
        exportAADir = os.path.join(exportDir,'exportAA/SCASMEAlias')    
        exportAuthAliasByName(UT80AuthName,exportAADir)
        
        #test export all authentication aliases
        print "### test export all authentication aliases"
        exportAADir = os.path.join(exportDir,'exportAA')
        exportAllAuthAliases(exportAADir)
    
        print "### test export all data sources"
        doAllDatasourceUT(exportDir,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export data source by JNDI name"
        doDatasourceUT(exportDir, UT80DsJndiName, UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export all connection factories"
        doAllConnFactoryUT(exportDir,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export connection factory by JNDI name"
        doConnFactoryUT(exportDir,UT80CfJndiName,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export all activation specifications"
        doAllASesUT(exportDir,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export activation specification by JNDI name"
        doASesUT(exportDir, UT80AsJndiName,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export all JDBC providers"
        doJDBCProviderUT(exportDir,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export all JMS providers"
        doJMSProviderUT(exportDir,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export all admin objects"
        doAllAOUT(exportDir,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export admin object by JNDI name"
        doAOUT(exportDir, UT80AoJndiName,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export all namespaces"
        doNamingSpaceUT(exportDir,UT80CellName, UT80DmgrNodeName,UT80DmgrServerName,UT80NodeName,UT80NodeAgentServerName,UT80AppServerName,UT80SupServerName,UT80MeServerName,UT80AppClusterName,UT80SupClusterName,UT80MeClusterName)
    
        print "### test export namespaces by identifier"
        exportNSDir = os.path.join(exportDir,'exportNSs/Specific') 
        scopeId = getScopeId(UT80CellName,UT80NodeName,UT80AppServerName,None)
        exportNsBindingsByIdentifier(UT80NamespaceName, exportNSDir,scopeId,"false", "false")
    
        print "### test export bus by name"
        #test bus configuration by bus name
        exportBusDir = os.path.join(exportDir,'exportBus') 
        exportSIBusConfigByName(UT80BusName,exportBusDir)
        
#################################################################
#  bpm 85 UT
#################################################################    
    if(str(version_prefix).startswith("85")):
        #test export authentication alias by alias name
        print "### test export all authentication aliases by name"
        exportAADir = os.path.join(exportDir,'exportAA/SCASMEAlias')    
        exportAuthAliasByName(UT85AuthName,exportAADir)
        
        #test export all authentication aliases
        print "### test export all authentication aliases"
        exportAADir = os.path.join(exportDir,'exportAA')
        exportAllAuthAliases(exportAADir)
    
        print "### test export all data sources"
        doAllDatasourceUT(exportDir,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export data source by JNDI name"
        doDatasourceUT(exportDir, UT85DsJndiName, UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export all connection factories"
        doAllConnFactoryUT(exportDir,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export connection factory by JNDI name"
        doConnFactoryUT(exportDir,UT85CfJndiName,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export all activation specifications"
        doAllASesUT(exportDir,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export activation specification by JNDI name"
        doASesUT(exportDir, UT85AsJndiName,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export all JDBC providers"
        doJDBCProviderUT(exportDir,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export all JMS providers"
        doJMSProviderUT(exportDir,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export all admin objects"
        doAllAOUT(exportDir,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export admin object by JNDI name"
        doAOUT(exportDir, UT85AoJndiName,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export all namespaces"
        doNamingSpaceUT(exportDir,UT85CellName, UT85DmgrNodeName,UT85DmgrServerName,UT85NodeName,UT85NodeAgentServerName,UT85AppServerName,UT85SupServerName,UT85MeServerName,UT85AppClusterName,UT85SupClusterName,UT85MeClusterName)
    
        print "### test export namespaces by identifier"
        exportNSDir = os.path.join(exportDir,'exportNSs/Specific') 
        scopeId = getScopeId(UT85CellName,UT85NodeName,UT85AppServerName,None)
        exportNsBindingsByIdentifier(UT85NamespaceName, exportNSDir,scopeId,"false", "false")
    
        print "### test export bus by name"
        #test bus configuration by bus name
        exportBusDir = os.path.join(exportDir,'exportBus') 
        exportSIBusConfigByName(UT85BusName,exportBusDir)
    
def doDatasourceUT(exportDir, jndiName, _UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export specific data sources in all scopes
    exportDSDir = os.path.join(exportDir,'exportDS/specific/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in cell scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "true", "false")
    
    #test export specific data sources in dmgr node scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "true")
    
    #test export specific data sources in dmgr node server scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in node scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "true")
    
    #test export specific data sources in nodeagent server scope 
    exportDSDir = os.path.join(exportDir,'exportDS/specific/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in app server scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in sup server scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in me server scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in app cluster scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in sup cluster scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
    #test export specific data sources in me cluster scope
    exportDSDir = os.path.join(exportDir,'exportDS/specific/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportDataSourceByJNDI(jndiName, exportDSDir,scopeId, "false", "false")
    
def doAllDatasourceUT(exportDir,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export datasources in all scopes
    exportDSDir = os.path.join(exportDir,'exportDS/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
    #test export data sources in cell scope
    exportDSDir = os.path.join(exportDir,'exportDS/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllDataSources(exportDSDir,scopeId, "true", "false")
    
    #test export data sources in dmgr node scope
    exportDSDir = os.path.join(exportDir,'exportDS/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAllDataSources(exportDSDir,scopeId, "false", "true")
    
    #test export data sources in dmgr node server scope
    exportDSDir = os.path.join(exportDir,'exportDS/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
    #test export data sources in node scope
    exportDSDir = os.path.join(exportDir,'exportDS/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAllDataSources(exportDSDir,scopeId, "false", "true")
    
    #test export data sources in custom nodeagent server scope
    exportDSDir = os.path.join(exportDir,'exportDS/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
    #test export data sources in app server scope
    exportDSDir = os.path.join(exportDir,'exportDS/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
    #test export data sources in sup server scope
    exportDSDir = os.path.join(exportDir,'exportDS/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
    #test export data sources in me server scope
    exportDSDir = os.path.join(exportDir,'exportDS/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
    #test export data sources in app cluster scope
    exportDSDir = os.path.join(exportDir,'exportDS/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
    #test export data sources in support cluster scope
    exportDSDir = os.path.join(exportDir,'exportDS/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")

    #test export data sources in me cluster scope
    exportDSDir = os.path.join(exportDir,'exportDS/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAllDataSources(exportDSDir,scopeId, "false", "false")
    
def doAllConnFactoryUT(exportDir,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export connection factories in all scopes
    exportCFDir = os.path.join(exportDir,'exportCF/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
    #test export connection factories in cell scope
    exportCFDir = os.path.join(exportDir,'exportCF/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllCFs(exportCFDir,scopeId, "true", "false")
    
    #test export connection factories in dmgr node scope
    exportCFDir = os.path.join(exportDir,'exportCF/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAllCFs(exportCFDir,scopeId, "false", "true")
    
    #test export connection factories in dmgr node server scope
    exportCFDir = os.path.join(exportDir,'exportCF/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
    #test export connection factories in custom node scope
    exportCFDir = os.path.join(exportDir,'exportCF/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAllCFs(exportCFDir,scopeId, "false", "true")
    
    #test export connection factories in nodeagent server scope
    exportCFDir = os.path.join(exportDir,'exportCF/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
    #test export connection factories in app server scope
    exportCFDir = os.path.join(exportDir,'exportCF/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
    #test export connection factories in sup server scope
    exportCFDir = os.path.join(exportDir,'exportCF/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
    #test export connection factories in me server scope
    exportCFDir = os.path.join(exportDir,'exportCF/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
    #test export connection factories in app cluster scope
    exportCFDir = os.path.join(exportDir,'exportCF/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAllCFs(exportCFDir,scopeId, "false", "false")

    #test export connection factories in sup cluster scope
    exportCFDir = os.path.join(exportDir,'exportCF/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
    #test export connection factories in me cluster scope
    exportCFDir = os.path.join(exportDir,'exportCF/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAllCFs(exportCFDir,scopeId, "false", "false")
    
def doConnFactoryUT(exportDir, jndiName,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export specific connection factories in all scopes
    exportCFDir = os.path.join(exportDir,'exportCF/specific/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in cell scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "true", "false")
    
    #test export specific connection factories in dmgr node scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "true")
    
    #test export specific connection factories in dmgr node scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in custom node scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "true")
    
    #test export specific connection factories in custom node scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/CustomNodeScope/NodeagnetServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in app server scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in sup server scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in me server scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in app cluster scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in sup cluster scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
    #test export specific connection factories in me cluster scope
    exportCFDir = os.path.join(exportDir,'exportCF/specific/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportCFByJNDI(jndiName, exportCFDir,scopeId, "false", "false")
    
def doAllASesUT(exportDir,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export activation specifications in all scopes
    exportASDir = os.path.join(exportDir,'exportAS/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllASes(exportASDir,scopeId,"false","false")
    
    #test export activation specifications in cell scope
    exportASDir = os.path.join(exportDir,'exportAS/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllASes(exportASDir,scopeId,"true","false")
    
    #test export activation specifications in dmgr node scope
    exportASDir = os.path.join(exportDir,'exportAS/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAllASes(exportASDir,scopeId,"false","true")
    
    #test export activation specifications in dmgr node server scope
    exportASDir = os.path.join(exportDir,'exportAS/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAllASes(exportASDir,scopeId,"false","false")
    
    #test export activation specifications in custom node scope
    exportASDir = os.path.join(exportDir,'exportAS/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAllASes(exportASDir,scopeId,"false","true")
    
    #test export activation specifications in nodeagent server scope
    exportASDir = os.path.join(exportDir,'exportAS/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAllASes(exportASDir,scopeId,"false","false")
    
    #test export activation specifications in app server scope
    exportASDir = os.path.join(exportDir,'exportAS/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAllASes(exportASDir,scopeId,"false","false")
    
    #test export activation specifications in sup server scope
    exportASDir = os.path.join(exportDir,'exportAS/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAllASes(exportASDir,scopeId,"false","false")
    
    #test export activation specifications in me server scope
    exportASDir = os.path.join(exportDir,'exportAS/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAllASes(exportASDir,scopeId,"false","false")
    
    #test export activation specifications in app cluster scope
    exportASDir = os.path.join(exportDir,'exportAS/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAllASes(exportASDir,scopeId,"false","false")

    #test export activation specifications in sup cluster scope
    exportASDir = os.path.join(exportDir,'exportAS/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAllASes(exportASDir,scopeId,"false","false")
    
    #test export activation specifications in me cluster scope
    exportASDir = os.path.join(exportDir,'exportAS/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAllASes(exportASDir,scopeId,"false","false")
    
def doASesUT(exportDir, jndiName,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export specific activation specifications in all scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")
    
    #test export specific activation specifications in cell scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"true","false")
    
    #test export specific activation specifications in dmgr node scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","true")
    
    #test export specific activation specifications in dmgr server scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")
    
    #test export specific activation specifications in custom node scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","true")
    
    #test export specific activation specifications in nodeagent server scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")
    
    #test export specific activation specifications in app server scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")
    
    #test export specific activation specifications in sup server scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")
    
    #test export specific activation specifications in me server scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")
    
    #test export specific activation specifications in app cluster scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")

    #test export specific activation specifications in sup cluster scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")

    #test export specific activation specifications in me cluster scope
    exportASDir = os.path.join(exportDir,'exportAS/specific/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportASByJNDI(jndiName, exportASDir,scopeId,"false","false")
    
def doJDBCProviderUT(exportDir,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export JDBC providers in all scopes
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in cell scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"true","false")
    
    #test export JDBC providers in dmgr node scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","true")
    
    #test export JDBC providers in dmgr server scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in custom node scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","true")
    
    #test export JDBC providers in nodeagent server scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in app server scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in sup server scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in me server scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in app cluster scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in sup cluster scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
    #test export JDBC providers in me cluster scope
    exportJDBCProviderDir = os.path.join(exportDir,'exportJDBCProvider/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAllJDBCProviders(exportJDBCProviderDir,scopeId,"false","false")
    
def doJMSProviderUT(exportDir,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export JMS providers in all scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in cell scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"true","false")
    
    #test export JMS providers in dmgr node scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","true")
    
    #test export JMS providers in dmgr server scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in custom node scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","true")
    
    #test export JMS providers in nodeagent server scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in app server scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in sup server scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in me server scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in app cluster scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in sup cluster scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
    #test export JMS providers in me cluster scope
    exportJMSProviderDir = os.path.join(exportDir,'exportJMSProvider/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAllJMSProviders(exportJMSProviderDir,scopeId,"false","false")
    
def doAllAOUT(exportDir,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export admin objects in all scopes
    exportAODir = os.path.join(exportDir,'exportAOs/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
    #test export admin objects in cell scope
    exportAODir = os.path.join(exportDir,'exportAOs/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllAOs(exportAODir,scopeId,"true","false")
    
    #test export admin objects in dmg node scope
    exportAODir = os.path.join(exportDir,'exportAOs/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAllAOs(exportAODir,scopeId,"false","true")
    
    #test export admin objects in dmgr server scope
    exportAODir = os.path.join(exportDir,'exportAOs/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
    #test export admin objects in custom node scope
    exportAODir = os.path.join(exportDir,'exportAOs/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAllAOs(exportAODir,scopeId,"false","true")
    
    #test export admin objects in nodeagent server scope
    exportAODir = os.path.join(exportDir,'exportAOs/CustomNodeScope/NodeagentServer')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAllAOs(exportAODir,scopeId,"false","true")
    
    #test export admin objects in app server scope
    exportAODir = os.path.join(exportDir,'exportAOs/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
    #test export admin objects in sup server scope
    exportAODir = os.path.join(exportDir,'exportAOs/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
    #test export admin objects in me server scope
    exportAODir = os.path.join(exportDir,'exportAOs/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
    #test export admin objects in app cluster scope
    exportAODir = os.path.join(exportDir,'exportAOs/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
    #test export admin objects in Sup cluster scope
    exportAODir = os.path.join(exportDir,'exportAOs/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
    #test export admin objects in me cluster scope
    exportAODir = os.path.join(exportDir,'exportAOs/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAllAOs(exportAODir,scopeId,"false","false")
    
def doAOUT(exportDir, jndiName,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export specific admin objects in all scopes
    exportAODir = os.path.join(exportDir,'exportAOs/specific/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in cell scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"true","false")
    
    #test export specific admin objects in dmgr node scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","true")
    
    #test export specific admin objects in dmgr server scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in custom node scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","true")
    
    #test export specific admin objects in nodeagent server scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in app server scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in sup server scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in me server scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in app cluster scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in sup cluster scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
    #test export specific admin objects in me cluster scope
    exportAODir = os.path.join(exportDir,'exportAOs/specific/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAOByJNDI(jndiName, exportAODir, scopeId,"false","false")
    
def doNamingSpaceUT(exportDir,_UT80CellName, _UT80DmgrName,_UT80DmgrServerName, _UT80NodeName,_UT80NodeAgentServerName,_UT80AppServerName,_UT80SupServerName,_UT80MeServerName,_UT80AppClusterName,_UT80SupClusterName,_UT80MeClusterName):
    #test export namespace bindings in all scopes
    exportNSDir = os.path.join(exportDir,'exportNSs/AllScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in cell scope
    exportNSDir = os.path.join(exportDir,'exportNSs/CellScope')
    scopeId=getScopeId(_UT80CellName, None, None, None)
    exportAllBindings(exportNSDir,scopeId,"true","false")
    
    #test export namespace bindings in dmgr node scope
    exportNSDir = os.path.join(exportDir,'exportNSs/DmgrNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,None,None)
    exportAllBindings(exportNSDir,scopeId,"false","true")
    
    #test export namespace bindings in dmgr server scope
    exportNSDir = os.path.join(exportDir,'exportNSs/DmgrNodeScope/DmgrServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80DmgrName,_UT80DmgrServerName,None)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in custom node scope
    exportNSDir = os.path.join(exportDir,'exportNSs/CustomNodeScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,None,None)
    exportAllBindings(exportNSDir,scopeId,"false","true")
    
    #test export namespace bindings in  nodeagent server scope
    exportNSDir = os.path.join(exportDir,'exportNSs/CustomNodeScope/NodeagentServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80NodeAgentServerName,None)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in app server scope
    exportNSDir = os.path.join(exportDir,'exportNSs/CustomNodeScope/AppServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80AppServerName,None)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in sup server scope
    exportNSDir = os.path.join(exportDir,'exportNSs/CustomNodeScope/SupServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80SupServerName,None)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in me server scope
    exportNSDir = os.path.join(exportDir,'exportNSs/CustomNodeScope/MeServerScope')
    scopeId = getScopeId(_UT80CellName,_UT80NodeName,_UT80MeServerName,None)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in app cluster scope
    exportNSDir = os.path.join(exportDir,'exportNSs/AppClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80AppClusterName)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in sup cluster scope
    exportNSDir = os.path.join(exportDir,'exportNSs/SupClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80SupClusterName)
    exportAllBindings(exportNSDir,scopeId,"false","false")
    
    #test export namespace bindings in me cluster scope
    exportNSDir = os.path.join(exportDir,'exportNSs/MeClusterScope')
    scopeId = getScopeId(_UT80CellName,None,None,_UT80MeClusterName)
    exportAllBindings(exportNSDir,scopeId,"false","false")

#main()
MAIN_METHOD="main"
logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Entering exportWASConfig.py")
logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Length of param:" + str(len(sys.argv)))
# parameter range
if len(sys.argv) < 1 or len(sys.argv) > 7:
    logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "Length of param < 1 or >7, print usage")
    usage()
    
# UT purpose
if len(sys.argv) == 3 and sys.argv[0] == "UT":
    outputDir = sys.argv[1]
    version_prefix=sys.argv[2]
    # concatenate exportDir with version_prefix 
    outputDir=os.path.join(outputDir,version_prefix)
    if(os.path.exists(outputDir)):
        shutil.rmtree(outputDir)
    os.makedirs(outputDir)
    doUT(outputDir,version_prefix)
    sys.exit()
    
# parameter type
exportAction=sys.argv[0]
logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Action name="+str(exportAction))
if exportAction == "-exportHelp":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Print usage as requested.")
    usage()
found="false"
for action in actions:
    logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "Export action: "+str(action))
    if exportAction == action:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Found export action: "+str(action))
        found="true"
        break
if found == "false":
    logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Not found export action, print usage")
    usage()

if sys.argv[0] == "-listDataSources":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list datasources as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "correct parameter and list datasources as requested.")
        listDataSources()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        dsUsage()
    sys.exit()

if sys.argv[0] == "-listJDBCProviders":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list JDBC providers as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "correct parameter and list JDBC providers as requested.")
        listJDBCProviders()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        jdbcProviderUsage()
    sys.exit()

if sys.argv[0] == "-listJMSProviders":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list JMS providers as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and list JMS providers as requested.")
        listJMSProviders()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        jmsProviderUsage()
    sys.exit()    

if sys.argv[0] == "-listAuthAliases":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list authentication alias as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and list authentication alias as requested.")
        listAuthAliases()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        aaUsage()
    sys.exit()

if sys.argv[0] == "-listConnectionFactories":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list connection factories as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and list connection factories as requested.")
        listConnectionFactories()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        cfUsage()
    sys.exit()
     
if sys.argv[0] == "-listActivationSpecs":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list activation specifications as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and list activation specifications as requested.")
        listActivationSpecs()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        asUsage()
    sys.exit()
    
if sys.argv[0] == "-listQueuesAndTopics":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list queues and topics as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and list queues and topics as requested.")
        listQueuesAndTopics()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        aoUsage()
    sys.exit()
    
if sys.argv[0] == "-listNameSpaceBindings":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "list namespace bindings as requested.")
    if len(sys.argv)==1:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and list namespace bindings as requested.")
        listNameSpaceBindings()
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        nsUsage()
    sys.exit()
    
if sys.argv[0] == "-exportAllDataSources":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all datasources as requested.")
    if len(sys.argv) >= 2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            dsUsage()
        if (len(sys.argv[2:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            dsUsage()
        paramMap = pasrseParam(sys.argv[2:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 2:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 4 and sys.argv[2] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 4 and sys.argv[2] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 4 and sys.argv[2] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 6 and sys.argv[2] == "-node" and sys.argv[4] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="NodeScope:"+nodeName + "; " + "ServerScope:"+serverName

        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            dsUsage()
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export all datasources as requested.")
            exportAllDataSources(outputDir,scopeId, cellOnly, nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        dsUsage()
    sys.exit()

if sys.argv[0] == "-exportAllConnectionFactories":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all connection factories as requested.")
    if len(sys.argv) >= 2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            cfUsage()
        if(len(sys.argv[2:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            cfUsage()
        paramMap = pasrseParam(sys.argv[2:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 2:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 4 and sys.argv[2] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 4 and sys.argv[2] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 4 and sys.argv[2] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 6 and sys.argv[2] == "-node" and sys.argv[4] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            cfUsage()
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export all connection factories as requested.")
            exportAllCFs(outputDir,scopeId, cellOnly, nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        cfUsage()
    sys.exit()
    
if sys.argv[0] == "-exportConnectionFactory":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export connection factory by JNDI name as requested.")
    if len(sys.argv) >= 3:
        cfJNDI = sys.argv[1]
        outputDir = sys.argv[2]
        if cfJNDI == "-exportHelp":
            cfUsage()
        if (len(sys.argv[3:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            cfUsage()
        paramMap = pasrseParam(sys.argv[3:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 3:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 5 and sys.argv[3] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 5 and sys.argv[3] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 5 and sys.argv[3] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 7 and sys.argv[3] == "-node" and sys.argv[5] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            cfUsage()
            
        # call export method to export
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export connection factory by JNDI name as requested.")
            exportCFByJNDI(cfJNDI,outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        cfUsage()
    sys.exit()

if sys.argv[0] == "-exportAllActivationSpecs":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all activation specifications as requested.")
    if len(sys.argv) >= 2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            asUsage()
        if (len(sys.argv[2:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            asUsage()
        paramMap = pasrseParam(sys.argv[2:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 2:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 4 and sys.argv[2] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 4 and sys.argv[2] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 4 and sys.argv[2] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 6 and sys.argv[2] == "-node" and sys.argv[4] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            asUsage()
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export all activation specifications as requested.")
            exportAllASes(outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        asUsage()
    sys.exit()

if sys.argv[0] == "-exportActivationSpec":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export activation specification by JNDI name as requested.")
    if len(sys.argv) >= 3:
        asJNDI = sys.argv[1]
        outputDir = sys.argv[2]
        if asJNDI == "-exportHelp":
            asUsage()
        if (len(sys.argv[3:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            asUsage()
        paramMap = pasrseParam(sys.argv[3:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 3:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 5 and sys.argv[3] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 5 and sys.argv[3] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 5 and sys.argv[3] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 7 and sys.argv[3] == "-node" and sys.argv[5] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            asUsage()
            
        # call export method to export
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export activation specification by JNDI name as requested.")
            exportASByJNDI(asJNDI,outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        asUsage()
    sys.exit()

if sys.argv[0] == "-exportAllJDBCProviders":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all JDBC providers as requested.")
    if len(sys.argv) >= 2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            jdbcProviderUsage()
        if (len(sys.argv[2:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            jdbcProviderUsage()
        paramMap = pasrseParam(sys.argv[2:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 2:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 4 and sys.argv[2] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 4 and sys.argv[2] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 4 and sys.argv[2] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 6 and sys.argv[2] == "-node" and sys.argv[4] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            jdbcProviderUsage()
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export all JDBC providers as requested.")
            exportAllJDBCProviders(outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        jdbcProviderUsage()
    sys.exit()

if sys.argv[0] == "-exportAllJMSProviders":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all JMS providers as requested.")
    if len(sys.argv) >= 2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            jmsProviderUsage()
        if (len(sys.argv[2:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            jmsProviderUsage()
        paramMap = pasrseParam(sys.argv[2:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 2:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 4 and sys.argv[2] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 4 and sys.argv[2] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 4 and sys.argv[2] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 6 and sys.argv[2] == "-node" and sys.argv[4] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            jmsProviderUsage()
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export all JMS providers as requested.")
            exportAllJMSProviders(outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        jmsProviderUsage()
    sys.exit()

if sys.argv[0] == "-exportAllQueuesAndTopics":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all queues and topics as requested.")
    if len(sys.argv) >= 2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            aoUsage()
        if (len(sys.argv[2:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            aoUsage()
        paramMap = pasrseParam(sys.argv[2:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 2:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 4 and sys.argv[2] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 4 and sys.argv[2] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 4 and sys.argv[2] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 6 and sys.argv[2] == "-node" and sys.argv[4] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            aoUsage()
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export all queues and topics as requested.")
            exportAllAOs(outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        aoUsage()
    sys.exit()
    
if sys.argv[0] == "-exportQueueOrTopic":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export queue and topic by JNDI name as requested.")
    if len(sys.argv) >= 3:
        aoJNDI = sys.argv[1]
        outputDir = sys.argv[2]
        if aoJNDI == "-exportHelp":
            aoUsage()
        if (len(sys.argv[3:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            aoUsage()
        paramMap = pasrseParam(sys.argv[3:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 3:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 5 and sys.argv[3] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 5 and sys.argv[3] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 5 and sys.argv[3] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 7 and sys.argv[3] == "-node" and sys.argv[5] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            aoUsage()
            
        # call export method to export
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export queue or topic by JNDI name as requested.")
            exportAOByJNDI(aoJNDI,outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        aoUsage()
    sys.exit()
    
if sys.argv[0] == "-exportNameSpaceBinding":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export namespace binding by identifier as requested.")
    if len(sys.argv) >= 3:
        nsIdentifier = sys.argv[1]
        outputDir = sys.argv[2]
        if nsIdentifier == "-exportHelp":
            nsUsage()
        if (len(sys.argv[3:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            nsUsage()
        paramMap = pasrseParam(sys.argv[3:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 3:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 5 and sys.argv[3] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 5 and sys.argv[3] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 5 and sys.argv[3] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 7 and sys.argv[3] == "-node" and sys.argv[5] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            print "INFO: Incorrect scope parameters input."
            nsUsage()
            
        # call export method to export
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export namespace binding by identifier as requested.")
            exportNsBindingsByIdentifier(nsIdentifier,outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        nsUsage()
    sys.exit()

if sys.argv[0] == "-exportAllNameSpaceBindings":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all namespace binding as requested.")
    if len(sys.argv) >= 2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            nsUsage()
        if (len(sys.argv[2:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            nsUsage()
        paramMap = pasrseParam(sys.argv[2:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 2:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 4 and sys.argv[2] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 4 and sys.argv[2] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 4 and sys.argv[2] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 6 and sys.argv[2] == "-node" and sys.argv[4] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Incorrect scope parameters input.")
            print "SEVERE: Incorrect scope parameters input."
            nsUsage()
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export all namespace bindings as requested.")
            exportAllBindings(outputDir,scopeId,cellOnly,nodeOnly)
        else:
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        nsUsage()
    sys.exit()

if sys.argv[0] == "-exportDataSource":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export data source by data source JNDI name as requested.")
    if len(sys.argv) >= 3:
        dsJNDI = sys.argv[1]
        outputDir = sys.argv[2]
        if dsJNDI == "-exportHelp":
            dsUsage()
        if (len(sys.argv[3:]))%2 != 0:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
            dsUsage()
        paramMap = pasrseParam(sys.argv[3:])
        cellName = paramMap.get("-cell")
        if not cellName:
            cellName = getCellName()
        nodeName = paramMap.get("-node")
        serverName = paramMap.get("-server")
        clusterName = paramMap.get("-cluster")
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Cell:"+str(cellName)+" Node:"+str(nodeName)+" Server:"+str(serverName)+" Cluster:"+str(clusterName))
        scopeId = getScopeId(cellName,nodeName,serverName,clusterName)
        #when scope ID is cell scope, all objects are exported, so we must set a flag to remove non-cell-scope objects
        cellOnly="false"
        #when scope ID is node scope, objects in both node and server scopes are exported, so we must set a flag to remove non-node-scope objects if the scope is set to node
        nodeOnly="false"
        #scopeStr is used to print log message when scope is not correct
        scopeStr=""
        if len(sys.argv) == 3:
            cellOnly="false"
            nodeOnly="false"
        
        elif len(sys.argv) == 5 and sys.argv[3] == "-cell":
            cellOnly="true"
            nodeOnly="false"
            scopeStr="CellScope: "+cellName
            
        elif len(sys.argv) == 5 and sys.argv[3] == "-node":
            cellOnly="false"
            nodeOnly="true"
            scopeStr="NodeScope: "+nodeName
    
        elif len(sys.argv) == 5 and sys.argv[3] == "-cluster":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ClusterScope: "+clusterName
            
        elif len(sys.argv) == 7 and sys.argv[3] == "-node" and sys.argv[5] == "-server":
            cellOnly="false"
            nodeOnly="false"
            scopeStr="ServerScope:"+serverName + "; " + "NodeScope:"+nodeName
        else:
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Incorrect scope parameters input.")
            print "INFO: Incorrect scope parameters input."
            dsUsage()
            
        # call export method to export
        if(scopeId):
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and export data source by JNDI name as requested.")
            exportDataSourceByJNDI(dsJNDI,outputDir,scopeId,cellOnly,nodeOnly)
        else:
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "INFO: Incorrect scope input. Confirm input: "+scopeStr+".")
            logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Failed to export WebSphere Application Server object.")
            print "**************************************"
            print "INFO: Incorrect scope input. Confirm input: "+scopeStr+"."
            print "ERROR: Failed to export WebSphere Application Server object."
            print "**************************************"
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        dsUsage()
    sys.exit()

if sys.argv[0] == "-exportSIBusConfig":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export SIBus configuration by bus name as requested.")
    if len(sys.argv)==3:
        busName = sys.argv[1]
        outputDir = sys.argv[2]
        if busName == "-exportHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "pint exportSIBusConfig action help as requested.")
            busUsage()
        exportSIBusConfigByName(busName,outputDir)
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        busUsage()
    sys.exit()

if sys.argv[0] == "-exportAuthAlias":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export authentication alias by name as requested.")
    if len(sys.argv)==3:
        authAliasName = sys.argv[1]
        outputDir = sys.argv[2]
        if authAliasName == "-exportHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "pint exportAuthAlias action help as requested.")
            aaUsage()
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "export  auth Aliase by name as requested.")
        exportAuthAliasByName(authAliasName,outputDir)
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        aaUsage()
    sys.exit()

if sys.argv[0] == "-exportAllAuthAliases":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all authentication aliases as requested.")
    if len(sys.argv)==2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "pint exportAllAuthAliases action help as requested.")
            aaUsage()
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "export all Auth Aliases as requested.")
        exportAllAuthAliases(outputDir)
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        aaUsage()
    sys.exit()

if sys.argv[0] == "-exportSSLSettings":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export all SSL settings as requested.")
    if len(sys.argv)==2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "pint exportSSLSettings action help as requested.")
            sslUsage()
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "export SSL Settings as requested.")
        exportSSLSettings(outputDir)
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        sslUsage()
    sys.exit()
    
if sys.argv[0] == "-exportJavaSecurityFile":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "export Java security settings as requested.")
    if len(sys.argv)==2:
        outputDir = sys.argv[1]
        if outputDir == "-exportHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "pint exportJavaSecurityFile action help as requested.")
            javaUsage()
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "export Java security settings as requested.")
        exportJavaSecurityFile(outputDir)
    else:
        logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "encounter incorrect parameter["+str(sys.argv)+"] and print usage.")
        javaUsage()
    sys.exit()
    
logger.logp(Level.SEVERE, _pyFileName, MAIN_METHOD, "Input parameters["+str(sys.argv)+"] are not incorrected, print usage.")
usage()