#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2014, 2016. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
import os,sys,shutil
import re
from java.lang import System
from java.util import Properties
from java.io import FileInputStream
from java.util import HashMap
from java.util.logging import Logger
from java.util.logging import FileHandler
from java.util.logging import ConsoleHandler
from java.util.logging import Level
from java.text import SimpleDateFormat
from java.util.logging import LogRecord
from java.lang import Boolean
from java.util.logging import Formatter
from java.util import Date
from java.io import File

loglevel=Level.INFO
actions = ["-importAuthAlias",\
           "-importAllAuthAliases",\
           "-importAllJDBCProviders",\
           "-importAllJMSProviders",\
           "-importDataSource",\
           "-importAllDataSources",\
           "-importNameSpaceBinding",\
           "-importAllNameSpaceBindings",\
           "-importSIBusConfig",\
           "-importConnectionFactory",\
           "-importAllConnectionFactories",\
           "-importQueueOrTopic",\
           "-importAllQueuesAndTopics",\
           "-importActivationSpec",\
           "-importAllActivationSpecs",\
           "-importJavaSecurityFile",\
           "-importAllSSLSettings",\
           "-importSSLSetting"]

overWriteExistingOne="false"
destinationAttributeMap = {}
aliasDestinationAttributeMap = {}
foreignDestinationAttributeMap = {}
sourceTargetMEMap={}
foreignBusMEMap={}
EXIT_CHOICE="Exit"

#------------------------------------------------------------------------------
# Print usage
#------------------------------------------------------------------------------
def usage():
    tips=[  "Import J2C authentication alias contained in the import directory by authentication alias name",\
            "Import all J2C authentication alias contained in the import directory",\
            "Import all JDBC providers contained in the import directory",\
            "Import all JMS providers contained in the import directory",\
            "Import data source configuration contained in the import directory by JNDI name",\
            "Import all data source configurations contained in the import directory",\
            "Import namespace bindings contained in the import directory by namespace bingding identifier",\
            "Import all namespace bindings contained in the import directory",\
            "Import SIBus configuration by bus name contained in the import directory",\
            "Import connection factory contained in the import directory by JNDI name",\
            "Import all connection factories contained in the import directory",\
            "Import queue or topic contained in the import directory by JNDI name",\
            "Import all queues and topics contained in the import directory",\
            "Import activation specification contained in the import directory by JNDI name",\
            "Import all activation specifications contained in the import directory",\
            "Import Java security file java.security",\
            "Import all SSL settings",\
            "Import SSL setting by alias name"]
    
    print "WebSphere Application Server configuration import usage:"
    print "For each detailed action usage, use '<Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py <action name> -importHelp':"
    print "For example: '<Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importDataSource -importHelp' will list import datasource usage."
    for action, tip in zip(actions,tips):
        if(len(action) >= 24):
            print action +"\t\t"+tip
        else:
            print action +"\t\t\t"+tip
    sys.exit()
    
#------------------------------------------------------------------------------
# Print activation specification import usage
#------------------------------------------------------------------------------
def asUsage():
    print "Activation specification related usage:\n"
    print "Import activation specification configuration contained in the import directory by JNDI name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importActivationSpec <activation_specification_JNDI> <import_dir>\n"
    
    print "Import all activation specifications contained in the import directory:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllActivationSpecs <import_dir>\n"
    sys.exit()
    
#------------------------------------------------------------------------------
# Print admin object import usage
#------------------------------------------------------------------------------
def aoUsage():
    print "Queue and Topic related usage:\n"
    print "Import queue or topic configuration contained in the import directory by JNDI name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importQueueOrTopic <queue_or_topic_JNDI> <import_dir>\n"
    
    print "Import all queues and topics contained in the import directory:\n"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllQueuesAndTopics <import_dir>\n"
    sys.exit()
    
#------------------------------------------------------------------------------
# Print connection factory import usage
#------------------------------------------------------------------------------
def cfUsage():
    print "Connection factory related usage:\n"
    print "Import connection factory configuration contained in the import directory by JNDI name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importConnectionFactory <connection_factory_JNDI> <import_dir>\n"
    
    print "Import all connection factories contained in the import directory:\n"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllConnectionFactories <import_dir>\n"
    sys.exit()
    
#------------------------------------------------------------------------------
# Print data source import usage
#------------------------------------------------------------------------------
def dsUsage():
    print "Datasource related usage:\n"
    print "Import data source configuration contained in the import directory by JNDI name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importDataSource <Datasource_JNDI> <import_dir>\n"
    
    print "Import all data sources configuration contained in the import directory:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllDataSources <import_dir>\n"
    sys.exit()
    
#------------------------------------------------------------------------------
# Print JDBC provider import usage
#------------------------------------------------------------------------------
def jdbcProviderUsage():
    print "JDBC provider related usage:\n"
    print "Import all JDBC providers contained in the import directory:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllJDBCProviders <import_dir>\n"
    
#------------------------------------------------------------------------------
# Print JMS provider provider import usage
#------------------------------------------------------------------------------
def jmsProviderUsage():
    print "JMS provider related usage:\n"
    print "Import all JMS providers contained in the import directory:\n"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllJMSProviders <import_dir>\n"
    sys.exit()
    
def busUsage():
    print "SIB bus related usage:\n"
    print "Import SIBbus configuration by bus name contained in the import directory:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importSIBusConfig <bus_name> <import_dir>\n"
    sys.exit()
    
def aaUsage():
    print "Authentication alias related usage:\n"
    print "Import J2C authentication alias contained in the import directory by authentication alias name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAuthAlias <Auth_Alias_Name> <import_dir>\n"
    
    print "Import all J2C authentication aliases contained in the import directory:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllAuthAliases <import_dir>\n"
    sys.exit()
    
def nsUsage():
    print "Namespace bindings related usage:\n"
    print "Import namespace bindings contained in the import directory by namespace identifier:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importNameSpaceBinding <namespace_identifier> <import_dir>\n"
    
    print "Import all namespace bindings contained in the import directory:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllNameSpaceBindings <import_dir>\n"
    sys.exit()

def javaUsage():
    print "java security related usage:\n"
    print "Import Java security file java.security:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importJavaSecurityFile <import_dir>\n"
    sys.exit()
    
def sslUsage():
    print "SSL related usage:\n"
    print "Import all SSL settings:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importAllSSLSettings <import_dir>\n"
    
    print "Import SSL setting by alias name:"
    print "usage: <Dmgr_Profile>/bin/wsadmin.sh -conntype NONE -f importWASConfig.py -importSSLSetting <SSLSetting_Alias_Name> <import_dir>\n"
    sys.exit()

class exportLogFormatter(Formatter):
    def format(self,LogRecord):
        logMsg = ""
        if LogRecord.getSourceClassName():
            logMsg=logMsg+"["+str(LogRecord.getLoggerName())+"/"+str(LogRecord.getLevel())+"]: "
            if LogRecord.getSourceMethodName():
                logMsg=logMsg+""+str(LogRecord.getSourceMethodName())+"()"
            logMsg=logMsg+": "
            if LogRecord.getMessage():
                logMsg=logMsg+str(LogRecord.getMessage())
        logMsg=logMsg+ System.getProperty("line.separator", "\r\n")
        return logMsg
    
def initlog():
    # define log file name
    pyFileName=_pyFileName[0:-3]
    datFormat=str(SimpleDateFormat("yyyyMMdd_HHmmss").format(Date()))
    _pyLogFileName=pyFileName+"_"+datFormat+".log"
    _pyLogFilePathName=os.path.join(sys.path[0], _pyLogFileName)
    print "INFO: the log file is in current directory and the name is: "+str(_pyLogFilePathName)
    # get the log object
    logger = Logger.getLogger("")
    # remove all handlers
    for handler  in logger.getHandlers():
        logger.removeHandler(handler)
    logger = Logger.getLogger(_pyFileName)
    logger.setLevel(Level.ALL)
    # define file handler
    filehandler = FileHandler(_pyLogFilePathName,Boolean.TRUE)
    filehandler.setLevel(loglevel)
    logger.addHandler(filehandler)
    formatter = exportLogFormatter()
    filehandler.setFormatter(formatter)
    # define console handler
    consoleHandler = ConsoleHandler()
    consoleHandler.setLevel(Level.OFF)
    logger.addHandler(consoleHandler)
    return logger

_pyFileName="importWASConfig.py"
logger=initlog()
#-----------------------------------------------------------------------------
# get the cell name
#-----------------------------------------------------------------------------
def getCellName():
    method="getCellName"
    logger.entering(_pyFileName, method)
    cellList = wsadminToList(AdminConfig.list('Cell'))
    cellName = AdminConfig.showAttribute(cellList[0],'name')
    logger.logp(Level.INFO, _pyFileName, method, "cellName: "+str(cellName))
    logger.exiting(_pyFileName, method)
    return cellName 

#--------------------------------------------------------------
# Helper Class to convert string to list
#--------------------------------------------------------------
def wsadminToList(inlist):
    method="wsadminToList"
    logger.entering(_pyFileName, method)
    logger.logp(Level.FINE, _pyFileName, method, "input string="+str(inlist))
    outList=[]
    if (len(inlist) > 0):
        if (inlist[0] == '[' and inlist[len(inlist) - 1] == ']'):
            # Special checking when the config name contain space 
            if (inlist[1] == "\"" and inlist[len(inlist)-2] == "\""):
                clist = inlist[1:len(inlist) -1].split(")\" ")
            else:
                clist = inlist[1:len(inlist) - 1].split(" ")
        else:
            clist = inlist.split(System.getProperty("line.separator"))

        for elem in clist:
            elem = elem.rstrip();   #removes any Windows "\r"
            if (len(elem) > 0):
                if (elem[0] == "\"" and elem[len(elem) -1] != "\""):
                    elem = elem+")\""
                outList.append(elem)
    logger.logp(Level.INFO, _pyFileName, method, "after convert="+str(outList))
    logger.exiting(_pyFileName, method)
    return outList
#endDef

def isJDBCProviderTypeMatch(objProviderType,jdbcProvider):
    method="isJDBCProviderTypeMatch"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(objProviderType)+", "+str(jdbcProvider))
    if jdbcProvider == EXIT_CHOICE:
        logger.logp(Level.INFO, _pyFileName, method, "jdbc provider is Exit, so return true directly.")
        logger.exiting(_pyFileName, method)
        return "true"
    selectedJDBCProviderType = AdminConfig.showAttribute(jdbcProvider,'providerType')
    logger.logp(Level.FINE, _pyFileName, method, "JDBC provider type of data source that will be imported is:" + str(objProviderType))
    logger.logp(Level.FINE, _pyFileName, method, "Selected JDBC provider type is:" + str(selectedJDBCProviderType))
    if(selectedJDBCProviderType == objProviderType):
        logger.logp(Level.INFO, _pyFileName, method, "is JDBC provider type matched? true")
        logger.exiting(_pyFileName, method)
        return "true"
    else:
        print "INFO: Selected JDBC provider type does not match the data source that will be imported. The JDBC provider type of the data source that will be imported is " +str(objProviderType) + " but selected JDBC provider type is " + str(selectedJDBCProviderType) + ". Select the JDBC provider again. If there is no matching JDBC provider listed, you must first create the JDBC provider."
        logger.logp(Level.INFO, _pyFileName, method, "INFO: Selected JDBC provider type does not match the data source that will be imported. The JDBC provider type of the data source that will be imported is " +str(objProviderType) + " but selected JDBC provider type is " + str(selectedJDBCProviderType) + ". Select the JDBC provider again. If there is no matching JDBC provider listed, you must first create the JDBC provider.")
        logger.logp(Level.INFO, _pyFileName, method, "is JDBC provider type matched? false")
        logger.exiting(_pyFileName, method)
        return "false"

def getPropertyValue(originalString,strRegexp):
    method="getPropertyValue"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(originalString)+", "+str(strRegexp))
    regexp=re.compile(strRegexp)
    value = None
    match = re.match(regexp,originalString)
    if(match != "" and match != None):
        value = match.group(1)
    #print "value of property " + strRegexp + str(value)
    if value:
        value=str(value)
        if value.startswith("\"") and value.endswith("\""):
            value = value[1:len(value)-1]
        #defect 232884, the description, sometime if we did not give value for this property, it will be "[]" which cannot be accepted by wasadmin API
        if value.startswith("[") and value.endswith("]"):
            temvalue = value[1:len(value)-1]
            if not temvalue:
                value=None
    logger.logp(Level.INFO, _pyFileName, method, "property value: "+str(value))
    logger.exiting(_pyFileName, method)
    return value

def excludeJDBCProviderByImplClassName(implClassName):
    method="excludeJDBCProviderByImplClassName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(implClassName))
    # Only provider implementation class name in this array should be exported
    implClassNameArray=["com.microsoft.sqlserver.jdbc.SQLServerXADataSource","com.microsoft.sqlserver.jdbc.SQLServerConnectionPoolDataSource","oracle.jdbc.xa.client.OracleXADataSource","com.ibm.db2.jcc.DB2XADataSource","com.ibm.db2.jcc.DB2ConnectionPoolDataSource","oracle.jdbc.pool.OracleConnectionPoolDataSource"]
    excluded="true"
    if(implClassName==None or implClassName ==""):
        excluded="true"
    else:
        for _implClassName in implClassNameArray:
            if(implClassName == _implClassName):
                excluded="false"
                break
    logger.logp(Level.INFO, _pyFileName, method, "is JDBC provider excluded? "+str(excluded))
    logger.exiting(_pyFileName, method)
    return excluded

########################################################################
# List all scopes for message engine during bus creation
# only clusters and cluster members and MQ server will be listed based on forMQServer flag
# cell scope, dmgr server, node agent, ME cluster will not be listed
########################################################################
def listScopeForMe(forMQServer):
    method="listScopeForMe"
    logger.entering(_pyFileName, method)
    scopes = []
    cellName = getCellName()
    nodeList = wsadminToList(AdminConfig.list('Node'))
    logger.logp(Level.INFO, _pyFileName, method, "node list: " + str(nodeList))    
    clusterList = wsadminToList(AdminConfig.list('ServerCluster'))
    logger.logp(Level.INFO, _pyFileName, method, "cluster list: " + str(clusterList))
    mqServerlist = wsadminToList(AdminConfig.list('SIBMQServer'))
    logger.logp(Level.INFO, _pyFileName, method, "mq server list: " + str(mqServerlist))
    index = 1
    if forMQServer == "false":
        for node in nodeList:
            nodeName = AdminConfig.showAttribute(node,'name')
            serverList = wsadminToList(AdminConfig.list('Server',node))
            for server in serverList:
                serverName = AdminConfig.showAttribute(server,'name')
                # only application server needed here
                if not ((serverName.find("dmgr") >=0 ) or (serverName.find("nodeagent") >=0)):
                    logger.logp(Level.INFO, _pyFileName, method, str(index) + ": Node=" + str(nodeName) + ",Server=" + str(serverName))
                    print str(index) + ": Node=" + nodeName + ",Server=" + serverName
                    scopes.append("/Cell:" + cellName + "/Node:"+nodeName + "/Server:" + serverName + "/")
                    index = index + 1
        for cluster in clusterList:
            clusterName = AdminConfig.showAttribute(cluster,'name')
            logger.logp(Level.INFO, _pyFileName, method, str(index) + ": Cluster=" + str(clusterName))
            #TODO exclude me cluster???
            print str(index) + ": Cluster=" + clusterName
            scopes.append("/Cell:" + cellName + "/ServerCluster:"+clusterName + "/")
            index = index + 1
    else:
        for mqServer in mqServerlist:
            mqServerName = AdminConfig.showAttribute(mqServer,'name')
            logger.logp(Level.INFO, _pyFileName, method, str(index) + ": WebSphere MQ server=" + mqServerName)
            print str(index) + ": WebSphere MQ server=" + mqServerName
            scopes.append("/Cell:" + cellName + "/MQServer:"+mqServerName + "/")
            index = index + 1
    logger.logp(Level.INFO, _pyFileName, method, "scopes for messaging engine are: "+str(scopes))
    logger.exiting(_pyFileName, method)
    return scopes
    
########################################################################
# List all scopes for user select based on flag
# needDmgrAndNodeagentServer = "true" means list dmgr server and 
#                              nodeagent server
# needDmgrAndNodeagentServer = "false" or None or empty  means only list
#                              application servers
########################################################################
def listScope(needDmgrAndNodeagentServer):
    method="listScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(needDmgrAndNodeagentServer))
    scopes = []
    cellList = wsadminToList(AdminConfig.list('Cell'))
    cellName = AdminConfig.showAttribute(cellList[0],'name') 
    nodeList = wsadminToList(AdminConfig.list('Node'))    
    clusterList = wsadminToList(AdminConfig.list('ServerCluster'))
    index = 1
    print str(index) + ": Cell=" + cellName
    logger.logp(Level.INFO, _pyFileName, method, str(index) + ": Cell=" + cellName)    
    index = index + 1    
    scopes.append("/Cell:" + cellName + "/")
    for node in nodeList:
        nodeName = AdminConfig.showAttribute(node,'name')
        print str(index) +": Node=" + nodeName
        logger.logp(Level.INFO, _pyFileName, method, str(index) +": Node=" + str(nodeName))
        scopes.append("/Cell:" + cellName + "/Node:"+nodeName + "/")
        index = index + 1
        serverList = wsadminToList(AdminConfig.list('Server',node))
        for server in serverList:
            serverName = AdminConfig.showAttribute(server,'name')
            if needDmgrAndNodeagentServer and needDmgrAndNodeagentServer == "false":
                # only application server needed here
                if (not serverName.startswith("dmgr")) and (not serverName.startswith("nodeagent")):
                    logger.logp(Level.INFO, _pyFileName, method, str(index) + ": Node=" + str(nodeName) + ",Server=" + str(serverName))
                    print str(index) + ": Node=" + nodeName + ",Server=" + serverName
                    scopes.append("/Cell:" + cellName + "/Node:"+nodeName + "/Server:" + serverName + "/")
                    index = index + 1
            # None, empty, or NOT "false" means list all servers
            else:
                logger.logp(Level.INFO, _pyFileName, method, str(index) + ": Node=" + str(nodeName) + ",Server=" + str(serverName))
                print str(index) + ": Node=" + nodeName + ",Server=" + serverName
                scopes.append("/Cell:" + cellName + "/Node:"+nodeName + "/Server:" + serverName + "/")
                index = index + 1
    for cluster in clusterList:
        clusterName = AdminConfig.showAttribute(cluster,'name')
        logger.logp(Level.INFO, _pyFileName, method, str(index) + ": Cluster=" + str(clusterName))
        print str(index) + ": Cluster=" + clusterName
        scopes.append("/Cell:" + cellName + "/ServerCluster:"+clusterName + "/")
        index = index + 1 
    logger.logp(Level.INFO, _pyFileName, method, "scopes: "+str(scopes))
    logger.exiting(_pyFileName, method)
    return scopes

########################################################################
# List all JDBC providers in specified scope
########################################################################
def listJDBCProviderByScope(selectedScope):        
    method="listJDBCProviderByScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(selectedScope))
    scopeId=AdminConfig.getid(selectedScope)
    jdbcProvderList = wsadminToList(AdminConfig.list('JDBCProvider',scopeId))
    jdbcProvderList=refreshObjIdListByScopeId(jdbcProvderList, scopeId)
    jdbcProviderFreshList=[]
    if (len(jdbcProvderList) <= 0):
        logger.logp(Level.INFO, _pyFileName, method, "There is no JDBC provider in the selected scope. You must create one first.")
    else:
        index = 1
        logger.logp(Level.INFO, _pyFileName, method, "INFO: JDBC providers in selected scope:")
        for jdbcProvider in jdbcProvderList:
            providerImplClassName=AdminConfig.showAttribute(jdbcProvider, "implementationClassName")
            if(excludeJDBCProviderByImplClassName(providerImplClassName)=="true"):
                continue
            logger.logp(Level.INFO, _pyFileName, method, str(index) + ": " + str(AdminConfig.showAttribute(jdbcProvider,'name')))
            print str(index) + ": " + AdminConfig.showAttribute(jdbcProvider,'name')
            jdbcProviderFreshList.append(jdbcProvider)
            index = index + 1
        # give user a chance to exit if no matched provider in scope
        if index > 1:
            logger.logp(Level.INFO, _pyFileName, method, str(index) + ": " + EXIT_CHOICE)
            print str(index) + ": " + EXIT_CHOICE
            jdbcProviderFreshList.append(EXIT_CHOICE)
    logger.logp(Level.INFO, _pyFileName, method, "JDBC providers: "+str(jdbcProviderFreshList))
    logger.exiting(_pyFileName, method)
    return jdbcProviderFreshList  

########################################################################
# List all messaging engines that belong to a certain bus for user select
########################################################################
def listMe(sibMEList):
    method="listMe"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(sibMEList))
    sibMeNames = []
    index = 1
    for sibME in sibMEList:
        sibMeName = AdminConfig.showAttribute(sibME,'name')
        logger.logp(Level.INFO, _pyFileName, method, str(index) + ": " + str(sibMeName))
        print str(index) + ": " + str(sibMeName)
        index = index + 1 
        sibMeNames.append(sibMeName)
    logger.logp(Level.INFO, _pyFileName, method, "List all messaging engines: "+str(sibMeNames))
    logger.exiting(_pyFileName, method)
    return sibMeNames

########################################################################
# Get matched resource adapter in specified scope for creating data source
# If match not found, will use built-in resource adapter
########################################################################
def getResourceAdapterIDByScope(selectedScope,objRAName):
    method="getResourceAdapterIDByScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(selectedScope)+", "+str(objRAName))
    matchedResourceAdapter = None
    builtinResourceAdapterID = None
    scopeId=AdminConfig.getid(selectedScope)
    resourceAdapterList = wsadminToList(AdminConfig.list('J2CResourceAdapter',scopeId))
    resourceAdapterList=refreshObjIdListByScopeId(resourceAdapterList, scopeId)
    if (len(resourceAdapterList) <= 0):
        logger.logp(Level.INFO, _pyFileName, method, "INFO: There is no resource adapter in the selected scope. You must create a new one first.")
    else:        
        for resourceAdapter in resourceAdapterList:
            logger.logp(Level.FINE, _pyFileName, method, "resource adapter is:"+str(resourceAdapter))
            if(AdminConfig.showAttribute(resourceAdapter,"name") == objRAName):                
                matchedResourceAdapter = resourceAdapter                
                break
            if(resourceAdapter.find("builtin_rra") > 0):
                logger.logp(Level.INFO, _pyFileName, method, "Built-in resource adapter was found.")
                builtinResourceAdapterID = resourceAdapter                
    if(matchedResourceAdapter != None):
        logger.logp(Level.INFO, _pyFileName, method, "INFO: Resource adapter " + str(objRAName) + " was found, and will be used to create the object.")
        logger.exiting(_pyFileName, method)
        return matchedResourceAdapter
    else:
        logger.logp(Level.INFO, _pyFileName, method, "INFO: Resource adapter " + str(objRAName) + " was not found. The built-in resource adapter will be used to create the object.")
        logger.logp(Level.INFO, _pyFileName, method, "resource adapter: "+str(matchedResourceAdapter))
        logger.exiting(_pyFileName, method)
        return builtinResourceAdapterID 

def readObjectAttributeFromFile(attributeFilePath):
    method="readObjectAttributeFromFile"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(attributeFilePath))
    try:
        attributeFile = open(attributeFilePath, "r")
        objAttributes = attributeFile.read()
        attributeFile.close()
        tmp = objAttributes.splitlines()
        objAttributesString = "".join(tmp)
    except:
        logger.logp(Level.SEVERE, _pyFileName, method, "Import action failed when reading attributes from "+str(attributeFilePath)+".")
        print "ERROR: Import action failed when reading attributes from "+str(attributeFilePath)+"."
        sys.exit()
        
    logger.logp(Level.FINE, _pyFileName, method, "object string from file: "+str(objAttributesString))
    logger.exiting(_pyFileName, method)
    return objAttributesString

def processAttriubutes(objAttributesString):
    method="processAttriubutes"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(objAttributesString))
    regexp = re.compile('''    (                # begin group 1
                            \[                # [
                            \w+\s+            # propertyName followed by spaces/newlines
                            \"[^\"]*        # " followed by a string (non-"-chars)
                            )                # end group 1
                            (\")            # group 2: evil "
                            (                # begin group 3
                            (?!\]+\s*\[).*?    # anything but ]..] [
                            \"\]            # "]
                            )                # end group 3
                        ''', re.DOTALL | re.VERBOSE)
                
                
    lastMatch = re.search(regexp, objAttributesString)
    while lastMatch != "" and lastMatch != None:
        objAttributesString = re.sub(regexp, r"\1'\3", objAttributesString)
        lastMatch = re.search(regexp, objAttributesString)
    logger.logp(Level.INFO, _pyFileName, method, "after process attribute string: "+str(objAttributesString))
    logger.exiting(_pyFileName, method)
    return objAttributesString

########################################################################
# get the sub-string from string that matched the regular expression
########################################################################
def getRegexpString(targetString,strRegexp):
    method="getRegexpString"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(targetString)+", "+str(strRegexp))
    returnStr=None
    regexp=re.compile(strRegexp)
    match = re.match(regexp,targetString)
    if(match != "" and match != None):
        returnStr = match.group(1)
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No match.")
    logger.logp(Level.INFO, _pyFileName, method, "matched sub string is: " + str(returnStr))
    logger.exiting(_pyFileName, method)
    return returnStr

########################################################################
# Replace the string that matched the regular expression with new value
########################################################################
def replaceRegexpWithNewValue(originalString,strRegexp,newValue):
    method="replaceRegexpWithNewValue"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(originalString)+", "+str(strRegexp)+", "+str(newValue))
    replaceString=originalString
    regexp=re.compile(strRegexp)
    match = re.match(regexp,originalString)
    if(match != "" and match != None):
        originalValue = match.group(1)
        replaceString = originalString.replace(originalValue, newValue)        
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No match.")
    logger.logp(Level.INFO, _pyFileName, method, "after replace new value: " + originalString)
    logger.exiting(_pyFileName, method)
    return replaceString
########################################################################
# Create data source with JDNI name and exported attributes
########################################################################
def importDataSourceByJNDIAndAttributes(jndiName,attributeFilePath,jdbcProvider,builtinresourceAdapterID):
    method="importDataSourceByJNDIAndAttributes"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(jndiName)+", "+str(attributeFilePath)+", "+str(jdbcProvider)+", "+str(builtinresourceAdapterID))
    objAttributesString = readObjectAttributeFromFile(attributeFilePath)
#     objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.+\[provider (\".+JDBCProvider_[0-9]+\)\")\].+',jdbcProvider)
#     objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.+\[relationalResourceAdapter (\".+builtin_rra\)\")\].+',builtinresourceAdapterID)
     
    #Need replace jdbc provider and relationResourceAdapter with actual one in target environment
    logger.logp(Level.INFO, _pyFileName, method, 'Replace "provider"['+jdbcProvider+'] property with actual value in target environment.')
    objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*\[provider (\[*.*?\]*)\].*',jdbcProvider)
    logger.logp(Level.INFO, _pyFileName, method, 'Replace "relationalResourceAdapter"['+builtinresourceAdapterID+']  property with actual value in target environment.')
    objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*\[relationalResourceAdapter (\[*.*?\]*)\].*',builtinresourceAdapterID)                   
    objAttributesString = processAttriubutes(objAttributesString)
    logger.logp(Level.INFO, _pyFileName, method, "INFO: Importing data source...")
    print "INFO: Importing data source..."
    AdminConfig.create("DataSource", jdbcProvider, "[" + objAttributesString + "]")
    AdminConfig.save()
    logger.exiting(_pyFileName, method)

def updateExistedDataSource(existedDataSource,attributeFilePath):
    method="updateExistedDataSource"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(existedDataSource)+", "+str(attributeFilePath))
    objAttributesString = readObjectAttributeFromFile(attributeFilePath)
    
    #Because the following three properties are read-only and cannot be updated, remove them from exported attributes
    logger.logp(Level.INFO, _pyFileName, method, 'Remove property "provider" from imported data source configuration because it is a read-only property that cannot be updated.')
    objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*(\[provider .*?\]).*',"")
    logger.logp(Level.INFO, _pyFileName, method, 'Remove property "relationalResourceAdapter" from imported data source configuration because it is a read-only property that cannot be updated.')
    objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*(\[relationalResourceAdapter .*?\]).*',"")      
    logger.logp(Level.INFO, _pyFileName, method, 'Remove property "providerType" from imported data source configuration because it is a read-only property that cannot be updated.')
    objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*(\[providerType .*?\]).*',"")
    
    objAttributesString = processAttriubutes(objAttributesString)
    AdminConfig.modify(existedDataSource,"[" + objAttributesString + "]")
    AdminConfig.save()
    logger.exiting(_pyFileName, method)
    
########################################################################
# Create data source by JNDI name
########################################################################                          
def importDataSourceByJNDI(jndiName, attributeFilePath,objProviderName,objProviderType,objRAName):
    method="importDataSourceByJNDI"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(jndiName)+", "+str(attributeFilePath)+", "+str(objProviderName)+", "+str(objProviderType)+", "+str(objRAName))
    selectedScope = getUserSelectedScope("false")
    if(selectedScope != None):
        scopeId = AdminConfig.getid(selectedScope)
        existedDataSource = dataSourceExisted(jndiName,scopeId)
        if(existedDataSource != None):
            overwrite = raw_input("Data source with JNDI name " + jndiName + " already exists. Would you like to overwrite its configuration?(Y/N)")
            isCorrectInput = 'false'
            while isCorrectInput == 'false':
                logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(overwrite)+".")
                if(overwrite == "Y" or overwrite == "y" or overwrite == "N" or overwrite == "n"):
                    isCorrectInput = 'true'
                else:
                    overwrite = raw_input("Data source with JNDI name " + jndiName + " already exists. Would you like to overwrite its configuration?(Y/N)")
            if(overwrite == "Y" or overwrite == "y"):
                updateExistedDataSource(existedDataSource,attributeFilePath)
                logger.logp(Level.INFO, _pyFileName, method, "INFO: Data source with JNDI name " + jndiName + " was updated successfully.")
                print "INFO: Data source with JNDI name " + jndiName + " was updated successfully."
            else:
                logger.logp(Level.INFO, _pyFileName, method, "INFO: Import of data source with JNDI name was skipped.")
                print "INFO: Import of data source with JNDI name was skipped."
        else:
            logger.logp(Level.INFO, _pyFileName, method, "INFO: Data source with JNDI name " + jndiName + " does not exist. Will import it.")
            print "INFO: Data source with JNDI name " + jndiName + " does not exist. Will import it."    
            builtinresourceAdapterID= getResourceAdapterIDByScope(selectedScope,objRAName)
            logger.logp(Level.INFO, _pyFileName, method, "Found builtin resource adapter in selected scope:" + str(builtinresourceAdapterID))
            jdbcProvider = getUserSelectedJDBCProvider(selectedScope)
            while builtinresourceAdapterID and jdbcProvider and isJDBCProviderTypeMatch(objProviderType,jdbcProvider) != "true":
                jdbcProvider = getUserSelectedJDBCProvider(selectedScope)                         
            if(jdbcProvider != None and builtinresourceAdapterID != None ):
                if not jdbcProvider == EXIT_CHOICE:
                    importDataSourceByJNDIAndAttributes(jndiName,attributeFilePath,jdbcProvider,builtinresourceAdapterID)
                    logger.logp(Level.INFO, _pyFileName, method, "INFO: Data source with JNDI name [" + jndiName + "] was imported successfully.")
                    print "INFO: Data source with JNDI name [" + jndiName + "] was imported successfully."
                else:
                    logger.logp(Level.INFO, _pyFileName, method, "Exit and skip to import WebSphere Application Object [" + jndiName + "].")
                    print "INFO: Skip to import WebSphere Application Object [" + jndiName + "]."
            else:
                logger.logp(Level.SEVERE, _pyFileName, method, ": Failed to import data source with JNDI name " + jndiName + " because the JDBC provider or adapter cannot be found.")
                print "ERROR: Failed to import data source with JNDI name " + jndiName + " because the JDBC provider or adapter cannot be found."
    logger.exiting(_pyFileName, method)

########################################################################
# Prompt user to select JDBC provider for creating data source
######################################################################## 
def getUserSelectedJDBCProvider(selectedScope):    
    method="getUserSelectedJDBCProvider"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(selectedScope))
    jdbcProvider = None
    jdbcProvderList = listJDBCProviderByScope(selectedScope)
    logger.logp(Level.FINE, _pyFileName, method, "provider list: "+str(jdbcProvderList))
    if(len(jdbcProvderList) > 0):
        selectJDBCProviderIndex = raw_input("Input the number to select the JDBC Provider for the data source:")
        isCorrectNumber = 'false'
        while isCorrectNumber == 'false':
            try:
                selectJDBCProviderIndex = int(selectJDBCProviderIndex)
                if(selectJDBCProviderIndex >= 1 and selectJDBCProviderIndex <= len(jdbcProvderList)):
                    isCorrectNumber = 'true'         
                else:
                    selectJDBCProviderIndex = raw_input("Incorrect number. Input the number of the JDBC provider for the data source:")                           
            except ValueError:
                selectJDBCProviderIndex = raw_input("Incorrect number. Input the number of the JDBC provider for the data source:")
        logger.logp(Level.INFO, _pyFileName, method, "selected JDBC Provider " + str(selectJDBCProviderIndex) + ": " + str(jdbcProvderList[selectJDBCProviderIndex - 1]))
        jdbcProvider = jdbcProvderList[selectJDBCProviderIndex - 1]
    else:
        logger.logp(Level.INFO, _pyFileName, method, "INFO: There is no JDBC provider in the selected scope. You must first create the required JDBC provider for the data source.")
        print( "INFO: There is no JDBC provider in the selected scope. You must first create the required JDBC provider for the data source.")
    logger.logp(Level.INFO, _pyFileName, method, "selected JDBC provider: "+str(jdbcProvider))
    logger.exiting(_pyFileName, method)
    return jdbcProvider

########################################################################
# Prompt user to select scope where to create data source based on flag
########################################################################            
def getUserSelectedScope(needDmgrAndNodeagentServer):
    method="getUserSelectedScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(needDmgrAndNodeagentServer))
    scopes = listScope(needDmgrAndNodeagentServer)
    logger.logp(Level.FINE, _pyFileName, method, "scopes="+str(scopes))
    selectScopeIndex = raw_input("Input the number to select the scope where you want to import this object:")
    isNumber = 'false'
    while isNumber == 'false':
        try:
            selectScopeIndex = int(selectScopeIndex)
            if(selectScopeIndex >= 1 and selectScopeIndex <= len(scopes)):
                isNumber = 'true'
            else:
                selectScopeIndex = raw_input("Incorrect number. Input the number to select the scope where you want to import the data source:")                     
        except ValueError:
            selectScopeIndex = raw_input("Incorrect number. Input the number to select the scope where you want to import this object:")
    logger.logp(Level.INFO, _pyFileName, method, "selected scope index " + str(selectScopeIndex) + ": " + str(scopes[selectScopeIndex - 1]))
    logger.exiting(_pyFileName, method)
    return scopes[selectScopeIndex - 1]

########################################################################
# Prompt user to select messaging engine used by activation specification
########################################################################            
def getUserSelectedME(sibMEList):
    method="getUserSelectedME"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(sibMEList))
    meNameList = listMe(sibMEList)
    selectScopeIndex = raw_input("Select the name of the messaging engine used to store messages delivered to durable subscriptions:")
    isNumber = 'false'
    while isNumber == 'false':
        try:
            selectScopeIndex = int(selectScopeIndex)
            if(selectScopeIndex >= 1 and selectScopeIndex <= len(meNameList)):
                isNumber = 'true'
        except ValueError:
            selectScopeIndex = raw_input("Incorrect number. Input the number to select the scope for which messaging engine you want to use:") 
    logger.logp(Level.INFO, _pyFileName, method, "selected scope index " + str(selectScopeIndex) + ": " + str(meNameList[selectScopeIndex - 1])) 
    logger.exiting(_pyFileName, method)
    return meNameList[selectScopeIndex - 1]

########################################################################
# Prompt user to select JDBC provider for creating data source
######################################################################## 
def getJDBCProviderByScopeAndName(selectedScope, providerName):
    method="getJDBCProviderByScopeAndName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(selectedScope)+", "+str(providerName))
    jdbcProvider = None
    jdbcProvderList = wsadminToList(AdminConfig.list('JDBCProvider',AdminConfig.getid(selectedScope)))
    if (len(jdbcProvderList) <= 0):
        logger.logp(Level.INFO, _pyFileName, method, "There is no JDBC provider in the selected scope. You must first create a new one.") 
    else:
        for provider in jdbcProvderList:
            if (AdminConfig.showAttribute(provider,'name') == providerName):
                jdbcProvider = provider
                break
    logger.logp(Level.INFO, _pyFileName, method, "selected JDBC provider: "+str(jdbcProvider))
    logger.exiting(_pyFileName, method)
    return jdbcProvider

def checkImportDirExisted(importDir):
    method="checkImportDirExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir))
    if(not os.path.exists(importDir) or not os.path.isdir(importDir)):
        logger.logp(Level.INFO, _pyFileName, method, "Import directory " + str(importDir) + " does not exist.") 
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.") 
        print "**************************************"
        print "INFO: Import directory " + str(importDir) + " does not exist."
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
        logger.exiting(_pyFileName, method)   
        sys.exit()
    logger.logp(Level.INFO, _pyFileName, method, "Import directory exists, and is " + str(importDir)) 
    logger.exiting(_pyFileName, method)
        
def importAuthAliasByName(authAliasName, attributeFilePath):
    method="importAuthAliasByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(authAliasName)+", "+str(attributeFilePath))
    existedAlias = None
    security = AdminConfig.list("Security")
    objAttributesString = readObjectAttributeFromFile(attributeFilePath)    
    objAttributesString = processAttriubutes(objAttributesString)    
    authAliasList = wsadminToList(AdminConfig.list("JAASAuthData",security))
    for authAlias in authAliasList:
        if(AdminConfig.showAttribute(authAlias,"alias") == authAliasName):
            existedAlias = authAlias
            break
    if(existedAlias == None ):
        logger.logp(Level.INFO, _pyFileName, method, "Importing J2C authentication...")
        print "INFO: Importing J2C authentication..."   
        AdminConfig.create('JAASAuthData', security, "[" + objAttributesString + "]")
        AdminConfig.save()
        logger.logp(Level.INFO, _pyFileName, method, "Import of J2C authentication data configuration was completed successfully.")
        print "INFO: Import of J2C authentication data configuration was completed successfully."
    else:
        overwrite = raw_input("J2C authentication alias with name " + authAliasName + " already exists. Would you like to overwrite it?(Y/N)")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            if(overwrite == "Y" or overwrite == "y" or overwrite == "N" or overwrite == "n"):
                isCorrectInput = 'true'
            else:
                overwrite = raw_input("J2C authentication alias with name " + authAliasName + " already exists. Would you like to overwrite it?(Y/N)")
        
        if(overwrite == "Y" or overwrite == "y"):
            AdminConfig.modify(existedAlias, "[" + objAttributesString + "]")
            AdminConfig.save()
            logger.logp(Level.INFO, _pyFileName, method, "J2C authentication with name " + authAliasName + " was updated successfully.")
            print "INFO: J2C authentication with name " + authAliasName + " was updated successfully."  
        else:
            logger.logp(Level.INFO, _pyFileName, method, "Import of J2C authentication with name " + authAliasName + " will be skipped.")
            print "INFO: Import of J2C authentication with name " + authAliasName + " will be skipped."    
    logger.exiting(_pyFileName, method)         
        
def printPrompt(objType):
    method="printPrompt"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(objType))
    if(objType == 0):
        print
        answer = raw_input("If the data source, connection factory, activation specification or SIBus configuration you are about to import refers to some non-default resources like J2C authentication data, resource adapter, or JDBC provider, make sure that you have already created those resources. Continue? (Y/N):")
        logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input("If the data source configuration you are about to import refers to some non-default resources like J2C authentication data, resource adapter, or JDBC provider, make sure that you have already created those resources. Continue? (Y/N):")
        if (answer != 'Y' and answer != 'y' ):
            logger.logp(Level.INFO, _pyFileName, method, "answer is not 'Y' or 'y' and exist.")
            logger.exiting(_pyFileName, method)
            sys.exit()
    if(objType == 1):
        print
        answer = raw_input('Before you import the J2C authentication data, check that all the exported object files like "JAASAuthData_<ID>.obj" have the correct value for the "password" property instead of the value"*****". Continue? (Y/N):')
        logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input('Before you import the J2C authentication data, check that all the exported object files like "JAASAuthData_<ID>.obj" have the correct value for the "password" property instead of the value"*****". Continue? (Y/N):')
        if (answer != 'Y' and answer != 'y' ):
            logger.exiting(_pyFileName, method)
            sys.exit()
    logger.exiting(_pyFileName, method)

def importSpecifiedDataSource(importDir,jndiName):
    method="importSpecifiedDataSource"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir)+", "+str(jndiName))
    printPrompt(0)
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    found="false"
    foundPropertiesFile="false"
    for fileName in dirList:
        if (fileName == "exportDS.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            if propsFile.keySet().size() <=0:
                continue
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                subPropertyName=str(key)[0:str(key).find(".ObjectFileName")]
                if(subPropertyName[0:subPropertyName.rfind(".")]==jndiName):
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    objType = propsFile.getProperty(propertyNamePrefix + ".ObjectType")
                    objFileName = propsFile.getProperty(propertyNamePrefix + ".ObjectFileName")
                    objProviderName = propsFile.getProperty(propertyNamePrefix + ".Provider")
                    objProviderType = propsFile.getProperty(propertyNamePrefix + ".ProviderType")
                    scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                    objRAName = propsFile.getProperty(propertyNamePrefix + ".ResourceAdapter")
                    print "**************************************"
                    if (objType and objType == "DataSource"):
                        found="true"
                        # check authentication alias is existed or not
                        # RTC defect 237151
                        objExisted=checkAuthAliasObjectOnTargetEnv(os.path.join(importDir,objFileName))
                        if objExisted == "true":
                            logger.logp(Level.INFO, _pyFileName, method,"Importing data source with JNDI name [" + str(jndiName) + "].")
                            print "INFO: Importing data source with JNDI name [" + str(jndiName) + "]."
                            logger.logp(Level.INFO, _pyFileName, method,"The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                            print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]."
                            importDataSourceByJNDI(jndiName,os.path.join(importDir,objFileName),objProviderName,objProviderType,objRAName)
                        else:
                            logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for datasource with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly.")
                            print "INFO: The authentication alias for object with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly."
                            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
                            print "ERROR: Failed to import WebSphere Application Server object."
                    else:
                        logger.logp(Level.INFO, _pyFileName, method,"The object with JNDI name " + str(jndiName) +" that you want to import is not a data source type.")
                        print "INFO: The object with JNDI name " + str(jndiName) +" that you want to import is not a data source type."
                        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
                        print "ERROR: Failed to import WebSphere Application Server object."
                    print "**************************************"                     
            inputSream.close()
    if(foundPropertiesFile=="true" and found=="false"):
        logger.logp(Level.INFO, _pyFileName, method, "The object with JNDI name " + str(jndiName) +" that you want to import could not be found in property file in the import directory " + str(importDir) + ".")
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object." )    
        print "**************************************"
        print "INFO: The object with JNDI name " + str(jndiName) +" that you want to import could not be found in property file in the import directory " + str(importDir) + "."
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    if(foundPropertiesFile=="false"):    
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportDS.properties could not be found in the import directory " + str(importDir) + ".")
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object." )    
        print "**************************************"    
        print "INFO: The property file exportDS.properties could not be found in the import directory " + str(importDir) + "." 
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
#--------------------------------------------------------------------------
# RTC defect 237151, check the authentication alias in target environment
# before import datasource object or other object
#--------------------------------------------------------------------------
def checkAuthAliasObjectOnTargetEnv(attributeFilePath):
    method="checkAuthAliasObjectOnTargetEnv"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(attributeFilePath))
    aliasPropNameList=["authDataAlias","xaRecoveryAuthAlias","authenticationAlias","interEngineAuthAlias","authAlias"]
    aliasCount=len(aliasPropNameList)
    existed = "false"
    objAttributesString = readObjectAttributeFromFile(attributeFilePath)
    for aliasPropName in aliasPropNameList:
        srcAuthAliasName=getRegexpString(objAttributesString, '.*?\['+aliasPropName+' (\[*.*?\]*)\].*')
        if srcAuthAliasName:
            # get the target authentication alias list
            globalSecurity = AdminConfig.list("Security" )
            authAliasesOnTargetEnvs = AdminConfig.list("JAASAuthData",globalSecurity)
            if len(authAliasesOnTargetEnvs) > 0:
                logger.logp(Level.INFO, _pyFileName, method, "looping auth alias list")
                for authAlias in wsadminToList(authAliasesOnTargetEnvs):
                    aliasName = AdminConfig.showAttribute(authAlias,"alias")
                    if aliasName and aliasName == srcAuthAliasName:
                        aliasCount=aliasCount-1
                        logger.logp(Level.INFO, _pyFileName, method, "target authentication alias found, aliasCount is " + str(aliasCount))
            else:
                logger.logp(Level.INFO, _pyFileName, method, "cannot check target authentication alias, since no target authentication alias found " + str(len(authAliasesOnTargetEnvs)))
        else:
            # if for certain alias property name it doesnot exist in source obj, return 'existed=true' directly
            aliasCount=aliasCount-1
            logger.logp(Level.INFO, _pyFileName, method, "no source authentication alias configured "+str(srcAuthAliasName) + ", return true directly.")
    if aliasCount == 0:
        existed = "true"
    logger.logp(Level.INFO, _pyFileName, method, "authentication alias existed in target environment? " + str(existed))
    logger.exiting(_pyFileName, method)
    return existed
    
def importAllDataSources(importDir):
    method="importAllDataSources"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir))
    printPrompt(0)
    checkImportDirExisted(importDir)
    logger.logp(Level.INFO, _pyFileName, method, "importDir: " + str(importDir))
    dirList = os.listdir(importDir)
    isEmpty="true"
    foundPropertiesFile="false"
    for fileName in dirList:
        if (fileName == "exportDS.properties"):
            foundPropertiesFile="true"
            propsFile = Properties()   
            propsFilePath = os.path.join(importDir,fileName) 
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            if propsFile.keySet().size() <=0:
                continue
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    isEmpty="false"
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    jndiName = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    logger.logp(Level.INFO, _pyFileName, method, "jndiName: " + str(jndiName))
                    attributeFileName = propsFile.getProperty(str(key))
                    logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + str(attributeFileName))
                    print "**************************************"
                    if(propsFile.getProperty(propertyNamePrefix + ".ObjectType") == "DataSource"):
                        # check authentication alias is existed or not
                        # RTC defect 237151
                        objExisted=checkAuthAliasObjectOnTargetEnv(os.path.join(importDir,attributeFileName))
                        if objExisted == "true":                            
                            objProviderName = propsFile.getProperty(propertyNamePrefix + ".Provider")
                            objProviderType = propsFile.getProperty(propertyNamePrefix + ".ProviderType")
                            objRAName = propsFile.getProperty(propertyNamePrefix + ".ResourceAdapter")
                            scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                            logger.logp(Level.INFO, _pyFileName, method, "Importing data source with JNDI name [" + str(jndiName) + "].")
                            logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                            print "INFO: Importing data source with JNDI name [" + str(jndiName) + "]."
                            print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]."
                            importDataSourceByJNDI(jndiName,os.path.join(importDir,attributeFileName),objProviderName,objProviderType,objRAName)            
                        else:
                            logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for object with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly.")
                            print "INFO: The authentication alias for object with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly."
                            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
                            print "ERROR: Failed to import WebSphere Application Server object."
                    else:
                        logger.logp(Level.INFO, _pyFileName, method, "The object with JNDI name " + str(jndiName) +" that you want to import is not a data source type.")
                        print "INFO: The object with JNDI name " + str(jndiName) +" that you want to import is not a data source type."
                        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
                        print "ERROR: Failed to import this WebSphere Application Server object."
                    print "**************************************"
    if foundPropertiesFile == "true" and isEmpty == "true":
        logger.logp(Level.INFO, _pyFileName, method, "No object could be found in property file in the import directory "+str(importDir)+".")
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "**************************************"
        print "INFO: No object could be found in property file in the import directory "+str(importDir)+"."
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    if(foundPropertiesFile=="false"):    
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportDS.properties could not be found in the import directory " + str(importDir) + ".")
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "**************************************"    
        print "INFO: The property file exportDS.properties could not be found in the import directory " + str(importDir) + "."
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
def importSpecifiedAuthAliasByName(importDir,authAliasName):
    method="importSpecifiedAuthAliasByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir)+", "+str(authAliasName))
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    found="false"
    foundPropertiesFile="false"
    for fileName in dirList:
        if (fileName == "exportAlias.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            objType = propsFile.getProperty(authAliasName + ".ObjectType")
            objFileName = propsFile.getProperty(authAliasName + ".ObjectFileName")
            inputSream.close()           
            if (objType):
                found="true"
                print "**************************************"
                if(objType == "JAASAuthData"):
                    logger.logp(Level.INFO, _pyFileName, method, "Importing J2C authentication with name [" + str(authAliasName) +"].")
                    print "INFO: Importing J2C authentication with name [" + str(authAliasName) +"]."
                    importAuthAliasByName(authAliasName,os.path.join(importDir,objFileName))
                else:
                    logger.logp(Level.INFO, _pyFileName, method, "The object with name " + str(authAliasName) +" that you want to import is not a J2C authentication type.")
                    logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                    print "INFO: The object with name " + str(authAliasName) +" that you want to import is not a J2C authentication type."
                    print "ERROR: Failed to import this WebSphere Application Server object."
                print "**************************************"
    if foundPropertiesFile=="true" and found =="false":
        logger.logp(Level.INFO, _pyFileName, method, "The object with name " + str(authAliasName) +" that you want to import could not be found in property file in the import directory " + str(importDir) +".")
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "**************************************"
        print "INFO: The object with name " + str(authAliasName) +" that you want to import could not be found in property file in the import directory " + str(importDir) +"."
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    if(foundPropertiesFile=="false"):    
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportAlias.properties could not be found in the import directory " + str(importDir) + ".")
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "**************************************"    
        print "INFO: The property file exportAlias.properties could not be found in the import directory " + str(importDir) + "."
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
def importAllAuthAliases(importDir):
    method="importAllAuthAliases"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir))
    checkImportDirExisted(importDir)
    logger.logp(Level.INFO, _pyFileName, method, "importDir: " + str(importDir))
    dirList = os.listdir(importDir)
    isEmpty="true"
    foundPropertiesFile="false"
    for fileName in dirList:
        if (fileName == "exportAlias.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.INFO, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    isEmpty="false"
                    authAiasName = str(key)[0:index]
                    logger.logp(Level.INFO, _pyFileName, method, "authAiasName: " + authAiasName)
                    attributeFileName = propsFile.getProperty(str(key))
                    logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + attributeFileName)
                    print "**************************************"
                    if(propsFile.getProperty(authAiasName + ".ObjectType") == "JAASAuthData"):
                        logger.logp(Level.INFO, _pyFileName, method, "Importing J2C authentication with name [" + str(authAiasName) + "].")
                        print "INFO: Importing J2C authentication with name [" + str(authAiasName) + "]."
                        importAuthAliasByName(authAiasName,os.path.join(importDir,attributeFileName))
                    else:
                        logger.logp(Level.INFO, _pyFileName, method, "The object with name " + str(authAiasName) +" that you want to import is not a J2C authentication type.")
                        print "INFO: The object with name " + str(authAiasName) +" that you want to import is not a J2C authentication type."
                        logger.logp(Level.INFO, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                        print "ERROR: Failed to import this WebSphere Application Server object."
                    print "**************************************"
    if foundPropertiesFile=="true" and isEmpty == "true":
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "No object could be found in property file in the import directory "+str(importDir)+".")
        print "INFO: No object could be found in property file in the import directory "+str(importDir)+"."
        logger.logp(Level.INFO, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"    
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportDS.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportDS.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.INFO, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
def importSSLSetting(importDir):   
    method="importSSLSetting"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir))
    print "**************************************"
    # SSL import will replace the original SSL setting, which may cause dmgr can not be started well, give this message to user
    answer = raw_input("Backup target <dmgr-profile>/config/cells/<cell-name>/security.xml file firstly, continue? (Y/N):")
    isCorrectInput = 'false'
    while isCorrectInput == 'false':
        logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
        if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
            isCorrectInput = 'true'
        else:
            answer = raw_input("Backup target <dmgr-profile>/config/cells/<cell-name>/security.xml file firstly, continue? (Y/N):")
    logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
    if (answer != 'Y' and answer != 'y' ):
        logger.logp(Level.INFO, _pyFileName, method, "answer is not 'Y' or 'y' and exist.")
        logger.exiting(_pyFileName, method)
        sys.exit()
    checkImportDirExisted(importDir) 
    dirList = os.listdir(importDir)
    sslSettingsIndex=1
    sslConfigAliasName=None
    srcSslSettingsIndexObjnameMap=HashMap()
    srcSslSettingsIndexScopeMap=HashMap()

    for fileName in dirList:
        if (fileName == "exportSSL.properties"):
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.INFO, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    sslConfigAliasName=propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    sslSettingFile = propsFile.getProperty(str(key))
                    sslSettingScope=propsFile.getProperty(str(propertyNamePrefix+".ScopeName"))
                    srcSslSettingsIndexObjnameMap.put(sslSettingsIndex, sslSettingFile)
                    srcSslSettingsIndexScopeMap.put(sslSettingsIndex,sslConfigAliasName + " - "+ sslSettingScope)
                    sslSettingsIndex=sslSettingsIndex+1
                       
    if srcSslSettingsIndexScopeMap and srcSslSettingsIndexScopeMap.keySet().size()>0:
        updatingSslSettings(srcSslSettingsIndexObjnameMap,srcSslSettingsIndexScopeMap, importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, method, "No setting for SSL configuration was found in the import directory " + str(importDir) + ".")
        print "INFO: No setting for SSL configuration was found in the import directory " + str(importDir) + "."
        logger.logp(Level.INFO, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to update WebSphere Application Server object."
    print "**************************************"
    logger.exiting(_pyFileName, method)

def importSpecifiedSSLSetting(importDir,sslConfigAliasName):
    method="importSpecifiedSSLSetting"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir)+", "+str(sslConfigAliasName))
    print "**************************************"
    # SSL import will replace the original SSL setting, which may cause dmgr can not be started well, give this message to user
    answer = raw_input("Backup target <dmgr-profile>/config/cells/<cell-name>/security.xml file firstly, continue? (Y/N):")
    isCorrectInput = 'false'
    while isCorrectInput == 'false':
        logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
        if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
            isCorrectInput = 'true'
        else:
            answer = raw_input("Backup target <dmgr-profile>/config/cells/<cell-name>/security.xml file firstly, continue? (Y/N):")
    logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
    if (answer != 'Y' and answer != 'y' ):
        logger.logp(Level.INFO, _pyFileName, method, "answer is not 'Y' or 'y' and exist.")
        logger.exiting(_pyFileName, method)
        sys.exit()
        
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    sslSettingsIndex=1
    srcSslSettingsIndexObjnameMap=HashMap()
    srcSslSettingsIndexScopeMap=HashMap()
    for fileName in dirList:
        if (fileName == "exportSSL.properties"):
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.INFO, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    if(propertyNamePrefix[0:propertyNamePrefix.rfind(".")] == sslConfigAliasName):
                        sslSettingFile = propsFile.getProperty(str(key))
                        sslSettingScope=propsFile.getProperty(str(propertyNamePrefix+".ScopeName"))
                        srcSslSettingsIndexObjnameMap.put(sslSettingsIndex, sslSettingFile)
                        srcSslSettingsIndexScopeMap.put(sslSettingsIndex,sslConfigAliasName + " - "+ sslSettingScope)
                        sslSettingsIndex=sslSettingsIndex+1
    if srcSslSettingsIndexScopeMap and srcSslSettingsIndexScopeMap.keySet().size()>0:
        updatingSslSettings(srcSslSettingsIndexObjnameMap,srcSslSettingsIndexScopeMap,importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, method, "INFO: Setting for SSL configuration with alias name " + str(sslConfigAliasName) + " was not found in the import directory " + str(importDir) + ".")
        print "INFO: Setting for SSL configuration with alias name " + str(sslConfigAliasName) + " was not found in the import directory " + str(importDir) + "."
        logger.logp(Level.INFO, _pyFileName, method, "Failed to update WebSphere Application Server object.")
        print "ERROR: Failed to update WebSphere Application Server object."
    print "**************************************" 
    logger.exiting(_pyFileName, method)

def updatingSslSettings(srcSslSettingsIndexObjnameMap,srcSslSettingsIndexScopeMap,importDir):
    method="updatingSslSettings"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(srcSslSettingsIndexObjnameMap)+", "+str(srcSslSettingsIndexScopeMap) +", "+str(importDir))
    if srcSslSettingsIndexScopeMap and srcSslSettingsIndexScopeMap.keySet().size()>0:
        targetSslIndexSettingsMap= HashMap()
        targetSslSettingsIndexScopeMap=HashMap()
        sslSettingsIndex=1
        sslConfigs = wsadminToList(AdminTask.listSSLConfigs('[-all true -displayObjectName true ]'))    
        if(len(sslConfigs) > 0):
            for sslConfig in sslConfigs:
                alias = AdminConfig.showAttribute(sslConfig,"alias")
                managementScope = AdminConfig.showAttribute(sslConfig,"managementScope")
                scopeName = AdminConfig.showAttribute(managementScope,"scopeName")
                targetSslSettingsIndexScopeMap.put(sslSettingsIndex, alias+ " - " +scopeName)
                targetSslIndexSettingsMap.put(sslSettingsIndex,sslConfig)
                sslSettingsIndex=sslSettingsIndex+1
                
            while srcSslSettingsIndexObjnameMap.keySet().size() >0:
                logger.logp(Level.INFO, _pyFileName, method, "Select source SSL setting scope which you want to update:")
                print
                print "Select source SSL setting scope which you want to update:"
                srcScopeindex=selectSslSettingScope(srcSslSettingsIndexScopeMap)
                srcSslSettingScope=str(srcSslSettingsIndexScopeMap.get(srcScopeindex))
                sslSettingObjFile=str(srcSslSettingsIndexObjnameMap.get(srcScopeindex))
                srcSslSettingsIndexScopeMap.remove(srcScopeindex)
                srcSslSettingsIndexObjnameMap.remove(srcScopeindex)
                logger.logp(Level.INFO, _pyFileName, method, "\nSelect target SSL setting scope where you want to update SSL setting:")
                print "\nSelect target SSL setting scope where you want to update SSL setting:"
                targetScopeIndex=selectSslSettingScope(targetSslSettingsIndexScopeMap)
                targetSslSettingScope=str(targetSslSettingsIndexScopeMap.get(targetScopeIndex))
                targetSslSetting = str(targetSslIndexSettingsMap.get(targetScopeIndex))
                targetSslIndexSettingsMap.remove(targetScopeIndex)
                targetSslSettingsIndexScopeMap.remove(targetScopeIndex)
                logger.logp(Level.INFO, _pyFileName, method, "Updating setting for SSL configuration ...")
                print "INFO: Updating setting for SSL configuration ..."
                updateStatus=updateExistedSSLSetting(AdminConfig.showAttribute(targetSslSetting,"setting"),os.path.join(importDir,sslSettingObjFile))
                if updateStatus=="true":
                    logger.logp(Level.INFO, _pyFileName, method, "Updating setting for SSL configuration: " + str(srcSslSettingScope) + " to target scope: "+ str(targetSslSettingScope) + " was completed.")
                    print "INFO: Updating setting for SSL configuration: " + str(srcSslSettingScope) + " to target scope: "+ str(targetSslSettingScope) + " was completed."
        else:
            logger.logp(Level.INFO, _pyFileName, method, "Failed to update WebSphere Application Server object.")
            print "ERROR: Failed to update WebSphere Application Server object."
            logger.logp(Level.INFO, _pyFileName, method, "No setting for SSL configuration was found in the target environment.")
            print "INFO: No setting for SSL configuration was found in the target environment."
    logger.exiting(_pyFileName, method)

def selectSslSettingScope(sslSettingsMap):
    method="selectSslSettingScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(sslSettingsMap))
    indexKeyMap={}
    index=1
    for key in sslSettingsMap.keySet():
        scopeName = str(sslSettingsMap.get(key))
        print str(index) + ", " +scopeName
        indexKeyMap[index]=str(key)
        index=index+1
    selectScopeIndex = raw_input("Input the number to select the SSL setting name and scope:")
    isNumber = 'false'
    while isNumber == 'false':
        try:
            selectScopeIndex = int(selectScopeIndex)
            if(selectScopeIndex >= 1 and selectScopeIndex <= sslSettingsMap.keySet().size()):
                isNumber = 'true'
            else:
                selectScopeIndex = raw_input("Incorrect number. Input the number to select the SSL setting name and scope:")                     
        except ValueError:
            selectScopeIndex = raw_input("Incorrect number. Input the number to select the SSL setting name and scope:")
    logger.logp(Level.INFO, _pyFileName, method, "selected scope index " + str(selectScopeIndex) + ", and scope name ="+str(sslSettingsMap.get(int(indexKeyMap[int(selectScopeIndex)]))))
    logger.exiting(_pyFileName, method)
    return int(indexKeyMap[int(selectScopeIndex)])
        
def updateExistedSSLSetting(sslConfigSetting, attributeFilePath):
    method="updateExistedSSLSetting"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(sslConfigSetting) + ", "+str(attributeFilePath))
    returnedStatus="false"
    #Read attributes for SSL setting that will be imported from file
    sslAttributeString = readObjectAttributeFromFile(attributeFilePath)
    #Replace 'keyManager' in SSL setting by the existing one in the target environment because the one exported from the source environment is not available in the target
    existedKeyManager = AdminConfig.showAttribute(sslConfigSetting,"keyManager")
    if(existedKeyManager != None and existedKeyManager != ""):
        sslAttributeString = replaceRegexpWithNewValue(sslAttributeString,'.*\[keyManager (\[*.*?\]*)\].*',existedKeyManager)
    else:
        logger.logp(Level.WARNING, _pyFileName, method, "KeyManager does not exist for selected SSL on target environment, will skip to update.")
        print "WARNING: KeyManager does not exist for selected SSL on target environment, will skip to update."
        logger.exiting(_pyFileName, method)
        return returnedStatus
    
    #Replace 'keyStore' in SSL setting by the existing one in the target environment because the one exported from the source environment is not available in the target
    existedKeyStore = AdminConfig.showAttribute(sslConfigSetting,"keyStore")
    if(existedKeyStore != None and existedKeyStore != ""):
        sslAttributeString = replaceRegexpWithNewValue(sslAttributeString,'.*\[keyStore (\[*.*?\]*)\].*',existedKeyStore)
    else:
        logger.logp(Level.WARNING, _pyFileName, method, "KeyStore does not exist for selected SSL on target environment, will skip to update.")
        print "WARNING: KeyStore does not exist for selected SSL on target environment, will skip to update."
        logger.exiting(_pyFileName, method)
        return returnedStatus
    
    #Replace 'trustManager' in SSL setting by the existing one in the target environment because the one exported from the source environment is not available in the target
    existedtrustManager = AdminConfig.showAttribute(sslConfigSetting,"trustManager")
    if(existedtrustManager != None and existedtrustManager != ""):
        sslAttributeString = replaceRegexpWithNewValue(sslAttributeString,'.*\[trustManager (\[*.*?\]*)\].*',existedtrustManager)
    else:
        logger.logp(Level.WARNING, _pyFileName, method, "TrustManager does not exist for selected SSL on target environment, will skip to update.")
        print "WARNING: TrustManager does not exist for selected SSL on target environment, will skip to update."
        logger.exiting(_pyFileName, method)
        return returnedStatus
    
    #Replace 'trustStore' in SSL setting by the existing one in the target environment because the one exported from the source environment is not available in the target
    existedtruststore = AdminConfig.showAttribute(sslConfigSetting,"trustStore")
    if(existedtruststore != None and existedtruststore != ""):
        sslAttributeString = replaceRegexpWithNewValue(sslAttributeString,'.*\[trustStore (\[*.*?\]*)\].*',existedtruststore)    
    else:
        logger.logp(Level.WARNING, _pyFileName, method, "TrustStore does not exist for selected SSL on target environment, will skip to update.")
        print "WARNING: TrustStore does not exist for selected SSL on target environment, will skip to update."
        logger.exiting(_pyFileName, method)
        return returnedStatus
    
    sslAttributeString = processAttriubutes(sslAttributeString)
    returnedStatus="true"
    AdminConfig.modify(sslConfigSetting,"[" + sslAttributeString + "]")
    AdminConfig.save()
    logger.logp(Level.INFO, _pyFileName, method, "update SSL statue: "+str(returnedStatus))
    logger.exiting(_pyFileName, method)
    return returnedStatus

########################################################################
# object list will contains all scope object id, this method will remove
# unwanted object id based on scope id
########################################################################
def refreshObjIdListByScopeId(objectIdlist, scopeId):
    method="refreshObjIdListByScopeId"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(objectIdlist) + ", "+str(scopeId))
    refreshedList=[]
    if objectIdlist:
        subScopeId = scopeId[scopeId.rfind("(")+1:scopeId.rfind("|")]
        scopes=subScopeId.split("/")
        for objectId in objectIdlist:
            subObjId = objectId[objectId.rfind("(")+1:objectId.rfind("|")]
            objScopes=subObjId.split("/")
            if(len(scopes) == len(objScopes)):
                if len(scopes) == 2 and str(objScopes[0])=="cells":
                    refreshedList.append(objectId)
                elif len(scopes) == 4 and str(objScopes[0])=="cells" and (str(objScopes[2])=="nodes" or str(objScopes[2])=="clusters"):
                    refreshedList.append(objectId)
                elif len(scopes) == 6 and str(objScopes[0])=="cells" and str(objScopes[2])=="nodes" and str(objScopes[4])=="servers":
                    refreshedList.append(objectId)
    logger.logp(Level.INFO, _pyFileName, method, "after refresh: "+str(refreshedList))
    logger.exiting(_pyFileName, method)
    return refreshedList

########################################################################
# Check if data source with specified JNDI name exists
########################################################################
def dataSourceExisted(jndiName, scopeId):
    method="dataSourceExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(jndiName) + ", "+str(scopeId))
    dataSourceList=AdminConfig.list("DataSource", scopeId)
    dataSources = wsadminToList(dataSourceList)
    dataSources=refreshObjIdListByScopeId(dataSources,scopeId)
    matchedDS = None
    for datasource in dataSources:
        tmpJNDIName=AdminConfig.showAttribute(datasource,"jndiName")
        if (tmpJNDIName != None and tmpJNDIName == jndiName):     
            matchedDS = datasource
            break
    logger.logp(Level.INFO, _pyFileName, method, "data source existed? "+str(matchedDS))
    logger.exiting(_pyFileName, method)
    return matchedDS

def importJavaSecurityFile(importDir):
    method="importJavaSecurityFile"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(importDir))
    print "**************************************" 
    checkImportDirExisted(importDir)    
    defaultJDKPath = getDefaultJDKPath()
    if defaultJDKPath:
        targetJavaSecurityFilePath = os.path.join(defaultJDKPath,'jre/lib/security/java.security')
        if not os.path.exists(targetJavaSecurityFilePath):
            logger.logp(Level.INFO, _pyFileName, method, "Target java.security file ["+str(targetJavaSecurityFilePath)+"] does not exist.")
            print "INFO: Target java.security file ["+str(targetJavaSecurityFilePath)+"] does not exist."
            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
            print "ERROR: Failed to import WebSphere Application Server object."
            print "**************************************"
            return
        sourceJavaSecurityFilePath = os.path.join(importDir,'java.security')
        if not os.path.exists(sourceJavaSecurityFilePath):
            logger.logp(Level.INFO, _pyFileName, method, "Source java.security file ["+str(sourceJavaSecurityFilePath)+"] does not exist.")
            print "INFO: Source java.security file ["+str(sourceJavaSecurityFilePath)+"] does not exist."
            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
            print "ERROR: Failed to import WebSphere Application Server object."
            print "**************************************"
            return
        mergeJavaSecurityFileContent(sourceJavaSecurityFilePath,targetJavaSecurityFilePath)
        logger.logp(Level.INFO, _pyFileName, method, ""+str(sourceJavaSecurityFilePath) + " was merged into " + str(targetJavaSecurityFilePath))
        print "INFO:" + str(sourceJavaSecurityFilePath) + " was merged into " + str(targetJavaSecurityFilePath)
    else:
        logger.logp(Level.INFO, _pyFileName, method, "Target cmd default JDK path "+str(defaultJDKPath)+" can not be found.")
        print "INFO: Target cmd default JDK path "+str(defaultJDKPath)+" can not be found."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object."
    print "**************************************"
    logger.exiting(_pyFileName, method)

def mergeJavaSecurityFileContent(sourceJavaSecurityFilePath,targetJavaSecurityFilePath):
    method="mergeJavaSecurityFileContent"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters: "+str(sourceJavaSecurityFilePath)+", "+str(targetJavaSecurityFilePath))
    #Backup java.security in target environment
    targetJavaSecurityFilePathBak = str(targetJavaSecurityFilePath) + ".bak"
    if(not os.path.exists(targetJavaSecurityFilePathBak)):
        logger.logp(Level.INFO, _pyFileName, method, "Backup " + str(targetJavaSecurityFilePath) + " to " + str(targetJavaSecurityFilePathBak))
        print "INFO: Backup " + str(targetJavaSecurityFilePath) + " to " + str(targetJavaSecurityFilePathBak)
        shutil.copy(targetJavaSecurityFilePath,targetJavaSecurityFilePathBak)
    else:
        logger.logp(Level.INFO, _pyFileName, method, "java.security file was already backup to " + str(targetJavaSecurityFilePathBak))
        print "INFO: java.security file was already backup to " + str(targetJavaSecurityFilePathBak)
    #Load source java.security content into a Properties object
    sourceJavaSecurityProperties = Properties()
    inputFile = FileInputStream(sourceJavaSecurityFilePath)
    sourceJavaSecurityProperties.load(inputFile)
    inputFile.close()
    #Load target java.security content into a Properties object
    targetJavaSecurityProperties = Properties()
    inputFile = FileInputStream(targetJavaSecurityFilePath)
    targetJavaSecurityProperties.load(inputFile)
    inputFile.close()
    #Process target java.security line by line and write to another temp file
    targetJavaSecurityFile = open(targetJavaSecurityFilePath,"r")
    tmpTargetJavaSecurityFile = open(str(targetJavaSecurityFilePath)+".tmp","w")
    while 1:
        line = targetJavaSecurityFile.readline()
        if (not line):
            break        
        #If the line is a comment line, write it into the temp file without any change
        if (line.startswith("# ")):
            tmpTargetJavaSecurityFile.write(line)
        #If the line is a commented-out property line, check if the property already exists in the target or source java.security file
        #If it exists in the target, we will handle it in the next step. If not, we will check if it exists in the source. If the commented-out property 
        # exists in the source, write the property into the temp file using the value set in the source
        elif (line.startswith("#") and line.find("=") != -1):
            key = line[1:line.find("=")]            
            if(not targetJavaSecurityProperties.containsKey(key) and sourceJavaSecurityProperties.containsKey(key)):
                tmpTargetJavaSecurityFile.write(key + "=" + str(sourceJavaSecurityProperties.get(key)) + "\n")
                sourceJavaSecurityProperties.put(key,"None")
            else:
                tmpTargetJavaSecurityFile.write(line)
        #Process property line. If the property exists in the source, replace the property value with the source value and write to temp file
        elif (line.find("=") != -1):
            key = line[0:line.find("=")]            
            if(sourceJavaSecurityProperties.containsKey(key)):
                tmpTargetJavaSecurityFile.write(key + "=" + str(sourceJavaSecurityProperties.get(key))+ "\n")
                sourceJavaSecurityProperties.put(key,"None")
            else:
                tmpTargetJavaSecurityFile.write(line)
        else:
            tmpTargetJavaSecurityFile.write(line)      
    # Append all properties that exist in the source java.security file but do not exist in the target  
    for key in sourceJavaSecurityProperties.keySet():
        if(sourceJavaSecurityProperties.get(key) != "None"):
            tmpTargetJavaSecurityFile.write(key + "=" + str(sourceJavaSecurityProperties.get(key))+ "\n")             
    targetJavaSecurityFile.close()
    tmpTargetJavaSecurityFile.close()
    #Replace the target java.security file with the temp file and delete the temp file
    shutil.copy(str(targetJavaSecurityFilePath)+".tmp",targetJavaSecurityFilePath)
    os.remove(str(targetJavaSecurityFilePath)+".tmp")
    logger.exiting(_pyFileName, method)
    
def getDefaultJDKPath():
    method="getDefaultJDKPath"
    logger.entering(_pyFileName, method)
    defaultSDKPath=None
    wasInstallRoot = System.getProperty('was.install.root')
    cmdDefaultSDKPropertyFilePath = os.path.join(wasInstallRoot,'properties/sdk/cmdDefaultSDK.properties')
    if not os.path.exists(cmdDefaultSDKPropertyFilePath):
        logger.logp(Level.INFO, _pyFileName, method, "Cmd JDK property file path ["+str(cmdDefaultSDKPropertyFilePath)+"] does not exist.")
        print "INFO: Cmd JDK property file path ["+str(cmdDefaultSDKPropertyFilePath)+"] does not exist."
        return defaultSDKPath
    cmdDefaultSDKProperty = Properties()    
    inputFile = FileInputStream(cmdDefaultSDKPropertyFilePath)
    cmdDefaultSDKProperty.load(inputFile)
    defaultSDKValue = cmdDefaultSDKProperty.getProperty('COMMAND_DEFAULT_SDK')
    inputFile.close()
    defaultSdkProperty = Properties()
    defaultSdkPropertyFilePath = os.path.join(wasInstallRoot,'properties/sdk/' + str(defaultSDKValue) + ".properties")
    if not os.path.exists(defaultSdkPropertyFilePath):
        logger.logp(Level.INFO, _pyFileName, method, "Cmd default JDK property file path ["+str(defaultSdkPropertyFilePath)+"] does not exist.")
        print "INFO: Cmd default JDK property file path ["+str(defaultSdkPropertyFilePath)+"] does not exist."
        return defaultSDKPath
    inputFile = FileInputStream(defaultSdkPropertyFilePath)
    defaultSdkProperty.load(inputFile)
    defaultSDKPath = defaultSdkProperty.get('com.ibm.websphere.sdk.location.' + str(defaultSDKValue))
    defaultSDKPath = defaultSDKPath.replace('${WAS_INSTALL_ROOT}',wasInstallRoot)
    logger.logp(Level.INFO, _pyFileName, method, "Default JDK path is " + str(defaultSDKPath))
    print "INFO: Default JDK path is " + str(defaultSDKPath)
    inputFile.close()
    logger.logp(Level.INFO, _pyFileName, method, "Default JDK path is: "+str(defaultSDKPath))
    logger.exiting(_pyFileName, method)    
    return defaultSDKPath

def checkNsObjectType(objType):
    method="checkNsObjectType"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(objType))
    correctType="false"
    if(objType):
        if(objType =="StringNameSpaceBinding" or objType == "EjbNameSpaceBinding" or objType == "CORBAObjectNameSpaceBinding" or objType=="IndirectLookupNameSpaceBinding"):
            correctType="true"
    logger.logp(Level.INFO, _pyFileName, method, "namespace object type is: "+str(correctType))
    logger.exiting(_pyFileName, method)
    return correctType
    
########################################################################
# Create namespace bindings
########################################################################
def importNameSpaceBinding(identifier, importDir):
    method="importNameSpaceBinding"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(identifier)+", "+str(importDir))
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    found="false"
    foundPropertiesFile="false"
    for fileName in dirList:
        if fileName.endswith("exportNameSpaceBinding.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    name = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    if not (name == identifier):
                        continue
                    found="true"
                    scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                    attributeFileName = propsFile.getProperty(str(key))
                    objType=propsFile.getProperty(propertyNamePrefix + ".ObjectType")
                    print "**************************************"
                    if(objType and (checkNsObjectType(objType)=="true")):
                        logger.logp(Level.INFO, _pyFileName, method, "Importing namespace binding with name [" + str(name) + "]")
                        print "INFO: Importing namespace binding with name [" + str(name) + "]"
                        logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"]")
                        print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]"
                        importNameSpaceBindingByName(name, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), os.path.join(importDir,attributeFileName))
                    else:
                        logger.logp(Level.WARNING, _pyFileName, method, "The object with name " + str(identifier) +" that you want to import is not a namespace binding type.")
                        print "WARNING: The object with name " + str(identifier) +" that you want to import is not a namespace binding type."
                    print "**************************************"
    if(foundPropertiesFile=="true" and found=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The namespace binding object with name " + str(identifier) +" that you want to import could not be found in property file in the import directory " + importDir + ".")
        print "INFO: The namespace binding object with name " + str(identifier) +" that you want to import could not be found in property file in the import directory " + importDir + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"    
        print "INFO: The property file exportNameSpaceBinding.properties could not be found in the import directory " + importDir + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
########################################################################
# Create namespace bindings
########################################################################
def importAllNameSpaceBindings(importDir):
    method="importAllNameSpaceBindings"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(importDir))
    checkImportDirExisted(importDir)
    # printPrompt(0) 
    dirList = os.listdir(importDir)
    isEmpty="true"
    foundPropertiesFile="false"
    for fileName in dirList:
        if fileName.endswith("exportNameSpaceBinding.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    isEmpty="false"
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    name = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    logger.logp(Level.INFO, _pyFileName, method, "name: " + str(name))
                    attributeFileName = propsFile.getProperty(str(key))
                    scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                    objType=propsFile.getProperty(propertyNamePrefix + ".ObjectType")
                    print "**************************************"
                    if(objType and (checkNsObjectType(objType)=="true")):
                        logger.logp(Level.INFO, _pyFileName, method, "Importing namespace binding with name [" + str(name) + "]")
                        logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"]")
                        print "INFO: Importing namespace binding with name [" + str(name) + "]"
                        print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]"
                        importNameSpaceBindingByName(name, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), os.path.join(importDir,attributeFileName))
                    else:
                        logger.logp(Level.INFO, _pyFileName, method, "The object with name " + str(name) +" that you want to import is not a namespace binding type.")
                        print "INFO: The object with name " + str(name) +" that you want to import is not a namespace binding type."
                        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                        print "ERROR: Failed to import this WebSphere Application Server object."
                    print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"    
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportNameSpaceBinding.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportNameSpaceBinding.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    if foundPropertiesFile=="true" and isEmpty == "true":
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "No namespace binding object could be found in property file in the import directory "+str(importDir)+".")
        print "INFO: No namespace binding object could be found in property file in the import directory "+str(importDir)+"."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
def nsExisted(name,objType,scopeId):
    method="nsExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(name)+", "+str(objType)+", "+str(scopeId))
    nsObjectList = AdminConfig.list(objType,scopeId)
    nsList = wsadminToList(nsObjectList)
    nsList=refreshObjIdListByScopeId(nsList, scopeId)
    matchedNs = None
    for ns in nsList:
        tmpJPName=AdminConfig.showAttribute(ns,"name")
        if (tmpJPName != None and tmpJPName == name):     
            matchedNs = ns
            break
    logger.logp(Level.INFO, _pyFileName, method, "namespace existed? "+str(matchedNs))
    logger.exiting(_pyFileName, method)
    return matchedNs

def importNameSpaceBindingByName(name, objType, attributeFilePath):
    method="importNameSpaceBindingByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(name)+", "+str(objType)+", "+str(attributeFilePath))
    selectedScope = getUserSelectedScope("true")
    scopeId = AdminConfig.getid(selectedScope)
    
    existedNs = nsExisted(name,objType, scopeId)
    
    if(existedNs != None):
        logger.logp(Level.INFO, _pyFileName, method, "Import of namespace binding with name " + str(name) + " already exists. Will skip it.")
        print "INFO: Import of namespace binding with name " + str(name) + " already exists. Will skip it."
        #if (overWriteExistingOne == "true"):
            # TODO: for update
            #updateExistedDataSource(existedDataSource,attributeFilePath)
        #   print "INFO: TODO: JMS provider with name [" + providerName + "] was updated successfully."
        #else:
        #    print "INFO: JMS provider with name [" + providerName + "] already exists. Will skip it."
    else:    
        logger.logp(Level.INFO, _pyFileName, method, "Namespace binding with name " + str(name) + " does not exist on target environment. Will import it.")
        print "INFO: Namespace binding with name " + str(name) + " does not exist on target environment. Will import it."  
        answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        if (answer != 'Y' and answer != 'y' ):
            return

        if (selectedScope != None):
            #print "INFO: Using " + selectedScope
            objAttributesString = readObjectAttributeFromFile(attributeFilePath)
            objAttributesString = processAttriubutes(objAttributesString) 
            logger.logp(Level.INFO, _pyFileName, method, "Importing namespace binding...")
            print "INFO: Importing namespace binding..."          
            result = AdminConfig.create(objType, scopeId, "[" + objAttributesString + "]")
            AdminConfig.save()
            logger.logp(Level.INFO, _pyFileName, method, "namespace binding importing result: "+str(result))
            print "INFO: Import of namespace binding with name [" + name + "] was imported successfully."
        else:
            logger.logp(Level.INFO, _pyFileName, method, "No scope found on target environment " + str(selectedScope) + ".")
            print "INFO: No scope found on target environment " + str(selectedScope) + "."
            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
            print "ERROR: Failed to import this WebSphere Application Server object."
    logger.exiting(_pyFileName, method)
    
########################################################################
# Create JDBC providers
########################################################################
def importAllJDBCProviders(importDir):
    method="importAllJDBCProviders"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(importDir))
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    foundPropertiesFile="false"
    isEmpty = "true"
    for fileName in dirList:
        if fileName.endswith("exportJDBCProvider.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            if(propsFile.keySet().size()>0):
                for key in propsFile.keySet():
                    logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                    index = str(key).find(".ObjectFileName")
                    namePrefix=key[0:index+1]
                    if(index > 0):
                        isEmpty = "false"
                        providerName = str(propsFile.getProperty(namePrefix+"JDBCProviderName"))
                        scopeIdInSrc = propsFile.getProperty(namePrefix + "ScopeId")
                        objType = propsFile.getProperty(namePrefix + "ObjectType")
                        attributeFileName = propsFile.getProperty(str(key))
                        print "**************************************"
                        if objType and objType == "JDBCProvider":
                            logger.logp(Level.INFO, _pyFileName, method, "Importing JDBC provider with name [" + str(providerName)+"].")
                            logger.logp(Level.FINE, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                            print "INFO: Importing JDBC provider with name [" + str(providerName)+"]."
                            print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]."
                            importJDBCProvider(providerName, propsFile.getProperty(namePrefix+"ObjectType"), os.path.join(importDir,attributeFileName))
                        else:
                            logger.logp(Level.FINE, _pyFileName, method, "The object that you want to import is not a JDBC provider type.")
                            print "INFO: The object that you want to import is not a JDBC provider type."
                            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                            print "ERROR: Failed to import this WebSphere Application Server object."
                        print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.FINE, _pyFileName, method, "The property file exportJDBCProvider.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportJDBCProvider.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
        
    if foundPropertiesFile=="true" and isEmpty == "true":
        print "**************************************"
        logger.logp(Level.FINE, _pyFileName, method, "No JDBC provider object could be found in property file in the import directory "+str(importDir)+".")
        print "INFO: No JDBC provider object could be found in property file in the import directory "+str(importDir)+"."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
def importJDBCProvider(providerName, objType, attributeFilePath):
    method="importJDBCProvider"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(providerName)+", "+str(objType)+", "+str(attributeFilePath))
    selectedScope = getUserSelectedScope("false")
    scopeId = AdminConfig.getid(selectedScope)     
    
    existedJDBCProvider = jdbcProviderExisted(providerName, scopeId)

    if(existedJDBCProvider != None):
        logger.logp(Level.FINE, _pyFileName, method, "Import of JDBC provider with name " + str(providerName) + " already exists. Will skip it.")
        print "INFO: Import of JDBC provider with name " + str(providerName) + " already exists. Will skip it."
        #if (overWriteExistingOne == "true"):
            # TODO: for update
            #updateExistedDataSource(existedDataSource,attributeFilePath)
        #    print "INFO: TODO: JDBC provider with name [" + providerName + "] was updated successfully."
        #else:
        #    print "INFO: JDBC provider with name [" + providerName + "] already exists. Will skip it."
    else:    
        logger.logp(Level.FINE, _pyFileName, method, "JDBC provider with name [" + str(providerName) + "] does not exist. Will import it.")
        print "INFO: JDBC provider with name [" + str(providerName) + "] does not exist. Will import it."  
        answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        if (answer != 'Y' and answer != 'y' ):
            return

        objAttributesString = readObjectAttributeFromFile(attributeFilePath)

        #print "INFO: Using " + selectedScope
        objAttributesString = readObjectAttributeFromFile(attributeFilePath)
        objAttributesString = processAttriubutes(objAttributesString)
        logger.logp(Level.FINE, _pyFileName, method, "Importing JDBC provider ...")
        print "INFO: Importing JDBC provider ..."      
        result = AdminConfig.create(objType, scopeId, "[" + objAttributesString + "]")
        AdminConfig.save()
        logger.logp(Level.INFO, _pyFileName, method, "JDBC provider importing result: " + str(result))
        print "INFO: JDBC provider with name [" + providerName + "] was imported successfully."        
    logger.exiting(_pyFileName, method)
        
def jdbcProviderExisted(providerName,scopeId):
    method="jdbcProviderExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(providerName)+", "+str(scopeId))
    jpObjectList = AdminConfig.list("JDBCProvider",scopeId)
    jpList = wsadminToList(jpObjectList)
    jpList=refreshObjIdListByScopeId(jpList, scopeId)
    matchedJP = None
    for jp in jpList:
        tmpJPName=AdminConfig.showAttribute(jp,"name")
        if (tmpJPName != None and tmpJPName == providerName):     
            matchedJP = jp
            break
    logger.logp(Level.INFO, _pyFileName, method, "JDBC provider existed? "+str(matchedJP))
    logger.exiting(_pyFileName, method)
    return matchedJP

########################################################################
# Create JMS providers
########################################################################
def importAllJMSProviders(importDir):
    method="importAllJMSProviders"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(importDir))
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    foundPropertiesFile="false"
    isEmpty="true"
    for fileName in dirList:
        if fileName.endswith("exportJMSProvider.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            if(propsFile.keySet().size()>0):
                for key in propsFile.keySet():
                    logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                    index = str(key).find(".ObjectFileName")
                    namePrefix=key[0:index+1]
                    if(index > 0):
                        isEmpty="false"
                        providerName = str(propsFile.getProperty(namePrefix+"JMSProviderName"))
                        attributeFileName = propsFile.getProperty(str(key))
                        scopeIdInSrc = propsFile.getProperty(namePrefix + "ScopeId")
                        objType = propsFile.getProperty(namePrefix + "ObjectType")
                        print "**************************************"
                        if objType and objType == "JMSProvider":
                            logger.logp(Level.FINE, _pyFileName, method, "Importing JMS provider with name [" + str(providerName)+"].")
                            print "INFO: Importing JMS provider with name [" + str(providerName)+"]."
                            logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                            print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]."
                            importJMSProvider(providerName, propsFile.getProperty(namePrefix+"ObjectType"), os.path.join(importDir,attributeFileName))
                        else:
                            logger.logp(Level.INFO, _pyFileName, method, "The object that you want to import is not a JMS provider type.")
                            print "INFO: The object that you want to import is not a JMS provider type."
                            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                            print "ERROR: Failed to import this WebSphere Application Server object."
                        print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportJMSProvider.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportJMSProvider.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
        
    if foundPropertiesFile=="true" and isEmpty == "true":
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "No JMS provider object could be found in property file in the import directory "+str(importDir)+".")
        print "INFO: No JMS provider object could be found in property file in the import directory "+str(importDir)+"."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"                    
    logger.exiting(_pyFileName, method)

def importJMSProvider(providerName, objType, attributeFilePath):
    method="importJMSProvider"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(providerName)+", "+str(objType)+", "+str(attributeFilePath))
    selectedScope = getUserSelectedScope("false")
    scopeId = AdminConfig.getid(selectedScope)     
    
    existedJMSProvider = jmsProviderExisted(providerName, scopeId)

    if(existedJMSProvider != None):
        logger.logp(Level.INFO, _pyFileName, method, "Import of JMS Provider with name " + str(providerName) + " already exists. Will skip it.")
        print "INFO: Import of JMS Provider with name " + str(providerName) + " already exists. Will skip it."
        #if (overWriteExistingOne == "true"):
            # TODO: for update
            #updateExistedDataSource(existedDataSource,attributeFilePath)
        #   print "INFO: TODO: JMS provider with name [" + providerName + "] was updated successfully."
        #else:
        #    print "INFO: JMS provider with name [" + providerName + "] already exists. Will skip it."
    else:   
        logger.logp(Level.INFO, _pyFileName, method, "JMS provider with name [" + str(providerName) + "] does not exist. Will import it.") 
        print "INFO: JMS provider with name [" + str(providerName) + "] does not exist. Will import it."  
        answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        if (answer != 'Y' and answer != 'y' ):
            return

        if (selectedScope != None):
            #print "INFO: Using " + selectedScope
            objAttributesString = readObjectAttributeFromFile(attributeFilePath)
            objAttributesString = processAttriubutes(objAttributesString)    
            logger.logp(Level.INFO, _pyFileName, method, "Importing JMS provider...")
            print "INFO: Importing JMS provider..."        
            result = AdminConfig.create(objType, scopeId, "[" + objAttributesString + "]")
            AdminConfig.save()
            logger.logp(Level.FINE, _pyFileName, method, "JMS provider importing result: "+result)
            print "INFO: JMS provider with name [" + providerName + "] was imported successfully."
        else:
            logger.logp(Level.INFO, _pyFileName, method, "No scope was found on target environment " + str(selectedScope) + ".")
            print "INFO: No scope was found on target environment " + str(selectedScope) + "."
            logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
            print "ERROR: Failed to import this WebSphere Application Server object."
    logger.exiting(_pyFileName, method)
    
def jmsProviderExisted(providerName,scopeId):
    method="jmsProviderExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(providerName)+", "+str(scopeId))
    jpObjectList = AdminConfig.list("JMSProvider",scopeId)
    jpList = wsadminToList(jpObjectList)
    jpList=refreshObjIdListByScopeId(jpList, scopeId)
    matchedJP = None
    for jp in jpList:
        tmpJPName=AdminConfig.showAttribute(jp,"name")
        if (tmpJPName != None and tmpJPName == providerName):     
            matchedJP = jp
            break
    logger.logp(Level.INFO, _pyFileName, method, "JMS provider existed? "+str(matchedJP))
    logger.exiting(_pyFileName, method)
    return matchedJP
########################################################################
# Create WebSphere Application Server connection factories
########################################################################
connectoryFactoryTypeName = {'com.ibm.ws.sib.api.jms.impl.JmsTopicConnFactoryImpl': 'Topic connection factory',
    'com.ibm.ws.sib.api.jms.impl.JmsConnFactoryImpl': 'Connection factory',
    'com.ibm.ws.sib.api.jms.impl.JmsQueueConnFactoryImpl': 'Queue connection factory',
    'com.ibm.ws.sib.ra.impl.SibRaManagedConnectionFactory"': 'J2C connection factory'}
def importAllConnectionFactories(importDir):
    method="importAllConnectionFactories"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(importDir))
    printPrompt(0)
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    foundPropertiesFile="false"
    isEmpty = "true"
    for fileName in dirList:
        if fileName.endswith("exportCF.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    isEmpty="false"
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    jndiName = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    logger.logp(Level.INFO, _pyFileName, method, "jndiName: " + jndiName)
                    attributeFileName = propsFile.getProperty(str(key))
                    # check authentication alias is existed or not
                    # RTC defect 237151
                    objExisted=checkAuthAliasObjectOnTargetEnv(os.path.join(importDir,attributeFileName))
                    print "**************************************"
                    if objExisted == "true":
                        implClass = propsFile.getProperty(propertyNamePrefix + ".ConnectionFactoryImplClass")
                        scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                        logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + attributeFileName)
                        logger.logp(Level.INFO, _pyFileName, method, "impleClass: " + implClass)
                        logger.logp(Level.INFO, _pyFileName, method, "The type of this object: " + str(connectoryFactoryTypeName[implClass]))
                        print "INFO: The type of this object: " + str(connectoryFactoryTypeName[implClass])
                        logger.logp(Level.INFO, _pyFileName, method, "Importing connection factory with JDNI name [" + str(jndiName)+"]")
                        print "INFO: Importing connection factory with JDNI name [" + str(jndiName)+"]"
                        logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"]")
                        print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]"
                        importConnectionFactory(jndiName, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), implClass, os.path.join(importDir,attributeFileName))
                    else:
                        logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for JMS connection factory with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly.")
                        print "INFO: The authentication alias for object with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly."
                        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                        print "ERROR: Failed to import this WebSphere Application Server object."
                    print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportCF.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportCF.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    if foundPropertiesFile=="true" and isEmpty == "true":
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "No connection factory object could be found in property file in the import directory "+str(importDir)+".")
        print "INFO: No connection factory object could be found in property file in the import directory "+str(importDir)+"."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    logger.exiting(_pyFileName, method)

def importConnectionFactoryByJndiname(inputJndiName,importDir):
    method="importConnectionFactoryByJndiname"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(inputJndiName)+", "+str(importDir))
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    printPrompt(0)
    foundPropertiesFile="false"
    found = "false"
    for fileName in dirList:
        if fileName.endswith("exportCF.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    jndiName = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    if not (jndiName and jndiName == inputJndiName):
                        continue
                    found="true"
                    logger.logp(Level.INFO, _pyFileName, method, "jndiName: " + jndiName)
                    attributeFileName = propsFile.getProperty(str(key))
                    # check authentication alias is existed or not
                    # RTC defect 237151
                    objExisted=checkAuthAliasObjectOnTargetEnv(os.path.join(importDir,attributeFileName))
                    print "**************************************"
                    if objExisted == "true":
                        implClass = propsFile.getProperty(propertyNamePrefix + ".ConnectionFactoryImplClass")
                        scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                        logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + attributeFileName)
                        logger.logp(Level.INFO, _pyFileName, method, "impleClass: " + implClass)
                        logger.logp(Level.INFO, _pyFileName, method, "The type of this object: " + str(connectoryFactoryTypeName[implClass]))
                        print "INFO: The type of this object: " + str(connectoryFactoryTypeName[implClass])
                        logger.logp(Level.INFO, _pyFileName, method, "Importing connection factory with JDNI name [" + str(jndiName)+"]")
                        print "INFO: Importing connection factory with JDNI name [" + str(jndiName)+"]"
                        logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"]")
                        print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]"
                        importConnectionFactory(jndiName, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), implClass, os.path.join(importDir,attributeFileName))
                    else:
                        logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for JMS connection factory with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly.")
                        print "INFO: The authentication alias for object with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly."
                        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                        print "ERROR: Failed to import this WebSphere Application Server object."
                    print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportCF.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportCF.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    if(foundPropertiesFile == "true" and found=="false"):    
        print "**************************************"    
        logger.logp(Level.INFO, _pyFileName, method, "INFO: The connection factory object with JNDI name " + inputJndiName +" that you want to import could not be found in property file in the import directory " + str(importDir) + ".")
        print "INFO: The connection factory object with JNDI name " + inputJndiName +" that you want to import could not be found in property file in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    logger.exiting(_pyFileName, method)

def importConnectionFactory(jndiName, objType, implClass, attributeFilePath):
    method="importConnectionFactory"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(jndiName)+", "+str(objType)+", "+str(implClass)+", "+str(attributeFilePath))
    selectedScope = getUserSelectedScope("false")
    existedCF = connectionFactoryExisted(jndiName,selectedScope)
    if(existedCF != None):
        logger.logp(Level.INFO, _pyFileName, method, "Import of connection factory with JNDI name " + str(jndiName) + " already exists. Will skip it.")
        print "INFO: Import of connection factory with JNDI name " + str(jndiName) + " already exists. Will skip it."
        #if (overWriteExistingOne == "true"):
            # TODO: for update
            #updateExistedDataSource(existedDataSource,attributeFilePath)
        #    print "INFO: TODO: Connection factory with JDNI name " + jndiName + " was updated successfully."
        #else:
        #    print "INFO: Connection factory with JDNI name " + jndiName + " already exists. Will skip it."
    else:    
        logger.logp(Level.INFO, _pyFileName, method, "Connection factory with JNDI name " + str(jndiName) + " does not exist. Will import it.")
        print "INFO: Connection factory with JNDI name " + str(jndiName) + " does not exist. Will import it."  
        answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        if (answer != 'Y' and answer != 'y' ):
            return
        
        objAttributesString = readObjectAttributeFromFile(attributeFilePath)
        # Find the name of the provider
        regexp = re.compile('.*\[provider "(.*)\(.*')
        match = re.match(regexp, objAttributesString)
        if(match != "" and match != None):
            providerName =  match.group(1)
        if (selectedScope != None):
            connectionDefinition= getConnectionDefinitionByScope(selectedScope, implClass)
            jmsResourceProvider = getJMSResourceProviderByScope(selectedScope, providerName)
            if (jmsResourceProvider != None and connectionDefinition != None):
                logger.logp(Level.INFO, _pyFileName, method, "Using " + connectionDefinition)
                logger.logp(Level.INFO, _pyFileName, method, "Using " + jmsResourceProvider)
                importCFByNameAndAttributes(jndiName, objType, connectionDefinition, jmsResourceProvider, attributeFilePath)
                logger.logp(Level.INFO, _pyFileName, method, "Connection factory with JNDI name [" + str(jndiName) + "] was imported successfully.")
                print "INFO: Connection factory with JNDI name [" + str(jndiName) + "] was imported successfully."
            else:
                logger.logp(Level.INFO, _pyFileName, method, "No jmsResourceProvider or connectionDefinition found on target environment " + str(jmsResourceProvider) + ", " + str(connectionDefinition) + ".")
                print "INFO: No jmsResourceProvider or connectionDefinition found on target environment " + str(jmsResourceProvider) + ", " + str(connectionDefinition) + "."
                logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                print "ERROR: Failed to import this WebSphere Application Server object."
    logger.exiting(_pyFileName, method)
    
def importCFByNameAndAttributes(jndiName, objType, connectionDefinition, jmsResourceProvider, attributeFilePath):#,builtinresourceAdapterID):
    method="importCFByNameAndAttributes"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(jndiName)+", "+str(objType)+", "+str(connectionDefinition)+", "+str(jmsResourceProvider)+", "+str(attributeFilePath))
    objAttributesString = readObjectAttributeFromFile(attributeFilePath)
    # Replace provider and connectionDefinition with the ones in the target environment
    #trace('Replace "provider" property with the value in the target environment.')
    objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*\[provider (\[*.*?\]*)\].*',jmsResourceProvider)
    #trace('Replace "relationalResourceAdapter" property with the value in the target environment.')
    objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*\[connectionDefinition (\[*.*?\]*)\].*',connectionDefinition)                   
    objAttributesString = processAttriubutes(objAttributesString) 
    logger.logp(Level.INFO, _pyFileName, method, "Importing connection factory...")               
    print "INFO: Importing connection factory..."
    AdminConfig.create(objType, jmsResourceProvider, "[" + objAttributesString + "]")
    AdminConfig.save()
    logger.exiting(_pyFileName, method)
    
def connectionFactoryExisted(jndiName,selectedScope):
    method="connectionFactoryExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(jndiName)+", "+str(selectedScope))
    scopeId=AdminConfig.getid(selectedScope)
    cfObjectList = AdminConfig.list("J2CConnectionFactory",scopeId)
    cfList = wsadminToList(cfObjectList)
    cfList=refreshObjIdListByScopeId(cfList, scopeId)
    matchedCF = None
    for cf in cfList:
        tmpJNDIName=AdminConfig.showAttribute(cf,"jndiName")
        if (tmpJNDIName != None and tmpJNDIName == jndiName):     
            matchedCF = cf
            break
    logger.logp(Level.INFO, _pyFileName, method, "connection factory existed? "+str(matchedCF))
    logger.exiting(_pyFileName, method)
    return matchedCF

def getConnectionDefinitionByScope(selectedScope, implClass):
    method="getConnectionDefinitionByScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(selectedScope)+", "+str(implClass))
    connectionDefinition = None
    scopeId=AdminConfig.getid(selectedScope)
    connectionDefinitionList = wsadminToList(AdminConfig.list('ConnectionDefinition',scopeId))
    connectionDefinitionList=refreshObjIdListByScopeId(connectionDefinitionList, scopeId)
    if (len(connectionDefinitionList) <= 0):
        logger.logp(Level.INFO, _pyFileName, method, "There is no connection definition in the selected scope. You must create a new one first.")
    else:
        connectionDefinition = None
        for cd in connectionDefinitionList:
            if (implClass == AdminConfig.showAttribute(cd, 'connectionFactoryImplClass')):
                connectionDefinition = cd
                logger.logp(Level.INFO, _pyFileName, method, "Found the connectionFactory: " + connectionDefinition)
                break
    logger.logp(Level.INFO, _pyFileName, method, "get connection factory: "+str(connectionDefinition))
    logger.exiting(_pyFileName, method)
    return connectionDefinition

def getJMSResourceProviderByScope(selectedScope, name):
    method="getJMSResourceProviderByScope"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(selectedScope)+", "+str(name))
    jmsResourceProvider = getResourceAdapterIDByScope(selectedScope, name)
    logger.logp(Level.INFO, _pyFileName, method, "get JMS provider: "+str(jmsResourceProvider))
    logger.exiting(_pyFileName, method)
    return jmsResourceProvider

########################################################################
# Create WebSphere Application Server activation specs
########################################################################
activationSpecTypeName = {'com.ibm.ws.sib.api.jmsra.impl.JmsJcaActivationSpecImpl': 'Activation Specification on JMS messaging provider',
    'com.ibm.mq.connector.inbound.ActivationSpecImpl': 'Activation Specification on WebSphere MQ messaging provider'}
def importActivationSpec(inputJndiName, importDir):
    method="importActivationSpec"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(inputJndiName)+", "+str(importDir))
    checkImportDirExisted(importDir)
    printPrompt(0)
    dirList = os.listdir(importDir)
    found = "false"
    foundPropertiesFile="false"
    for fileName in dirList:
        if fileName.endswith("exportAS.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    jndiName = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    if not (inputJndiName == jndiName):
                        continue
                    found="true"
                    logger.logp(Level.FINE, _pyFileName, method,"jndiName: " + jndiName)
                    attributeFileName = propsFile.getProperty(str(key))
                    # check authentication alias is existed or not
                    # RTC defect 237151
                    objExisted=checkAuthAliasObjectOnTargetEnv(os.path.join(importDir,attributeFileName))
                    print "**************************************"
                    if objExisted == "true":
                        adapterName = propsFile.getProperty(propertyNamePrefix + ".AdapterName")
                        activationSpecClass = propsFile.getProperty(propertyNamePrefix + ".ActivationSpec")
                        busName = propsFile.getProperty(propertyNamePrefix + ".BusName")
                        scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                        logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + str(attributeFileName))
                        logger.logp(Level.INFO, _pyFileName, method, "adapterName : " + str(adapterName))
                        logger.logp(Level.INFO, _pyFileName, method, "activationSpecClass : " + str(activationSpecClass))
                        logger.logp(Level.INFO, _pyFileName, method, "The type of this object: " + str(activationSpecTypeName[activationSpecClass]))
                        print "INFO: The type of this object: " + str(activationSpecTypeName[activationSpecClass])
                        logger.logp(Level.INFO, _pyFileName, method, "Importing JMS activation specification with JNDI name [" + str(jndiName)+ "].")
                        print "INFO: Importing JMS activation specification with JNDI name [" + str(jndiName)+ "]."
                        logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                        print "INFO: The scope ID in source environment is ["+scopeIdInSrc+"]."
                        importActivationSpecs(busName, jndiName, adapterName, activationSpecClass, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), os.path.join(importDir,attributeFileName))
                    else:
                        logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for JMS activation specification with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly.")
                        print "INFO: The authentication alias for object with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly."
                        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                        print "ERROR: Failed to import this WebSphere Application Server object."
                    print "**************************************"    
    if foundPropertiesFile=="true" and found == "false":
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The object with JNDI name " + str(inputJndiName) +" that you want to import could not be found in property file in the import directory " + str(importDir) + ".")
        print "INFO: The object with JNDI name " + str(inputJndiName) +" that you want to import could not be found in property file in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportAS.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportAS.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
########################################################################
# Create WebSphere Application Server activation specs
########################################################################
def importAllActivationSpecs(importDir):
    method="importAllActivationSpecs"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(importDir))
    checkImportDirExisted(importDir)
    printPrompt(0)
    dirList = os.listdir(importDir)
    foundPropertiesFile="false"
    isEmpty="true"
    for fileName in dirList:
        if fileName.endswith("exportAS.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.INFO, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    isEmpty="false"
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    jndiName = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    logger.logp(Level.INFO, _pyFileName, method, "jndiName: " + jndiName)
                    attributeFileName = propsFile.getProperty(str(key))
                    # check authentication alias is existed or not
                    # RTC defect 237151
                    objExisted=checkAuthAliasObjectOnTargetEnv(os.path.join(importDir,attributeFileName))
                    print "**************************************"
                    if objExisted == "true":
                        adapterName = propsFile.getProperty(propertyNamePrefix + ".AdapterName")
                        activationSpecClass = propsFile.getProperty(propertyNamePrefix + ".ActivationSpec")
                        busName = propsFile.getProperty(propertyNamePrefix + ".BusName")
                        scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                        logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + attributeFileName)
                        logger.logp(Level.INFO, _pyFileName, method, "adapterName : " + adapterName)
                        logger.logp(Level.INFO, _pyFileName, method, "activationSpecClass : " + str(activationSpecClass))
                        logger.logp(Level.INFO, _pyFileName, method, "The type of this object: " + str(activationSpecTypeName[activationSpecClass]))
                        print "INFO: The type of this object: " + str(activationSpecTypeName[activationSpecClass])
                        logger.logp(Level.INFO, _pyFileName, method, "Importing activation specification with JNDI name [" + str(jndiName)+ "].")
                        print "INFO: Importing activation specification with JNDI name [" + str(jndiName)+ "]."
                        logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                        print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]."
                        importActivationSpecs(busName, jndiName, adapterName, activationSpecClass, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), os.path.join(importDir,attributeFileName))
                    else:
                        logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for JMS activation specification with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly.")
                        print "INFO: The authentication alias for object with JNDI name " + str(jndiName) +" doesnot exist in target environment, create it firstly."
                        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import this WebSphere Application Server object.")
                        print "ERROR: Failed to import this WebSphere Application Server object."
                    print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportAS.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportAS.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
        
    if foundPropertiesFile=="true" and isEmpty == "true":
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "No activation specification object could be found in property file in the import directory "+importDir+".")
        print "INFO: No activation specification object could be found in property file in the import directory "+importDir+"."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object.")
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
########################################################################
# for property arbitraryProperties value "was_stopEndpointIfDeliveryFails="true",was_failureDeliveryCount="0",sslType="NONE",sslConfiguration="""
# AdminConfig cannot handle this, we need to add sing quotation mark
########################################################################
def handleArbitraryPropertiesAttriubutes(objAttributesString):
    method="handleArbitraryPropertiesAttriubutes"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(objAttributesString))
    if objAttributesString and objAttributesString.find("arbitraryProperties") > 0:
        logger.logp(Level.INFO, _pyFileName, method, "property arbitraryProperties exists.")
        propRegexp=re.compile(".*([\[]{2}.*?\[name arbitraryProperties\]\[.*?[\]]{2}).*")
        propMatch = re.match(propRegexp,objAttributesString)
        if propMatch:
            propValue = propMatch.group(1)
            logger.logp(Level.INFO, _pyFileName, method, "property arbitraryProperties value: "+str(propValue))
            valueRegexp=re.compile(".*value[ ]{1,}(.*?)[ ]{0,}\]{1}.*")
            valueMatch = re.match(valueRegexp,propValue)
            if valueMatch:
                value = str(valueMatch.group(1)).rstrip().lstrip()
                valueWithMarks=value
                if not (value.find("'") >=0 and value.find("\"") >=0):
                    if value.find("'") >=0:
                        valueWithMarks = "\"" + value + "\""
                    else:
                        valueWithMarks = "'" + value + "'"
                objAttributesString= objAttributesString.replace(value, valueWithMarks)
    logger.logp(Level.INFO, _pyFileName, method, "objAttributesString="+str(objAttributesString))
    logger.exiting(_pyFileName, method)
    return objAttributesString
    
def importActivationSpecs(busName, jndiName, adapterName, activationSpecClass, objType, attributeFilePath):
    method="importActivationSpecs"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName)+", "+str(jndiName)+", "+str(activationSpecClass)+", "+str(objType)+", "+str(attributeFilePath))
    selectedScope = getUserSelectedScope("false")
    existedAS = activationSpecsExisted(jndiName,selectedScope)
    if(existedAS != None):
        logger.logp(Level.INFO, _pyFileName, method, "Import of activation specification with JNDI name " + str(jndiName) + " already exists. Will skip it.")
        print "INFO: Import of activation specification with JNDI name " + str(jndiName) + " already exists. Will skip it."
        #if (overWriteExistingOne == "true"):
            # TODO: for update
            #updateExistedDataSource(existedDataSource,attributeFilePath)
        #    print "INFO: TODO: Activation specification with JNDI name " + jndiName + " was updated successfully."
        #else:
        #    print "INFO: Activation specification with JNDI name " + jndiName + " already exists. Will skip it."
    else:
        logger.logp(Level.INFO, _pyFileName, method, "Activation specification with JNDI name " + str(jndiName) + " does not exist. Will import it.")
        print "INFO: Activation specification with JNDI name " + str(jndiName) + " does not exist. Will import it."  
        answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        if (answer != 'Y' and answer != 'y' ):
            return
        objAttributesString = readObjectAttributeFromFile(attributeFilePath)
        if (selectedScope != None):
            objAttributesString = processAttriubutes(objAttributesString)
            # Replace activationSpec using activationSpecClass
            # Get the activationSpec using the specClass
            activationSpec = getActivationSpecsByClass(selectedScope, activationSpecClass)
            objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*\[activationSpec (.*\))\].*', activationSpec)
            
            # for "arbitraryProperties" property we need to add single quotation mark
            objAttributesString = handleArbitraryPropertiesAttriubutes(objAttributesString)
            
            # Update the property durableSubscriptionHome value(ME name) to user selected
            # ONLY WHEN: 1, source bus name is equal to target bus name
            #            2, there's a value for property durableSubscriptionHome; "value []" will be treated as NO value
            # User needs to select one if there is more than one messaging engine within bus this AS existed
            # If there is only one messaging engine, we will replace source messaging engine name with this messaging engine directly without tip message
            if(busName != None and findASDurableSubScriptionHomeMEName(objAttributesString) != None):
                for bus in wsadminToList(AdminTask.listSIBuses()):
                    if(busName == AdminConfig.showAttribute(bus, "name")):
                        sibMEList = wsadminToList(AdminTask.listSIBEngines("-bus " + busName))
                        # If there are more than one messaging engines for bus, user need to select one
                        if(len(sibMEList)>1):
                            selectedMEName = getUserSelectedME(sibMEList)
                            objAttributesString=replaceASDurableSubScriptionHomeMEName(objAttributesString, selectedMEName)
                        # If only one messaging engine was found, using this one to replace source messaging engine name directly
                        elif(len(sibMEList)==1):
                            meName=AdminConfig.showAttribute(sibMEList[0],'name')
                            objAttributesString=replaceASDurableSubScriptionHomeMEName(objAttributesString, meName)
                        break
            logger.logp(Level.INFO, _pyFileName, method, "Importing activation specification...")
            print "INFO: Importing activation specification..."
            adapterToUse = getResourceAdapterIDByScope(selectedScope, adapterName)
            if(adapterToUse):
                logger.logp(Level.INFO, _pyFileName, method, "Resource adapter: " + adapterToUse)
                logger.logp(Level.INFO, _pyFileName, method, "Object type: " + objType)
                AdminConfig.create(objType, adapterToUse, "[" + objAttributesString + "]")
                AdminConfig.save()
                logger.logp(Level.INFO, _pyFileName, method, "Activation specification with JNDI name [" + str(jndiName) + "] was imported successfully.")
                print "INFO: Activation specification with JNDI name [" + str(jndiName) + "] was imported successfully."
            else:
                logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import activation specification with JNDI name " + str(jndiName) + " because the adapter cannot be found in this scope.")
                print "ERROR: Failed to import activation specification with JNDI name " + str(jndiName) + " because the adapter cannot be found in this scope."
    logger.exiting(_pyFileName, method)
    
def findASDurableSubScriptionHomeMEName(objAttributesString):
    method="findASDurableSubScriptionHomeMEName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(objAttributesString))
    findDurableSubRegx='([\[]{2}name durableSubscriptionHome.*?[value|].*?[\]]{2}\s)'
    findValueSubRegx='(value .*?)[\]]{2}\s'
    durableSubAttri = re.search(re.compile(findDurableSubRegx),objAttributesString)
    asDurableSubScriptionHomeMEName=None
    if(durableSubAttri != None):
        durableSubValue=re.search(re.compile(findValueSubRegx),durableSubAttri.group(1))
        if(durableSubValue!=None and durableSubValue.group(1)!= "value []"):
            asDurableSubScriptionHomeMEName = durableSubValue.group(1)
    logger.logp(Level.INFO, _pyFileName, method, "ASDurableSubScriptionHomeMEName="+str(asDurableSubScriptionHomeMEName))
    logger.exiting(_pyFileName, method)
    return asDurableSubScriptionHomeMEName

def replaceASDurableSubScriptionHomeMEName(objAttributesString, selectedMEName):
    method="replaceASDurableSubScriptionHomeMEName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(objAttributesString)+", "+str(selectedMEName))
    findDurableSubRegx='([\[]{2}name durableSubscriptionHome.*?[value|].*?[\]]{2}\s)'
    findValueSubRegx='(value .*?)[\]]{2}\s'
    durableSubAttri = re.search(re.compile(findDurableSubRegx),objAttributesString)
    if(durableSubAttri != None):
        durableSubValue=re.search(re.compile(findValueSubRegx),durableSubAttri.group(1))
        if(durableSubValue!=None):
            objAttributesString=objAttributesString.replace(durableSubValue.group(1), "value "+selectedMEName)
    logger.logp(Level.INFO, _pyFileName, method, "after replace asDurableSubScriptionHome="+str(objAttributesString))
    logger.exiting(_pyFileName, method)
    return objAttributesString

def activationSpecsExisted(jndiName,selectedScope):
    method="activationSpecsExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(jndiName)+", "+str(selectedScope))
    scopeId=AdminConfig.getid(selectedScope)
    asObjectList = AdminConfig.list("J2CActivationSpec",scopeId)
    asList = wsadminToList(asObjectList)
    asList=refreshObjIdListByScopeId(asList, scopeId)
    matchedAS = None
    for _as in asList:
        tmpJNDIName=AdminConfig.showAttribute(_as,"jndiName")
        if (tmpJNDIName != None and tmpJNDIName == jndiName):     
            matchedAS = _as
            break
    logger.logp(Level.INFO, _pyFileName, method, "find activation specification="+str(matchedAS))
    logger.exiting(_pyFileName, method)
    return matchedAS

def getActivationSpecsByClass(selectedScope, activationSpecClass):
    method="getActivationSpecsByClass"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(selectedScope)+", "+str(activationSpecClass))
    scopeId=AdminConfig.getid(selectedScope)
    logger.logp(Level.INFO, _pyFileName, method, "scope id="+str(scopeId))
    activationSpecList = wsadminToList(AdminConfig.list('ActivationSpec',scopeId))
    activationSpecList = refreshObjIdListByScopeId(activationSpecList,scopeId)
    logger.logp(Level.INFO, _pyFileName, method, "activationSpec List="+str(activationSpecList))
    matchedAS = None
    for asItem in activationSpecList:
        tmpActivationSpecClass=AdminConfig.showAttribute(asItem,"activationSpecClass")
        if (tmpActivationSpecClass != None and tmpActivationSpecClass == activationSpecClass):     
            matchedAS = asItem
            break
    logger.logp(Level.INFO, _pyFileName, method, "activation specification class="+str(matchedAS))
    logger.exiting(_pyFileName, method)
    return matchedAS

########################################################################
# Create queue and topic specifications
########################################################################
adminObjectTypeName = {'com.ibm.ws.sib.api.jms.impl.JmsTopicImpl': 'Topic',
    'com.ibm.ws.sib.api.jms.impl.JmsQueueImpl': 'Queue'}
def importAllQueuesAndTopics(importDir):
    method="importAllQueuesAndTopics"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(importDir))
    checkImportDirExisted(importDir)
    logger.logp(Level.INFO, _pyFileName, method, "importDir: " + importDir)
    dirList = os.listdir(importDir)
    foundPropertiesFile="false"
    isEmpty ="true"
    for fileName in dirList:
        if fileName.endswith("exportAO.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.INFO, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    isEmpty ="false"
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    jndiName = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    logger.logp(Level.INFO, _pyFileName, method, "jndiName: " + jndiName)
                    attributeFileName = propsFile.getProperty(str(key))
                    adapterName = propsFile.getProperty(propertyNamePrefix + ".AdapterName")
                    adminObjectClass = propsFile.getProperty(propertyNamePrefix + ".AdminObjectClass")
                    scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                    logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + attributeFileName)
                    logger.logp(Level.INFO, _pyFileName, method, "adapterName: " + adapterName)
                    print "**************************************"
                    logger.logp(Level.INFO, _pyFileName, method, "The type of this object: " + str(adminObjectTypeName[adminObjectClass]))
                    print "INFO: The type of this object: " + str(adminObjectTypeName[adminObjectClass])
                    logger.logp(Level.INFO, _pyFileName, method, "Importing queue or topic specification with JNDI name [" + str(jndiName)+"].")
                    print "INFO: Importing queue or topic specification with JNDI name [" + str(jndiName)+"]."
                    logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                    print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]."
                    importQueueOrTopic(jndiName, adapterName, adminObjectClass, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), os.path.join(importDir,attributeFileName))
                    print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportAO.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportAO.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object." )
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
        
    if foundPropertiesFile=="true" and isEmpty == "true":
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "No queue or topic specification object could be found in property file in the import directory "+str(importDir)+".")
        print "INFO: No queue or topic specification object could be found in property file in the import directory "+str(importDir)+"."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object." )
        print "ERROR: Failed to import WebSphere Application Server object."
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
def importQueueOrTopicByJndiName(inputJndiName,importDir):
    method="importQueueOrTopicByJndiName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(inputJndiName)+", "+str(importDir))
    checkImportDirExisted(importDir)
    dirList = os.listdir(importDir)
    foundPropertiesFile="false"
    found ="false"
    for fileName in dirList:
        if fileName.endswith("exportAO.properties"):
            foundPropertiesFile="true"
            propsFilePath = os.path.join(importDir,fileName)
            propsFile = Properties()    
            inputSream = FileInputStream(propsFilePath)
            propsFile.load(inputSream)
            for key in propsFile.keySet():
                logger.logp(Level.FINE, _pyFileName, method, "Key: " + str(key))
                index = str(key).find(".ObjectFileName")
                if(index > 0):
                    propertyNamePrefix=str(key)[0:key.rfind(".")]
                    jndiName = propertyNamePrefix[0:propertyNamePrefix.rfind(".")]
                    logger.logp(Level.INFO, _pyFileName, method, "jndiName: " + jndiName)
                    if not (jndiName and jndiName == inputJndiName):
                        continue
                    found="true"
                    attributeFileName = propsFile.getProperty(str(key))
                    adapterName = propsFile.getProperty(propertyNamePrefix + ".AdapterName")
                    adminObjectClass = propsFile.getProperty(propertyNamePrefix + ".AdminObjectClass")
                    scopeIdInSrc = propsFile.getProperty(propertyNamePrefix + ".ScopeId")
                    logger.logp(Level.INFO, _pyFileName, method, "attributeFileName: " + attributeFileName)
                    logger.logp(Level.INFO, _pyFileName, method, "adapterName: " + adapterName)
                    print "**************************************"
                    logger.logp(Level.INFO, _pyFileName, method, "The type of this object: " + str(adminObjectTypeName[adminObjectClass]))
                    logger.logp(Level.INFO, _pyFileName, method, "Importing queue or topic specification with JNDI name [" + str(jndiName)+"].")
                    logger.logp(Level.INFO, _pyFileName, method, "The scope ID in source environment is ["+str(scopeIdInSrc)+"].")
                    print "INFO: The type of this object: " + str(adminObjectTypeName[adminObjectClass])
                    print "INFO: Importing queue or topic specification with JNDI name [" + str(jndiName)+"]."
                    print "INFO: The scope ID in source environment is ["+str(scopeIdInSrc)+"]."
                    importQueueOrTopic(jndiName, adapterName, adminObjectClass, propsFile.getProperty(propertyNamePrefix + ".ObjectType"), os.path.join(importDir,attributeFileName))
                    print "**************************************"
    if(foundPropertiesFile=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The property file exportAO.properties could not be found in the import directory " + str(importDir) + ".")
        print "INFO: The property file exportAO.properties could not be found in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object." )
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    if(foundPropertiesFile == "true" and found=="false"):    
        print "**************************************"
        logger.logp(Level.INFO, _pyFileName, method, "The queue or topic specification with JNDI name " + str(inputJndiName) +" that you want to import could not be found in property file in the import directory " + str(importDir) + ".")
        print "INFO: The queue or topic specification with JNDI name " + str(inputJndiName) +" that you want to import could not be found in property file in the import directory " + str(importDir) + "."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import WebSphere Application Server object." )
        print "ERROR: Failed to import WebSphere Application Server object." 
        print "**************************************"
    logger.exiting(_pyFileName, method)
    
def importQueueOrTopic(jndiName, adapterName,adminObjectClass, objType, attributeFilePath):
    method="importQueueOrTopic"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(jndiName)+", "+str(adapterName)+", "+str(adminObjectClass)+", "+str(objType)+", "+str(attributeFilePath))
    selectedScope = getUserSelectedScope("false")
    existedAdminObject = queueOrTopicExisted(jndiName,selectedScope)
    if(existedAdminObject != None):
        logger.logp(Level.INFO, _pyFileName, method, "Import of queue or topic with JNDI name " + jndiName + " already exists. Will skip it.")
        print "INFO: Import of queue or topic with JNDI name " + jndiName + " already exists. Will skip it."
        #if (overWriteExistingOne == "true"):
            # TODO: for update
            #updateExistedDataSource(existedDataSource,attributeFilePath)
        #    print "INFO: TODO: Queue or topic with JNDI name " + jndiName + " was updated successfully."
        #else:
        #    print "INFO: Queue or topic with JNDI name " + jndiName + " already exists. Will skip it."
    else:
        logger.logp(Level.INFO, _pyFileName, method, "Queue or topic with JNDI name " + jndiName + " does not exist. Will import it.")
        print "INFO: Queue or topic with JNDI name " + jndiName + " does not exist. Will import it."  
        answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        isCorrectInput = 'false'
        while isCorrectInput == 'false':
            logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
            if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
                isCorrectInput = 'true'
            else:
                answer = raw_input("Do you want to import this WebSphere Application Server object? (Y/N):")
        if (answer != 'Y' and answer != 'y' ):
            return
        if (selectedScope != None):
            objAttributesString = readObjectAttributeFromFile(attributeFilePath)
            objAttributesString = processAttriubutes(objAttributesString)
            # there are two properties forwardRoutingPath, reverseRoutingPath which would prevent creating AdminObject
            # Remove them before creating AdminObject, technote: http://www-01.ibm.com/support/docview.wss?uid=swg21701283. Customer must reconfigure their values in the admin console
            objAttributesString = replaceRegexpWithNewValue(objAttributesString, '.*([\[]{2}.*?\[name forwardRoutingPath\]\[.*?[\]]{2}).*',"")
            objAttributesString = replaceRegexpWithNewValue(objAttributesString, '.*([\[]{2}.*?\[name reverseRoutingPath\]\[.*?[\]]{2}).*',"")
            # Replace adminObjectClass
            # Get the adminObjectClass using the one from property file
            adminObjectClass = getAdminObjectClassByClass(selectedScope, adminObjectClass)
            objAttributesString = replaceRegexpWithNewValue(objAttributesString,'.*\[adminObject (.*\))\].*',adminObjectClass) 
            adapterToUse = getResourceAdapterIDByScope(selectedScope, adapterName)
            if(adapterToUse):
                logger.logp(Level.INFO, _pyFileName, method, "Importing queue or topic...")
                print "INFO: Importing queue or topic..."
                logger.logp(Level.INFO, _pyFileName, method, "Resource adapter: " + adapterToUse)
                logger.logp(Level.INFO, _pyFileName, method, "Object type: " + objType)
                AdminConfig.create(objType, adapterToUse, "[" + objAttributesString + "]")
                AdminConfig.save()
                logger.logp(Level.FINE, _pyFileName, method, "Queue or topic with JNDI name [" + jndiName + "] was imported successfully.")
                print "INFO: Queue or topic with JNDI name [" + jndiName + "] was imported successfully."
            else:
                logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import queue or topic with JNDI name " + jndiName + " because the adapter cannot be found.")
                print "ERROR: Failed to import queue or topic with JNDI name " + jndiName + " because the adapter cannot be found."
    logger.exiting(_pyFileName, method)

def getAdminObjectClassByClass(selectedScope, adminObjectClass):
    method="getAdminObjectClassByClass"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(selectedScope)+", "+str(adminObjectClass))
    scopeId=AdminConfig.getid(selectedScope)
    adminObjectClassList = wsadminToList(AdminConfig.list('AdminObject',scopeId))
    adminObjectClassList = refreshObjIdListByScopeId(adminObjectClassList,scopeId)
    matchedAO = None
    for aoItem in adminObjectClassList:
        tmpAdminObjectClass=AdminConfig.showAttribute(aoItem,"adminObjectClass")
        if (tmpAdminObjectClass != None and tmpAdminObjectClass == adminObjectClass):     
            matchedAO = aoItem
            break
    logger.logp(Level.INFO, _pyFileName, method, "queue or topic class="+str(matchedAO))
    logger.exiting(_pyFileName, method)
    return matchedAO

def queueOrTopicExisted(jndiName,selectedScope):
    method="queueOrTopicExisted"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(jndiName)+", "+str(selectedScope))
    scopeId=AdminConfig.getid(selectedScope)
    adminObjectList = AdminConfig.list("J2CAdminObject",scopeId)
    objectList = wsadminToList(adminObjectList)
    objectList=refreshObjIdListByScopeId(objectList, scopeId)
    matchedRecord = None
    for adminObject in objectList:
        tmpJNDIName=AdminConfig.showAttribute(adminObject,"jndiName")
        if (tmpJNDIName != None and tmpJNDIName == jndiName):     
            matchedRecord = adminObject
            break
    logger.logp(Level.INFO, _pyFileName, method, "queue or topic existed? "+str(matchedRecord))
    return matchedRecord

def getDestinationAndAttributeMap(busFolder):    
    method="getDestinationAndAttributeMap"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busFolder))
    if (busFolder != None):
        #read queue destination obj
        queueDestinationRootFolder = os.path.join(busFolder,"Destination/Queue")
        if(os.path.exists(queueDestinationRootFolder)):
            queueDestinationFolders = os.listdir(queueDestinationRootFolder)
            for queueDestinationFolder in queueDestinationFolders:
                if queueDestinationFolder.endswith(".properties"):
                    continue
                destinationAttributeString = readObjectAttributeFromFile(os.path.join(queueDestinationRootFolder,queueDestinationFolder,"Queue.obj"))
                identifier = getPropertyValue(destinationAttributeString,'.*\[identifier (\[*.*?\]*)\].*')
                destinationAttributeMap[identifier] = destinationAttributeString
            logger.logp(Level.INFO, _pyFileName, method, "after handling queue destination, the map size is:"+str(len(destinationAttributeMap)))
        #read topic destination obj
        topicDestinationRootFolder = os.path.join(busFolder,"Destination/TopicSpace")
        if(os.path.exists(topicDestinationRootFolder)):
            topicDestinationFolders = os.listdir(topicDestinationRootFolder)
            for topicDestinationFolder in topicDestinationFolders:
                if topicDestinationFolder.endswith(".properties"):
                    continue
                destinationAttributeString = readObjectAttributeFromFile(os.path.join(topicDestinationRootFolder,topicDestinationFolder,"TopicSpace.obj"))
                identifier = getPropertyValue(destinationAttributeString,'.*\[identifier (\[*.*?\]*)\].*')
                destinationAttributeMap[identifier] = destinationAttributeString
            logger.logp(Level.INFO, _pyFileName, method, "after handling topic destination, the map size is:"+str(len(destinationAttributeMap)))
        logger.logp(Level.FINER, _pyFileName, method, "the foreign destination map contents:"+str(destinationAttributeMap))
        #read alias destination obj
        aliasDestinationRootFolder = os.path.join(busFolder,"Destination/Alias")
        if(os.path.exists(aliasDestinationRootFolder)):          
            aliasDestinationFolders = os.listdir(aliasDestinationRootFolder)
            for aliasDestinationFolder in aliasDestinationFolders:
                if aliasDestinationFolder.endswith(".properties"):
                    continue
                destinationAttributeString = readObjectAttributeFromFile(os.path.join(aliasDestinationRootFolder,aliasDestinationFolder,"Alias.obj"))
                identifier = getPropertyValue(destinationAttributeString,'.*\[identifier (\[*.*?\]*)\].*')
                aliasDestinationAttributeMap[identifier] = destinationAttributeString
            logger.logp(Level.INFO, _pyFileName, method, "after handling alias destination, the map size is:"+str(len(aliasDestinationAttributeMap)))
        logger.logp(Level.FINER, _pyFileName, method, "the alias destination map contents:"+str(aliasDestinationAttributeMap))
        #read foreign destination obj
        foreignDestinationRootFolder = os.path.join(busFolder,"Destination/Foreign")            
        if(os.path.exists(foreignDestinationRootFolder)):
            foreignDestinationFolders = os.listdir(foreignDestinationRootFolder)
            for foreignDestinationFolder in foreignDestinationFolders:
                if foreignDestinationFolder.endswith(".properties"):
                    continue
                destinationAttributeString = readObjectAttributeFromFile(os.path.join(foreignDestinationRootFolder,foreignDestinationFolder,"Foreign.obj"))
                identifier = getPropertyValue(destinationAttributeString,'.*\[identifier (\[*.*?\]*)\].*')
                foreignDestinationAttributeMap[identifier] = destinationAttributeString
            logger.logp(Level.INFO, _pyFileName, method, "after handling foreign destination, the map size is:"+str(len(foreignDestinationAttributeMap)))
        logger.logp(Level.FINER, _pyFileName, method, "the foreign destination map contents:"+str(foreignDestinationAttributeMap))
    else:
        logger.logp(Level.SEVERE, _pyFileName, method, "input bus folder is empty, exit:"+str(busFolder))
        print "ERROR: Input bus folder is empty: "+str(busFolder)+"." 
        print "**************************************"
        sys.exit()
    logger.exiting(_pyFileName, method)
    
def appendOptionalAttributesForDestination(destArgs,identifier):    
    method="appendOptionalAttributesForDestination"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(destArgs)+", "+str(identifier))
    if(destinationAttributeMap.has_key(identifier)):
        destinationAttribute = destinationAttributeMap[identifier]
    logger.logp(Level.FINE, _pyFileName, method, "after appending optional attributs: "+str(destArgs))
    logger.exiting(_pyFileName, method)
    return destArgs

def isSystemOrExistedDestination(identifier,busName):
    method="isSystemOrExistedDestination"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(identifier)+", "+str(busName))
    result = "false"
    if(identifier.startswith("_SYSTEM.Exception")):
        result = "true"
    destArgs = ['-bus',busName]
    allDestinations = wsadminToList(AdminTask.listSIBDestinations(destArgs))
    for destination in allDestinations:
        if(AdminConfig.showAttribute(destination,"identifier") == identifier):
            result = "true"
            break
    logger.logp(Level.INFO, _pyFileName, method, "destination exists? "+str(result))
    logger.exiting(_pyFileName, method)
    return result

def createDestination(busName,queueObjFilePath, cluster,node,server, _type):
    method="createDestination"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName)+", "+str(queueObjFilePath)+", "+str(cluster)+", "+str(node)+", "+str(server)+", "+str(_type))
    attributeString = readObjectAttributeFromFile(queueObjFilePath)
    identifier = getPropertyValue(attributeString,'.*\[identifier (\[*.*?\]*)\].*')
    indexofat = identifier.find("@")
    identifier = identifier[0:indexofat]    
    if(isSystemOrExistedDestination(identifier,busName) == "false"):        
        destArgs = None
        if(_type == "Queue"):
            destArgs=["-bus",busName,"-type","Queue","-name"]        
            destArgs.append(identifier)
        if(_type == "Topic"):
            destArgs=["-bus",busName,"-type","TopicSpace","-name"]        
            destArgs.append(identifier)    
        if(cluster != None):
            destArgs.append("-cluster")
            destArgs.append(cluster)
        else:
            destArgs.append("-node")
            destArgs.append(node)
            destArgs.append("-server")
            destArgs.append(server)
        destArgs = appendOptionalAttributesForDestination(destArgs,identifier)
        logger.logp(Level.INFO, _pyFileName, method, "Creating queue destination :" + str(identifier) + " with parameter " + str(destArgs) + ".")
        AdminTask.createSIBDestination(destArgs)
        logger.logp(Level.INFO, _pyFileName, method, "Queue destination :" + str(identifier) + " was created.")
    else:
        logger.logp(Level.WARNING, _pyFileName, method, "Destination with name " + identifier + " exists. Will skip it.")
    logger.exiting(_pyFileName, method)
    
def createMessageEngine(busName,buMemberFolder):
    method="createMessageEngine"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName)+", "+str(buMemberFolder))
    destinationRootFolder=None
    # get the message engine server type
    isMQServerType="false"
    serverScope=""
    try:
        sibBusMemberPropPath = os.path.join(buMemberFolder,"exportSIBusMember.properties")
        sibBusMemberPropsFile = Properties()    
        inputSream = FileInputStream(sibBusMemberPropPath)
        sibBusMemberPropsFile.load(inputSream)
        if sibBusMemberPropsFile.keySet().size() <=0:
            logger.logp(Level.WARNING, _pyFileName, method, "exportSIBusMember.properties in "+str(buMemberFolder) +" is empty.")
            print "**************************************"
            sys.exit()
        for sibBusMember in sibBusMemberPropsFile.keySet():
            if sibBusMember=="SIBusMember.ScopeId":
                serverScope = sibBusMemberPropsFile.get(sibBusMember)
                if serverScope.find("MQServer") >=0:
                    isMQServerType = "true"
    except :
        print "ERROR: Failed to read exportSIBusMember.properties in directory: "+str(buMemberFolder)+"."
        logger.logp(Level.SEVERE, _pyFileName, method, "failed to read exportSIBusMember.properties in directory"+str(buMemberFolder)+".")
        print "**************************************"
        sys.exit()
    
    # show what scope is on source environment, it would help user create message engine
    print "INFO: The scope ID in source environment is ["+str(serverScope)+"]."
    
    createMEArgs = ["-bus",busName]
    #if server is not mq server, then read the object file
    if isMQServerType == "false":
        meFolder=None
        meFolderNames = os.listdir(buMemberFolder)
        for meFolderName in meFolderNames:
            if(meFolderName.startswith("SIBMessagingEngine")):
                meFolder = os.path.join(buMemberFolder,meFolderName)                
        if not meFolder:
            logger.logp(Level.SEVERE, _pyFileName, method, "cannot find message engine object folder in directory "+str(buMemberFolder)+".")
            print "ERROR: cannot find message engine object folder in directory "+str(buMemberFolder)+"."
            print "**************************************"
            sys.exit()
        destinationRootFolder=meFolder
        meObjFilePath = os.path.join(meFolder,"SIBMessagingEngine.obj")    
        meObjString = readObjectAttributeFromFile(meObjFilePath)
        meName = getPropertyValue(meObjString,'.*\[name (\[*.*?\]*)\].*')
        logger.logp(Level.INFO, _pyFileName, method, "Start to import messaging engine that is named " + meName + " in source environment.")
        scopes = listScopeForMe("false")    
        selectScopeIndex = raw_input("Input the number to select the scope where you want to create the messaging engine:")
        isNumber = 'false'
        while isNumber == 'false':
            try:
                selectScopeIndex = int(selectScopeIndex)
                if(selectScopeIndex >= 1 and selectScopeIndex <= len(scopes)):
                    isNumber = 'true'
                else:
                    selectScopeIndex = raw_input("Incorrect number. Input the number to select the scope where you want to create the messaging engine:")
            except ValueError:
                selectScopeIndex = raw_input("Incorrect number. Input the number to select the scope where you want to create the messaging engine:")
        logger.logp(Level.INFO, _pyFileName, method, "selected scope index " + str(selectScopeIndex) + ": " + str(scopes[selectScopeIndex - 1]))    
        scope = scopes[selectScopeIndex - 1]
        cluster=None
        node=None
        server=None
        mePrefix = None
        index = scope.rfind("ServerCluster:")
        if(index >= 0):
            cluster = scope[index+14:-1]
            mePrefix = cluster
        else:
            index = scope.rfind("Node:")
            serverIndex = scope.rfind("Server:")
            node = scope[index+5:serverIndex-1]
            server = scope[serverIndex+7:-1]
            mePrefix = node + "." + server
        logger.logp(Level.INFO, _pyFileName, method, "selected scope: "+str(cluster)+ ", "+str(node)+", "+str(server))  
        #attributeString = readObjectAttributeFromFile(meAttributeFilePath)
        if(cluster != None):
            createMEArgs.append("-cluster")
            createMEArgs.append(cluster)
        else:
            createMEArgs.append("-node")
            createMEArgs.append(node)
            createMEArgs.append("-server")
            createMEArgs.append(server)
        description = getPropertyValue(meObjString,'.*\[description (\[*.*?\]*)\].*')
        if description:
            createMEArgs.append("-description ")
            createMEArgs.append(description )
    #    highMessageThreshold = getPropertyValue(meObjString,'.*\[highMessageThreshold (\[*.*?\]*)\].*')
    #    if(highMessageThreshold != None):
    #        createMEArgs.append("-highMessageThreshold")
    #        createMEArgs.append(highMessageThreshold)
    #    initialState = getPropertyValue(meObjString,'.*\[initialState (\[*.*?\]*)\].*')
    #    if(initialState != None):
    #        createMEArgs.append("-initialState")
    #        createMEArgs.append(initialState)
        storeType = getPropertyValue(meObjString,'.*\[messageStoreType (\[*.*?\]*)\].*')
        if(storeType == "DATASTORE"):
            # check authentication alias is existed or not
            # RTC defect 237151
            objExisted=checkAuthAliasObjectOnTargetEnv(os.path.join(meFolder,"SIBDatastore.obj") )
            if objExisted == "false":
                logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for SIBus " + str(busName) +" message engine datasource doesnot exist in target environment, create it firstly.")
                print "INFO: The authentication alias for SIBus " + str(busName) +" message engine datasource doesnot exist in target environment, create it firstly."
                logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import SIBus configuration.")
                print "ERROR: Failed to import SIBus configuration."
                print "**************************************"
                logger.exiting(_pyFileName, method)
                sys.exit()
            datastoreAttributeString = readObjectAttributeFromFile(os.path.join(meFolder,"SIBDatastore.obj"))
            createMEArgs.append("-dataStore")
            createDefaultDatasource=getPropertyValue(datastoreAttributeString,'.*\[createDefaultDatasource (\[*.*?\]*)\].*')
            if cluster == None and createDefaultDatasource:
                createMEArgs.append("-createDefaultDatasource")
                createMEArgs.append(createDefaultDatasource)
            datasourceJndiName=getPropertyValue(datastoreAttributeString,'.*\[dataSourceName (\[*.*?\]*)\].*')
            if datasourceJndiName:
                createMEArgs.append("-datasourceJndiName")
                createMEArgs.append(datasourceJndiName)
            authAlias=getPropertyValue(datastoreAttributeString,'.*\[authAlias (\[*.*?\]*)\].*')
            if authAlias:
                createMEArgs.append("-authAlias")
                createMEArgs.append(authAlias)
            createTables=getPropertyValue(datastoreAttributeString,'.*\[createTables (\[*.*?\]*)\].*')
            if createTables:
                createMEArgs.append("-createTables")
                createMEArgs.append(createTables)
            restrictLongDBLock=getPropertyValue(datastoreAttributeString,'.*\[restrictLongDBLock (\[*.*?\]*)\].*')
            if restrictLongDBLock:
                createMEArgs.append("-restrictLongDBLock")
                createMEArgs.append(restrictLongDBLock)
            schemaName=getPropertyValue(datastoreAttributeString,'.*\[schemaName (\[*.*?\]*)\].*')
            if schemaName:
                createMEArgs.append("-schemaName")
                createMEArgs.append(schemaName)
        # fileStore
        elif(storeType == "FILESTORE"):
            filestoreAttributeString = readObjectAttributeFromFile(os.path.join(meFolder,"SIBFilestore.obj"))        
            createMEArgs.append("-fileStore")
            logSize=getPropertyValue(filestoreAttributeString,'.*\[logSize (\[*.*?\]*)\].*')
            if logSize:
                createMEArgs.append("-logSize")
                createMEArgs.append(logSize)
            logDirectory = getPropertyValue(filestoreAttributeString,'.*\[logDirectory (\[*.*?\]*)\].*')
            if logDirectory:
                createMEArgs.append("-logDirectory")
                createMEArgs.append(logDirectory)
            minTemporaryStoreSize=getPropertyValue(filestoreAttributeString,'.*\[minTemporaryStoreSize (\[*.*?\]*)\].*')
            if minTemporaryStoreSize:
                createMEArgs.append("-minTemporaryStoreSize")
                createMEArgs.append(minTemporaryStoreSize)
            maxPermanentStoreSize=getPropertyValue(filestoreAttributeString,'.*\[maxPermanentStoreSize (\[*.*?\]*)\].*')
            if maxPermanentStoreSize:
                createMEArgs.append("-maxPermanentStoreSize")
                createMEArgs.append(maxPermanentStoreSize)
            maxTemporaryStoreSize=getPropertyValue(filestoreAttributeString,'.*\[maxTemporaryStoreSize (\[*.*?\]*)\].*')
            if maxTemporaryStoreSize:
                createMEArgs.append("-maxTemporaryStoreSize")
                createMEArgs.append(maxTemporaryStoreSize)
            unlimitedPermanentStoreSize = getPropertyValue(filestoreAttributeString,'.*\[unlimitedPermanentStoreSize (\[*.*?\]*)\].*')
            if unlimitedPermanentStoreSize:
                createMEArgs.append("-unlimitedPermanentStoreSize")
                createMEArgs.append(unlimitedPermanentStoreSize)
            unlimitedTemporaryStoreSize=getPropertyValue(filestoreAttributeString,'.*\[unlimitedTemporaryStoreSize (\[*.*?\]*)\].*')
            if unlimitedTemporaryStoreSize:
                createMEArgs.append("-unlimitedTemporaryStoreSize")
                createMEArgs.append(unlimitedTemporaryStoreSize)
            permanentStoreDirectory = getPropertyValue(filestoreAttributeString,'.*\[permanentStoreDirectory (\[*.*?\]*)\].*')
            if permanentStoreDirectory:
                createMEArgs.append("-permanentStoreDirectory")
                createMEArgs.append(permanentStoreDirectory)
            temporaryStoreDirectory = getPropertyValue(filestoreAttributeString,'.*\[temporaryStoreDirectory (\[*.*?\]*)\].*')
            if temporaryStoreDirectory:
                createMEArgs.append("-temporaryStoreDirectory ")
                createMEArgs.append(temporaryStoreDirectory )
        else:
            logger.logp(Level.SEVERE, _pyFileName, method, "Can not recognise message engine .") 
            print "ERROR: Failed to import message engine, due to can not recognise message engine."
            sys.exit()
        
    # for mq server message engine
    else:
        scopes = listScopeForMe("true")
        if len(scopes) == 0:
            logger.logp(Level.INFO, _pyFileName, method, "No MQ server found on target environment, create one firstly.") 
            print "INFO: No MQ server found on target environment, create one firstly."
            sys.exit()  
        selectScopeIndex = raw_input("Input the number to select the scope where you want to create the messaging engine:")
        isNumber = 'false'
        while isNumber == 'false':
            try:
                selectScopeIndex = int(selectScopeIndex)
                if(selectScopeIndex >= 1 and selectScopeIndex <= len(scopes)):
                    isNumber = 'true'
                else:
                    selectScopeIndex = raw_input("Incorrect number. Input the number to select the scope where you want to create the messaging engine:")
            except ValueError:
                selectScopeIndex = raw_input("Incorrect number. Input the number to select the scope where you want to create the messaging engine:")
        logger.logp(Level.INFO, _pyFileName, method, "selected scope index " + str(selectScopeIndex) + ": " + str(scopes[selectScopeIndex - 1]))    
        scope = scopes[selectScopeIndex - 1]
        mqServer=None
        mePrefix = None
        index = scope.rfind("MQServer:")
        if (index >= 0):
            mqServer = scope[index+9:-1]
            mePrefix = mqServer
        logger.logp(Level.INFO, _pyFileName, method, "selected scope: "+str(mqServer))
        createMEArgs.append("-wmqServer")
        createMEArgs.append(mqServer)
        # read mq server attribute
        destinationRootFolder=buMemberFolder
        mqMeObjFilePath = os.path.join(buMemberFolder,"SIBMQServerBusMember.obj")    
        mqMeObjString = readObjectAttributeFromFile(mqMeObjFilePath)
        meName = getPropertyValue(mqMeObjString,'.*\[name (\[*.*?\]*)\].*')
        logger.logp(Level.INFO, _pyFileName, method, "Start to import messaging engine that is named " + meName + " in source environment.")
        virtualQueueManagerName=getPropertyValue(mqMeObjString,'.*\[virtualQueueManagerName (\[*.*?\]*)\].*')
        if(virtualQueueManagerName != None):
            createMEArgs.append("-virtualQueueManagerName")
            createMEArgs.append(virtualQueueManagerName)
        host = getPropertyValue(mqMeObjString,'.*\[host (\[*.*?\]*)\].*')
        if(host != None):
            createMEArgs.append("-host")
            createMEArgs.append(host)
        port=getPropertyValue(mqMeObjString,'.*\[port (\[*.*?\]*)\].*')
        if(port != None):
            createMEArgs.append("-port")
            createMEArgs.append(port)
        channel=getPropertyValue(mqMeObjString,'.*\[channel (\[*.*?\]*)\].*')
        if(channel != None):
            createMEArgs.append("-channel")
            createMEArgs.append(channel)
        securityAuthAlias=getPropertyValue(mqMeObjString,'.*\[securityAuthAlias (\[*.*?\]*)\].*')
        if(securityAuthAlias != None):
            createMEArgs.append("-securityAuthAlias")
            createMEArgs.append(securityAuthAlias)
        transportChainName=getPropertyValue(mqMeObjString,'.*\[transportChainName (\[*.*?\]*)\].*')
        if(transportChainName != None):
            createMEArgs.append("-transportChain")
            createMEArgs.append(transportChainName)
        trustMessageUserIdentifiers=getPropertyValue(mqMeObjString,'.*\[trustMessageUserIdentifiers (\[*.*?\]*)\].*')
        if(trustMessageUserIdentifiers != None):
            createMEArgs.append("-trustUserIds")
            createMEArgs.append(trustMessageUserIdentifiers)
#        overrideDefaultConnectionSettings=getPropertyValue(mqMeObjString,'.*\[overrideDefaultConnectionSettings (\[*.*?\]*)\].*')
#        if(overrideDefaultConnectionSettings != None):
#            createMEArgs.append("-overrideDefaultConnectionSettings")
#            createMEArgs.append(overrideDefaultConnectionSettings)
    # create message engine for either bpm server or mq server    
    logger.logp(Level.INFO, _pyFileName, method, "Add bus member with parameters -- " + str(createMEArgs))
    createdME = AdminTask.addSIBusMember(createMEArgs)
    logger.logp(Level.INFO, _pyFileName, method, "Add bus member done.")
    sourceTargetMEMap[meName] = mePrefix
    logger.logp(Level.INFO, _pyFileName, method, "Bus member added." + str(createdME))
    
    queueFolder = os.path.join(destinationRootFolder,"SIBQueueLocalizationPoint")
    if os.path.exists(queueFolder):
        allFiles = os.listdir(queueFolder)
        logger.logp(Level.INFO, _pyFileName, method, "create queue destinations.")
        for queueObjFile in allFiles:
            if(str(queueObjFile).endswith(".obj")):
                queueObjFilePath = os.path.join(queueFolder,str(queueObjFile))
                createDestination(busName,queueObjFilePath, cluster,node,server,"Queue")
        logger.logp(Level.INFO, _pyFileName, method, "completed creating queue destinations.")
    
    topicFolder = os.path.join(destinationRootFolder,"SIBTopicSpaceLocalizationPoint")    
    if os.path.exists(topicFolder):
        allFiles = os.listdir(topicFolder)
        logger.logp(Level.INFO, _pyFileName, method, "create topic destinations.")
        for topicObjFile in allFiles:
            if(str(topicObjFile).endswith(".obj")):
                topicObjFilePath = os.path.join(topicFolder,str(topicObjFile))
                createDestination(busName,topicObjFilePath, cluster,node,server,"Topic")
        logger.logp(Level.INFO, _pyFileName, method, "completed creating topic destinations.")
    logger.exiting(_pyFileName, method)
    return meName

def splitProperties(strProps):
    method="splitProperties"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(strProps))
    count = len(strProps)
    index = 0
    stack = []
    properties = []
    startIndex = 0
    endIndex = 0
    while(index < count):
        if(len(stack) == 0):
            if(endIndex > startIndex):
                properties.append(strProps[startIndex:endIndex])
            startIndex = endIndex
        if(strProps[index] == "["):
            stack.append("[")
        if(strProps[index] == "]"):
            stack.pop()
        endIndex = endIndex + 1
        index = index + 1
    logger.logp(Level.INFO, _pyFileName, method, "splited properties: "+str(strProps))
    logger.exiting(_pyFileName, method)
    return properties
            
def createForeignBus(foreignBusFolder,busName):    
    method="createForeignBus"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(foreignBusFolder)+", "+str(busName))
    foreignBusAttributeString = readObjectAttributeFromFile(os.path.join(foreignBusFolder,"SIBForeignBus.obj"))
    remoteBusName = getPropertyValue(foreignBusAttributeString,'.*\[name (\[*.*?\]*)\].*')
    foreignBusDestinationAttributeString = readObjectAttributeFromFile(os.path.join(foreignBusFolder,"SIBDestinationDefault.obj"))
    virtualGatewayAttributeString = readObjectAttributeFromFile(os.path.join(foreignBusFolder,"SIBVirtualGatewayLink/SIBVirtualGatewayLink.obj"))   
    sibLinkRefRootFolder = os.path.join(foreignBusFolder,"SIBVirtualGatewayLink/SIBLinkRef")
    sibLinkFolderNames = os.listdir(sibLinkRefRootFolder)
    if(sibLinkFolderNames != None and len(sibLinkFolderNames)>0):     
        sibLinkFolderName = sibLinkFolderNames[0]
        sibLinkRefFolder = os.path.join(sibLinkRefRootFolder,sibLinkFolderName)
        sibLinkRefAttributeString = readObjectAttributeFromFile(os.path.join(sibLinkRefFolder,"SIBLinkRef.obj"))
        sibLinkRefTargetAttributeString = readObjectAttributeFromFile(os.path.join(sibLinkRefFolder,"SIBusMemberTarget/SIBusMemberTarget.obj"))
        buslinkName= getPropertyValue(sibLinkRefAttributeString,'.*\[name (\[*.*?\]*)\].*')
        relatedSourceEngineName = getPropertyValue(sibLinkRefTargetAttributeString,'.*\[engineName (\[*.*?\]*)\].*')
        foreignBusMEMap[buslinkName] = remoteBusName
    inboundUserid = getPropertyValue(virtualGatewayAttributeString,'.*\[inboundUserid (\[*.*?\]*)\].*')
    outboundUserid = getPropertyValue(virtualGatewayAttributeString,'.*\[outboundUserid (\[*.*?\]*)\].*')   
    sendAllowed = getPropertyValue(foreignBusDestinationAttributeString,'.*\[sendAllowed (\[*.*?\]*)\].*')
    createForeignBusArgs = ["-bus",busName]
    createForeignBusArgs.append("-name")
    createForeignBusArgs.append(remoteBusName)
    createForeignBusArgs.append("-routingType")
    createForeignBusArgs.append("Direct")
    createForeignBusArgs.append("-type")
    createForeignBusArgs.append("SIBus")
    if(inboundUserid != None):
        createForeignBusArgs.append("-inboundUserid")
        createForeignBusArgs.append(inboundUserid)
    if(outboundUserid != None):
        createForeignBusArgs.append("-outboundUserid")    
        createForeignBusArgs.append(outboundUserid)
    if(sendAllowed != None):
        createForeignBusArgs.append("-sendAllowed")  
        createForeignBusArgs.append(sendAllowed)
    logger.logp(Level.INFO, _pyFileName, method, "Creating foreign bus with parameters for creating bus -- " + str(createForeignBusArgs))
    AdminTask.createSIBForeignBus(createForeignBusArgs)
    logger.logp(Level.INFO, _pyFileName, method, "Foreign bus created")
    logger.exiting(_pyFileName, method)
    return remoteBusName

def getTargetMENameBySourceMEName(sourceMEName,busName):
    method="getTargetMENameBySourceMEName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(sourceMEName)+", "+str(busName))
    targetMEName = None
    targetMEList = wsadminToList(AdminTask.listSIBEngines("[-bus " + busName + " ]"))
    logger.logp(Level.INFO, _pyFileName, method, "ME list: " + str(targetMEList))
    if(targetMEList != None and len(targetMEList) == 1):
        targetMEName = AdminConfig.showAttribute(targetMEList[0],"name")
    elif (len(targetMEList) > 1):
        targetMEPrefix = sourceTargetMEMap[sourceMEName]
        for targetME in targetMEList:
            tempMEName = AdminConfig.showAttribute(targetME,"name")
            if(tempMEName.startswith(targetMEPrefix)):
                targetMEName = tempMEName
                break
    logger.logp(Level.INFO, _pyFileName, method, "New ME name is " + targetMEName)
    logger.exiting(_pyFileName, method)
    return targetMEName
     
def createBusLink(sourceMEName, busName,gatewayLinkAttributeFilePath):
    method="createBusLink"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(sourceMEName)+", "+str(busName)+", "+str(gatewayLinkAttributeFilePath))
    logger.logp(Level.INFO, _pyFileName, method, "creating bus link")
    gatewayLinkAttributeString = readObjectAttributeFromFile(gatewayLinkAttributeFilePath)
    authAlias = getPropertyValue(gatewayLinkAttributeString,'.*\[authAlias (\[*.*?\]*)\].*')
    bootstrapEndpoints= getPropertyValue(gatewayLinkAttributeString,'.*\[bootstrapEndpoints (\[*.*?\]*)\].*')
    name= getPropertyValue(gatewayLinkAttributeString,'.*\[name (\[*.*?\]*)\].*')
    protocolName= getPropertyValue(gatewayLinkAttributeString,'.*\[protocolName (\[*.*?\]*)\].*')
    remoteMessagingEngineName= getPropertyValue(gatewayLinkAttributeString,'.*\[remoteMessagingEngineName (\[*.*?\]*)\].*')
    createArgs = ["-bus",busName]
    newMEName = getTargetMENameBySourceMEName(sourceMEName,busName)
    createArgs.append("-messagingEngine")
    createArgs.append(newMEName)
    createArgs.append("-name")
    createArgs.append(name)    
    if(foreignBusMEMap != None and foreignBusMEMap.has_key(name)):        
        createArgs.append("-foreignBusName")
        createArgs.append(foreignBusMEMap[name])
    if(protocolName != None):
        createArgs.append("-protocolName")
        createArgs.append(protocolName)
    if(authAlias != None):
        createArgs.append("-authAlias")    
        createArgs.append(authAlias)
    if(bootstrapEndpoints != None):
        createArgs.append("-bootstrapEndpoints")
        createArgs.append(bootstrapEndpoints)
    if(remoteMessagingEngineName != None):
        createArgs.append("-remoteMessagingEngineName")
        createArgs.append(remoteMessagingEngineName)
    logger.logp(Level.INFO, _pyFileName, method, "Create bus link: "+str(name)+" with args " + str(createArgs))
    AdminTask.createSIBLink(createArgs)
    logger.logp(Level.INFO, _pyFileName, method, "completed creating bus link: "+str(name)+".")
    logger.exiting(_pyFileName, method)
    
def checkIfBusExised(busName):
    method="checkIfBusExised"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName))
    buses = wsadminToList(AdminTask.listSIBuses())
    for bus in buses:
        if(busName == AdminConfig.showAttribute(bus,"name")):
            logger.logp(Level.INFO, _pyFileName, method, "Bus with name " + busName + " already exists. Will skip creation.")
            print "INFO: Bus with name " + str(busName) + " already exists. Will skip creation."
            print "**************************************"
            logger.exiting(_pyFileName, method)
            sys.exit()
    logger.exiting(_pyFileName, method)

def createBusByName(busName, busObjFilePath):
    method="createBusByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName) +", "+str(busObjFilePath))
    checkIfBusExised(busName)
    # check authentication alias is existed or not
    # RTC defect 237151
    objExisted=checkAuthAliasObjectOnTargetEnv(busObjFilePath)
    if objExisted == "false":
        logger.logp(Level.INFO, _pyFileName, method, "The authentication alias for SIBus " + str(busName) +" doesnot exist in target environment, create it firstly.")
        print "INFO: The authentication alias for SIBus " + str(busName) +" doesnot exist in target environment, create it firstly."
        logger.logp(Level.SEVERE, _pyFileName, method, "Failed to import SIBus configuration.")
        print "ERROR: Failed to import SIBus configuration."
        print "**************************************"
        logger.exiting(_pyFileName, method)
        sys.exit()
    busObjString = readObjectAttributeFromFile(busObjFilePath)
    createBusArgs = ["-bus",busName]
    description=getPropertyValue(busObjString,'.*\[description (\[*.*?\]*)\].*')
    if description != None:
        createBusArgs.append("-description")
        createBusArgs.append(description)
    propValue = getPropertyValue(busObjString,'.*\[interEngineAuthAlias (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-interEngineAuthAlias")
        createBusArgs.append(propValue)
    propValue = getPropertyValue(busObjString,'.*\[mediationsAuthAlias (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-mediationsAuthAlias")
        createBusArgs.append(propValue)
    propValue = getPropertyValue(busObjString,'.*\[bootstrapMemberPolicy (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-bootstrapPolicy")
        createBusArgs.append(propValue)
    propValue = getPropertyValue(busObjString,'.*\[secure (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-secure")
        createBusArgs.append(propValue)
    propValue = getPropertyValue(busObjString,'.*\[useServerIdForMediations (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-useServerIdForMediations")
        createBusArgs.append(propValue)
    propValue = getPropertyValue(busObjString,'.*\[discardMsgsAfterQueueDeletion (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-discardOnDelete")
        createBusArgs.append(propValue)
    createBusArgs.append("-auditAllowed")
    createBusArgs.append("true")
    propValue = getPropertyValue(busObjString,'.*\[configurationReloadEnabled (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-configurationReloadEnabled")
        createBusArgs.append(propValue)
    propValue = getPropertyValue(busObjString,'.*\[highMessageThreshold (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-highMessageThreshold")
        createBusArgs.append(propValue)
    propValue = getPropertyValue(busObjString,'.*\[securityGroupCacheTimeout (\[*.*?\]*)\].*')
    if(propValue != None):
        createBusArgs.append("-securityGroupCacheTimeout")
        createBusArgs.append(propValue)
    logger.logp(Level.INFO, _pyFileName, method, "Creating bus with parameters for creating bus -- " + str(createBusArgs))
    AdminTask.createSIBus(createBusArgs)    
    logger.exiting(_pyFileName, method)
    
#AdminTask.createSIBDestination('[-name AliasQ -aliasBus TestForeignConnection -targetName TestQ -targetBus TestForeignConnection -type ALIAS -reliability INHERIT -maxReliability INHERIT 
#-overrideOfQOSByProducerAllowed INHERIT -sendAllowed INHERIT -receiveAllowed INHERIT -description  -replyDestination  -replyDestinationBus  -delegateAuthorizationCheckToTarget true -bus 
#TestForeignConnection ]')
def createAliasAndForeignDestination(busName):
    method="createAliasAndForeignDestination"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName))
    logger.logp(Level.INFO, _pyFileName, method, "the alias destination map size is:"+str(len(aliasDestinationAttributeMap.keys())))
    for key in aliasDestinationAttributeMap.keys():
        aliasDestinationName = key
        aliasDestinationAttribute = aliasDestinationAttributeMap[key]
        destArgs = ["-bus",busName]
        aliasBus = getPropertyValue(aliasDestinationAttribute,'.*\[bus (\[*.*?\]*)\].*')
        if(aliasBus != None):
            destArgs.append("-aliasBus")
            destArgs.append(aliasBus)
        targetBus = getPropertyValue(aliasDestinationAttribute,'.*\[targetBus (\[*.*?\]*)\].*')
        if(targetBus != None):
            destArgs.append("-targetBus")
            destArgs.append(targetBus)
        targetIdentifier = getPropertyValue(aliasDestinationAttribute,'.*\[targetIdentifier (\[*.*?\]*)\].*')
        if(targetIdentifier != None):
            destArgs.append("-targetName")
            destArgs.append(targetIdentifier)
        identifier = getPropertyValue(aliasDestinationAttribute,'.*\[identifier (\[*.*?\]*)\].*')
        if(targetBus != None):
            destArgs.append("-name")
            destArgs.append(identifier)
        reliability = getPropertyValue(aliasDestinationAttribute,'.*\[reliability (\[*.*?\]*)\].*')
        if(reliability != None):
            destArgs.append("-reliability")
            destArgs.append(reliability)
        destArgs.append("-type")
        destArgs.append("ALIAS")
        sendAllowed = getPropertyValue(aliasDestinationAttribute,'.*\[sendAllowed (\[*.*?\]*)\].*')
        if(sendAllowed != None):
            destArgs.append("-sendAllowed")
            destArgs.append(sendAllowed)
        maxReliability = getPropertyValue(aliasDestinationAttribute,'.*\[maxReliability (\[*.*?\]*)\].*')
        if(maxReliability != None):
            destArgs.append("-maxReliability")
            destArgs.append(maxReliability)
        receiveAllowed = getPropertyValue(aliasDestinationAttribute,'.*\[receiveAllowed (\[*.*?\]*)\].*')
        if(receiveAllowed != None):
            destArgs.append("-receiveAllowed")
            destArgs.append(receiveAllowed)
        overrideOfQOSByProducerAllowed = getPropertyValue(aliasDestinationAttribute,'.*\[overrideOfQOSByProducerAllowed (\[*.*?\]*)\].*')
        if(overrideOfQOSByProducerAllowed != None):
            destArgs.append("-overrideOfQOSByProducerAllowed")
            destArgs.append(overrideOfQOSByProducerAllowed)
        delegateAuthorizationCheckToTarget = getPropertyValue(aliasDestinationAttribute,'.*\[delegateAuthorizationCheckToTarget (\[*.*?\]*)\].*')
        if(delegateAuthorizationCheckToTarget != None):
            destArgs.append("-delegateAuthorizationCheckToTarget")
            destArgs.append(delegateAuthorizationCheckToTarget)
        overrideOfQOSByProducerAllowed = getPropertyValue(aliasDestinationAttribute,'.*\[overrideOfQOSByProducerAllowed (\[*.*?\]*)\].*')
        if(overrideOfQOSByProducerAllowed != None):
            destArgs.append("-overrideOfQOSByProducerAllowed")
            destArgs.append(overrideOfQOSByProducerAllowed)
#         defaultPriority = getPropertyValue(aliasDestinationAttribute,'.*\[defaultPriority (\[*.*?\]*)\].*')
#         if(defaultPriority != None):
#             destArgs.append("-defaultPriority")
#             destArgs.append(defaultPriority)
        logger.logp(Level.INFO, _pyFileName, method, "Creating alias destination :" + str(identifier) + " with parameter " + str(destArgs))
        AdminTask.createSIBDestination(destArgs)
        logger.logp(Level.INFO, _pyFileName, method, "Alias destination :" + str(identifier) + " was created.")
    #AdminTask.createSIBDestination('[-name ForeignQ -foreignBus CEI.Mon855Cell01.BUS -type FOREIGN -reliability ASSURED_PERSISTENT -maxReliability ASSURED_PERSISTENT -overrideOfQOSByProducerAllowed true 
    #-sendAllowed true -description  -bus TestForeignConnection ]')
    logger.logp(Level.INFO, _pyFileName, method, "the foreign destination map size is:"+str(len(foreignDestinationAttributeMap.keys())))
    for key in foreignDestinationAttributeMap.keys():
        foreignDestinationName = key
        foreignDestinationAttribute = foreignDestinationAttributeMap[key]
        destArgs = ["-bus",busName]
        destArgs.append("-type")
        destArgs.append("FOREIGN")
        
        foreignBus = getPropertyValue(foreignDestinationAttribute,'.*\[bus (\[*.*?\]*)\].*')
        if(foreignBus != None):
            destArgs.append("-foreignBus")
            destArgs.append(foreignBus)
        
        identifier = getPropertyValue(foreignDestinationAttribute,'.*\[identifier (\[*.*?\]*)\].*')
        if(identifier != None):
            destArgs.append("-name")
            destArgs.append(identifier)
        
        reliability = getPropertyValue(foreignDestinationAttribute,'.*\[reliability (\[*.*?\]*)\].*')
        if(reliability != None):
            destArgs.append("-reliability")
            destArgs.append(reliability)
        
        maxReliability = getPropertyValue(foreignDestinationAttribute,'.*\[maxReliability (\[*.*?\]*)\].*')
        if(maxReliability != None):
            destArgs.append("-maxReliability")
            destArgs.append(maxReliability)
        
        overrideOfQOSByProducerAllowed = getPropertyValue(foreignDestinationAttribute,'.*\[overrideOfQOSByProducerAllowed (\[*.*?\]*)\].*')
        if(overrideOfQOSByProducerAllowed != None):
            destArgs.append("-overrideOfQOSByProducerAllowed")
            destArgs.append(overrideOfQOSByProducerAllowed)
        
        sendAllowed = getPropertyValue(foreignDestinationAttribute,'.*\[sendAllowed (\[*.*?\]*)\].*')
        if(sendAllowed != None):
            destArgs.append("-sendAllowed")
            destArgs.append(sendAllowed)
        logger.logp(Level.INFO, _pyFileName, method, "Creating foreign destination :" + str(identifier) + " with parameter " + str(destArgs))
        AdminTask.createSIBDestination(destArgs)
        logger.logp(Level.INFO, _pyFileName, method, "Foreign destination :" + str(identifier) + " was created.")
    logger.exiting(_pyFileName, method) 
        
def createBusAndAllChildObjectByName(busName, busObjFolder):
    method="createBusAndAllChildObjectByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName) + ", "+str(busObjFolder))
    #Create SIBus by name
    busObjFilePath = os.path.join(busObjFolder,"SIBus.obj")
    logger.logp(Level.INFO, _pyFileName, method, "Creating bus with bus object file: " + str(busObjFilePath))
    # creating bus ..."
    createBusByName(busName, busObjFilePath)
    logger.logp(Level.INFO, _pyFileName, method, "Bus was created successfully.")
    #Get all destination information for using later
    logger.logp(Level.INFO, _pyFileName, method, "prapare all destinations from import folder.")
    getDestinationAndAttributeMap(busObjFolder)
    
    # create messaging engine    
    topBusMemFolder = os.path.join(busObjFolder,"SIBusMember")
    logger.logp(Level.INFO, _pyFileName, method, "SIBus memeber top directory: " + str(topBusMemFolder))
    busMemFolderNames = os.listdir(topBusMemFolder)
    for busFolderName in busMemFolderNames:
        if(busFolderName.startswith("SIBusMember")):
            topMeFolder = os.path.join(topBusMemFolder,busFolderName)
            logger.logp(Level.INFO, _pyFileName, method, "Message engine top directory: " + str(topMeFolder))
            createMessageEngine(busName,topMeFolder)  
    
    # create foreign buses ..."
    foreignBusRootFolder = os.path.join(busObjFolder,"SIBForeignBus")
    logger.logp(Level.INFO, _pyFileName, method, "Creating message engine with configuration in directory: " + str(foreignBusRootFolder))
    foreignBusFolderNames = os.listdir(foreignBusRootFolder)   
    for foreignBusFolderName in foreignBusFolderNames:
        if foreignBusFolderName.endswith(".properties"):
            continue
        foreignBusFolder = os.path.join(foreignBusRootFolder,foreignBusFolderName)
        logger.logp(Level.INFO, _pyFileName, method, "Creating foreign bus with configuration in directory: " + str(foreignBusFolder))
        foreignBusName = createForeignBus(foreignBusFolder,busName)

    # create aliases and foreign destinations ..."
    createAliasAndForeignDestination(busName)   
    
    # create bus link
    logger.logp(Level.INFO, _pyFileName, method, "creating bus link.")
    for busFolderName in busMemFolderNames:
        if(busFolderName.startswith("SIBusMember")):
            topMeFolder = os.path.join(topBusMemFolder,busFolderName)
            logger.logp(Level.INFO, _pyFileName, method, "Message engine top directory: " + str(topMeFolder))
            meFolderNames = os.listdir(topMeFolder)
            for meFolderName in meFolderNames:
                if meFolderName.endswith(".properties") or meFolderName.endswith(".obj"):
                    continue
                if(meFolderName.startswith("SIBMessagingEngine")):
                    meObjFolder = os.path.join(topMeFolder,meFolderName)
                    meObjFile = os.path.join(meObjFolder,"SIBMessagingEngine.obj")
                    logger.logp(Level.FINER, _pyFileName, method, "SIBMessage engine object file: "+str(meObjFile))
                    if os.path.exists(meObjFile):
                        meObjString = readObjectAttributeFromFile(meObjFile)
                        sourceMEName = getPropertyValue(meObjString,'.*\[name (\[*.*?\]*)\].*')
                        gatewayLinkFolder = os.path.join(meObjFolder,"SIBGatewayLink")
                        logger.logp(Level.INFO, _pyFileName, method, "gateway link directory: "+str(gatewayLinkFolder) + ".")
                        if os.path.exists(gatewayLinkFolder):
                            allGatewayLinks = os.listdir(gatewayLinkFolder)
                            logger.logp(Level.INFO, _pyFileName, method, "gateway link size: "+str(len(allGatewayLinks)) + ".")
                            logger.logp(Level.FINER, _pyFileName, method, "gateway link folder content: "+str(allGatewayLinks) + ".")
                            for gatewayLink in allGatewayLinks:
                                if(gatewayLink.endswith(".obj")):
                                    createBusLink(sourceMEName,busName,os.path.join(gatewayLinkFolder,gatewayLink))
                        else:
                            logger.logp(Level.INFO, _pyFileName, method, "SIBMessage engine object file: "+str(meObjFile) +" doesnot exist, skip to create its bus link.")
                    else:
                        logger.logp(Level.WARNING, _pyFileName, method, "gateway link directory: "+str(gatewayLinkFolder) + ".")
    logger.exiting(_pyFileName, method)        
       

def importBusByName(busName,importDir):
    method="importBusByName"
    logger.entering(_pyFileName, method)
    logger.logp(Level.INFO, _pyFileName, method, "input parameters:"+str(busName) + ", "+str(importDir))
    busFound = "false"
    checkImportDirExisted(importDir)
    busDirNames = os.listdir(importDir)
    print
    answer = raw_input("If this SIBus configuration contains message engine on MQ Server or it was configured with J2C authentication alias, creating MQ Server and J2C authentication alias firstly, continue? (Y/N):")
    isCorrectInput = 'false'
    while isCorrectInput == 'false':
        logger.logp(Level.INFO, _pyFileName, method, "answer is "+str(answer)+".")
        if(answer == "Y" or answer == "y" or answer == "N" or answer == "n"):
            isCorrectInput = 'true'
        else:
            answer = raw_input("If this SIBus configuration contains message engine on MQ Server or it was configured with J2C authentication alias, creating MQ Server and J2C authentication alias firstly, continue? (Y/N):")
    logger.logp(Level.INFO, _pyFileName, method, "answer is ["+str(answer)+"].")
    if (answer != 'Y' and answer != 'y' ):
        logger.logp(Level.INFO, _pyFileName, method, "answer is not 'Y' or 'y' and exist.")
        logger.exiting(_pyFileName, method)
        print "**************************************"
        sys.exit()
    print "**************************************"
    print "INFO: Create SIBus " + str(busName) + " ..."
    for busDirName in busDirNames:
        if(busDirName == busName):
            busFound = "true"
            busObjFolder = os.path.join(importDir,busName)                       
            createBusAndAllChildObjectByName(busName,busObjFolder)
            AdminConfig.save()
            logger.logp(Level.INFO, _pyFileName, method, "Create SIBus " + str(busName) + " successfully.")
            print "INFO: Create SIBus " + str(busName) + " successfully."
            print "**************************************"
    if(busFound == "false"):
        logger.logp(Level.SEVERE, _pyFileName, method, "Bus with name " + str(busName) + " was not found in the import directory " + str(importDir) + ". Check the import directory.")
        print "ERROR: Bus with name " + str(busName) + " was not found in the import directory " + str(importDir) + ". Check the import directory."
        print "**************************************"
    logger.exiting(_pyFileName, method)

############################################################################
# importDir should be a folder that contains three sub-folders with names 
# 'exportDS','exportAA','exportSSL'
############################################################################         
def doUT(importDir):
    print "Testing importSpecifiedAuthAliasByName"
    toImportAAName = 'SCASYSME00_Auth_Alias'
    exportAADir = os.path.join(importDir,'exportAA/SCASMEAlias')
    importSpecifiedAuthAliasByName(exportAADir,toImportAAName)
    print "Testing importSpecifiedAuthAliasByName was done"
    
    print "Testing importSpecifiedAuthAliasByName"
    toImportAAName = 'PROCSVR_BPM8011DE.AppTarget_Auth_Alias'
    importSpecifiedAuthAliasByName(exportAADir,toImportAAName)
    print "Testing importSpecifiedAuthAliasByName was done"
    
    print "Testing importAllAuthAliases"
    exportAADir = os.path.join(importDir,'exportAA')
    importAllAuthAliases(exportAADir)
    print "Testing importAllAuthAliases was done"
    
    print "Testing importAllJDBCProviders"
    exportJdbcProviderDir = os.path.join(importDir,'exportJDBCProvider/CellScope')
    importAllJDBCProviders(exportJdbcProviderDir)
    print "Testing importAllJDBCProviders was done"   
    
    print "Testing importAllJMSProviders"
    exportJmsProviderDir = os.path.join(importDir,'exportJMSProvider/CellScope')
    importAllJMSProviders(exportJmsProviderDir)
    print "Testing importAllJMSProviders was done" 
    
    print "Testing importDataSourceByJNDIName"
    toImportDSJNDI = 'jdbc/com.ibm.ws.sib/advpc_3.Messaging-SCA.SYSTEM.bxv9v444Cell10.Bus'
    exportDSDir = os.path.join(importDir,'exportDS/specific/CellScope')
    importSpecifiedDataSource(exportDSDir,toImportDSJNDI)
    print "Testing importDataSourceByJNDIName was done"
    
    print "Testing importAllDataSources"
    exportDSDir = os.path.join(importDir,'exportDS/CellScope')
    importAllDataSources(exportDSDir)
    print "Testing importAllDataSources was done"
    
    print "Testing importNameSpaceBinding"
    exportNSDir = os.path.join(importDir,'exportNSs/AllScope')
    importNameSpaceBinding("ss",exportNSDir)
    print "Testing importNameSpaceBinding was done"
    
    print "Testing importNameSpaceBinding"
    exportNSDir = os.path.join(importDir,'exportNSs/AllScope')
    importNameSpaceBinding("not existed",exportNSDir)
    print "Testing importNameSpaceBinding was done"
    
    print "Testing importAllNameSpaceBindings"
    exportNSDir = os.path.join(importDir,'exportNSs/CellScope')
    importAllNameSpaceBindings(exportNSDir)
    print "Testing importAllNameSpaceBindings was done"
    
    print "Testing importBusByName"
    exportBusDir = os.path.join(importDir,'exportBus')
    importBusByName("BPC.bxv9v444Cell10.Bus",exportBusDir)
    print "Testing iimportBusByName was done"
    
    print "Testing importConnectionFactory by JNDI name"
    exportCfDir = os.path.join(importDir,'exportCF/AllScope')
    importConnectionFactoryByJndiname("javax.jms.TopicConnectionFactory",exportCfDir)
    print "Testing importConnectionFactory by JNDI name was done"
    
    print "Testing importConnectionFactory by JNDI name"
    exportCfDir = os.path.join(importDir,'exportCF/AllScope')
    importConnectionFactoryByJndiname("javax.jms.TopicConnectionFactory.not.existed",exportCfDir)
    print "Testing importConnectionFactory by JNDI name was done"
    
    print "Testing importAllConnectionFactories"
    exportCfDir = os.path.join(importDir,'exportCF/CellScope')
    importAllConnectionFactories(exportCfDir)
    print "Testing importAllConnectionFactories was done"
    
    print "Testing importQueueOrTopic by JNDI name"
    exportAoDir = os.path.join(importDir,'exportAOs/AllScope')
    importQueueOrTopicByJndiName("jms/BFMJMSReplyQueue", exportAoDir)
    print "Testing importQueueOrTopic by JNDI name was done"
    
    print "Testing importQueueOrTopic by JNDI name"
    exportAoDir = os.path.join(importDir,'exportAOs/AllScope')
    importQueueOrTopicByJndiName("jms/BFMJMSReplyQueue.not.existed", exportAoDir)
    print "Testing importQueueOrTopic by JNDI name was done"
    
    print "Testing importAllQueuesAndTopics"
    exportAoDir = os.path.join(importDir,'exportAOs/CellScope')
    importAllQueuesAndTopics(exportAoDir)
    print "Testing importAllQueuesAndTopics was done"
    
    print "Testing importActivationSpec"
    exportAsDir = os.path.join(importDir,'exportAS/AllScope')
    importActivationSpec("sca/HTMIF_advpc_3.AppTarget/ActivationSpec.not.existed",exportAsDir)
    print "Testing importActivationSpec was done"
    
    print "Testing importActivationSpec"
    exportAsDir = os.path.join(importDir,'exportAS/AllScope')
    importActivationSpec("sca/HTMIF_advpc_3.AppTarget/ActivationSpec",exportAsDir)
    print "Testing importActivationSpec was done"
    
    print "Testing importAllActivationSpecs"
    exportAsDir = os.path.join(importDir,'exportAS/CellScope')
    importAllActivationSpecs(exportAsDir)
    print "Testing importAllActivationSpecs was done"
    
    print "Testing importSSLSettings"
    toImportSSLName = 'CellDefaultSSLSettings'
    exportSSLDir = os.path.join(importDir,'exportSSL')
    importSSLSetting(exportSSLDir)
    print "Testing importSSLSettings was done"
    
    print "Testing importSpecifiedSSLSetting"
    importSpecifiedSSLSetting(exportSSLDir,toImportSSLName)
    print "Testing importSpecifiedSSLSetting was done"
    
########################################################################
# main()
######################################################################## 
MAIN_METHOD="main"
logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Entering importWASConfig.py")
logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Length of param:" + str(len(sys.argv)))
# parameter range
if len(sys.argv) < 1 or len(sys.argv) > 3:
    logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "Length of param < 1 or >3, print usage")
    usage()

if len(sys.argv) == 2 and sys.argv[0] == "UT":
    doUT(sys.argv[1])
    sys.exit()

# parameter type
importAction=sys.argv[0]
logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Action name="+str(importAction))
if importAction == "-importHelp":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Print usage as requested.")
    usage()
found="false"
for action in actions:
    logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "Import action: "+str(action))
    if importAction == action:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Found export action: "+str(action))
        found="true"
        break
if found == "false":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "Not found export action, print usage")
    usage()

if sys.argv[0] == "-importDataSource":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import data source by JNDI name as requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import data source by JNDI as requested.")
        jndiName = sys.argv[1]
        if jndiName == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            dsUsage()
        importDir = sys.argv[2]
        importSpecifiedDataSource(importDir,jndiName)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        dsUsage()
    sys.exit()

if sys.argv[0] == "-importAllDataSources":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import datasources as requested.")
    if len(sys.argv)==2:
        logger.logp(Level.FINE, _pyFileName, MAIN_METHOD, "correct parameter and import datasources as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            dsUsage()
        importAllDataSources(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        dsUsage()
    sys.exit()

if sys.argv[0] == "-importAuthAlias":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import authentication alias by name as requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import authentication alias by name as requested.")
        authAliasName = sys.argv[1]
        if authAliasName == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            aaUsage()
        importDir = sys.argv[2]
        importSpecifiedAuthAliasByName(importDir,authAliasName)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        aaUsage()
    sys.exit()
    
if sys.argv[0] == "-importAllAuthAliases":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import all authentication aliases requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import all authentication aliases as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            aaUsage()
        importAllAuthAliases(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        aaUsage()
    sys.exit() 

if sys.argv[0] == "-importAllSSLSettings":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import all SSL settings requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import all SSL settings as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            sslUsage()
        importSSLSetting(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        sslUsage()
    sys.exit() 

if sys.argv[0] == "-importSSLSetting":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import SSL setting by name requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import SSL setting as requested.")
        sslConfigAliasName = sys.argv[1]
        if sslConfigAliasName == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            sslUsage()
        importDir = sys.argv[2]
        importSpecifiedSSLSetting(importDir,sslConfigAliasName)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        sslUsage()
    sys.exit()
    
if sys.argv[0] == "-importJavaSecurityFile":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import Java security settings requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import Java security settings as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            javaUsage()
        importJavaSecurityFile(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        javaUsage()
    sys.exit() 

if sys.argv[0] == "-importNameSpaceBinding":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import namespace binding by namespace identifier as requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import namespace binding by namespace identifier as requested.")
        identifier = sys.argv[1]
        if identifier == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            nsUsage()
        importDir = sys.argv[2]
        importNameSpaceBinding(identifier,importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        nsUsage()
    sys.exit()

if sys.argv[0] == "-importAllNameSpaceBindings":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import namespace bindings as requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import namespace binding as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            nsUsage()
        importAllNameSpaceBindings(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        nsUsage()
    sys.exit()

if sys.argv[0] == "-importConnectionFactory":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import JMS connection factory by JNDI name as requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import JMS connection factory by JNDI name as requested.")
        jndiName = sys.argv[1]
        if jndiName == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            cfUsage()
        importDir = sys.argv[2]
        importConnectionFactoryByJndiname(jndiName,importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        cfUsage()
    sys.exit()

if sys.argv[0] == "-importAllConnectionFactories":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import all JMS connection factories as requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import all JMS connection factories as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            cfUsage()
        importAllConnectionFactories(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        cfUsage()
    sys.exit()

if sys.argv[0] == "-importAllJMSProviders":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import all JMS providers as requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import all JMS providers  as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            jmsProviderUsage()
        importAllJMSProviders(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        jmsProviderUsage()
    sys.exit()

if sys.argv[0] == "-importAllJDBCProviders":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import all JDBC providers as requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import all JDBC providers as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            jdbcProviderUsage()
        importAllJDBCProviders(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        jdbcProviderUsage()
    sys.exit()

if sys.argv[0] == "-importActivationSpec":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import JMS activation specification by JNDI name as requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import JMS activation specification by JNDI name as requested.")
        jndiName = sys.argv[1]
        if jndiName == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            asUsage()
        importDir = sys.argv[2]
        importActivationSpec(jndiName,importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        asUsage()
    sys.exit()

if sys.argv[0] == "-importAllActivationSpecs":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import all JMS activation specifications as requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import all JMS activation specifications as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            asUsage()
        importAllActivationSpecs(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        asUsage()
    sys.exit()

if sys.argv[0] == "-importQueueOrTopic":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import JMS queue or topic by JNDI name as requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import JMS queue or topic by JNDI name as requested.")
        jndiName = sys.argv[1]
        if jndiName == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            aoUsage()
        importDir = sys.argv[2]
        importQueueOrTopicByJndiName(jndiName,importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        aoUsage()
    sys.exit()

if sys.argv[0] == "-importAllQueuesAndTopics":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import all JMS queues and topics as requested.")
    if len(sys.argv)==2:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import all JMS queues and topics as requested.")
        importDir = sys.argv[1]
        if importDir == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            aoUsage()
        importAllQueuesAndTopics(importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        aoUsage()
    sys.exit()

if sys.argv[0] == "-importSIBusConfig":
    logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "import SIBus configuration as requested.")
    if(len(sys.argv) == 3):
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "correct parameter and import SIBus configuration as requested.")
        busName = sys.argv[1]
        if busName == "-importHelp":
            logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "print action usage as requested.")
            busUsage()
        importDir = sys.argv[2]
        importBusByName(busName,importDir)
    else:
        logger.logp(Level.INFO, _pyFileName, MAIN_METHOD, "encounter incorrect parameter and print usage.")
        busUsage()
    sys.exit()

usage()
